/*= R&S SMF Microwave Signal Generator Include File =========================*/
/*===========================================================================*/
/*  Please do not use global variables or arrays in the include file of      */
/*  instrument drivers that will be submitted for inclusion into the         */
/*  LabWindows Instrument Driver Library.                                    */
/*===========================================================================*/

#ifndef __RSSMF_HEADER
#define __RSSMF_HEADER

#include <visa.h>

#if defined(__cplusplus) || defined(__cplusplus__)
extern "C" {
#endif

/*****************************************************************************/
/*= Instrument Driver Specific Error/Warning Codes ==========================*/
/*****************************************************************************/
#define VI_WARN_NSUP_ID_QUERY     (          0x3FFC0101L)
#define VI_WARN_NSUP_RESET        (          0x3FFC0102L)
#define VI_WARN_NSUP_SELF_TEST    (          0x3FFC0103L)
#define VI_WARN_NSUP_ERROR_QUERY  (          0x3FFC0104L)
#define VI_WARN_NSUP_REV_QUERY    (          0x3FFC0105L)

#define VI_ERROR_FAIL_ID_QUERY    (_VI_ERROR+0x3FFC0011L)
#define VI_ERROR_INV_RESPONSE     (_VI_ERROR+0x3FFC0012L)

#define VI_ERROR_INSTR_FILE_OPEN                (_VI_ERROR+0x3FFC0800L)
#define VI_ERROR_INSTR_FILE_WRITE               (_VI_ERROR+0x3FFC0801L)
#define VI_ERROR_INSTR_FILE_READ                (_VI_ERROR+0x3FFC0802L)
#define VI_ERROR_INSTR_INTERPRETING_RESPONSE    (_VI_ERROR+0x3FFC0803L)
#define VI_ERROR_INSTR_PARAMETER                (_VI_ERROR+0x3FFC0810L)

/*****************************************************************************/
/*= Define Instrument Specific Error/Warning Codes Here =====================*/
/*****************************************************************************/
#define VI_WARNING_INSTR_OFFSET                          (0x3FFC0900L)
#define VI_ERROR_INSTR_OFFSET                  (_VI_ERROR+0x3FFC0900L)

#define RSSMF_ERROR_INSTRUMENT_ERROR           (VI_ERROR_INSTR_OFFSET + 0xF0L)
/* Add instrument driver specific error codes here */

#define RSSMF_ERROR_INVALID_CONFIGURATION      (VI_ERROR_INSTR_OFFSET + 0xF1L)
#define RSSMF_ERROR_INSTRUMENT_OPTION          (VI_ERROR_INSTR_OFFSET + 0xF2L)
#define RSSMF_ERROR_INSTRUMENT_NSUP_MODEL      (VI_ERROR_INSTR_OFFSET + 0xF3L)
#define RSSMF_ERROR_SETTINGS_CONFLICT          (VI_ERROR_INSTR_OFFSET + 0xF4L)
#define RSSMF_ERROR_CALIBRATION_FAILED         (VI_ERROR_INSTR_OFFSET + 0xF5L)
/* Add instrument driver specific warning codes here */
#define RSSMF_WARNING_SMALL_BUFFER             (VI_WARNING_INSTR_OFFSET + 0xF1L)
#define RSSMF_WARNING_NOT_SUPPORTED            (VI_WARNING_INSTR_OFFSET + 0xF2L)

/*****************************************************************************/
/*= Instrument specific defines =============================================*/
/*****************************************************************************/
#define RSSMF_LFSWEEP_SOURCE_LF1       0
#define RSSMF_LFSWEEP_SOURCE_LF2       1

#define RSSMF_SWEEP_MODE_AUTO          0
#define RSSMF_SWEEP_MODE_SINGLE        1
#define RSSMF_SWEEP_MODE_STEP          2
#define RSSMF_SWEEP_MODE_EXT_SINGLE    3
#define RSSMF_SWEEP_MODE_EXT_STEP      4

#define RSSMF_SWEEP_LOW_MODE_AUTO      0
#define RSSMF_SWEEP_LOW_MODE_MAN       1
#define RSSMF_SWEEP_LOW_MODE_STEP      2

#define RSSMF_TRIG_SOURCE_SWEEP_AUTO      0
#define RSSMF_TRIG_SOURCE_SWEEP_IMMEDIATE 1
#define RSSMF_TRIG_SOURCE_SWEEP_SINGLE    2
#define RSSMF_TRIG_SOURCE_SWEEP_EXTERNAL  3
#define RSSMF_TRIG_SOURCE_SWEEP_BUS       4

#define RSSMF_FREQUENCY_MODE_CW           0
#define RSSMF_FREQUENCY_MODE_SWEEP        1
#define RSSMF_FREQUENCY_MODE_LIST         2
    
#define RSSMF_POWER_MODE_CW      0
#define RSSMF_POWER_MODE_SWEEP   1
#define RSSMF_POWER_MODE_LIST    2

#define RSSMF_LFOUTPUT_FREQUENCY_MODE_CW    0
#define RSSMF_LFOUTPUT_FREQUENCY_MODE_SWEEP 1
    
#define RSSMF_LFOUTPUT_SWEEP_FREQUENCY_SPACING_LINEAR      0
#define RSSMF_LFOUTPUT_SWEEP_FREQUENCY_SPACING_LOGARITHMIC 1
    
#define RSSMF_NOISE_DISTRIBUTION_GAUSS 0
#define RSSMF_NOISE_DISTRIBUTION_EQUAL 1

#define RSSMF_PULM_SOURCE_INTERNAL 0
#define RSSMF_PULM_SOURCE_EXTERNAL 1
#define RSSMF_PULM_SOURCE_RANDOM   2
    
#define RSSMF_PULM_POLARITY_NORMAL      0
#define RSSMF_PULM_POLARITY_INVERTED    1

#define RSSMF_PULM_TRIGGER_MODE_AUTO      0
#define RSSMF_PULM_TRIGGER_MODE_EXTERNAL  1
#define RSSMF_PULM_TRIGGER_MODE_EGATE     2
    
#define RSSMF_FM_MODE_NORMAL  0
#define RSSMF_FM_MODE_LNOIS   1
    
#define RSSMF_PM_MODE_HBAN  0
#define RSSMF_PM_MODE_HDEV  1
#define RSSMF_PM_MODE_LNOIS 2
    
#define RSSMF_FREQUENCY_RCL_INCLUDE 0
#define RSSMF_FREQUENCY_RCL_EXCLUDE 1
    
#define RSSMF_INPUT_TRIGGER_SLOPE_POSITIVE 0
#define RSSMF_INPUT_TRIGGER_SLOPE_NEGATIVE 1
    
#define RSSMF_FREQ_SWEEP_SPACING_LIN  0
#define RSSMF_FREQ_SWEEP_SPACING_LOG  1
#define RSSMF_FREQ_SWEEP_SPACING_RAMP 2
  
#define RSSMF_SENSE_POWER_SWEEP_TIMING_NORM 0
#define RSSMF_SENSE_POWER_SWEEP_TIMING_FAST 1
#define RSSMF_SENSE_POWER_SWEEP_TIMING_HPR  2
  
#define RSSMF_SENSE_POWER_SWEEP_SPACING_LIN 0
#define RSSMF_SENSE_POWER_SWEEP_SPACING_LOG 1
  
#define RSSMF_SENSE_POWER_SWEEP_FREQ_SPACING_LIN 0
#define RSSMF_SENSE_POWER_SWEEP_FREQ_SPACING_LOG 1
    
#define RSSMF_ROSC_SOURCE_INTERNAL    0
#define RSSMF_ROSC_SOURCE_EXTERNAL    1
    
#define RSSMF_EXTERN_REF_FREQ_5MHZ     0
#define RSSMF_EXTERN_REF_FREQ_10MHZ    1
#define RSSMF_EXTERN_REF_FREQ_13MHZ    2
    
#define RSSMF_ROSC_SBAN_NARROW 0
#define RSSMF_ROSC_SBAN_WIDE   1
    
#define RSSMF_POWER_LEVEL_RCL_INCLUDE 0
#define RSSMF_POWER_LEVEL_RCL_EXCLUDE 1
    
#define RSSMF_OUTPUT_STATE_PON_OFF       0
#define RSSMF_OUTPUT_STATE_PON_UNCHANGED 1
    
#define RSSMF_OUTPUT_AMODE_AUTO   0
#define RSSMF_OUTPUT_AMODE_FIXED  1
    
#define RSSMF_TEST_COMMAND_SSYN       0
#define RSSMF_TEST_COMMAND_SSYNEX     1
#define RSSMF_TEST_COMMAND_IQOP3      2
#define RSSMF_TEST_COMMAND_IQOP6      3
#define RSSMF_TEST_COMMAND_SATT3      4
#define RSSMF_TEST_COMMAND_SATT6      5
#define RSSMF_TEST_COMMAND_BBINS      6
#define RSSMF_TEST_COMMAND_DIRECTLAST 7
    
#define RSSMF_SYSTEM_KEYBOARD_US 0
#define RSSMF_SYSTEM_KEYBOARD_DE 1
    
#define RSSMF_DISPLAY_BLANK_MODE_OFF  0
#define RSSMF_DISPLAY_BLANK_MODE_ON   1
#define RSSMF_DISPLAY_BLANK_MODE_AUTO 2
    
#define RSSMF_SYSTEM_COMMUNICATE_IP_MODE_STATIC 0
#define RSSMF_SYSTEM_COMMUNICATE_IP_MODE_P2P    1
#define RSSMF_SYSTEM_COMMUNICATE_IP_MODE_AUTO   2
    
#define RSSMF_SYSTEM_COMMUNICATE_DNS_MODE_STATIC 0
#define RSSMF_SYSTEM_COMMUNICATE_DNS_MODE_AUTO   1
    
#define RSSMF_LFOUTPUT_SHAPE_SINE      0
#define RSSMF_LFOUTPUT_SHAPE_SQUARE    1
#define RSSMF_LFOUTPUT_SHAPE_TRIANGLE  2
#define RSSMF_LFOUTPUT_SHAPE_TRAPEZE   3
    
#define RSSMF_LFO_MONITOR_OFF 0
#define RSSMF_LFO_MONITOR_AM  1
#define RSSMF_LFO_MONITOR_FM  2
    
#define RSSMF_LFOUTPUT_SOURCE_LF1   0
#define RSSMF_LFOUTPUT_SOURCE_LF2   1
#define RSSMF_LFOUTPUT_SOURCE_EXT1  2
#define RSSMF_LFOUTPUT_SOURCE_EXT2  3
#define RSSMF_LFOUTPUT_SOURCE_NOISE 4
    
#define RSSMF_EXTERNAL_COUPLING_AC 0
#define RSSMF_EXTERNAL_COUPLING_DC 1
    
#define RSSMF_DISPLAY_PROPORTIONAL_SCALE_S0V5 0
#define RSSMF_DISPLAY_PROPORTIONAL_SCALE_S1V0 1
    
#define RSSMF_DEXC_MODE_IMPORT 0
#define RSSMF_DEXC_MODE_EXPORT 1
    
#define RSSMF_DEXC_ASCII_SOURCE_FILE_EXT_TXT 0
#define RSSMF_DEXC_ASCII_SOURCE_FILE_EXT_CSV 1
    
#define RSSMF_DEXC_ASCII_SOURCE_FILE_COLUMN_SEP_TAB   0
#define RSSMF_DEXC_ASCII_SOURCE_FILE_COLUMN_SEP_SEM   1
#define RSSMF_DEXC_ASCII_SOURCE_FILE_COLUMN_SEP_COMMA 2
#define RSSMF_DEXC_ASCII_SOURCE_FILE_COLUMN_SEP_SPACE 3
    
#define RSSMF_DEXC_ASCII_SOURCE_FILE_COLUMN_DEC_SEP_DOT   0
#define RSSMF_DEXC_ASCII_SOURCE_FILE_COLUMN_DEC_SEP_COMMA 1
    
#define RSSMF_OUTPUT_BLANK_POLARITY_NORMAL 0
#define RSSMF_OUTPUT_BLANK_POLARITY_INVERS 1
  
#define RSSMF_OUTPUT_BLANK_WIDTH_RFBL 0
#define RSSMF_OUTPUT_BLANK_WIDTH_TRIG 1
    
#define RSSMF_EXT_INPUT_IMPEDANCE_G50   0
#define RSSMF_EXT_INPUT_IMPEDANCE_G600  1
#define RSSMF_EXT_INPUT_IMPEDANCE_G100K 2
    
#define RSSMF_EXT_INPUT_BWIDTH_200K 0
#define RSSMF_EXT_INPUT_BWIDTH_10M  1

#define RSSMF_PULM_TRIGGER_LEVEL_TTL 0
#define RSSMF_PULM_TRIGGER_LEVEL_0V5 1
#define RSSMF_PULM_TRIGGER_LEVEL_2V5 2
    
#define RSSMF_INPUT_IMPEDANCE_G50   0
#define RSSMF_INPUT_IMPEDANCE_G10K  1
    
#define RSSMF_DM_SOURCE_EXT1 0
#define RSSMF_DM_SOURCE_EXT2 1
#define RSSMF_DM_SOURCE_PGEN 2
#define RSSMF_DM_SOURCE_RAND 3
    
#define RSSMF_POWER_RESOLUTION_R01 0
#define RSSMF_POWER_RESOLUTION_R1  1
    
#define RSSMF_POWER_ALC_SEARCH_NORM 0
#define RSSMF_POWER_ALC_SEARCH_MIN  1
    
#define RSSMF_LFOUTPUT_SHAPE_TRAPEZE_FALL   0
#define RSSMF_LFOUTPUT_SHAPE_TRAPEZE_HIGH   1
#define RSSMF_LFOUTPUT_SHAPE_TRAPEZE_PERIOD 2
#define RSSMF_LFOUTPUT_SHAPE_TRAPEZE_RISE   3
    
#define RSSMF_LFOUTPUT_SHAPE_TRIANGLE_PERIOD 0
#define RSSMF_LFOUTPUT_SHAPE_TRIANGLE_RISE   1
    
#define RSSMF_LFOUTPUT_SHAPE_PULSE_DUTY   0
#define RSSMF_LFOUTPUT_SHAPE_PULSE_PERIOD 1
#define RSSMF_LFOUTPUT_SHAPE_PULSE_WIDTH  2
    
#define RSSMF_REGISTER_OPERATION    0
#define RSSMF_REGISTER_QUESTIONABLE 1
    
#define RSSMF_REGISTER_ENABLE 2
#define RSSMF_REGISTER_NTR    3
#define RSSMF_REGISTER_PTR    4
    
#define RSSMF_FREQ_CENTER_SPAN    0
#define RSSMF_FREQ_START_STOP     1
    
#define RSSMF_EXTERNAL_IMPEDANCE_G50   0
#define RSSMF_EXTERNAL_IMPEDANCE_G600  1
#define RSSMF_EXTERNAL_IMPEDANCE_G100K 2

#define RSSMF_REGISTER_COND 0
#define RSSMF_REGISTER_EVENT 1
    
/* --- Units --------------------------------------------------------------- */
#define RSSMF_UNIT_ANGLE_DEG                0
#define RSSMF_UNIT_ANGLE_RAD                1
   
/* --- Velocity ------------------------------------------------------------ */
#define RSSMF_UNIT_VELOCITY_MPS               0
#define RSSMF_UNIT_VELOCITY_KMH               1
#define RSSMF_UNIT_VELOCITY_MPH               2
  
/* --- HCOPY --------------------------------------------------------------- */
  
#define RSSMF_HCOPY_LANG_BMP                0
#define RSSMF_HCOPY_LANG_JPG                1
#define RSSMF_HCOPY_LANG_XPM                2
#define RSSMF_HCOPY_LANG_PNG                3
  
#define RSSMF_HCOPY_DEV_FILE                                0   
    
#define RSSMF_HCOPY_AUTO_FILE_DAY                           0
#define RSSMF_HCOPY_AUTO_FILE_MONTH                         1
#define RSSMF_HCOPY_AUTO_FILE_YEAR                          2
    
#define RSSMF_HCOPY_SIZE_320_240                            0
#define RSSMF_HCOPY_SIZE_640_480                            1
#define RSSMF_HCOPY_SIZE_800_600                            2
#define RSSMF_HCOPY_SIZE_1024_768                           3   

#define RSSMF_PULM_MODE_SING                0
#define RSSMF_PULM_MODE_DOUB                1
#define RSSMF_PULM_MODE_PTR                 2
  
#define RSSMF_CHIRP_TRIGGER_MODE_AUTO                       0
#define RSSMF_CHIRP_TRIGGER_MODE_EXT                        1
#define RSSMF_CHIRP_TRIGGER_MODE_EGAT                       2
  
#define RSSMF_CHIRP_TRIGGER_SLOPE_POS             0
#define RSSMF_CHIRP_TRIGGER_SLOPE_NEG             1
  
#define RSSMF_CHIRP_TRIGGER_LEVEL_TTL             0
#define RSSMF_CHIRP_TRIGGER_LEVEL_POV5            1
#define RSSMF_CHIRP_TRIGGER_LEVEL_M2V5            2
  
#define RSSMF_CHIRP_GATE_POLARITY_INV             0
#define RSSMF_CHIRP_GATE_POLARITY_NORM            1
  
#define RSSMF_CHIRP_IMPEDANCE_G10K              0
#define RSSMF_CHIRP_IMPEDANCE_G50               1
  
#define RSSMF_CHIRP_DIRECTION_UP                0
#define RSSMF_CHIRP_DIRECTION_DOWN              1
  
#define RSSMF_UNIT_POWER_V                  0
#define RSSMF_UNIT_POWER_DBM                1
  
#define RSSMF_FREQ_SWEEP_SHAPE_SAWT               0
#define RSSMF_FREQ_SWEEP_SHAPE_TRI                1
  
#define RSSMF_SENSE_POWER_FILTER_TYPE_AUTO          0
#define RSSMF_SENSE_POWER_FILTER_TYPE_USER          1
#define RSSMF_SENSE_POWER_FILTER_TYPE_NSR           2
  
#define RSSMF_SENSE_POWER_SWEEP_FREQ_TIMING_NORM      0
#define RSSMF_SENSE_POWER_SWEEP_FREQ_TIMING_FAST      1
#define RSSMF_SENSE_POWER_SWEEP_FREQ_TIMING_HPR           2
  
#define RSSMF_SENSE_POWER_SWEEP_POWER_SPACING_LIN       0
#define RSSMF_SENSE_POWER_SWEEP_POWER_SPACING_LOG       1
  
#define RSSMF_SENSE_POWER_SWEEP_POWER_TIMING_NORM       0
#define RSSMF_SENSE_POWER_SWEEP_POWER_TIMING_FAST       1
#define RSSMF_SENSE_POWER_SWEEP_POWER_TIMING_HPR            2
  
#define RSSMF_SENSE_POWER_SWEEP_RMODE_SING          0
#define RSSMF_SENSE_POWER_SWEEP_RMODE_CONT          1
  
#define RSSMF_SENSE_POWER_SWEEP_HARDCOPY_LANG_BMP       0
#define RSSMF_SENSE_POWER_SWEEP_HARDCOPY_LANG_JPG       1
#define RSSMF_SENSE_POWER_SWEEP_HARDCOPY_LANG_XPM       2
#define RSSMF_SENSE_POWER_SWEEP_HARDCOPY_LANG_PNG       3
  
#define RSSMF_SENSE_POWER_SOURCE_RF               0
#define RSSMF_SENSE_POWER_SOURCE_USER             1
#define RSSMF_SENSE_POWER_SOURCE_B                2
  
#define RSSMF_SENSE_POWER_UNIT_DBM              0
#define RSSMF_SENSE_POWER_UNIT_DBUV             1
#define RSSMF_SENSE_POWER_UNIT_WATT             2
  
#define RSSMF_ALC_OFF_MODE_SHOLD              0
  
#define RSSMF_SENSE_POWER_SWEEP_MODE_FREQ           0
#define RSSMF_SENSE_POWER_SWEEP_MODE_POW            1
#define RSSMF_SENSE_POWER_SWEEP_MODE_TIME                   2

/* --- Power Sensor Time Trigger Source ------------------------------------ */   
#define RSSMF_SENSE_POWER_TIME_TRIG_SOURCE_AUTO             0
#define RSSMF_SENSE_POWER_TIME_TRIG_SOURCE_FREE             1
#define RSSMF_SENSE_POWER_TIME_TRIG_SOURCE_EXT              2
  
/* --- Power Sensor Display Indication ------------------------------------- */   
#define RSSMF_SENSE_POWER_PERM_PRIOR_AVER                   0
#define RSSMF_SENSE_POWER_PERM_PRIOR_PEAK                   1
  
#define RSSMF_LIST_SWEEP_MODE_AUTO                          0
#define RSSMF_LIST_SWEEP_MODE_STEP                          1
  
#define RSSMF_LIST_TRIGGER_SOURCE_AUTO                      0
#define RSSMF_LIST_TRIGGER_SOURCE_SINGLE                    1
#define RSSMF_LIST_TRIGGER_SOURCE_EXTERNAL                  2
  
#define RSSMF_LIST_ATTEN_MODE_NORM                          0
#define RSSMF_LIST_ATTEN_MODE_HPOW                          1
  
#define RSSMF_SENSE_POWER_SWEEP_TIME_TIMING_NORM            0
#define RSSMF_SENSE_POWER_SWEEP_TIME_TIMING_FAST            1
#define RSSMF_SENSE_POWER_SWEEP_TIME_TIMING_HPR             2
  
#define RSSMF_POW_SWEEP_SHAPE_SAWT                          0
#define RSSMF_POW_SWEEP_SHAPE_TRI                           1
  
#define RSSMF_CAL_DATA_FACT                                 0 
#define RSSMF_CAL_DATA_CUST                                 1
  
#define RSSMF_SENSE_POWER_DISP_POWER_AVER                   6
#define RSSMF_SENSE_POWER_DISP_POWER_HREF                   7
#define RSSMF_SENSE_POWER_DISP_POWER_REF                    8
#define RSSMF_SENSE_POWER_DISP_POWER_LREF                   9
#define RSSMF_SENSE_POWER_DISP_POWER_MAX                    10
#define RSSMF_SENSE_POWER_DISP_POWER_MIN                    11
#define RSSMF_SENSE_POWER_DISP_POWER_PULSE_BASE             12
#define RSSMF_SENSE_POWER_DISP_POWER_PULSE_TOP              13
#define RSSMF_SENSE_POWER_DISP_PULSE_DCYCLE                 14
#define RSSMF_SENSE_POWER_DISP_PULSE_DUR                    15
#define RSSMF_SENSE_POWER_DISP_PULSE_PERIOD                 16
#define RSSMF_SENSE_POWER_DISP_PULSE_SEP                    17
#define RSSMF_SENSE_POWER_DISP_TRAN_NEG_DUR                 18
#define RSSMF_SENSE_POWER_DISP_TRAN_NEG_OCC                 19
#define RSSMF_SENSE_POWER_DISP_TRAN_NEG_OVER                20
#define RSSMF_SENSE_POWER_DISP_TRAN_POS_DUR                 21
#define RSSMF_SENSE_POWER_DISP_TRAN_POS_OCC                 22
#define RSSMF_SENSE_POWER_DISP_TRAN_POS_OVER                23
  
#define RSSMF_SENSE_POWER_SWEEP_HARDCOPY_CSV_DECPOINT_DOT   0
#define RSSMF_SENSE_POWER_SWEEP_HARDCOPY_CSV_DECPOINT_COM   1

#define RSSMF_SENSE_POWER_SWEEP_HARDCOPY_CSV_COL_TAB    0
#define RSSMF_SENSE_POWER_SWEEP_HARDCOPY_CSV_COL_SEM    1
#define RSSMF_SENSE_POWER_SWEEP_HARDCOPY_CSV_COL_COM    2
#define RSSMF_SENSE_POWER_SWEEP_HARDCOPY_CSV_COL_BLN    3
  
#define RSSMF_SENSE_POWER_SWEEP_HARDCOPY_CSV_ORIENT_HOR   0
#define RSSMF_SENSE_POWER_SWEEP_HARDCOPY_CSV_ORIENT_VER   1
  
#define RSSMF_SENSE_POWER_SWEEP_HARDCOPY_CSV_HEADER_OFF   0
#define RSSMF_SENSE_POWER_SWEEP_HARDCOPY_CSV_HEADER_STD   1
  
#define RSSMF_SENSE_POWER_DISPLAY_BC_BLACK                  0
#define RSSMF_SENSE_POWER_DISPLAY_BC_WHITE                  1
  
#define RSSMF_SENSE_POWER_TIME_THRESHOLD_DISTAL             0
#define RSSMF_SENSE_POWER_TIME_THRESHOLD_MESIAL             1
#define RSSMF_SENSE_POWER_TIME_THRESHOLD_PROXIM             2
  
#define RSSMF_SENSE_POWER_SWEEP_TRACE_SOURCE_S1       0
#define RSSMF_SENSE_POWER_SWEEP_TRACE_SOURCE_S2       1
#define RSSMF_SENSE_POWER_SWEEP_TRACE_SOURCE_S3       2
#define RSSMF_SENSE_POWER_SWEEP_TRACE_SOURCE_REF      3
#define RSSMF_SENSE_POWER_SWEEP_TRACE_SOURCE_NON      4
  
#define RSSMF_SENSE_POWER_SWEEP_TRACE_COPY_REF        0
  
#define RSSMF_SENSE_POWER_SWEEP_TRACE_COLOR_INVE      0
#define RSSMF_SENSE_POWER_SWEEP_TRACE_COLOR_GRAY      1
#define RSSMF_SENSE_POWER_SWEEP_TRACE_COLOR_YELL      2
#define RSSMF_SENSE_POWER_SWEEP_TRACE_COLOR_BLUE      3
#define RSSMF_SENSE_POWER_SWEEP_TRACE_COLOR_GREE      4
#define RSSMF_SENSE_POWER_SWEEP_TRACE_COLOR_RED       5
#define RSSMF_SENSE_POWER_SWEEP_TRACE_COLOR_MAGN      6
  
#define RSSMF_SENSE_POWER_SWEEP_YSCALE_AUTO_OFF             0
#define RSSMF_SENSE_POWER_SWEEP_YSCALE_AUTO_CEXP            1
#define RSSMF_SENSE_POWER_SWEEP_YSCALE_AUTO_FEXP            2
#define RSSMF_SENSE_POWER_SWEEP_YSCALE_AUTO_CFL             3
#define RSSMF_SENSE_POWER_SWEEP_YSCALE_AUTO_FFL             4
  
#define RSSMF_SENSE_POWER_SWEEP_TIME_SPACING_LIN            0

#define RSSMF_SENSE_POWER_TIME_THRESHOLD_BASE_VOLT      0
#define RSSMF_SENSE_POWER_TIME_THRESHOLD_BASE_POW       1

#define RSSMF_SENSE_POWER_GATE_TRAC_1                       0
#define RSSMF_SENSE_POWER_GATE_TRAC_2                       1
#define RSSMF_SENSE_POWER_GATE_TRAC_3                       2
  
/* --- Power Sensor Display Indication ------------------------------------- */     
#define RSSMF_SENSE_POWER_DISP_PULS_ALL                     0
#define RSSMF_SENSE_POWER_DISP_PULS                         1
#define RSSMF_SENSE_POWER_DISP_MARK                         2
#define RSSMF_SENSE_POWER_DISP_GATE                         3
#define RSSMF_SENSE_POWER_DISP_STAN                         4
#define RSSMF_SENSE_POWER_DISP_FULL_SCR                     5
  
#define RSSMF_POWER_SENSOR_TYPE_NRP                         0
#define RSSMF_POWER_SENSOR_TYPE_NRVD                        1
#define RSSMF_POWER_SENSOR_TYPE_HP437                       2
#define RSSMF_POWER_SENSOR_TYPE_ML2438                      3
#define RSSMF_POWER_SENSOR_TYPE_P44X                        4
#define RSSMF_POWER_SENSOR_TYPE_HP436                       5
#define RSSMF_POWER_SENSOR_TYPE_HP438                       6
  
#define RSSMF_ALC_DETECTOR_INTERNAL                         0
#define RSSMF_ALC_DETECTOR_DIODE                            1
#define RSSMF_ALC_DETECTOR_PMETER                           2

#define RSSMF_OUTPUT_AMODE_OFF_NORMAL                       0
#define RSSMF_OUTPUT_AMODE_OFF_ATTN                         1

#define RSSMF_SWEEP_MARKER_POLARITY_NORMAL   0
#define RSSMF_SWEEP_MARKER_POLARITY_INVERTED 1

#define RSSMF_SWEEP_MARKER_ACTIVE_NONE 0
#define RSSMF_SWEEP_MARKER_ACTIVE_1    1
#define RSSMF_SWEEP_MARKER_ACTIVE_2    2
#define RSSMF_SWEEP_MARKER_ACTIVE_3    3
#define RSSMF_SWEEP_MARKER_ACTIVE_4    4
#define RSSMF_SWEEP_MARKER_ACTIVE_5    5
#define RSSMF_SWEEP_MARKER_ACTIVE_6    6
#define RSSMF_SWEEP_MARKER_ACTIVE_7    7
#define RSSMF_SWEEP_MARKER_ACTIVE_8    8
#define RSSMF_SWEEP_MARKER_ACTIVE_9    9
#define RSSMF_SWEEP_MARKER_ACTIVE_10   10

#define RSSMF_LFSWEEP_SHAPE_SAWTOOTH 0
#define RSSMF_LFSWEEP_SHAPE_TRIANGLE 1
	
#define RSSMF_INPUT_TRIGGER_SLOPE_POSITIVE 0
#define RSSMF_INPUT_TRIGGER_SLOPE_NEGATIVE 1
	
#define RSSMF_SENSE_POWER_SWEEP_TIME_TRIGGER_AND 0
#define RSSMF_SENSE_POWER_SWEEP_TIME_TRIGGER_OR  1
	
#define RSSMF_CALIBRATION_EXTERNAL_CORR_FACT 0
#define RSSMF_CALIBRATION_EXTERNAL_CORR_CUST 1

#define RSSMF_SERIAL_BAUDRATE_2400   0
#define RSSMF_SERIAL_BAUDRATE_4800   1
#define RSSMF_SERIAL_BAUDRATE_9600   2
#define RSSMF_SERIAL_BAUDRATE_19200  3
#define RSSMF_SERIAL_BAUDRATE_38400  4
#define RSSMF_SERIAL_BAUDRATE_57600  5
#define RSSMF_SERIAL_BAUDRATE_115200 6
	
#define RSSMF_SERIAL_PARITY_NONE 0
#define RSSMF_SERIAL_PARITY_ODD  1
#define RSSMF_SERIAL_PARITY_EVEN 2

#define RSSMF_SERIAL_SBITS_1 0
#define RSSMF_SERIAL_SBITS_2 1

#define RSSMF_SYSTEM_IDN_AUTO 0
#define RSSMF_SYSTEM_IDN_USER 1
	
#define RSSMF_FORMAT_BORDER_NORM 0
#define RSSMF_FORMAT_BORDER_SWAP 1

#define RSSMF_LFOUTPUT_BW_BW0M2 0
#define RSSMF_LFOUTPUT_BW_BW10M 1

/*****************************************************************************/
/*= GLOBAL USER-CALLABLE FUNCTION DECLARATIONS (Exportable Functions) =======*/
/*****************************************************************************/
ViStatus _VI_FUNC rssmf_init (ViRsrc resourceName, ViBoolean IDQuery,
                              ViBoolean resetDevice, ViPSession instrumentHandle);
ViStatus _VI_FUNC rssmf_confLFFreqSweep (ViSession instrumentHandle, ViInt32 mode,
                                         ViReal64 startFrequency,
                                         ViReal64 stopFrequency, ViInt32 spacing,
                                         ViReal64 step, ViReal64 dwellTime);
ViStatus _VI_FUNC rssmf_LFSweepTrigger (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmf_ConfigureLFSweepMarker (ViSession instrumentHandle,
                                                ViUInt32 channel, ViBoolean state,
                                                ViBoolean amplitudeMarker,
                                                ViReal64 frequency,
                                                ViReal64 amplitude,
                                                ViInt32 polarity,
                                                ViInt32 activeMarker);
ViStatus _VI_FUNC rssmf_SetLFSweepMode (ViSession instrumentHandle, ViInt32 mode);
ViStatus _VI_FUNC rssmf_SetLFSweepSource (ViSession instrumentHandle,
                                          ViInt32 source);
ViStatus _VI_FUNC rssmf_GetLFSweepSource (ViSession instrumentHandle,
                                          ViPInt32 source);
ViStatus _VI_FUNC rssmf_SetLFSweepStartFreq (ViSession instrumentHandle,
                                             ViReal64 startFrequency);
ViStatus _VI_FUNC rssmf_GetLFSweepStartFreq (ViSession instrumentHandle,
                                             ViPReal64 startFrequency);
ViStatus _VI_FUNC rssmf_SetLFSweepStopFreq (ViSession instrumentHandle,
                                            ViReal64 stopFrequency);
ViStatus _VI_FUNC rssmf_GetLFSweepStopFreq (ViSession instrumentHandle,
                                            ViPReal64 stopFrequency);
ViStatus _VI_FUNC rssmf_SetLFSweepShape (ViSession instrumentHandle, ViInt32 shape);
ViStatus _VI_FUNC rssmf_GetLFSweepShape (ViSession instrumentHandle,
                                         ViPInt32 shape);
ViStatus _VI_FUNC rssmf_SetLFSweepSpacing (ViSession instrumentHandle,
                                           ViInt32 spacing);
ViStatus _VI_FUNC rssmf_GetLFSweepSpacing (ViSession instrumentHandle,
                                           ViPInt32 spacing);
ViStatus _VI_FUNC rssmf_SetLFSweepStepLin (ViSession instrumentHandle,
                                           ViReal64 stepLin);
ViStatus _VI_FUNC rssmf_GetLFSweepStepLin (ViSession instrumentHandle,
                                           ViPReal64 stepLin);
ViStatus _VI_FUNC rssmf_SetLFSweepStepLog (ViSession instrumentHandle,
                                           ViReal64 stepLog);
ViStatus _VI_FUNC rssmf_GetLFSweepStepLog (ViSession instrumentHandle,
                                           ViPReal64 stepLog);
ViStatus _VI_FUNC rssmf_SetLFSweepDwellTime (ViSession instrumentHandle,
                                             ViReal64 dwellTime);
ViStatus _VI_FUNC rssmf_GetLFSweepDwellTime (ViSession instrumentHandle,
                                             ViPReal64 dwellTime);
ViStatus _VI_FUNC rssmf_SetLFSweepManualStep (ViSession instrumentHandle,
                                              ViReal64 manualLFSweep);
ViStatus _VI_FUNC rssmf_GetLFSweepManualStep (ViSession instrumentHandle,
                                              ViPReal64 manualLFSweep);
ViStatus _VI_FUNC rssmf_SetLFSweepPoints (ViSession instrumentHandle,
                                          ViUInt32 LFSweepPoints);
ViStatus _VI_FUNC rssmf_GetLFSweepPoints (ViSession instrumentHandle,
                                          ViPUInt32 LFSweepPoints);
ViStatus _VI_FUNC rssmf_SetLFSweepMarkerState (ViSession instrumentHandle,
                                               ViUInt32 channel, ViBoolean state);
ViStatus _VI_FUNC rssmf_GetLFSweepMarkerState (ViSession instrumentHandle,
                                               ViUInt32 channel, ViPBoolean state);
ViStatus _VI_FUNC rssmf_SetLFSweepMarkerFrequency (ViSession instrumentHandle,
                                                   ViUInt32 channel,
                                                   ViReal64 frequency);
ViStatus _VI_FUNC rssmf_GetLFSweepMarkerFrequency (ViSession instrumentHandle,
                                                   ViUInt32 channel,
                                                   ViPReal64 frequency);
ViStatus _VI_FUNC rssmf_SetLFSweepAmplitudeMarkerState (ViSession instrumentHandle,
                                                        ViUInt32 channel,
                                                        ViBoolean amplitudeMarker);
ViStatus _VI_FUNC rssmf_GetLFSweepAmplitudeMarkerState (ViSession instrumentHandle,
                                                        ViUInt32 channel,
                                                        ViPBoolean amplitudeMarker);
ViStatus _VI_FUNC rssmf_SetLFSweepAmplitudeMarkerAttenuation
             (ViSession instrumentHandle, ViReal64 amplitude);
ViStatus _VI_FUNC rssmf_GetLFSweepAmplitudeMarkerAttenuation
             (ViSession instrumentHandle, ViPReal64 amplitude);
ViStatus _VI_FUNC rssmf_SetLFSweepMarkerPolarity (ViSession instrumentHandle,
                                                  ViInt32 polarity);
ViStatus _VI_FUNC rssmf_GetLFSweepMarkerPolarity (ViSession instrumentHandle,
                                                  ViPInt32 polarity);
ViStatus _VI_FUNC rssmf_SetLFSweepActiveMarker (ViSession instrumentHandle,
                                                ViInt32 activeMarker);
ViStatus _VI_FUNC rssmf_GetLFSweepActiveMarker (ViSession instrumentHandle,
                                                ViPInt32 activeMarker);
ViStatus _VI_FUNC rssmf_SetLFSweepAllMarkersOff (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmf_SetLFGenBandwidth (ViSession instrumentHandle,
                                           ViInt32 channel, ViInt32 bandwidth);
ViStatus _VI_FUNC rssmf_GetLFGenBandwidth (ViSession instrumentHandle,
                                           ViInt32 channel, ViPInt32 bandwidth);
ViStatus _VI_FUNC rssmf_SetLFGenFrequency (ViSession instrumentHandle,
                                           ViInt32 channel,
                                           ViReal64 LFGenFrequency);
ViStatus _VI_FUNC rssmf_GetLFGenFrequency (ViSession instrumentHandle,
                                           ViInt32 channel,
                                           ViPReal64 LFGenFrequency);
ViStatus _VI_FUNC rssmf_SetLFGenShape (ViSession instrumentHandle, ViInt32 channel,
                                       ViInt32 shape);
ViStatus _VI_FUNC rssmf_GetLFGenShape (ViSession instrumentHandle, ViInt32 channel,
                                       ViPInt32 shape);
ViStatus _VI_FUNC rssmf_SetLFGenShapeTrapeze (ViSession instrumentHandle,
                                              ViInt32 channel, ViInt32 trapeze,
                                              ViReal64 time);
ViStatus _VI_FUNC rssmf_GetLFGenShapeTrapeze (ViSession instrumentHandle,
                                              ViInt32 channel, ViInt32 trapeze,
                                              ViPReal64 time);
ViStatus _VI_FUNC rssmf_SetLFGenShapeTriangle (ViSession instrumentHandle,
                                               ViInt32 channel, ViInt32 triangle,
                                               ViReal64 time);
ViStatus _VI_FUNC rssmf_GetLFGenShapeTriangle (ViSession instrumentHandle,
                                               ViInt32 channel, ViInt32 triangle,
                                               ViPReal64 time);
ViStatus _VI_FUNC rssmf_SetLFGenShapePulse (ViSession instrumentHandle,
                                            ViInt32 channel, ViInt32 pulse,
                                            ViReal64 time);
ViStatus _VI_FUNC rssmf_GetLFGenShapePulse (ViSession instrumentHandle,
                                            ViInt32 channel, ViInt32 pulse,
                                            ViPReal64 time);
ViStatus _VI_FUNC rssmf_confNoise (ViSession instrumentHandle, ViReal64 bandwidth,
                                   ViInt32 distribution);
ViStatus _VI_FUNC rssmf_SetNOISEBandwidth (ViSession instrumentHandle,
                                           ViReal64 bandwidth);
ViStatus _VI_FUNC rssmf_GetNOISEBandwidth (ViSession instrumentHandle,
                                           ViPReal64 bandwidth);
ViStatus _VI_FUNC rssmf_SetNOISEDistribution (ViSession instrumentHandle,
                                              ViInt32 distribution);
ViStatus _VI_FUNC rssmf_GetNOISEDistribution (ViSession instrumentHandle,
                                              ViPInt32 distribution);
ViStatus _VI_FUNC rssmf_GetNOISERelativeLevel (ViSession instrumentHandle,
                                               ViPReal64 relativeLevel);
ViStatus _VI_FUNC rssmf_GetNOISEAbsoluteLevel (ViSession instrumentHandle,
                                               ViPReal64 absoluteLevel);
ViStatus _VI_FUNC rssmf_SetNOISEBandwidthState (ViSession instrumentHandle,
                                                ViBoolean bandwidthState);
ViStatus _VI_FUNC rssmf_GetNOISEBandwidthState (ViSession instrumentHandle,
                                                ViPBoolean bandwidthState);
ViStatus _VI_FUNC rssmf_confLFOutput (ViSession instrumentHandle, ViInt32 channel,
                                      ViBoolean state, ViInt32 source,
                                      ViReal64 outputVoltage);
ViStatus _VI_FUNC rssmf_SetLFOutputMonitoring (ViSession instrumentHandle,
                                               ViInt32 monitoring);
ViStatus _VI_FUNC rssmf_SetLFOutputDCOffset (ViSession instrumentHandle,
                                             ViReal64 DCOffset);
ViStatus _VI_FUNC rssmf_GetLFOutputMonitoring (ViSession instrumentHandle,
                                               ViPInt32 monitoring);
ViStatus _VI_FUNC rssmf_GetLFOutputDCOffset (ViSession instrumentHandle,
                                             ViPReal64 DCOffset);
ViStatus _VI_FUNC rssmf_SetLFOutputState (ViSession instrumentHandle,
                                          ViBoolean LFOutputState);
ViStatus _VI_FUNC rssmf_GetLFOutputState (ViSession instrumentHandle,
                                          ViPBoolean LFOutputState);
ViStatus _VI_FUNC rssmf_SetLFOutputSource (ViSession instrumentHandle,
                                           ViInt32 channel, ViInt32 source);
ViStatus _VI_FUNC rssmf_GetLFOutputSource (ViSession instrumentHandle,
                                           ViInt32 channel, ViPInt32 source);
ViStatus _VI_FUNC rssmf_SetLFOutputVoltage (ViSession instrumentHandle,
                                            ViInt32 channel,
                                            ViReal64 outputVoltage);
ViStatus _VI_FUNC rssmf_GetLFOutputVoltage (ViSession instrumentHandle,
                                            ViInt32 channel,
                                            ViPReal64 LFGenVoltage);
ViStatus _VI_FUNC rssmf_ConfigureLFLevelSweepMode (ViSession instrumentHandle,
                                                   ViInt32 mode, ViInt32 source,
                                                   ViReal64 startLevel,
                                                   ViReal64 stopLevel,
                                                   ViReal64 step,
                                                   ViReal64 dwellTime);
ViStatus _VI_FUNC rssmf_LFLevelSweepTrigger (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmf_ConfigureLFLevelSweepMarker (ViSession instrumentHandle,
                                                     ViUInt32 channel,
                                                     ViBoolean state,
                                                     ViReal64 level,
                                                     ViInt32 polarity,
                                                     ViInt32 activeMarker);
ViStatus _VI_FUNC rssmf_SetLFLevelSweepMode (ViSession instrumentHandle,
                                             ViInt32 mode);
ViStatus _VI_FUNC rssmf_SetLFLevelSweepSource (ViSession instrumentHandle,
                                               ViInt32 source);
ViStatus _VI_FUNC rssmf_GetLFLevelSweepSource (ViSession instrumentHandle,
                                               ViPInt32 source);
ViStatus _VI_FUNC rssmf_SetLFLevelSweepStartLevel (ViSession instrumentHandle,
                                                   ViReal64 startLevel);
ViStatus _VI_FUNC rssmf_GetLFLevelSweepStartLevel (ViSession instrumentHandle,
                                                   ViPReal64 startLevel);
ViStatus _VI_FUNC rssmf_SetLFLevelSweepStopLevel (ViSession instrumentHandle,
                                                  ViReal64 stopLevel);
ViStatus _VI_FUNC rssmf_GetLFLevelSweepStopLevel (ViSession instrumentHandle,
                                                  ViPReal64 stopLevel);
ViStatus _VI_FUNC rssmf_SetLFLevelSweepStep (ViSession instrumentHandle,
                                             ViReal64 step);
ViStatus _VI_FUNC rssmf_GetLFLevelSweepStep (ViSession instrumentHandle,
                                             ViPReal64 step);
ViStatus _VI_FUNC rssmf_SetLFLevelSweepCount (ViSession instrumentHandle,
                                              ViUInt32 count);
ViStatus _VI_FUNC rssmf_GetLFLevelSweepCount (ViSession instrumentHandle,
                                              ViPUInt32 count);
ViStatus _VI_FUNC rssmf_SetLFLevelSweepShape (ViSession instrumentHandle,
                                              ViInt32 shape);
ViStatus _VI_FUNC rssmf_GetLFLevelSweepShape (ViSession instrumentHandle,
                                              ViPInt32 shape);
ViStatus _VI_FUNC rssmf_SetLFLevelSweepDwellTime (ViSession instrumentHandle,
                                                  ViReal64 dwellTime);
ViStatus _VI_FUNC rssmf_GetLFLevelSweepDwellTime (ViSession instrumentHandle,
                                                  ViPReal64 dwellTime);
ViStatus _VI_FUNC rssmf_SetLFLevelSweepManualStep (ViSession instrumentHandle,
                                                   ViReal64 manualLFSweep);
ViStatus _VI_FUNC rssmf_GetLFLevelSweepManualStep (ViSession instrumentHandle,
                                                   ViPReal64 manualLFSweep);
ViStatus _VI_FUNC rssmf_SetLFLevelSweepMarkerState (ViSession instrumentHandle,
                                                    ViUInt32 channel,
                                                    ViBoolean state);
ViStatus _VI_FUNC rssmf_GetLFLevelSweepMarkerState (ViSession instrumentHandle,
                                                    ViUInt32 channel,
                                                    ViPBoolean state);
ViStatus _VI_FUNC rssmf_SetLFLevelSweepMarkerLevel (ViSession instrumentHandle,
                                                    ViUInt32 channel,
                                                    ViReal64 level);
ViStatus _VI_FUNC rssmf_GetLFLevelSweepMarkerLevel (ViSession instrumentHandle,
                                                    ViUInt32 channel,
                                                    ViPReal64 level);
ViStatus _VI_FUNC rssmf_SetLFLevelSweepMarkerPolarity (ViSession instrumentHandle,
                                                       ViInt32 polarity);
ViStatus _VI_FUNC rssmf_GetLFLevelSweepMarkerPolarity (ViSession instrumentHandle,
                                                       ViPInt32 polarity);
ViStatus _VI_FUNC rssmf_SetLFLevelSweepActiveMarker (ViSession instrumentHandle,
                                                     ViInt32 activeMarker);
ViStatus _VI_FUNC rssmf_GetLFLevelSweepActiveMarker (ViSession instrumentHandle,
                                                     ViPInt32 activeMarker);
ViStatus _VI_FUNC rssmf_SetLFLevelSweepAllMarkersOff (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmf_ConfigureExternalInput (ViSession instrumentHandle,
                                                ViInt32 input, ViInt32 coupling,
                                                ViInt32 impedance,
                                                ViInt32 bandwidth);
ViStatus _VI_FUNC rssmf_SetExternalInputCoupling (ViSession instrumentHandle,
                                                  ViInt32 input, ViInt32 coupling);
ViStatus _VI_FUNC rssmf_GetExternalInputCoupling (ViSession instrumentHandle,
                                                  ViInt32 input, ViPInt32 coupling);
ViStatus _VI_FUNC rssmf_SetExternalInputImpedance (ViSession instrumentHandle,
                                                   ViInt32 input,
                                                   ViInt32 impedance);
ViStatus _VI_FUNC rssmf_GetExternalInputImpedance (ViSession instrumentHandle,
                                                   ViInt32 input,
                                                   ViPInt32 impedance);
ViStatus _VI_FUNC rssmf_SetExternalInputBandwidth (ViSession instrumentHandle,
                                                   ViInt32 input,
                                                   ViInt32 bandwidth);
ViStatus _VI_FUNC rssmf_GetExternalInputBandwidth (ViSession instrumentHandle,
                                                   ViInt32 input,
                                                   ViPInt32 bandwidth);
ViStatus _VI_FUNC rssmf_SetAllModulationsState (ViSession instrumentHandle,
                                                ViBoolean state);
ViStatus _VI_FUNC rssmf_confPulm (ViSession instrumentHandle, ViBoolean state,
                                  ViInt32 source, ViInt32 externalPolarity,
                                  ViInt32 videoPolarity);
ViStatus _VI_FUNC rssmf_confPulmGen (ViSession instrumentHandle,
                                     ViBoolean pulseOutputState,
                                     ViReal64 pulsePeriod, ViReal64 pulseWidth,
                                     ViReal64 pulseDelay,
                                     ViBoolean doublePulseState,
                                     ViReal64 doublePulseDelay,
                                     ViInt32 outputPolarity);
ViStatus _VI_FUNC rssmf_SetPULMState (ViSession instrumentHandle, ViBoolean state);
ViStatus _VI_FUNC rssmf_GetPULMState (ViSession instrumentHandle, ViPBoolean state);
ViStatus _VI_FUNC rssmf_SetPULMSource (ViSession instrumentHandle, ViInt32 source);
ViStatus _VI_FUNC rssmf_GetPULMSource (ViSession instrumentHandle, ViPInt32 source);
ViStatus _VI_FUNC rssmf_SetPULMExternalPolarity (ViSession instrumentHandle,
                                                 ViInt32 polarity);
ViStatus _VI_FUNC rssmf_GetPULMExternalPolarity (ViSession instrumentHandle,
                                                 ViPInt32 polarity);
ViStatus _VI_FUNC rssmf_SetPULMVideoPolarity (ViSession instrumentHandle,
                                              ViInt32 polarity);
ViStatus _VI_FUNC rssmf_GetPULMVideoPolarity (ViSession instrumentHandle,
                                              ViPInt32 polarity);
ViStatus _VI_FUNC rssmf_SetPULMSyncToInternalClock (ViSession instrumentHandle,
                                                    ViBoolean synchronizeToInternalClock);
ViStatus _VI_FUNC rssmf_GetPULMSyncToInternalClock (ViSession instrumentHandle,
                                                    ViPBoolean synchronizeToInternalClock);
ViStatus _VI_FUNC rssmf_SetPULMPeriod (ViSession instrumentHandle,
                                       ViReal64 pulsePeriod);
ViStatus _VI_FUNC rssmf_GetPULMPeriod (ViSession instrumentHandle,
                                       ViPReal64 pulsePeriod);
ViStatus _VI_FUNC rssmf_SetPULMWidth (ViSession instrumentHandle,
                                      ViReal64 pulseWidth);
ViStatus _VI_FUNC rssmf_GetPULMWidth (ViSession instrumentHandle,
                                      ViPReal64 pulseWidth);
ViStatus _VI_FUNC rssmf_SetPULMDelay (ViSession instrumentHandle,
                                      ViReal64 pulseDelay);
ViStatus _VI_FUNC rssmf_GetPULMDelay (ViSession instrumentHandle,
                                      ViPReal64 pulseDelay);
ViStatus _VI_FUNC rssmf_SetPULMDoubleState (ViSession instrumentHandle,
                                            ViBoolean doublePulseState);
ViStatus _VI_FUNC rssmf_GetPULMDoubleState (ViSession instrumentHandle,
                                            ViPBoolean doublePulseState);
ViStatus _VI_FUNC rssmf_SetPULMDoubleDelay (ViSession instrumentHandle,
                                            ViReal64 doublePulseDelay);
ViStatus _VI_FUNC rssmf_GetPULMDoubleDelay (ViSession instrumentHandle,
                                            ViPReal64 doublePulseDelay);
ViStatus _VI_FUNC rssmf_SetPULMDoubleWidth (ViSession instrumentHandle,
                                            ViReal64 doubleWidth);
ViStatus _VI_FUNC rssmf_GetPULMDoubleWidth (ViSession instrumentHandle,
                                            ViPReal64 doubleWidth);
ViStatus _VI_FUNC rssmf_SetPULMGeneratorOutputState (ViSession instrumentHandle,
                                                     ViBoolean outputState);
ViStatus _VI_FUNC rssmf_GetPULMGeneratorOutputState (ViSession instrumentHandle,
                                                     ViPBoolean outputState);
ViStatus _VI_FUNC rssmf_SetPULMOutputPolarity (ViSession instrumentHandle,
                                               ViInt32 polarity);
ViStatus _VI_FUNC rssmf_GetPULMOutputPolarity (ViSession instrumentHandle,
                                               ViPInt32 polarity);
ViStatus _VI_FUNC rssmf_PULMPulseTrainCatalog (ViSession instrumentHandle,
                                               ViString directoryPath,
                                               ViInt32 arraySize,
                                               ViChar _VI_FAR catalogList[]);
ViStatus _VI_FUNC rssmf_PULMDeletePulseTrainFile (ViSession instrumentHandle,
                                                  ViString fileName);
ViStatus _VI_FUNC rssmf_PULMSelectPulseTrainFile (ViSession instrumentHandle,
                                                  ViString fileName);
ViStatus _VI_FUNC rssmf_GetPULMPulseTrainLength (ViSession instrumentHandle,
                                                 ViPInt32 pulseTrainLength);
ViStatus _VI_FUNC rssmf_SetPULMMode (ViSession instrumentHandle, ViInt32 mode);
ViStatus _VI_FUNC rssmf_GetPULMMode (ViSession instrumentHandle, ViPInt32 mode);
ViStatus _VI_FUNC rssmf_SetPULMTrainOfftime (ViSession instrumentHandle,
                                             ViInt32 arraySize,
                                             ViReal64 _VI_FAR offtime[]);
ViStatus _VI_FUNC rssmf_GetPULMTrainOfftime (ViSession instrumentHandle,
                                             ViInt32 arraySize,
                                             ViReal64 _VI_FAR offtime[]);
ViStatus _VI_FUNC rssmf_GetTrainOfftimePoints (ViSession instrumentHandle,
                                               ViPInt32 numberOfOfftimePoints);
ViStatus _VI_FUNC rssmf_SetPULMTrainOntime (ViSession instrumentHandle,
                                            ViInt32 arraySize,
                                            ViReal64 _VI_FAR ontime[]);
ViStatus _VI_FUNC rssmf_GetPULMTrainOntime (ViSession instrumentHandle,
                                            ViInt32 arraySize,
                                            ViReal64 _VI_FAR ontime[]);
ViStatus _VI_FUNC rssmf_GetTrainOntimePoints (ViSession instrumentHandle,
                                              ViPInt32 numberOfOntimePoints);
ViStatus _VI_FUNC rssmf_SetPULMTrainRepetition (ViSession instrumentHandle,
                                                ViInt32 arraySize,
                                                ViInt32 _VI_FAR repetition[]);
ViStatus _VI_FUNC rssmf_GetPULMTrainRepetition (ViSession instrumentHandle,
                                                ViInt32 arraySize,
                                                ViInt32 _VI_FAR repetition[]);
ViStatus _VI_FUNC rssmf_SetPULMTrainImportExportListMode (ViSession instrumentHandle,
                                                          ViInt32 listMode);
ViStatus _VI_FUNC rssmf_GetPULMTrainImportExportListMode (ViSession instrumentHandle,
                                                          ViPInt32 listMode);
ViStatus _VI_FUNC rssmf_SetPULMTrainImportExportListFile (ViSession instrumentHandle,
                                                          ViString sourceFile);
ViStatus _VI_FUNC rssmf_GetPULMTrainImportExportListFile (ViSession instrumentHandle,
                                                          ViChar _VI_FAR sourceFile[]);
ViStatus _VI_FUNC rssmf_PULMTrainImportExportExecute (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmf_SetPULMTrainImportExportASCIIFile
             (ViSession instrumentHandle, ViString ASCIISourceFile);
ViStatus _VI_FUNC rssmf_GetPULMTrainImportExportASCIIFile
             (ViSession instrumentHandle, ViChar _VI_FAR ASCIISourceFile[]);
ViStatus _VI_FUNC rssmf_SetPULMTrainImportExportASCIIExtension
             (ViSession instrumentHandle, ViInt32 extension);
ViStatus _VI_FUNC rssmf_GetPULMTrainImportExportASCIIExtension
             (ViSession instrumentHandle, ViPInt32 extension);
ViStatus _VI_FUNC rssmf_SetPULMTrainImportExportASCIIColumnSeparator
             (ViSession instrumentHandle, ViInt32 separator);
ViStatus _VI_FUNC rssmf_GetPULMTrainImportExportASCIIColumnSeparator
             (ViSession instrumentHandle, ViPInt32 separator);
ViStatus _VI_FUNC rssmf_SetPULMTrainImportExportASCIIDecimalSeparator
             (ViSession instrumentHandle, ViInt32 decimalSeparator);
ViStatus _VI_FUNC rssmf_GetPULMTrainImportExportASCIIDecimalSeparator
             (ViSession instrumentHandle, ViPInt32 decimalSeparator);
ViStatus _VI_FUNC rssmf_PULMTrainImportExportCatalog (ViSession instrumentHandle,
                                                      ViInt32 arraySize,
                                                      ViChar _VI_FAR catalogList[]);
ViStatus _VI_FUNC rssmf_confPulmTrigger (ViSession instrumentHandle,
                                         ViInt32 triggerLevel,
                                         ViInt32 externalInputImpedance,
                                         ViInt32 triggerMode,
                                         ViInt32 extTriggerInputSlope,
                                         ViInt32 gateInputPolarity);
ViStatus _VI_FUNC rssmf_SetPULMTriggerLevel (ViSession instrumentHandle,
                                             ViInt32 triggerLevel);
ViStatus _VI_FUNC rssmf_GetPULMTriggerLevel (ViSession instrumentHandle,
                                             ViPInt32 triggerLevel);
ViStatus _VI_FUNC rssmf_SetPULMExternalInputImpedance (ViSession instrumentHandle,
                                                       ViInt32 externalInputImpedance);
ViStatus _VI_FUNC rssmf_GetPULMExternalInputImpedance (ViSession instrumentHandle,
                                                       ViPInt32 externalInputImpedance);
ViStatus _VI_FUNC rssmf_SetPULMTriggerMode (ViSession instrumentHandle,
                                            ViInt32 triggerMode);
ViStatus _VI_FUNC rssmf_GetPULMTriggerMode (ViSession instrumentHandle,
                                            ViPInt32 triggerMode);
ViStatus _VI_FUNC rssmf_SetPULMExtTriggerInputSlope (ViSession instrumentHandle,
                                                     ViInt32 extTriggerInputSlope);
ViStatus _VI_FUNC rssmf_GetPULMExtTriggerInputSlope (ViSession instrumentHandle,
                                                     ViPInt32 extTriggerInputSlope);
ViStatus _VI_FUNC rssmf_SetPULMGateInputPolarity (ViSession instrumentHandle,
                                                  ViInt32 polarity);
ViStatus _VI_FUNC rssmf_GetPULMGateInputPolarity (ViSession instrumentHandle,
                                                  ViPInt32 polarity);
ViStatus _VI_FUNC rssmf_configAM (ViSession instrumentHandle, ViInt32 channel,
                                  ViBoolean AMState, ViInt32 AMSource,
                                  ViReal64 AMDepth, ViBoolean scanState,
                                  ViReal64 AMSensitivity, ViReal64 ratio);
ViStatus _VI_FUNC rssmf_SetAMState (ViSession instrumentHandle, ViInt32 channel,
                                    ViBoolean AMState);
ViStatus _VI_FUNC rssmf_GetAMState (ViSession instrumentHandle, ViInt32 channel,
                                    ViPBoolean AMState);
ViStatus _VI_FUNC rssmf_SetAMSource (ViSession instrumentHandle, ViInt32 channel,
                                     ViInt32 AMSource);
ViStatus _VI_FUNC rssmf_GetAMSource (ViSession instrumentHandle, ViInt32 channel,
                                     ViPInt32 AMSource);
ViStatus _VI_FUNC rssmf_SetAMDepth (ViSession instrumentHandle, ViInt32 channel,
                                    ViReal64 AMDepth);
ViStatus _VI_FUNC rssmf_GetAMDepth (ViSession instrumentHandle, ViInt32 channel,
                                    ViPReal64 AMDepth);
ViStatus _VI_FUNC rssmf_SetAMSensitivity (ViSession instrumentHandle,
                                          ViInt32 channel, ViReal64 AMSensitivity);
ViStatus _VI_FUNC rssmf_GetAMSensitivity (ViSession instrumentHandle,
                                          ViInt32 channel, ViPReal64 AMSensitivity);
ViStatus _VI_FUNC rssmf_SetAMScanState (ViSession instrumentHandle,
                                        ViBoolean scanState);
ViStatus _VI_FUNC rssmf_GetAMScanState (ViSession instrumentHandle,
                                        ViPBoolean scanState);
ViStatus _VI_FUNC rssmf_SetAMRatio (ViSession instrumentHandle, ViReal64 ratio);
ViStatus _VI_FUNC rssmf_GetAMRatio (ViSession instrumentHandle, ViPReal64 ratio);
ViStatus _VI_FUNC rssmf_confFM (ViSession instrumentHandle, ViInt32 channel,
                                ViBoolean state, ViInt32 FMSource,
                                ViReal64 deviation, ViReal64 ratio, ViInt32 mode);
ViStatus _VI_FUNC rssmf_SetFMState (ViSession instrumentHandle, ViInt32 channel,
                                    ViBoolean state);
ViStatus _VI_FUNC rssmf_GetFMState (ViSession instrumentHandle, ViInt32 channel,
                                    ViPBoolean state);
ViStatus _VI_FUNC rssmf_SetFMSource (ViSession instrumentHandle, ViInt32 channel,
                                     ViInt32 FMSource);
ViStatus _VI_FUNC rssmf_GetFMSource (ViSession instrumentHandle, ViInt32 channel,
                                     ViPInt32 FMSource);
ViStatus _VI_FUNC rssmf_SetFMDeviation (ViSession instrumentHandle, ViInt32 channel,
                                        ViReal64 deviation);
ViStatus _VI_FUNC rssmf_GetFMDeviation (ViSession instrumentHandle, ViInt32 channel,
                                        ViPReal64 deviation);
ViStatus _VI_FUNC rssmf_SetFMRatio (ViSession instrumentHandle, ViReal64 ratio);
ViStatus _VI_FUNC rssmf_GetFMRatio (ViSession instrumentHandle, ViPReal64 ratio);
ViStatus _VI_FUNC rssmf_SetFMMode (ViSession instrumentHandle, ViInt32 mode);
ViStatus _VI_FUNC rssmf_GetFMMode (ViSession instrumentHandle, ViPInt32 mode);
ViStatus _VI_FUNC rssmf_confPM (ViSession instrumentHandle, ViInt32 channel,
                                ViBoolean state, ViInt32 PMSource,
                                ViReal64 deviation, ViReal64 ratio, ViInt32 mode);
ViStatus _VI_FUNC rssmf_SetPMState (ViSession instrumentHandle, ViInt32 channel,
                                    ViBoolean state);
ViStatus _VI_FUNC rssmf_GetPMState (ViSession instrumentHandle, ViInt32 channel,
                                    ViPBoolean state);
ViStatus _VI_FUNC rssmf_SetPMSource (ViSession instrumentHandle, ViInt32 channel,
                                     ViInt32 PMSource);
ViStatus _VI_FUNC rssmf_GetPMSource (ViSession instrumentHandle, ViInt32 channel,
                                     ViPInt32 PMSource);
ViStatus _VI_FUNC rssmf_SetPMDeviation (ViSession instrumentHandle, ViInt32 channel,
                                        ViReal64 deviation);
ViStatus _VI_FUNC rssmf_GetPMDeviation (ViSession instrumentHandle, ViInt32 channel,
                                        ViPReal64 deviation);
ViStatus _VI_FUNC rssmf_SetPMRatio (ViSession instrumentHandle, ViReal64 ratio);
ViStatus _VI_FUNC rssmf_GetPMRatio (ViSession instrumentHandle, ViPReal64 ratio);
ViStatus _VI_FUNC rssmf_SetPMMode (ViSession instrumentHandle, ViInt32 mode);
ViStatus _VI_FUNC rssmf_GetPMMode (ViSession instrumentHandle, ViPInt32 mode);
ViStatus _VI_FUNC rssmf_SetDMExternalInputsPolarity (ViSession instrumentHandle,
                                                     ViInt32 channel,
                                                     ViInt32 polarity);
ViStatus _VI_FUNC rssmf_GetDMExternalInputsPolarity (ViSession instrumentHandle,
                                                     ViInt32 channel,
                                                     ViPInt32 polarity);
ViStatus _VI_FUNC rssmf_configASK (ViSession instrumentHandle, ViBoolean ASKState,
                                   ViInt32 ASKSource, ViReal64 ASKDepth);
ViStatus _VI_FUNC rssmf_SetASKState (ViSession instrumentHandle,
                                     ViBoolean ASKState);
ViStatus _VI_FUNC rssmf_GetASKState (ViSession instrumentHandle,
                                     ViPBoolean ASKState);
ViStatus _VI_FUNC rssmf_SetASKSource (ViSession instrumentHandle,
                                      ViInt32 ASKSource);
ViStatus _VI_FUNC rssmf_GetASKSource (ViSession instrumentHandle,
                                      ViPInt32 ASKSource);
ViStatus _VI_FUNC rssmf_SetASKDepth (ViSession instrumentHandle, ViReal64 ASKDepth);
ViStatus _VI_FUNC rssmf_GetASKDepth (ViSession instrumentHandle,
                                     ViPReal64 ASKDepth);
ViStatus _VI_FUNC rssmf_configFSK (ViSession instrumentHandle, ViBoolean FSKState,
                                   ViInt32 FSKSource, ViReal64 FSKDeviation);
ViStatus _VI_FUNC rssmf_SetFSKState (ViSession instrumentHandle,
                                     ViBoolean FSKState);
ViStatus _VI_FUNC rssmf_GetFSKState (ViSession instrumentHandle,
                                     ViPBoolean FSKState);
ViStatus _VI_FUNC rssmf_SetFSKSource (ViSession instrumentHandle,
                                      ViInt32 FSKSource);
ViStatus _VI_FUNC rssmf_GetFSKSource (ViSession instrumentHandle,
                                      ViPInt32 FSKSource);
ViStatus _VI_FUNC rssmf_SetFSKDeviation (ViSession instrumentHandle,
                                         ViReal64 FSKDeviation);
ViStatus _VI_FUNC rssmf_GetFSKDeviation (ViSession instrumentHandle,
                                         ViPReal64 FSKDeviation);
ViStatus _VI_FUNC rssmf_configPSK (ViSession instrumentHandle, ViBoolean PSKState,
                                   ViInt32 PSKSource, ViReal64 PSKDeviation);
ViStatus _VI_FUNC rssmf_SetPSKState (ViSession instrumentHandle,
                                     ViBoolean PSKState);
ViStatus _VI_FUNC rssmf_GetPSKState (ViSession instrumentHandle,
                                     ViPBoolean PSKState);
ViStatus _VI_FUNC rssmf_SetPSKSource (ViSession instrumentHandle,
                                      ViInt32 PSKSource);
ViStatus _VI_FUNC rssmf_GetPSKSource (ViSession instrumentHandle,
                                      ViPInt32 PSKSource);
ViStatus _VI_FUNC rssmf_SetPSKDeviation (ViSession instrumentHandle,
                                         ViReal64 PSKDeviation);
ViStatus _VI_FUNC rssmf_GetPSKDeviation (ViSession instrumentHandle,
                                         ViPReal64 PSKDeviation);
ViStatus _VI_FUNC rssmf_confCHIRP (ViSession instrumentHandle, ViBoolean CHRIPState,
                                   ViInt32 direction, ViReal64 bandwidth,
                                   ViReal64 pulsePeriod, ViReal64 pulseWidth,
                                   ViInt32 triggerMode, ViInt32 triggerSlope,
                                   ViInt32 impedance);
ViStatus _VI_FUNC rssmf_confCHIRPTrigger (ViSession instrumentHandle,
                                          ViInt32 triggerSlope,
                                          ViInt32 gatePolarity, ViInt32 impedance,
                                          ViInt32 triggerMode,
                                          ViInt32 triggerLevel);
ViStatus _VI_FUNC rssmf_SetCHIRPTriggerMode (ViSession instrumentHandle,
                                             ViInt32 triggerMode);
ViStatus _VI_FUNC rssmf_GetCHIRPTriggerMode (ViSession instrumentHandle,
                                             ViPInt32 triggerMode);
ViStatus _VI_FUNC rssmf_SetCHIRPTriggerSlope (ViSession instrumentHandle,
                                              ViInt32 triggerSlope);
ViStatus _VI_FUNC rssmf_GetCHIRPTriggerSlope (ViSession instrumentHandle,
                                              ViPInt32 triggerSlope);
ViStatus _VI_FUNC rssmf_SetCHIRPTriggerLevel (ViSession instrumentHandle,
                                              ViInt32 triggerLevel);
ViStatus _VI_FUNC rssmf_GetCHIRPTriggerLevel (ViSession instrumentHandle,
                                              ViPInt32 triggerLevel);
ViStatus _VI_FUNC rssmf_SetCHIRPGatePolarity (ViSession instrumentHandle,
                                              ViInt32 gatePolarity);
ViStatus _VI_FUNC rssmf_GetCHIRPGatePolarity (ViSession instrumentHandle,
                                              ViPInt32 gatePolarity);
ViStatus _VI_FUNC rssmf_SetCHIRPExternalImpedance (ViSession instrumentHandle,
                                                   ViInt32 impedance);
ViStatus _VI_FUNC rssmf_GetCHIRPExternalImpedance (ViSession instrumentHandle,
                                                   ViPInt32 impedance);
ViStatus _VI_FUNC rssmf_SetCHIRPDirection (ViSession instrumentHandle,
                                           ViInt32 direction);
ViStatus _VI_FUNC rssmf_GetCHIRPDirection (ViSession instrumentHandle,
                                           ViPInt32 direction);
ViStatus _VI_FUNC rssmf_SetCHIRPState (ViSession instrumentHandle,
                                       ViBoolean CHRIPState);
ViStatus _VI_FUNC rssmf_GetCHIRPState (ViSession instrumentHandle,
                                       ViPBoolean CHRIPState);
ViStatus _VI_FUNC rssmf_SetCHIRPBandwidth (ViSession instrumentHandle,
                                           ViReal64 bandwidth);
ViStatus _VI_FUNC rssmf_GetCHIRPBandwidth (ViSession instrumentHandle,
                                           ViPReal64 bandwidth);
ViStatus _VI_FUNC rssmf_SetCHIRPPulsePeriod (ViSession instrumentHandle,
                                             ViReal64 pulsePeriod);
ViStatus _VI_FUNC rssmf_GetCHIRPPulsePeriod (ViSession instrumentHandle,
                                             ViPReal64 pulsePeriod);
ViStatus _VI_FUNC rssmf_SetCHIRPPulseWidth (ViSession instrumentHandle,
                                            ViReal64 pulseWidth);
ViStatus _VI_FUNC rssmf_GetCHIRPPulseWidth (ViSession instrumentHandle,
                                            ViPReal64 pulseWidth);
ViStatus _VI_FUNC rssmf_GetCHIRPCompressionRatio (ViSession instrumentHandle,
                                                  ViPReal64 compressionRatio);
ViStatus _VI_FUNC rssmf_SetOutputState (ViSession instrumentHandle,
                                        ViBoolean RFOutputState);
ViStatus _VI_FUNC rssmf_GetOutputState (ViSession instrumentHandle,
                                        ViPBoolean RFOutputState);
ViStatus _VI_FUNC rssmf_confRFFreq (ViSession instrumentHandle, ViReal64 frequency,
                                    ViReal64 offset, ViReal64 multiplier,
                                    ViBoolean variationActive,
                                    ViReal64 variationStep);
ViStatus _VI_FUNC rssmf_SetRFFrequency (ViSession instrumentHandle,
                                        ViReal64 frequency);
ViStatus _VI_FUNC rssmf_GetRFFrequency (ViSession instrumentHandle,
                                        ViPReal64 frequency);
ViStatus _VI_FUNC rssmf_SetRFFrequencyOffset (ViSession instrumentHandle,
                                              ViReal64 frequencyOffset);
ViStatus _VI_FUNC rssmf_GetRFFrequencyOffset (ViSession instrumentHandle,
                                              ViPReal64 frequencyOffset);
ViStatus _VI_FUNC rssmf_SetRFFrequencyMultiplier (ViSession instrumentHandle,
                                                  ViReal64 multiplier);
ViStatus _VI_FUNC rssmf_GetRFFrequencyMultiplier (ViSession instrumentHandle,
                                                  ViPReal64 multiplier);
ViStatus _VI_FUNC rssmf_SetRFVariationActive (ViSession instrumentHandle,
                                              ViBoolean variationActive);
ViStatus _VI_FUNC rssmf_GetRFVariationActive (ViSession instrumentHandle,
                                              ViPBoolean variationActive);
ViStatus _VI_FUNC rssmf_SetRFVariationStep (ViSession instrumentHandle,
                                            ViReal64 variationStep);
ViStatus _VI_FUNC rssmf_GetRFVariationStep (ViSession instrumentHandle,
                                            ViPReal64 variationStep);
ViStatus _VI_FUNC rssmf_SetRFFrequencyonRecall (ViSession instrumentHandle,
                                                ViInt32 RFFrequencyOnRecall);
ViStatus _VI_FUNC rssmf_GetRFFrequencyonRecall (ViSession instrumentHandle,
                                                ViPInt32 RFFrequencyOnRecall);
ViStatus _VI_FUNC rssmf_SetRFDeltaPhase (ViSession instrumentHandle,
                                         ViReal64 deltaPhase);
ViStatus _VI_FUNC rssmf_GetRFDeltaPhase (ViSession instrumentHandle,
                                         ViPReal64 deltaPhase);
ViStatus _VI_FUNC rssmf_ResetRFDeltaPhaseDisplay (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmf_confFrequencySweep (ViSession instrumentHandle,
                                            ViInt32 mode, ViInt32 frequencySetting,
                                            ViReal64 centerFrequency, ViReal64 span,
                                            ViReal64 startFrequency,
                                            ViReal64 stopFrequency, ViInt32 spacing,
                                            ViReal64 step, ViReal64 dwellTime);
ViStatus _VI_FUNC rssmf_FrequencySweepExecute (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmf_SetInstrumentTriggerInputSlope (ViSession instrumentHandle,
                                                        ViInt32 inputTriggerSlope);
ViStatus _VI_FUNC rssmf_ConfigureFrequencySweepMarker (ViSession instrumentHandle,
                                                       ViUInt32 channel,
                                                       ViBoolean state,
                                                       ViBoolean amplitudeMarker,
                                                       ViReal64 frequency,
                                                       ViReal64 amplitude,
                                                       ViInt32 polarity,
                                                       ViInt32 activeMarker);
ViStatus _VI_FUNC rssmf_SetFrequencySweepMode (ViSession instrumentHandle,
                                               ViInt32 mode);
ViStatus _VI_FUNC rssmf_SetFrequencySweepStartFreq (ViSession instrumentHandle,
                                                    ViReal64 startFrequency);
ViStatus _VI_FUNC rssmf_GetFrequencySweepStartFreq (ViSession instrumentHandle,
                                                    ViPReal64 startFrequency);
ViStatus _VI_FUNC rssmf_SetFrequencySweepStopFreq (ViSession instrumentHandle,
                                                   ViReal64 stopFrequency);
ViStatus _VI_FUNC rssmf_GetFrequencySweepStopFreq (ViSession instrumentHandle,
                                                   ViPReal64 stopFrequency);
ViStatus _VI_FUNC rssmf_SetFrequencySweepCenterFreq (ViSession instrumentHandle,
                                                     ViReal64 centerFrequency);
ViStatus _VI_FUNC rssmf_GetFrequencySweepCenterFreq (ViSession instrumentHandle,
                                                     ViPReal64 centerFrequency);
ViStatus _VI_FUNC rssmf_SetFrequencySweepSpan (ViSession instrumentHandle,
                                               ViReal64 span);
ViStatus _VI_FUNC rssmf_GetFrequencySweepSpan (ViSession instrumentHandle,
                                               ViPReal64 span);
ViStatus _VI_FUNC rssmf_SetFrequencySweepSpacing (ViSession instrumentHandle,
                                                  ViInt32 spacing);
ViStatus _VI_FUNC rssmf_GetFrequencySweepSpacing (ViSession instrumentHandle,
                                                  ViPInt32 spacing);
ViStatus _VI_FUNC rssmf_SetFrequencySweepStepLin (ViSession instrumentHandle,
                                                  ViReal64 stepLin);
ViStatus _VI_FUNC rssmf_GetFrequencySweepStepLin (ViSession instrumentHandle,
                                                  ViPReal64 stepLin);
ViStatus _VI_FUNC rssmf_SetFrequencySweepStepLog (ViSession instrumentHandle,
                                                  ViReal64 stepLog);
ViStatus _VI_FUNC rssmf_GetFrequencySweepStepLog (ViSession instrumentHandle,
                                                  ViPReal64 stepLog);
ViStatus _VI_FUNC rssmf_SetFrequencySweepTime (ViSession instrumentHandle,
                                               ViReal64 time);
ViStatus _VI_FUNC rssmf_GetFrequencySweepTime (ViSession instrumentHandle,
                                               ViPReal64 time);
ViStatus _VI_FUNC rssmf_SetFrequencySweepRampTime (ViSession instrumentHandle,
                                                   ViReal64 rampTime);
ViStatus _VI_FUNC rssmf_GetFrequencySweepRampTime (ViSession instrumentHandle,
                                                   ViPReal64 rampTime);
ViStatus _VI_FUNC rssmf_SetFrequencySweepDwellTime (ViSession instrumentHandle,
                                                    ViReal64 dwellTime);
ViStatus _VI_FUNC rssmf_GetFrequencySweepDwellTime (ViSession instrumentHandle,
                                                    ViPReal64 dwellTime);
ViStatus _VI_FUNC rssmf_SetFrequencySweepManualStep (ViSession instrumentHandle,
                                                     ViReal64 manualStep);
ViStatus _VI_FUNC rssmf_GetFrequencySweepManualStep (ViSession instrumentHandle,
                                                     ViPReal64 manualStep);
ViStatus _VI_FUNC rssmf_SetFrequencySweepPoints (ViSession instrumentHandle,
                                                 ViInt32 frequencySweepPoints);
ViStatus _VI_FUNC rssmf_GetFrequencySweepPoints (ViSession instrumentHandle,
                                                 ViPInt32 frequencySweepPoints);
ViStatus _VI_FUNC rssmf_GetInstrumentTriggerInputSlope (ViSession instrumentHandle,
                                                        ViPInt32 inputTriggerSlope);
ViStatus _VI_FUNC rssmf_SetFrequencySweepShape (ViSession instrumentHandle,
                                                ViInt32 shape);
ViStatus _VI_FUNC rssmf_GetFrequencySweepShape (ViSession instrumentHandle,
                                                ViPInt32 shape);
ViStatus _VI_FUNC rssmf_SetFrequencySweepMarkerState (ViSession instrumentHandle,
                                                      ViUInt32 channel,
                                                      ViBoolean state);
ViStatus _VI_FUNC rssmf_GetFrequencySweepMarkerState (ViSession instrumentHandle,
                                                      ViUInt32 channel,
                                                      ViPBoolean state);
ViStatus _VI_FUNC rssmf_SetFrequencySweepMarkerFrequency (ViSession instrumentHandle,
                                                          ViUInt32 channel,
                                                          ViReal64 frequency);
ViStatus _VI_FUNC rssmf_GetFrequencySweepMarkerFrequency (ViSession instrumentHandle,
                                                          ViUInt32 channel,
                                                          ViPReal64 frequency);
ViStatus _VI_FUNC rssmf_SetFrequencySweepAmplitudeMarkerState
             (ViSession instrumentHandle, ViUInt32 channel,
              ViBoolean amplitudeMarker);
ViStatus _VI_FUNC rssmf_GetFrequencySweepAmplitudeMarkerState
             (ViSession instrumentHandle, ViUInt32 channel,
              ViPBoolean amplitudeMarker);
ViStatus _VI_FUNC rssmf_SetFrequencySweepAmplitudeMarkerAttenuation
             (ViSession instrumentHandle, ViReal64 amplitude);
ViStatus _VI_FUNC rssmf_GetFrequencySweepAmplitudeMarkerAttenuation
             (ViSession instrumentHandle, ViPReal64 amplitude);
ViStatus _VI_FUNC rssmf_SetFrequencySweepMarkerPolarity (ViSession instrumentHandle,
                                                         ViInt32 polarity);
ViStatus _VI_FUNC rssmf_GetFrequencySweepMarkerPolarity (ViSession instrumentHandle,
                                                         ViPInt32 polarity);
ViStatus _VI_FUNC rssmf_SetFrequencySweepActiveMarker (ViSession instrumentHandle,
                                                       ViInt32 activeMarker);
ViStatus _VI_FUNC rssmf_GetFrequencySweepActiveMarker (ViSession instrumentHandle,
                                                       ViPInt32 activeMarker);
ViStatus _VI_FUNC rssmf_SetFrequencySweepAllMarkersOff (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmf_SetFrequencySweepMarkerTransfer
             (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmf_confList (ViSession instrumentHandle, ViString listName,
                                  ViInt32 listMode, ViInt32 arraySize,
                                  ViReal64 _VI_FAR frequencyValues[],
                                  ViReal64 _VI_FAR powerValues[],
                                  ViReal64 dwellTime);
ViStatus _VI_FUNC rssmf_LISTCatalog (ViSession instrumentHandle,
                                     ViString directoryPath, ViInt32 arraySize,
                                     ViChar _VI_FAR catalogList[]);
ViStatus _VI_FUNC rssmf_LISTDeleteList (ViSession instrumentHandle,
                                        ViString listName);
ViStatus _VI_FUNC rssmf_LISTDeleteAll (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmf_LISTResetList (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmf_LISTTriggerExecute (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmf_SetLISTMode (ViSession instrumentHandle, ViInt32 listMode);
ViStatus _VI_FUNC rssmf_SetLISTDwellTime (ViSession instrumentHandle,
                                          ViReal64 dwellTime);
ViStatus _VI_FUNC rssmf_GetLISTDwellTime (ViSession instrumentHandle,
                                          ViPReal64 dwellTime);
ViStatus _VI_FUNC rssmf_SetLISTSelectList (ViSession instrumentHandle,
                                           ViString listName);
ViStatus _VI_FUNC rssmf_GetLISTSelectList (ViSession instrumentHandle,
                                           ViChar _VI_FAR listName[]);
ViStatus _VI_FUNC rssmf_SetLISTFrequencyValues (ViSession instrumentHandle,
                                                ViInt32 arraySize,
                                                ViReal64 _VI_FAR frequencyValues[]);
ViStatus _VI_FUNC rssmf_GetLISTFrequencyValues (ViSession instrumentHandle,
                                                ViInt32 arraySize,
                                                ViReal64 _VI_FAR frequencyValues[]);
ViStatus _VI_FUNC rssmf_GetLISTFrequencyPoints (ViSession instrumentHandle,
                                                ViPInt32 numberOfFrequencyPoints);
ViStatus _VI_FUNC rssmf_SetLISTPowerValues (ViSession instrumentHandle,
                                            ViInt32 arraySize,
                                            ViReal64 _VI_FAR powerValues[]);
ViStatus _VI_FUNC rssmf_GetLISTPowerValues (ViSession instrumentHandle,
                                            ViInt32 arraySize,
                                            ViReal64 _VI_FAR powerValues[]);
ViStatus _VI_FUNC rssmf_GetLISTPowerPoints (ViSession instrumentHandle,
                                            ViPInt32 numberOfPowerPoints);
ViStatus _VI_FUNC rssmf_SetLISTAttenuatorMode (ViSession instrumentHandle,
                                               ViInt32 attenuatorMode);
ViStatus _VI_FUNC rssmf_GetLISTAttenuatorMode (ViSession instrumentHandle,
                                               ViPInt32 attenuatorMode);
ViStatus _VI_FUNC rssmf_SetLISTStepIndex (ViSession instrumentHandle,
                                          ViInt32 stepIndex);
ViStatus _VI_FUNC rssmf_GetLISTStepIndex (ViSession instrumentHandle,
                                          ViPInt32 stepIndex);
ViStatus _VI_FUNC rssmf_SetLISTStartIndex (ViSession instrumentHandle,
                                           ViInt32 startIndex);
ViStatus _VI_FUNC rssmf_GetLISTStartIndex (ViSession instrumentHandle,
                                           ViPInt32 startIndex);
ViStatus _VI_FUNC rssmf_SetLISTStopIndex (ViSession instrumentHandle,
                                          ViInt32 stopIndex);
ViStatus _VI_FUNC rssmf_GetLISTStopIndex (ViSession instrumentHandle,
                                          ViPInt32 stopIndex);
ViStatus _VI_FUNC rssmf_LearnLISTModeData (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmf_SetLISTImportExportListMode (ViSession instrumentHandle,
                                                     ViInt32 listMode);
ViStatus _VI_FUNC rssmf_GetLISTImportExportListMode (ViSession instrumentHandle,
                                                     ViPInt32 listMode);
ViStatus _VI_FUNC rssmf_SetLISTImportExportListFile (ViSession instrumentHandle,
                                                     ViString sourceFile);
ViStatus _VI_FUNC rssmf_GetLISTImportExportListFile (ViSession instrumentHandle,
                                                     ViChar _VI_FAR sourceFile[]);
ViStatus _VI_FUNC rssmf_ImportExportExecute (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmf_SetLISTImportExportASCIIFile (ViSession instrumentHandle,
                                                      ViString ASCIISourceFile);
ViStatus _VI_FUNC rssmf_GetLISTImportExportASCIIFile (ViSession instrumentHandle,
                                                      ViChar _VI_FAR ASCIISourceFile[]);
ViStatus _VI_FUNC rssmf_SetLISTImportExportASCIIExtension
             (ViSession instrumentHandle, ViInt32 extension);
ViStatus _VI_FUNC rssmf_GetLISTImportExportASCIIExtension
             (ViSession instrumentHandle, ViPInt32 extension);
ViStatus _VI_FUNC rssmf_SetLISTImportExportASCIIColumnSeparator
             (ViSession instrumentHandle, ViInt32 separator);
ViStatus _VI_FUNC rssmf_GetLISTImportExportASCIIColumnSeparator
             (ViSession instrumentHandle, ViPInt32 separator);
ViStatus _VI_FUNC rssmf_SetLISTImportExportASCIIColumnDecimalSeparator
             (ViSession instrumentHandle, ViInt32 decimalSeparator);
ViStatus _VI_FUNC rssmf_GetLISTImportExportASCIIColumnDecimalSeparator
             (ViSession instrumentHandle, ViPInt32 decimalSeparator);
ViStatus _VI_FUNC rssmf_LISTImportExportCatalog (ViSession instrumentHandle,
                                                 ViInt32 arraySize,
                                                 ViChar _VI_FAR catalogList[]);
ViStatus _VI_FUNC rssmf_confRosc (ViSession instrumentHandle, ViInt32 ROSCSource,
                                  ViInt32 externalReferenceFrequency,
                                  ViInt32 ROSCSynchronizationBandwidth,
                                  ViInt32 ROSCOutput, ViBoolean EFCState,
                                  ViBoolean adjustmentActive,
                                  ViInt32 adjustmentFrequency);
ViStatus _VI_FUNC rssmf_SetROSCSource (ViSession instrumentHandle,
                                       ViInt32 ROSCSource);
ViStatus _VI_FUNC rssmf_GetROSCSource (ViSession instrumentHandle,
                                       ViPInt32 ROSCSource);
ViStatus _VI_FUNC rssmf_SetROSCRFOutput (ViSession instrumentHandle,
                                         ViBoolean RFOutput);
ViStatus _VI_FUNC rssmf_GetROSCRFOutput (ViSession instrumentHandle,
                                         ViPBoolean RFOutput);
ViStatus _VI_FUNC rssmf_SetROSCExternalReferenceFrequency
             (ViSession instrumentHandle, ViInt32 externalReferenceFrequency);
ViStatus _VI_FUNC rssmf_GetROSCExternalReferenceFrequency
             (ViSession instrumentHandle, ViPInt32 externalReferenceFrequency);
ViStatus _VI_FUNC rssmf_SetROSCSynchronizationBandwidth (ViSession instrumentHandle,
                                                         ViInt32 ROSCSynchronizationBandwidth);
ViStatus _VI_FUNC rssmf_GetROSCSynchronizationBandwidth (ViSession instrumentHandle,
                                                         ViPInt32 ROSCSynchronizationBandwidth);
ViStatus _VI_FUNC rssmf_SetROSCOutput (ViSession instrumentHandle,
                                       ViInt32 ROSCOutput);
ViStatus _VI_FUNC rssmf_GetROSCOutput (ViSession instrumentHandle,
                                       ViPInt32 ROSCOutput);
ViStatus _VI_FUNC rssmf_SetROSCEFCState (ViSession instrumentHandle,
                                         ViBoolean EFCState);
ViStatus _VI_FUNC rssmf_GetROSCEFCState (ViSession instrumentHandle,
                                         ViPBoolean EFCState);
ViStatus _VI_FUNC rssmf_SetROSCAdjustmentActive (ViSession instrumentHandle,
                                                 ViBoolean adjustmentActive);
ViStatus _VI_FUNC rssmf_GetROSCAdjustmentActive (ViSession instrumentHandle,
                                                 ViPBoolean adjustmentActive);
ViStatus _VI_FUNC rssmf_SetROSCAdjustmentFrequency (ViSession instrumentHandle,
                                                    ViInt32 adjustmentFrequency);
ViStatus _VI_FUNC rssmf_GetROSCAdjustmentFrequency (ViSession instrumentHandle,
                                                    ViPInt32 adjustmentFrequency);
ViStatus _VI_FUNC rssmf_confPowerSense (ViSession instrumentHandle, ViInt32 sense,
                                        ViBoolean initPowerMeas, ViInt32 unit,
                                        ViBoolean permanentDisplay, ViInt32 source,
                                        ViReal64 frequency, ViInt32 filterMode,
                                        ViBoolean useSParameters);
ViStatus _VI_FUNC rssmf_confPowerResponseMeasurement (ViSession instrumentHandle,
                                                      ViInt32 sense,
                                                      ViInt32 sweepMode,
                                                      ViReal64 start, ViReal64 stop,
                                                      ViInt32 timing, ViInt32 steps,
                                                      ViInt32 spacing);
ViStatus _VI_FUNC rssmf_confPowerResponseMeasurementDiagram
             (ViSession instrumentHandle, ViInt32 sense,
              ViReal64 frequencyYScaleMinimum, ViReal64 frequencyYScaleMaximum,
              ViReal64 powerYScaleMinimum, ViReal64 powerYScaleMaximum,
              ViInt32 senseMode);
ViStatus _VI_FUNC rssmf_PowerZero (ViSession instrumentHandle, ViInt32 sense);
ViStatus _VI_FUNC rssmf_SetInitiatePowerMeasurement (ViSession instrumentHandle,
                                                     ViInt32 sense,
                                                     ViBoolean initPowerMeas);
ViStatus _VI_FUNC rssmf_GetInitiatePowerMeasurement (ViSession instrumentHandle,
                                                     ViInt32 sense,
                                                     ViPBoolean initPowerMeas);
ViStatus _VI_FUNC rssmf_GetPowerUseSParameters (ViSession instrumentHandle,
                                                ViInt32 sense,
                                                ViPBoolean useSParameters);
ViStatus _VI_FUNC rssmf_SetPowerFrequency (ViSession instrumentHandle,
                                           ViInt32 sense, ViReal64 frequency);
ViStatus _VI_FUNC rssmf_GetPowerFrequency (ViSession instrumentHandle,
                                           ViInt32 sense, ViPReal64 frequency);
ViStatus _VI_FUNC rssmf_SetPowerOffset (ViSession instrumentHandle, ViInt32 sense,
                                        ViReal64 offset);
ViStatus _VI_FUNC rssmf_GetPowerOffset (ViSession instrumentHandle, ViInt32 sense,
                                        ViPReal64 offset);
ViStatus _VI_FUNC rssmf_SetPowerOffsetState (ViSession instrumentHandle,
                                             ViInt32 sense, ViBoolean offsetState);
ViStatus _VI_FUNC rssmf_GetPowerOffsetState (ViSession instrumentHandle,
                                             ViInt32 sense, ViPBoolean offsetState);
ViStatus _VI_FUNC rssmf_SetPowerSource (ViSession instrumentHandle, ViInt32 sense,
                                        ViInt32 source);
ViStatus _VI_FUNC rssmf_GetPowerSource (ViSession instrumentHandle, ViInt32 sense,
                                        ViPInt32 source);
ViStatus _VI_FUNC rssmf_SetPowerUnit (ViSession instrumentHandle, ViInt32 sense,
                                      ViInt32 unit);
ViStatus _VI_FUNC rssmf_GetPowerUnit (ViSession instrumentHandle, ViInt32 sense,
                                      ViPInt32 unit);
ViStatus _VI_FUNC rssmf_SetPowerDisplayPermanentState (ViSession instrumentHandle,
                                                       ViInt32 sense,
                                                       ViBoolean permanentDisplay);
ViStatus _VI_FUNC rssmf_GetPowerDisplayPermanentState (ViSession instrumentHandle,
                                                       ViInt32 sense,
                                                       ViPBoolean permanentDisplay);
ViStatus _VI_FUNC rssmf_SetPowerDisplayPermanentPriority (ViSession instrumentHandle,
                                                          ViInt32 trace,
                                                          ViInt32 priority);
ViStatus _VI_FUNC rssmf_GetPowerDisplayPermanentPriority (ViSession instrumentHandle,
                                                          ViInt32 trace,
                                                          ViPInt32 priority);
ViStatus _VI_FUNC rssmf_confPowerFilter (ViSession instrumentHandle, ViInt32 sense,
                                         ViInt32 filterMode, ViReal64 noiseContent,
                                         ViReal64 timeout);
ViStatus _VI_FUNC rssmf_SetPowerFilterLength (ViSession instrumentHandle,
                                              ViInt32 sense, ViInt32 filterLength);
ViStatus _VI_FUNC rssmf_GetPowerFilterLength (ViSession instrumentHandle,
                                              ViInt32 sense, ViPInt32 filterLength);
ViStatus _VI_FUNC rssmf_SetPowerFilterMode (ViSession instrumentHandle,
                                            ViInt32 sense, ViInt32 filterMode);
ViStatus _VI_FUNC rssmf_GetPowerFilterMode (ViSession instrumentHandle,
                                            ViInt32 sense, ViPInt32 filterMode);
ViStatus _VI_FUNC rssmf_SetPowerFilterFixedNoiseContent (ViSession instrumentHandle,
                                                         ViInt32 sense,
                                                         ViReal64 noiseContent);
ViStatus _VI_FUNC rssmf_GetPowerFilterFixedNoiseContent (ViSession instrumentHandle,
                                                         ViInt32 sense,
                                                         ViPReal64 noiseContent);
ViStatus _VI_FUNC rssmf_SetPowerFilterFixedNoiseTimeout (ViSession instrumentHandle,
                                                         ViInt32 sense,
                                                         ViReal64 timeout);
ViStatus _VI_FUNC rssmf_GetPowerFilterFixedNoiseTimeout (ViSession instrumentHandle,
                                                         ViInt32 sense,
                                                         ViPReal64 timeout);
ViStatus _VI_FUNC rssmf_GetPowerFilterLengthAuto (ViSession instrumentHandle,
                                                  ViInt32 sense,
                                                  ViPInt32 filterLengthAuto);
ViStatus _VI_FUNC rssmf_PowerFilterSearchOnce (ViSession instrumentHandle,
                                               ViInt32 sense);
ViStatus _VI_FUNC rssmf_SetPowerSensorGateState (ViSession instrumentHandle,
                                                 ViBoolean state);
ViStatus _VI_FUNC rssmf_GetPowerSensorGateState (ViSession instrumentHandle,
                                                 ViPBoolean state);
ViStatus _VI_FUNC rssmf_SetPowerSensorGateStart (ViSession instrumentHandle,
                                                 ViInt32 gate, ViReal64 start);
ViStatus _VI_FUNC rssmf_GetPowerSensorGateStart (ViSession instrumentHandle,
                                                 ViInt32 gate, ViPReal64 start);
ViStatus _VI_FUNC rssmf_SetPowerSensorGateStop (ViSession instrumentHandle,
                                                ViInt32 gate, ViReal64 stop);
ViStatus _VI_FUNC rssmf_GetPowerSensorGateStop (ViSession instrumentHandle,
                                                ViInt32 gate, ViPReal64 stop);
ViStatus _VI_FUNC rssmf_SetPowerSensorGateTrace (ViSession instrumentHandle,
                                                 ViInt32 trace);
ViStatus _VI_FUNC rssmf_GetPowerSensorGateTrace (ViSession instrumentHandle,
                                                 ViPInt32 trace);
ViStatus _VI_FUNC rssmf_GetPowerSensorGateAveragePower (ViSession instrumentHandle,
                                                        ViInt32 gate,
                                                        ViPReal64 averagePower);
ViStatus _VI_FUNC rssmf_GetPowerSensorGatePeakPower (ViSession instrumentHandle,
                                                     ViInt32 gate,
                                                     ViPReal64 peakPower);
ViStatus _VI_FUNC rssmf_PowerSweepInitiate (ViSession instrumentHandle,
                                            ViInt32 sense, ViInt32 timeout);
ViStatus _VI_FUNC rssmf_PowerSweepAbort (ViSession instrumentHandle, ViInt32 sense);
ViStatus _VI_FUNC rssmf_confPowerSweepFrequencySeparateFrequencyRange
             (ViSession instrumentHandle, ViInt32 sense, ViBoolean state,
              ViReal64 separateFrequencyStart, ViReal64 separateFrequencyStop);
ViStatus _VI_FUNC rssmf_SetPowerSweepFrequencyStart (ViSession instrumentHandle,
                                                     ViInt32 sense,
                                                     ViReal64 frequencyStart);
ViStatus _VI_FUNC rssmf_GetPowerSweepFrequencyStart (ViSession instrumentHandle,
                                                     ViInt32 sense,
                                                     ViPReal64 frequencyStart);
ViStatus _VI_FUNC rssmf_SetPowerSweepFrequencyStop (ViSession instrumentHandle,
                                                    ViInt32 sense,
                                                    ViReal64 frequencyStop);
ViStatus _VI_FUNC rssmf_GetPowerSweepFrequencyStop (ViSession instrumentHandle,
                                                    ViInt32 sense,
                                                    ViPReal64 frequencyStop);
ViStatus _VI_FUNC rssmf_SetPowerSweepFrequencySlope (ViSession instrumentHandle,
                                                     ViInt32 sense,
                                                     ViInt32 triggerSlope);
ViStatus _VI_FUNC rssmf_GetPowerSweepFrequencySlope (ViSession instrumentHandle,
                                                     ViInt32 sense,
                                                     ViPInt32 triggerSlope);
ViStatus _VI_FUNC rssmf_SetPowerSweepFrequencyTiming (ViSession instrumentHandle,
                                                      ViInt32 sense,
                                                      ViInt32 frequencyTiming);
ViStatus _VI_FUNC rssmf_GetPowerSweepFrequencyTiming (ViSession instrumentHandle,
                                                      ViInt32 sense,
                                                      ViPInt32 frequencyTiming);
ViStatus _VI_FUNC rssmf_SetPowerSweepFrequencySpacing (ViSession instrumentHandle,
                                                       ViInt32 sense,
                                                       ViInt32 frequencySpacing);
ViStatus _VI_FUNC rssmf_GetPowerSweepFrequencySpacing (ViSession instrumentHandle,
                                                       ViInt32 sense,
                                                       ViPInt32 frequencySpacing);
ViStatus _VI_FUNC rssmf_SetPowerSweepFrequencySteps (ViSession instrumentHandle,
                                                     ViInt32 sense,
                                                     ViInt32 frequencySteps);
ViStatus _VI_FUNC rssmf_GetPowerSweepFrequencySteps (ViSession instrumentHandle,
                                                     ViInt32 sense,
                                                     ViPInt32 frequencySteps);
ViStatus _VI_FUNC rssmf_SetPowerSweepFrequencyYScaleMinimum
             (ViSession instrumentHandle, ViInt32 sense, ViReal64 yScaleMinimum);
ViStatus _VI_FUNC rssmf_GetPowerSweepFrequencyYScaleMinimum
             (ViSession instrumentHandle, ViInt32 sense, ViPReal64 yScaleMinimum);
ViStatus _VI_FUNC rssmf_SetPowerSweepFrequencyYScaleMaximum
             (ViSession instrumentHandle, ViInt32 sense, ViReal64 yScaleMaximum);
ViStatus _VI_FUNC rssmf_GetPowerSweepFrequencyYScaleMaximum
             (ViSession instrumentHandle, ViInt32 sense, ViPReal64 yScaleMaximum);
ViStatus _VI_FUNC rssmf_SetPowerSweepFrequencyExecution (ViSession instrumentHandle,
                                                         ViInt32 execution);
ViStatus _VI_FUNC rssmf_GetPowerSweepFrequencyExecution (ViSession instrumentHandle,
                                                         ViPInt32 execution);
ViStatus _VI_FUNC rssmf_SetPowerSweepFrequencyYAutoScale (ViSession instrumentHandle,
                                                          ViInt32 autoScale);
ViStatus _VI_FUNC rssmf_GetPowerSweepFrequencyYAutoScale (ViSession instrumentHandle,
                                                          ViPInt32 autoScale);
ViStatus _VI_FUNC rssmf_ResetPowerSweepFrequencyYScale (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmf_SetPowerSweepFrequencySeparateFrequencyRange
             (ViSession instrumentHandle, ViInt32 sense, ViBoolean state);
ViStatus _VI_FUNC rssmf_GetPowerSweepFrequencySeparateFrequencyRange
             (ViSession instrumentHandle, ViInt32 sense, ViPBoolean state);
ViStatus _VI_FUNC rssmf_SetPowerSweepFrequencySeparateFrequencyStart
             (ViSession instrumentHandle, ViInt32 sense,
              ViReal64 separateFrequencyStart);
ViStatus _VI_FUNC rssmf_GetPowerSweepFrequencySeparateFrequencyStart
             (ViSession instrumentHandle, ViInt32 sense,
              ViPReal64 separateFrequencyStart);
ViStatus _VI_FUNC rssmf_SetPowerSweepFrequencySeparateFrequencyStop
             (ViSession instrumentHandle, ViInt32 sense,
              ViReal64 separateFrequencyStop);
ViStatus _VI_FUNC rssmf_GetPowerSweepFrequencySeparateFrequencyStop
             (ViSession instrumentHandle, ViInt32 sense,
              ViPReal64 separateFrequencyStop);
ViStatus _VI_FUNC rssmf_SetPowerSweepFrequencyReferenceXValues
             (ViSession instrumentHandle, ViReal64 frequencyXPointA,
              ViReal64 frequencyXPointB);
ViStatus _VI_FUNC rssmf_GetPowerSweepFrequencyReferenceXValues
             (ViSession instrumentHandle, ViPReal64 frequencyXPointA,
              ViPReal64 frequencyXPointB);
ViStatus _VI_FUNC rssmf_SetPowerSweepFrequencyReferenceYValues
             (ViSession instrumentHandle, ViReal64 powerYPointA,
              ViReal64 powerYPointB);
ViStatus _VI_FUNC rssmf_GetPowerSweepFrequencyReferenceYValues
             (ViSession instrumentHandle, ViPReal64 powerYPointA,
              ViPReal64 powerYPointB);
ViStatus _VI_FUNC rssmf_GeneratePowerSweepFrequencyReferenceCurve
             (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmf_confPowerSweepPowerSeparateFrequencyRange
             (ViSession instrumentHandle, ViInt32 sense, ViBoolean state,
              ViReal64 separateFrequency);
ViStatus _VI_FUNC rssmf_SetPowerSweepPowerStart (ViSession instrumentHandle,
                                                 ViInt32 sense,
                                                 ViReal64 powerStart);
ViStatus _VI_FUNC rssmf_GetPowerSweepPowerStart (ViSession instrumentHandle,
                                                 ViInt32 sense,
                                                 ViPReal64 powerStart);
ViStatus _VI_FUNC rssmf_SetPowerSweepPowerStop (ViSession instrumentHandle,
                                                ViInt32 sense, ViReal64 powerStop);
ViStatus _VI_FUNC rssmf_GetPowerSweepPowerStop (ViSession instrumentHandle,
                                                ViInt32 sense, ViPReal64 powerStop);
ViStatus _VI_FUNC rssmf_SetPowerSweepPowerSpacing (ViSession instrumentHandle,
                                                   ViInt32 sense,
                                                   ViInt32 powerSpacing);
ViStatus _VI_FUNC rssmf_GetPowerSweepPowerSpacing (ViSession instrumentHandle,
                                                   ViInt32 sense,
                                                   ViPInt32 powerSpacing);
ViStatus _VI_FUNC rssmf_SetPowerSweepPowerTiming (ViSession instrumentHandle,
                                                  ViInt32 sense,
                                                  ViInt32 powerTiming);
ViStatus _VI_FUNC rssmf_GetPowerSweepPowerTiming (ViSession instrumentHandle,
                                                  ViInt32 sense,
                                                  ViPInt32 powerTiming);
ViStatus _VI_FUNC rssmf_SetPowerSweepPowerSteps (ViSession instrumentHandle,
                                                 ViInt32 sense, ViInt32 powerSteps);
ViStatus _VI_FUNC rssmf_GetPowerSweepPowerSteps (ViSession instrumentHandle,
                                                 ViInt32 sense,
                                                 ViPInt32 powerSteps);
ViStatus _VI_FUNC rssmf_SetPowerSweepPowerYScaleMinimum (ViSession instrumentHandle,
                                                         ViInt32 sense,
                                                         ViReal64 yScaleMinimum);
ViStatus _VI_FUNC rssmf_GetPowerSweepPowerYScaleMinimum (ViSession instrumentHandle,
                                                         ViInt32 sense,
                                                         ViPReal64 yScaleMinimum);
ViStatus _VI_FUNC rssmf_SetPowerSweepPowerYScaleMaximum (ViSession instrumentHandle,
                                                         ViInt32 sense,
                                                         ViReal64 yScaleMaximum);
ViStatus _VI_FUNC rssmf_GetPowerSweepPowerYScaleMaximum (ViSession instrumentHandle,
                                                         ViInt32 sense,
                                                         ViPReal64 yScaleMaximum);
ViStatus _VI_FUNC rssmf_SetPowerSweepPowerExecution (ViSession instrumentHandle,
                                                     ViInt32 execution);
ViStatus _VI_FUNC rssmf_GetPowerSweepPowerExecution (ViSession instrumentHandle,
                                                     ViPInt32 execution);
ViStatus _VI_FUNC rssmf_SetPowerSweepPowerYAutoScale (ViSession instrumentHandle,
                                                      ViInt32 autoScale);
ViStatus _VI_FUNC rssmf_GetPowerSweepPowerYAutoScale (ViSession instrumentHandle,
                                                      ViPInt32 autoScale);
ViStatus _VI_FUNC rssmf_ResetPowerSweepPowerYScale (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmf_SetPowerSweepPowerSeparateFrequencyState
             (ViSession instrumentHandle, ViInt32 sense, ViBoolean state);
ViStatus _VI_FUNC rssmf_GetPowerSweepPowerSeparateFrequencyState
             (ViSession instrumentHandle, ViInt32 sense, ViPBoolean state);
ViStatus _VI_FUNC rssmf_SetPowerSweepPowerSeparateFrequency
             (ViSession instrumentHandle, ViInt32 sense,
              ViReal64 separateFrequency);
ViStatus _VI_FUNC rssmf_GetPowerSweepPowerSeparateFrequency
             (ViSession instrumentHandle, ViInt32 sense,
              ViPReal64 separateFrequency);
ViStatus _VI_FUNC rssmf_SetPowerSweepPowerReferenceXValues
             (ViSession instrumentHandle, ViReal64 powerXPointA,
              ViReal64 powerXPointB);
ViStatus _VI_FUNC rssmf_GetPowerSweepPowerReferenceXValues
             (ViSession instrumentHandle, ViPReal64 powerXPointA,
              ViPReal64 powerXPointB);
ViStatus _VI_FUNC rssmf_SetPowerSweepPowerReferenceYValues
             (ViSession instrumentHandle, ViReal64 powerYPointA,
              ViReal64 powerYPointB);
ViStatus _VI_FUNC rssmf_GetPowerSweepPowerReferenceYValues
             (ViSession instrumentHandle, ViPReal64 powerYPointA,
              ViPReal64 powerYPointB);
ViStatus _VI_FUNC rssmf_GetPowerSweepPowerReferenceNumberOfPoints
             (ViSession instrumentHandle, ViPReal64 numberOfPoints);
ViStatus _VI_FUNC rssmf_GeneratePowerSweepPowerReferenceCurve
             (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmf_confPowerSweepTimeSeparateFrequencyRange
             (ViSession instrumentHandle, ViInt32 sense, ViBoolean state,
              ViReal64 separateFrequency);
ViStatus _VI_FUNC rssmf_SetPowerSweepTimePulseDataAnalysisState
             (ViSession instrumentHandle, ViInt32 sense, ViBoolean state);
ViStatus _VI_FUNC rssmf_GetPowerSweepTimePulseDataAnalysisState
             (ViSession instrumentHandle, ViInt32 sense, ViPBoolean state);
ViStatus _VI_FUNC rssmf_SetPowerSweepTimePulseThresholdBase
             (ViSession instrumentHandle, ViInt32 sense, ViInt32 base);
ViStatus _VI_FUNC rssmf_GetPowerSweepTimePulseThresholdBase
             (ViSession instrumentHandle, ViInt32 sense, ViPInt32 base);
ViStatus _VI_FUNC rssmf_SetPowerSweepTimePulseThresholdReferenceLevel
             (ViSession instrumentHandle, ViInt32 sense, ViInt32 mode,
              ViReal64 referenceLevel);
ViStatus _VI_FUNC rssmf_GetPowerSweepTimePulseThresholdReferenceLevel
             (ViSession instrumentHandle, ViInt32 sense, ViInt32 mode,
              ViPReal64 referenceLevel);
ViStatus _VI_FUNC rssmf_SetPowerSweepTimeTriggerSource (ViSession instrumentHandle,
                                                        ViInt32 sense,
                                                        ViInt32 source);
ViStatus _VI_FUNC rssmf_GetPowerSweepTimeTriggerSource (ViSession instrumentHandle,
                                                        ViInt32 sense,
                                                        ViPInt32 source);
ViStatus _VI_FUNC rssmf_SetPowerSweepTimeTriggerDropOutTime
             (ViSession instrumentHandle, ViInt32 sense, ViReal64 dropOutTime);
ViStatus _VI_FUNC rssmf_GetPowerSweepTimeTriggerDropOutTime
             (ViSession instrumentHandle, ViInt32 sense, ViPReal64 dropOutTime);
ViStatus _VI_FUNC rssmf_SetPowerSweepTimeTriggerHysteresis
             (ViSession instrumentHandle, ViInt32 sense, ViReal64 hysteresis);
ViStatus _VI_FUNC rssmf_GetPowerSweepTimeTriggerHysteresis
             (ViSession instrumentHandle, ViInt32 sense, ViPReal64 hysteresis);
ViStatus _VI_FUNC rssmf_SetPowerSweepTimeTriggerThreshold
             (ViSession instrumentHandle, ViInt32 sense, ViReal64 threshold);
ViStatus _VI_FUNC rssmf_GetPowerSweepTimeTriggerThreshold
             (ViSession instrumentHandle, ViInt32 sense, ViPReal64 threshold);
ViStatus _VI_FUNC rssmf_SetPowerSweepTimeTriggerAutoSet (ViSession instrumentHandle,
                                                         ViInt32 sense,
                                                         ViInt32 timeout);
ViStatus _VI_FUNC rssmf_SetPowerSweepTimeStart (ViSession instrumentHandle,
                                                ViInt32 sense, ViReal64 timeStart);
ViStatus _VI_FUNC rssmf_GetPowerSweepTimeStart (ViSession instrumentHandle,
                                                ViInt32 sense, ViPReal64 timeStart);
ViStatus _VI_FUNC rssmf_SetPowerSweepTimeStop (ViSession instrumentHandle,
                                               ViInt32 sense, ViReal64 timeStop);
ViStatus _VI_FUNC rssmf_GetPowerSweepTimeStop (ViSession instrumentHandle,
                                               ViInt32 sense, ViPReal64 timeStop);
ViStatus _VI_FUNC rssmf_SetPowerSweepTimeTriggerEvents (ViSession instrumentHandle,
                                                        ViInt32 sense,
                                                        ViInt32 triggerEvents);
ViStatus _VI_FUNC rssmf_GetPowerSweepTimeTriggerEvents (ViSession instrumentHandle,
                                                        ViInt32 sense,
                                                        ViPInt32 triggerEvents);
ViStatus _VI_FUNC rssmf_SetPowerSweepTimeSpacing (ViSession instrumentHandle,
                                                  ViInt32 sense,
                                                  ViInt32 timeSpacing);
ViStatus _VI_FUNC rssmf_GetPowerSweepTimeSpacing (ViSession instrumentHandle,
                                                  ViInt32 sense,
                                                  ViPInt32 timeSpacing);
ViStatus _VI_FUNC rssmf_SetPowerSweepTimeAveragingFactor (ViSession instrumentHandle,
                                                          ViInt32 averagingFactor);
ViStatus _VI_FUNC rssmf_GetPowerSweepTimeAveragingFactor (ViSession instrumentHandle,
                                                          ViPInt32 averagingFactor);
ViStatus _VI_FUNC rssmf_SetPowerSweepTimeSteps (ViSession instrumentHandle,
                                                ViInt32 sense, ViInt32 timeSteps);
ViStatus _VI_FUNC rssmf_GetPowerSweepTimeSteps (ViSession instrumentHandle,
                                                ViInt32 sense, ViPInt32 timeSteps);
ViStatus _VI_FUNC rssmf_SetPowerTimeTriggerSource (ViSession instrumentHandle,
                                                   ViInt32 sense, ViInt32 source);
ViStatus _VI_FUNC rssmf_GetPowerTimeTriggerSource (ViSession instrumentHandle,
                                                   ViInt32 sense, ViPInt32 source);
ViStatus _VI_FUNC rssmf_SetPowerSweepTimeYScaleMinimum (ViSession instrumentHandle,
                                                        ViInt32 sense,
                                                        ViReal64 yScaleMinimum);
ViStatus _VI_FUNC rssmf_GetPowerSweepTimeYScaleMinimum (ViSession instrumentHandle,
                                                        ViInt32 sense,
                                                        ViPReal64 yScaleMinimum);
ViStatus _VI_FUNC rssmf_SetPowerSweepTimeYScaleMaximum (ViSession instrumentHandle,
                                                        ViInt32 sense,
                                                        ViReal64 yScaleMaximum);
ViStatus _VI_FUNC rssmf_GetPowerSweepTimeYScaleMaximum (ViSession instrumentHandle,
                                                        ViInt32 sense,
                                                        ViPReal64 yScaleMaximum);
ViStatus _VI_FUNC rssmf_SetPowerSweepTimeExecution (ViSession instrumentHandle,
                                                    ViInt32 execution);
ViStatus _VI_FUNC rssmf_GetPowerSweepTimeExecution (ViSession instrumentHandle,
                                                    ViPInt32 execution);
ViStatus _VI_FUNC rssmf_SetPowerSweepTimeYAutoScale (ViSession instrumentHandle,
                                                     ViInt32 autoScale);
ViStatus _VI_FUNC rssmf_GetPowerSweepTimeYAutoScale (ViSession instrumentHandle,
                                                     ViPInt32 autoScale);
ViStatus _VI_FUNC rssmf_ResetPowerSweepTimeYScale (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmf_SetPowerSweepTimeSeparateFrequencyState
             (ViSession instrumentHandle, ViInt32 sense, ViBoolean state);
ViStatus _VI_FUNC rssmf_GetPowerSweepTimeSeparateFrequencyState
             (ViSession instrumentHandle, ViInt32 sense, ViPBoolean state);
ViStatus _VI_FUNC rssmf_SetPowerSweepTimeSeparateFrequency
             (ViSession instrumentHandle, ViInt32 sense,
              ViReal64 separateFrequency);
ViStatus _VI_FUNC rssmf_GetPowerSweepTimeSeparateFrequency
             (ViSession instrumentHandle, ViInt32 sense,
              ViPReal64 separateFrequency);
ViStatus _VI_FUNC rssmf_SetPowerSweepTimeReferenceXValues
             (ViSession instrumentHandle, ViReal64 timeXPointA,
              ViReal64 timeXPointB);
ViStatus _VI_FUNC rssmf_GetPowerSweepTimeReferenceXValues
             (ViSession instrumentHandle, ViPReal64 timeXPointA,
              ViPReal64 timeXPointB);
ViStatus _VI_FUNC rssmf_SetPowerSweepTimeReferenceYValues
             (ViSession instrumentHandle, ViReal64 powerYPointA,
              ViReal64 powerYPointB);
ViStatus _VI_FUNC rssmf_GetPowerSweepTimeReferenceYValues
             (ViSession instrumentHandle, ViPReal64 powerYPointA,
              ViPReal64 powerYPointB);
ViStatus _VI_FUNC rssmf_GetPowerSweepTimeReferenceNumberOfPoints
             (ViSession instrumentHandle, ViPReal64 numberOfPoints);
ViStatus _VI_FUNC rssmf_GeneratePowerSweepTimeReferenceCurve
             (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmf_SetPowerSweepTraceState (ViSession instrumentHandle,
                                                 ViInt32 trace, ViBoolean state);
ViStatus _VI_FUNC rssmf_GetPowerSweepTraceState (ViSession instrumentHandle,
                                                 ViInt32 trace, ViPBoolean state);
ViStatus _VI_FUNC rssmf_SetPowerSweepTraceColor (ViSession instrumentHandle,
                                                 ViInt32 trace, ViInt32 color);
ViStatus _VI_FUNC rssmf_GetPowerSweepTraceColor (ViSession instrumentHandle,
                                                 ViInt32 trace, ViPInt32 color);
ViStatus _VI_FUNC rssmf_copyPowerSweepTrace (ViSession instrumentHandle,
                                             ViInt32 trace, ViInt32 copyMode);
ViStatus _VI_FUNC rssmf_GetPowerSweepTraceDataPoints (ViSession instrumentHandle,
                                                      ViInt32 trace,
                                                      ViPInt32 dataPoints);
ViStatus _VI_FUNC rssmf_GetPowerSweepTraceXValues (ViSession instrumentHandle,
                                                   ViInt32 trace, ViInt32 arraySize,
                                                   ViReal64 _VI_FAR xValues[]);
ViStatus _VI_FUNC rssmf_GetPowerSweepTraceYValues (ViSession instrumentHandle,
                                                   ViInt32 trace, ViInt32 arraySize,
                                                   ViReal64 _VI_FAR yValues[]);
ViStatus _VI_FUNC rssmf_SetPowerSweepTraceSource (ViSession instrumentHandle,
                                                  ViInt32 trace, ViInt32 source);
ViStatus _VI_FUNC rssmf_GetPowerSweepTraceSource (ViSession instrumentHandle,
                                                  ViInt32 trace, ViPInt32 source);
ViStatus _VI_FUNC rssmf_GetPowerSweepTracePulseDataAnalysisState
             (ViSession instrumentHandle, ViInt32 trace, ViPBoolean state);
ViStatus _VI_FUNC rssmf_GetPowerSweepTracePulseThresholdBase
             (ViSession instrumentHandle, ViInt32 trace, ViPInt32 base);
ViStatus _VI_FUNC rssmf_GetPowerSweepTracePulseThresholdReferenceLevel
             (ViSession instrumentHandle, ViInt32 trace, ViInt32 mode,
              ViPReal64 referenceLevel);
ViStatus _VI_FUNC rssmf_SetPowerSweepSenseMode (ViSession instrumentHandle,
                                                ViInt32 sense, ViInt32 senseMode);
ViStatus _VI_FUNC rssmf_GetPowerSweepSenseMode (ViSession instrumentHandle,
                                                ViInt32 sense, ViPInt32 senseMode);
ViStatus _VI_FUNC rssmf_SetPowerSweepMode (ViSession instrumentHandle,
                                           ViInt32 sense, ViInt32 sweepMode);
ViStatus _VI_FUNC rssmf_GetPowerSweepMode (ViSession instrumentHandle,
                                           ViInt32 sense, ViPInt32 sweepMode);
ViStatus _VI_FUNC rssmf_GetPowerSweepDataPoints (ViSession instrumentHandle,
                                                 ViInt32 sense,
                                                 ViPInt32 dataPoints);
ViStatus _VI_FUNC rssmf_GetPowerSweepDataXValues (ViSession instrumentHandle,
                                                  ViInt32 sense, ViInt32 arraySize,
                                                  ViReal64 _VI_FAR dataXValues[]);
ViStatus _VI_FUNC rssmf_GetPowerSweepDataYValues (ViSession instrumentHandle,
                                                  ViInt32 sense, ViInt32 arraySize,
                                                  ViReal64 _VI_FAR dataYValues[]);
ViStatus _VI_FUNC rssmf_SetPowerDisplayIndication (ViSession instrumentHandle,
                                                   ViInt32 trace, ViInt32 type,
                                                   ViBoolean indication);
ViStatus _VI_FUNC rssmf_GetPowerDisplayIndication (ViSession instrumentHandle,
                                                   ViInt32 trace, ViInt32 type,
                                                   ViPBoolean indication);
ViStatus _VI_FUNC rssmf_GetPowerDisplayPulseDataAnalysis (ViSession instrumentHandle,
                                                          ViInt32 trace,
                                                          ViInt32 type,
                                                          ViPReal64 pulseDataAnalysis);
ViStatus _VI_FUNC rssmf_SetPowerSensorMathematicsState (ViSession instrumentHandle,
                                                        ViInt32 trace,
                                                        ViInt32 sweepMode,
                                                        ViBoolean state);
ViStatus _VI_FUNC rssmf_GetPowerSensorMathematicsState (ViSession instrumentHandle,
                                                        ViInt32 trace,
                                                        ViInt32 sweepMode,
                                                        ViPBoolean state);
ViStatus _VI_FUNC rssmf_SetPowerSensorMathematicsSubtraction
             (ViSession instrumentHandle, ViInt32 resultTrace, ViInt32 sweepMode,
              ViInt32 firstOperand, ViInt32 secondOperand);
ViStatus _VI_FUNC rssmf_PowerSensorDevice (ViSession instrumentHandle,
                                           ViInt32 sense, ViPInt32 device);
ViStatus _VI_FUNC rssmf_PowerSensorType (ViSession instrumentHandle, ViInt32 sense,
                                         ViChar _VI_FAR type[]);
ViStatus _VI_FUNC rssmf_PowerReadPower (ViSession instrumentHandle, ViInt32 read,
                                        ViPReal64 power);

ViStatus _VI_FUNC rssmf_PowerReadPowers (ViSession instrumentHandle,
                                         ViInt32 read, ViReal64 *averagePower,
                                         ViReal64 *peakPower);

ViStatus _VI_FUNC rssmf_GetPowerSensorVersion (ViSession instrumentHandle,
                                               ViInt32 sense,
                                               ViChar _VI_FAR version[]);
ViStatus _VI_FUNC rssmf_PowerSensorSerialNumber (ViSession instrumentHandle,
                                                 ViInt32 sense,
                                                 ViChar _VI_FAR serialNumber[]);
ViStatus _VI_FUNC rssmf_confDiagramDisplay (ViSession instrumentHandle,
                                            ViBoolean grid,
                                            ViInt32 backgroundColor);
ViStatus _VI_FUNC rssmf_SetDiagramGrid (ViSession instrumentHandle, ViBoolean grid);
ViStatus _VI_FUNC rssmf_GetDiagramGrid (ViSession instrumentHandle,
                                        ViPBoolean grid);
ViStatus _VI_FUNC rssmf_SetDiagramBackgroundColor (ViSession instrumentHandle,
                                                   ViInt32 backgroundColor);
ViStatus _VI_FUNC rssmf_GetDiagramBackgroundColor (ViSession instrumentHandle,
                                                   ViPInt32 backgroundColor);
ViStatus _VI_FUNC rssmf_SetPowerSweepHardcopyLNGFormat (ViSession instrumentHandle,
                                                        ViInt32 sense,
                                                        ViInt32 sweepHardcopyFormat);
ViStatus _VI_FUNC rssmf_GetPowerSweepHardcopyLNGFormat (ViSession instrumentHandle,
                                                        ViInt32 sense,
                                                        ViPInt32 sweepHardcopyFormat);
ViStatus _VI_FUNC rssmf_SetPowerSweepHardcopyFile (ViSession instrumentHandle,
                                                   ViString fileName);
ViStatus _VI_FUNC rssmf_GetPowerSweepHardcopyFile (ViSession instrumentHandle,
                                                   ViChar _VI_FAR fileName[]);
ViStatus _VI_FUNC rssmf_SetPowerSweepHardcopyDevice (ViSession instrumentHandle,
                                                     ViInt32 hardcopyDevice);
ViStatus _VI_FUNC rssmf_GetPowerSweepHardcopyDevice (ViSession instrumentHandle,
                                                     ViPInt32 hardcopyDevice);
ViStatus _VI_FUNC rssmf_SetPowerSweepHardcopyImageSize (ViSession instrumentHandle,
                                                        ViInt32 imageSize);
ViStatus _VI_FUNC rssmf_GetPowerSweepHardcopyImageSize (ViSession instrumentHandle,
                                                        ViPInt32 imageSize);
ViStatus _VI_FUNC rssmf_SetPowerSweepHardcopyMarkerState (ViSession instrumentHandle,
                                                          ViBoolean state);
ViStatus _VI_FUNC rssmf_GetPowerSweepHardcopyMarkerState (ViSession instrumentHandle,
                                                          ViPBoolean state);
ViStatus _VI_FUNC rssmf_SavePowerSweepHardcopy (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmf_SetPowerSweepHardcopyCSVHeader (ViSession instrumentHandle,
                                                        ViInt32 CSVHeader);
ViStatus _VI_FUNC rssmf_GetPowerSweepHardcopyCSVHeader (ViSession instrumentHandle,
                                                        ViPInt32 CSVHeader);
ViStatus _VI_FUNC rssmf_SetPowerSweepHardcopyCSVOrientation
             (ViSession instrumentHandle, ViInt32 CSVOrientation);
ViStatus _VI_FUNC rssmf_GetPowerSweepHardcopyCSVOrientation
             (ViSession instrumentHandle, ViPInt32 CSVOrientation);
ViStatus _VI_FUNC rssmf_SetPowerSweepHardcopyCSVColumnSeparator
             (ViSession instrumentHandle, ViInt32 CSVColumnSeparator);
ViStatus _VI_FUNC rssmf_GetPowerSweepHardcopyCSVColumnSeparator
             (ViSession instrumentHandle, ViPInt32 CSVColumnSeparator);
ViStatus _VI_FUNC rssmf_SetPowerSweepHardcopyCSVDecimalPoint
             (ViSession instrumentHandle, ViInt32 CSVDecimalPoint);
ViStatus _VI_FUNC rssmf_GetPowerSweepHardcopyCSVDecimalPoint
             (ViSession instrumentHandle, ViPInt32 CSVDecimalPoint);
ViStatus _VI_FUNC rssmf_GetPowerSweepHardcopyCSVData (ViSession instrumentHandle,
                                                      ViString destination);
ViStatus _VI_FUNC rssmf_SetPowerSweepHardcopyAutomaticNamingState
             (ViSession instrumentHandle, ViBoolean state);
ViStatus _VI_FUNC rssmf_GetPowerSweepHardcopyAutomaticNamingState
             (ViSession instrumentHandle, ViPBoolean state);
ViStatus _VI_FUNC rssmf_GetPowerSweepHardcopyAutomaticFileName
             (ViSession instrumentHandle, ViChar _VI_FAR fileName[]);
ViStatus _VI_FUNC rssmf_SetPowerSweepHardcopyAutomaticDirectory
             (ViSession instrumentHandle, ViString directoryName);
ViStatus _VI_FUNC rssmf_GetPowerSweepHardcopyAutomaticDirectory
             (ViSession instrumentHandle, ViChar _VI_FAR directoryName[]);
ViStatus _VI_FUNC rssmf_DeletePowerSweepHardcopyImageFiles
             (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmf_SetPowerSweepHardcopyAutomaticFileDateState
             (ViSession instrumentHandle, ViInt32 fileNamePart, ViBoolean state);
ViStatus _VI_FUNC rssmf_GetPowerSweepHardcopyAutomaticFileDateState
             (ViSession instrumentHandle, ViInt32 fileNamePart, ViPBoolean state);
ViStatus _VI_FUNC rssmf_GetPowerSweepHardcopyAutomaticFileDate
             (ViSession instrumentHandle, ViInt32 fileNamePart,
              ViChar _VI_FAR part[]);
ViStatus _VI_FUNC rssmf_SetPowerSweepHardcopyAutomaticFilePrefixState
             (ViSession instrumentHandle, ViBoolean state);
ViStatus _VI_FUNC rssmf_GetPowerSweepHardcopyAutomaticFilePrefixState
             (ViSession instrumentHandle, ViPBoolean state);
ViStatus _VI_FUNC rssmf_SetPowerSweepHardcopyAutomaticFilePrefix
             (ViSession instrumentHandle, ViString prefix);
ViStatus _VI_FUNC rssmf_GetPowerSweepHardcopyAutomaticFilePrefix
             (ViSession instrumentHandle, ViChar _VI_FAR prefix[]);
ViStatus _VI_FUNC rssmf_GetPowerSweepHardcopyAutomaticFileNumber
             (ViSession instrumentHandle, ViPInt32 number);
ViStatus _VI_FUNC rssmf_SetAllRFOutputsState (ViSession instrumentHandle,
                                              ViBoolean RFOutputStates);
ViStatus _VI_FUNC rssmf_confRFLevel (ViSession instrumentHandle, ViReal64 amplitude,
                                     ViReal64 offset, ViReal64 limit,
                                     ViInt32 powerResolution,
                                     ViBoolean variationActive,
                                     ViReal64 variationStep,
                                     ViInt32 RFLevelOnRecall);
ViStatus _VI_FUNC rssmf_SetRFAmplitude (ViSession instrumentHandle,
                                        ViReal64 amplitude);
ViStatus _VI_FUNC rssmf_GetRFAmplitude (ViSession instrumentHandle,
                                        ViPReal64 amplitude);
ViStatus _VI_FUNC rssmf_SetRFAmplitudeIgnoreOffset (ViSession instrumentHandle,
                                                    ViReal64 amplitude);
ViStatus _VI_FUNC rssmf_SetRFLevelLimit (ViSession instrumentHandle,
                                         ViReal64 limit);
ViStatus _VI_FUNC rssmf_GetRFLevelLimit (ViSession instrumentHandle,
                                         ViPReal64 limit);
ViStatus _VI_FUNC rssmf_SetRFLevelOffset (ViSession instrumentHandle,
                                          ViReal64 offset);
ViStatus _VI_FUNC rssmf_GetRFLevelOffset (ViSession instrumentHandle,
                                          ViPReal64 offset);
ViStatus _VI_FUNC rssmf_SetRFPowerResolution (ViSession instrumentHandle,
                                              ViInt32 powerResolution);
ViStatus _VI_FUNC rssmf_GetRFPowerResolution (ViSession instrumentHandle,
                                              ViPInt32 powerResolution);
ViStatus _VI_FUNC rssmf_SetRFLevelonRecall (ViSession instrumentHandle,
                                            ViInt32 RFLevelOnRecall);
ViStatus _VI_FUNC rssmf_GetRFLevelonRecall (ViSession instrumentHandle,
                                            ViPInt32 RFLevelOnRecall);
ViStatus _VI_FUNC rssmf_SetRFLevelVariationActive (ViSession instrumentHandle,
                                                   ViBoolean variationActive);
ViStatus _VI_FUNC rssmf_GetRFLevelVariationActive (ViSession instrumentHandle,
                                                   ViPBoolean variationActive);
ViStatus _VI_FUNC rssmf_SetRFLevelVariationStep (ViSession instrumentHandle,
                                                 ViReal64 variationStep);
ViStatus _VI_FUNC rssmf_GetRFLevelVariationStep (ViSession instrumentHandle,
                                                 ViPReal64 variationStep);
ViStatus _VI_FUNC rssmf_SetRFPowerOnState (ViSession instrumentHandle,
                                           ViInt32 powerOnState);
ViStatus _VI_FUNC rssmf_GetRFPowerOnState (ViSession instrumentHandle,
                                           ViPInt32 powerOnState);
ViStatus _VI_FUNC rssmf_SetALCState (ViSession instrumentHandle,
                                     ViBoolean ALCState);
ViStatus _VI_FUNC rssmf_GetALCState (ViSession instrumentHandle,
                                     ViPBoolean ALCState);
ViStatus _VI_FUNC rssmf_SetALCRFPowerDuringPowerSearch (ViSession instrumentHandle,
                                                        ViInt32 RFPowerDuringSearch);
ViStatus _VI_FUNC rssmf_GetALCRFPowerDuringPowerSearch (ViSession instrumentHandle,
                                                        ViPInt32 RFPowerDuringSearch);
ViStatus _VI_FUNC rssmf_ALCSearchOnce (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmf_SetALCDetector (ViSession instrumentHandle,
                                        ViInt32 detector);
ViStatus _VI_FUNC rssmf_GetALCDetector (ViSession instrumentHandle,
                                        ViPInt32 detector);
ViStatus _VI_FUNC rssmf_SetALCPowerSensorType (ViSession instrumentHandle,
                                               ViInt32 powerSensorType);
ViStatus _VI_FUNC rssmf_GetALCPowerSensorType (ViSession instrumentHandle,
                                               ViPInt32 powerSensorType);
ViStatus _VI_FUNC rssmf_SetALCReferenceVoltage (ViSession instrumentHandle,
                                                ViReal64 referenceVoltage);
ViStatus _VI_FUNC rssmf_GetALCReferenceVoltage (ViSession instrumentHandle,
                                                ViPReal64 referenceVoltage);
ViStatus _VI_FUNC rssmf_SetUserCorrectionDataState (ViSession instrumentHandle,
                                                    ViBoolean correctionState);
ViStatus _VI_FUNC rssmf_GetUserCorrectionDataState (ViSession instrumentHandle,
                                                    ViPBoolean correctionState);
ViStatus _VI_FUNC rssmf_GetUserCorrectionCurrentValue (ViSession instrumentHandle,
                                                       ViPReal64 correctionCurrentValue);
ViStatus _VI_FUNC rssmf_TriggerUserCorrectionMeasurement
             (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmf_GetUserCorrectionDataCatalog (ViSession instrumentHandle,
                                                      ViString directoryPath,
                                                      ViInt32 arraySize,
                                                      ViChar _VI_FAR catalogList[]);
ViStatus _VI_FUNC rssmf_SetUserCorrectionDataTable (ViSession instrumentHandle,
                                                    ViString correctionTable);
ViStatus _VI_FUNC rssmf_GetUserCorrectionDataTable (ViSession instrumentHandle,
                                                    ViChar _VI_FAR correctionTable[]);
ViStatus _VI_FUNC rssmf_SetUserCorrectionDataFrequencyValues
             (ViSession instrumentHandle, ViInt32 arraySize,
              ViReal64 _VI_FAR frequencyValues[]);
ViStatus _VI_FUNC rssmf_GetUserCorrectionDataFrequencyValues
             (ViSession instrumentHandle, ViInt32 arraySize,
              ViReal64 _VI_FAR frequencyValues[]);
ViStatus _VI_FUNC rssmf_GetUserCorrectionDataNumberofFrequencyValues
             (ViSession instrumentHandle, ViPInt32 numberOfFrequencyValues);
ViStatus _VI_FUNC rssmf_SetUserCorrectionDataLevelValues (ViSession instrumentHandle,
                                                          ViInt32 arraySize,
                                                          ViReal64 _VI_FAR levelValues[]);
ViStatus _VI_FUNC rssmf_GetUserCorrectionDataLevelValues (ViSession instrumentHandle,
                                                          ViInt32 arraySize,
                                                          ViReal64 _VI_FAR levelValues[]);
ViStatus _VI_FUNC rssmf_GetUserCorrectionDataNumberofLevelValues
             (ViSession instrumentHandle, ViPInt32 numberOfLevelValues);
ViStatus _VI_FUNC rssmf_SetUserCorrectionPowerSensorType (ViSession instrumentHandle,
                                                          ViInt32 powerSensorType);
ViStatus _VI_FUNC rssmf_GetUserCorrectionPowerSensorType (ViSession instrumentHandle,
                                                          ViPInt32 powerSensorType);
ViStatus _VI_FUNC rssmf_UserCorrectionFillListWithSensor (ViSession instrumentHandle,
                                                          ViInt32 sensor,
                                                          ViInt32 timeout);
ViStatus _VI_FUNC rssmf_UserCorrectionDataDeleteTable (ViSession instrumentHandle,
                                                       ViString tableName);
ViStatus _VI_FUNC rssmf_SetCORRectionImportExportListMode
             (ViSession instrumentHandle, ViInt32 listMode);
ViStatus _VI_FUNC rssmf_GetCORRectionImportExportListMode
             (ViSession instrumentHandle, ViPInt32 listMode);
ViStatus _VI_FUNC rssmf_SetCORRectionImportExportListFile
             (ViSession instrumentHandle, ViString sourceFile);
ViStatus _VI_FUNC rssmf_GetCORRectionImportExportListFile
             (ViSession instrumentHandle, ViChar _VI_FAR sourceFile[]);
ViStatus _VI_FUNC rssmf_CORRectionImportExportExecute (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmf_SetCORRectionImportExportASCIIFile
             (ViSession instrumentHandle, ViString ASCIISourceFile);
ViStatus _VI_FUNC rssmf_GetCORRectionImportExportASCIIFile
             (ViSession instrumentHandle, ViChar _VI_FAR ASCIISourceFile[]);
ViStatus _VI_FUNC rssmf_SetCORRectionImportExportASCIIExtension
             (ViSession instrumentHandle, ViInt32 extension);
ViStatus _VI_FUNC rssmf_GetCORRectionImportExportASCIIExtension
             (ViSession instrumentHandle, ViPInt32 extension);
ViStatus _VI_FUNC rssmf_SetCORRectionImportExportASCIIColumnSeparator
             (ViSession instrumentHandle, ViInt32 separator);
ViStatus _VI_FUNC rssmf_GetCORRectionImportExportASCIIColumnSeparator
             (ViSession instrumentHandle, ViPInt32 separator);
ViStatus _VI_FUNC rssmf_SetCORRectionImportExportASCIIColumnDecimalSeparator
             (ViSession instrumentHandle, ViInt32 decimalSeparator);
ViStatus _VI_FUNC rssmf_GetCORRectionImportExportASCIIColumnDecimalSeparator
             (ViSession instrumentHandle, ViPInt32 decimalSeparator);
ViStatus _VI_FUNC rssmf_CORRectionImportExportCatalog (ViSession instrumentHandle,
                                                       ViString directoryPath,
                                                       ViInt32 arraySize,
                                                       ViChar _VI_FAR catalogList[]);
ViStatus _VI_FUNC rssmf_confRFLevelSweep (ViSession instrumentHandle,
                                          ViInt32 levelSweepMode,
                                          ViReal64 startLevel, ViReal64 stopLevel,
                                          ViReal64 stepLin, ViReal64 dwellTime);
ViStatus _VI_FUNC rssmf_LevelSweepExecute (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmf_ConfigureLevelSweepMarker (ViSession instrumentHandle,
                                                   ViUInt32 channel,
                                                   ViBoolean state, ViReal64 level,
                                                   ViInt32 polarity,
                                                   ViInt32 activeMarker);
ViStatus _VI_FUNC rssmf_SetLevelSweepMode (ViSession instrumentHandle,
                                           ViInt32 mode);
ViStatus _VI_FUNC rssmf_SetLevelSweepStartLevel (ViSession instrumentHandle,
                                                 ViReal64 startLevel);
ViStatus _VI_FUNC rssmf_GetLevelSweepStartLevel (ViSession instrumentHandle,
                                                 ViPReal64 startLevel);
ViStatus _VI_FUNC rssmf_SetLevelSweepStopLevel (ViSession instrumentHandle,
                                                ViReal64 stopLevel);
ViStatus _VI_FUNC rssmf_GetLevelSweepStopLevel (ViSession instrumentHandle,
                                                ViPReal64 stopLevel);
ViStatus _VI_FUNC rssmf_SetLevelSweepStep (ViSession instrumentHandle,
                                           ViReal64 step);
ViStatus _VI_FUNC rssmf_GetLevelSweepStep (ViSession instrumentHandle,
                                           ViPReal64 step);
ViStatus _VI_FUNC rssmf_SetLevelSweepDwell (ViSession instrumentHandle,
                                            ViReal64 dwellTime);
ViStatus _VI_FUNC rssmf_GetLevelSweepDwell (ViSession instrumentHandle,
                                            ViPReal64 dwellTime);
ViStatus _VI_FUNC rssmf_SetLevelSweepManualStep (ViSession instrumentHandle,
                                                 ViReal64 manualStep);
ViStatus _VI_FUNC rssmf_GetLevelSweepManualStep (ViSession instrumentHandle,
                                                 ViPReal64 manualStep);
ViStatus _VI_FUNC rssmf_SetLevelSweepPoints (ViSession instrumentHandle,
                                             ViInt32 levelSweepPoints);
ViStatus _VI_FUNC rssmf_GetLevelSweepPoints (ViSession instrumentHandle,
                                             ViPInt32 levelSweepPoints);
ViStatus _VI_FUNC rssmf_SetLevelSweepAttenuatorMode (ViSession instrumentHandle,
                                                     ViInt32 attenuatorMode);
ViStatus _VI_FUNC rssmf_GetLevelSweepAttenuatorMode (ViSession instrumentHandle,
                                                     ViPInt32 attenuatorMode);
ViStatus _VI_FUNC rssmf_SetLevelSweepShape (ViSession instrumentHandle,
                                            ViInt32 shape);
ViStatus _VI_FUNC rssmf_GetLevelSweepShape (ViSession instrumentHandle,
                                            ViPInt32 shape);
ViStatus _VI_FUNC rssmf_GetLevelSweepSpacing (ViSession instrumentHandle,
                                              ViPInt32 spacing);
ViStatus _VI_FUNC rssmf_ResetLevelSweep (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmf_SetLevelSweepMarkerState (ViSession instrumentHandle,
                                                  ViUInt32 channel,
                                                  ViBoolean state);
ViStatus _VI_FUNC rssmf_GetLevelSweepMarkerState (ViSession instrumentHandle,
                                                  ViUInt32 channel,
                                                  ViPBoolean state);
ViStatus _VI_FUNC rssmf_SetLevelSweepMarkerLevel (ViSession instrumentHandle,
                                                  ViUInt32 channel, ViReal64 level);
ViStatus _VI_FUNC rssmf_GetLevelSweepMarkerLevel (ViSession instrumentHandle,
                                                  ViUInt32 channel,
                                                  ViPReal64 level);
ViStatus _VI_FUNC rssmf_SetLevelSweepMarkerPolarity (ViSession instrumentHandle,
                                                     ViInt32 polarity);
ViStatus _VI_FUNC rssmf_GetLevelSweepMarkerPolarity (ViSession instrumentHandle,
                                                     ViPInt32 polarity);
ViStatus _VI_FUNC rssmf_SetLevelSweepActiveMarker (ViSession instrumentHandle,
                                                   ViInt32 activeMarker);
ViStatus _VI_FUNC rssmf_GetLevelSweepActiveMarker (ViSession instrumentHandle,
                                                   ViPInt32 activeMarker);
ViStatus _VI_FUNC rssmf_SetLevelSweepAllMarkersOff (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmf_SetRFAttenuatorMode (ViSession instrumentHandle,
                                             ViInt32 attenuatorMode);
ViStatus _VI_FUNC rssmf_GetRFAttenuatorMode (ViSession instrumentHandle,
                                             ViPInt32 attenuatorMode);
ViStatus _VI_FUNC rssmf_SetRFAttenuation (ViSession instrumentHandle,
                                          ViReal64 attenuation);
ViStatus _VI_FUNC rssmf_GetRFAttenuation (ViSession instrumentHandle,
                                          ViPReal64 attenuation);
ViStatus _VI_FUNC rssmf_GetRFAttenuatorLowerRange (ViSession instrumentHandle,
                                                   ViPReal64 attenuatorLowerRange);
ViStatus _VI_FUNC rssmf_GetRFAttenuatorUpperRange (ViSession instrumentHandle,
                                                   ViPReal64 attenuatorUpperRange);
ViStatus _VI_FUNC rssmf_SetRFOFFAttenuatorMode (ViSession instrumentHandle,
                                                ViInt32 OFFAttenuatorMode);
ViStatus _VI_FUNC rssmf_GetRFOFFAttenuatorMode (ViSession instrumentHandle,
                                                ViPInt32 OFFAttenuatorMode);
ViStatus _VI_FUNC rssmf_CALibrationAll (ViSession instrumentHandle, ViInt32 timeout,
                                        ViPInt32 response);
ViStatus _VI_FUNC rssmf_CALibrationFrequency (ViSession instrumentHandle,
                                              ViInt32 timeout, ViPInt32 response);
ViStatus _VI_FUNC rssmf_CALibrationModulationGenerators (ViSession instrumentHandle,
                                                         ViInt32 timeout,
                                                         ViPInt32 response);
ViStatus _VI_FUNC rssmf_CALibrationLevel (ViSession instrumentHandle,
                                          ViInt32 timeout, ViPInt32 response);
ViStatus _VI_FUNC rssmf_SetCALibrationLevelState (ViSession instrumentHandle,
                                                  ViBoolean levelState);
ViStatus _VI_FUNC rssmf_GetCALibrationLevelState (ViSession instrumentHandle,
                                                  ViPBoolean levelState);
ViStatus _VI_FUNC rssmf_SetCALibrationLevelLoopGainState (ViSession instrumentHandle,
                                                          ViBoolean levelLoopGainState);
ViStatus _VI_FUNC rssmf_GetCALibrationLevelLoopGainState (ViSession instrumentHandle,
                                                          ViPBoolean levelLoopGainState);
ViStatus _VI_FUNC rssmf_ClearStatus (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmf_EventStatusEnable (ViSession instrumentHandle,
                                           ViInt32 registerValue);
ViStatus _VI_FUNC rssmf_EventStatusQuery (ViSession instrumentHandle,
                                          ViPInt32 registerValue);
ViStatus _VI_FUNC rssmf_IdentificationQuery (ViSession instrumentHandle,
                                             ViChar _VI_FAR instrumentIdentification[]);
ViStatus _VI_FUNC rssmf_IndividualStatusQuery (ViSession instrumentHandle,
                                               ViPInt32 ISTFlag);
ViStatus _VI_FUNC rssmf_OperationComplete (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmf_OperationCompleteQuery (ViSession instrumentHandle,
                                                ViPInt32 OPCState);
ViStatus _VI_FUNC rssmf_OptionIdentificationQuery (ViSession instrumentHandle,
                                                   ViChar _VI_FAR optionIdentification[]);
ViStatus _VI_FUNC rssmf_ParallelPollRegisterEnable (ViSession instrumentHandle,
                                                    ViInt32 registerValue);
ViStatus _VI_FUNC rssmf_ParallelPollRegisterQuery (ViSession instrumentHandle,
                                                   ViPInt32 registerValue);
ViStatus _VI_FUNC rssmf_PowerOnStatusClear (ViSession instrumentHandle,
                                            ViInt32 registerValue);
ViStatus _VI_FUNC rssmf_PowerOnStatusClearQuery (ViSession instrumentHandle,
                                                 ViPInt32 registerValue);
ViStatus _VI_FUNC rssmf_Recall (ViSession instrumentHandle,
                                ViInt32 instrumentStatus);
ViStatus _VI_FUNC rssmf_Save (ViSession instrumentHandle, ViInt32 instrumentStatus);
ViStatus _VI_FUNC rssmf_ServiceRequestEnable (ViSession instrumentHandle,
                                              ViInt32 registerValue);
ViStatus _VI_FUNC rssmf_ServiceRequestEnableQuery (ViSession instrumentHandle,
                                                   ViPInt32 registerValue);
ViStatus _VI_FUNC rssmf_StatusByteQuery (ViSession instrumentHandle,
                                         ViPInt32 statusByte);
ViStatus _VI_FUNC rssmf_Trigger (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmf_TriggerWaitOPC (ViSession instrumentHandle,
                                        ViInt32 timeout);
ViStatus _VI_FUNC rssmf_SelfTestQuery (ViSession instrumentHandle,
                                       ViPInt32 errorCode);
ViStatus _VI_FUNC rssmf_WaittoContinue (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmf_PresetSignalPath (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmf_SetImageFileName (ViSession instrumentHandle,
                                          ViString fileName);
ViStatus _VI_FUNC rssmf_GetImageFileName (ViSession instrumentHandle,
                                          ViChar _VI_FAR fileName[]);
ViStatus _VI_FUNC rssmf_SetImageFormat (ViSession instrumentHandle,
                                        ViInt32 imageFormat);
ViStatus _VI_FUNC rssmf_GetImageFormat (ViSession instrumentHandle,
                                        ViPInt32 imageFormat);
ViStatus _VI_FUNC rssmf_GetImageSnapshot (ViSession instrumentHandle,
                                          ViString destination);
ViStatus _VI_FUNC rssmf_SetImageSize (ViSession instrumentHandle,
                                      ViInt32 imageSize);
ViStatus _VI_FUNC rssmf_GetImageSize (ViSession instrumentHandle,
                                      ViPInt32 imageSize);
ViStatus _VI_FUNC rssmf_SetOutputDevice (ViSession instrumentHandle,
                                         ViInt32 outputDevice);
ViStatus _VI_FUNC rssmf_GetOutputDevice (ViSession instrumentHandle,
                                         ViPInt32 outputDevice);
ViStatus _VI_FUNC rssmf_SaveHardCopy (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmf_SetAutomaticNamingState (ViSession instrumentHandle,
                                                 ViBoolean state);
ViStatus _VI_FUNC rssmf_GetAutomaticNamingState (ViSession instrumentHandle,
                                                 ViPBoolean state);
ViStatus _VI_FUNC rssmf_GetAutomaticFilePath (ViSession instrumentHandle,
                                              ViInt32 arraySize,
                                              ViChar _VI_FAR filePath[]);
ViStatus _VI_FUNC rssmf_GetAutomaticFileName (ViSession instrumentHandle,
                                              ViChar _VI_FAR fileName[]);
ViStatus _VI_FUNC rssmf_SetAutomaticDirectory (ViSession instrumentHandle,
                                               ViString directoryName);
ViStatus _VI_FUNC rssmf_GetAutomaticDirectory (ViSession instrumentHandle,
                                               ViChar _VI_FAR directory[]);
ViStatus _VI_FUNC rssmf_DeleteImageFiles (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmf_SetAutomaticFileDateState (ViSession instrumentHandle,
                                                   ViInt32 fileNamePart,
                                                   ViBoolean state);
ViStatus _VI_FUNC rssmf_GetAutomaticFileDateState (ViSession instrumentHandle,
                                                   ViInt32 fileNamePart,
                                                   ViPBoolean state);
ViStatus _VI_FUNC rssmf_GetAutomaticFileDate (ViSession instrumentHandle,
                                              ViInt32 fileNamePart,
                                              ViChar _VI_FAR part[]);
ViStatus _VI_FUNC rssmf_SetAutomaticFilePrefixState (ViSession instrumentHandle,
                                                     ViBoolean state);
ViStatus _VI_FUNC rssmf_GetAutomaticFilePrefixState (ViSession instrumentHandle,
                                                     ViPBoolean state);
ViStatus _VI_FUNC rssmf_SetAutomaticFilePrefix (ViSession instrumentHandle,
                                                ViString prefix);
ViStatus _VI_FUNC rssmf_GetAutomaticFilePrefix (ViSession instrumentHandle,
                                                ViChar _VI_FAR fileName[]);
ViStatus _VI_FUNC rssmf_GetAutomaticFileNumber (ViSession instrumentHandle,
                                                ViPInt32 number);
ViStatus _VI_FUNC rssmf_DIAGnosticModules (ViSession instrumentHandle,
                                           ViString moduleName, ViInt32 arraySize,
                                           ViChar _VI_FAR moduleConfiguration[]);
ViStatus _VI_FUNC rssmf_DIAGnosticModuleNames (ViSession instrumentHandle,
                                               ViInt32 arraySize,
                                               ViChar _VI_FAR moduleNames[]);
ViStatus _VI_FUNC rssmf_DIAGnosticTestPoints (ViSession instrumentHandle,
                                              ViInt32 arraySize,
                                              ViChar _VI_FAR testPoints[]);
ViStatus _VI_FUNC rssmf_DIAGnosticTestPointVoltages (ViSession instrumentHandle,
                                                     ViString testPointName,
                                                     ViPReal64 measuredVoltage);
ViStatus _VI_FUNC rssmf_DIAGnosticOperationTime (ViSession instrumentHandle,
                                                 ViPUInt32 operationTime);
ViStatus _VI_FUNC rssmf_DIAGnosticPowerOnEvents (ViSession instrumentHandle,
                                                 ViPUInt32 powerOnEvents);
ViStatus _VI_FUNC rssmf_TESTDirect (ViSession instrumentHandle, ViInt32 command,
                                    ViChar _VI_FAR assemblyResponse[]);
ViStatus _VI_FUNC rssmf_SetKeyboardLock (ViSession instrumentHandle,
                                         ViBoolean keyboardLock);
ViStatus _VI_FUNC rssmf_GetKeyboardLock (ViSession instrumentHandle,
                                         ViPBoolean keyboardLock);
ViStatus _VI_FUNC rssmf_SetDisplayPowerSaveState (ViSession instrumentHandle,
                                                  ViBoolean state);
ViStatus _VI_FUNC rssmf_GetDisplayPowerSaveState (ViSession instrumentHandle,
                                                  ViPBoolean state);
ViStatus _VI_FUNC rssmf_SetDisplayPowerSaveHoldoff (ViSession instrumentHandle,
                                                    ViInt32 holdoff);
ViStatus _VI_FUNC rssmf_GetDisplayPowerSaveHoldoff (ViSession instrumentHandle,
                                                    ViPInt32 holdoff);
ViStatus _VI_FUNC rssmf_SetDisplayBlankMode (ViSession instrumentHandle,
                                             ViInt32 blankMode);
ViStatus _VI_FUNC rssmf_GetDisplayBlankMode (ViSession instrumentHandle,
                                             ViPInt32 blankMode);
ViStatus _VI_FUNC rssmf_SetDisplayProportionalScale (ViSession instrumentHandle,
                                                     ViInt32 proportionalScale);
ViStatus _VI_FUNC rssmf_GetDisplayProportionalScale (ViSession instrumentHandle,
                                                     ViPInt32 proportionalScale);
ViStatus _VI_FUNC rssmf_SetDisplayUpdate (ViSession instrumentHandle,
                                          ViBoolean displayUpdate);
ViStatus _VI_FUNC rssmf_GetDisplayUpdate (ViSession instrumentHandle,
                                          ViPBoolean displayUpdate);
ViStatus _VI_FUNC rssmf_SetDisplayLock (ViSession instrumentHandle,
                                        ViBoolean displayLock);
ViStatus _VI_FUNC rssmf_GetDisplayLock (ViSession instrumentHandle,
                                        ViPBoolean displayLock);
ViStatus _VI_FUNC rssmf_MMEMoryCatalog (ViSession instrumentHandle,
                                        ViString directoryPath, ViInt32 arraySize,
                                        ViChar _VI_FAR catalogList[]);
ViStatus _VI_FUNC rssmf_MMEMoryCatalogLength (ViSession instrumentHandle,
                                              ViString directoryPath,
                                              ViPInt32 catalogLength);
ViStatus _VI_FUNC rssmf_MMEMoryChangeDirectory (ViSession instrumentHandle,
                                                ViString directoryName);
ViStatus _VI_FUNC rssmf_MMEMoryCopy (ViSession instrumentHandle,
                                     ViString sourcePath, ViString destinationPath);
ViStatus _VI_FUNC rssmf_MMEMoryBlockDataWrite (ViSession instrumentHandle,
                                               ViString fileName,
                                               ViInt32 binaryBlockLength,
                                               ViChar _VI_FAR binaryBlockData[]);
ViStatus _VI_FUNC rssmf_MMEMoryBlockDataRead (ViSession instrumentHandle,
                                              ViString fileName,
                                              ViInt32 binaryBlockLength,
                                              ViChar _VI_FAR binaryBlockData[]);
ViStatus _VI_FUNC rssmf_MMEMoryDirectoryCatalog (ViSession instrumentHandle,
                                                 ViString directoryPath,
                                                 ViInt32 arraySize,
                                                 ViChar _VI_FAR catalogList[]);
ViStatus _VI_FUNC rssmf_MMEMoryDirectoryCatalogLength (ViSession instrumentHandle,
                                                       ViString directoryPath,
                                                       ViPInt32 catalogLength);
ViStatus _VI_FUNC rssmf_MMEMoryDelete (ViSession instrumentHandle,
                                       ViString fileName);
ViStatus _VI_FUNC rssmf_MMEMoryLoad (ViSession instrumentHandle,
                                     ViInt32 instrumentSetting, ViString fileName);
ViStatus _VI_FUNC rssmf_MMEMoryMakeDirectory (ViSession instrumentHandle,
                                              ViString directoryName);
ViStatus _VI_FUNC rssmf_MMEMoryMove (ViSession instrumentHandle,
                                     ViString fileSource, ViString fileDestination);
ViStatus _VI_FUNC rssmf_MMEMoryRemoveDirectory (ViSession instrumentHandle,
                                                ViString directoryName);
ViStatus _VI_FUNC rssmf_MMEMoryStore (ViSession instrumentHandle,
                                      ViInt32 instrumentSetting, ViString fileName);
ViStatus _VI_FUNC rssmf_setRegister (ViSession instrumentHandle,
                                     ViInt32 registerGroup, ViInt32 registerType,
                                     ViInt32 value);
ViStatus _VI_FUNC rssmf_getRegister (ViSession instrumentHandle,
                                     ViInt32 registerGroup, ViInt32 registerType,
                                     ViPInt32 value);
ViStatus _VI_FUNC rssmf_STATusPRESet (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmf_SetSYSTemBeeper (ViSession instrumentHandle,
                                         ViBoolean systemBeeper);
ViStatus _VI_FUNC rssmf_GetSYSTemBeeper (ViSession instrumentHandle,
                                         ViPBoolean systemBeeper);
ViStatus _VI_FUNC rssmf_SYSTemErrorQueueAll (ViSession instrumentHandle,
                                             ViInt32 arraySize,
                                             ViChar _VI_FAR errorQueue[]);
ViStatus _VI_FUNC rssmf_SYSTemErrorQueueCodeAll (ViSession instrumentHandle,
                                                 ViInt32 arraySize,
                                                 ViChar _VI_FAR errorQueueCode[]);
ViStatus _VI_FUNC rssmf_SYSTemErrorQueueCodeNext (ViSession instrumentHandle,
                                                  ViPInt32 errorQueueCodeNext);
ViStatus _VI_FUNC rssmf_SYSTemErrorQueueCount (ViSession instrumentHandle,
                                               ViPInt32 errorQueueCount);
ViStatus _VI_FUNC rssmf_SYSTemUSBResource (ViSession instrumentHandle,
                                           ViInt32 arraySize,
                                           ViChar _VI_FAR USBResource[]);
ViStatus _VI_FUNC rssmf_SYSTemGPIBResource (ViSession instrumentHandle,
                                            ViInt32 arraySize,
                                            ViChar _VI_FAR GPIBResource[]);
ViStatus _VI_FUNC rssmf_SYSTemSerialResource (ViSession instrumentHandle,
                                              ViInt32 arraySize,
                                              ViChar _VI_FAR serialResource[]);
ViStatus _VI_FUNC rssmf_SYSTemOptionUserDefined (ViSession instrumentHandle,
                                                 ViString userDefinedIdentification);
ViStatus _VI_FUNC rssmf_SetSYSTemProtect (ViSession instrumentHandle,
                                          ViInt32 protectionLevel,
                                          ViBoolean protection, ViString password);
ViStatus _VI_FUNC rssmf_GetSYSTemVersion (ViSession instrumentHandle,
                                          ViChar _VI_FAR SCPIVersion[]);
ViStatus _VI_FUNC rssmf_GetSYSTemStartupStatus (ViSession instrumentHandle,
                                                ViPInt32 startupComplete);
ViStatus _VI_FUNC rssmf_SYSTemFactoryPreset (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmf_GetSYSTemErrorList (ViSession instrumentHandle,
                                            ViInt32 arraySize,
                                            ViChar _VI_FAR errorQueue[]);
ViStatus _VI_FUNC rssmf_SetSYSTemNetworkIPAddress (ViSession instrumentHandle,
                                                   ViString IPAddress);
ViStatus _VI_FUNC rssmf_GetSYSTemNetworkIPAddress (ViSession instrumentHandle,
                                                   ViInt32 arraySize,
                                                   ViChar _VI_FAR IPAddress[]);
ViStatus _VI_FUNC rssmf_SetSYSTemNetworkIPAddressSubnetMask
             (ViSession instrumentHandle, ViString IPAddressSubnetMask);
ViStatus _VI_FUNC rssmf_GetSYSTemNetworkIPAddressSubnetMask
             (ViSession instrumentHandle, ViInt32 arraySize,
              ViChar _VI_FAR IPAddressSubnetMask[]);
ViStatus _VI_FUNC rssmf_SetSYSTemNetworkIPAddressGateway (ViSession instrumentHandle,
                                                          ViString IPAddressGateway);
ViStatus _VI_FUNC rssmf_GetSYSTemNetworkIPAddressGateway (ViSession instrumentHandle,
                                                          ViInt32 arraySize,
                                                          ViChar _VI_FAR IPAddressGateway[]);
ViStatus _VI_FUNC rssmf_SetSYSTemNetworkIPAddressMode (ViSession instrumentHandle,
                                                       ViInt32 IPAddressMode);
ViStatus _VI_FUNC rssmf_GetSYSTemNetworkIPAddressMode (ViSession instrumentHandle,
                                                       ViPInt32 IPAddressMode);
ViStatus _VI_FUNC rssmf_SYSTemNetworkIPAddressExecute (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmf_SetSYSTemNetworkCommonWorkgroup (ViSession instrumentHandle,
                                                         ViString commonWorkgroup);
ViStatus _VI_FUNC rssmf_GetSYSTemNetworkCommonWorkgroup (ViSession instrumentHandle,
                                                         ViInt32 arraySize,
                                                         ViChar _VI_FAR commonWorkgroup[]);
ViStatus _VI_FUNC rssmf_SetSYSTemNetworkCommonDomain (ViSession instrumentHandle,
                                                      ViString commonDomain);
ViStatus _VI_FUNC rssmf_GetSYSTemNetworkCommonDomain (ViSession instrumentHandle,
                                                      ViInt32 arraySize,
                                                      ViChar _VI_FAR commonDomain[]);
ViStatus _VI_FUNC rssmf_SetSYSTemNetworkCommonHostname (ViSession instrumentHandle,
                                                        ViString commonHostname);
ViStatus _VI_FUNC rssmf_GetSYSTemNetworkCommonHostname (ViSession instrumentHandle,
                                                        ViInt32 arraySize,
                                                        ViChar _VI_FAR commonHostname[]);
ViStatus _VI_FUNC rssmf_SYSTemNetworkCommonExecute (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmf_SetSYSTemNetworkPreferedDNS (ViSession instrumentHandle,
                                                     ViString preferedDNS);
ViStatus _VI_FUNC rssmf_GetSYSTemNetworkPreferedDNS (ViSession instrumentHandle,
                                                     ViInt32 arraySize,
                                                     ViChar _VI_FAR preferedDNS[]);
ViStatus _VI_FUNC rssmf_SetSYSTemNetworkAlternateDNS (ViSession instrumentHandle,
                                                      ViString alternateDNS);
ViStatus _VI_FUNC rssmf_GetSYSTemNetworkAlternateDNS (ViSession instrumentHandle,
                                                      ViInt32 arraySize,
                                                      ViChar _VI_FAR alternateDNS[]);
ViStatus _VI_FUNC rssmf_SetSYSTemNetworkDNSMode (ViSession instrumentHandle,
                                                 ViInt32 DNSMode);
ViStatus _VI_FUNC rssmf_GetSYSTemNetworkDNSMode (ViSession instrumentHandle,
                                                 ViPInt32 DNSMode);
ViStatus _VI_FUNC rssmf_SYSTemNetworkDNSExecute (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmf_SetSYSTemNetworkDomain (ViSession instrumentHandle,
                                                ViString domain);
ViStatus _VI_FUNC rssmf_GetSYSTemNetworkDomain (ViSession instrumentHandle,
                                                ViInt32 arraySize,
                                                ViChar _VI_FAR domain[]);
ViStatus _VI_FUNC rssmf_SetSYSTemNetworkGateway (ViSession instrumentHandle,
                                                 ViString gateway);
ViStatus _VI_FUNC rssmf_GetSYSTemNetworkGateway (ViSession instrumentHandle,
                                                 ViInt32 arraySize,
                                                 ViChar _VI_FAR gateway[]);
ViStatus _VI_FUNC rssmf_GetSYSTemNetworkResource (ViSession instrumentHandle,
                                                  ViInt32 arraySize,
                                                  ViChar _VI_FAR resource[]);
ViStatus _VI_FUNC rssmf_SetSYSTemNetworkSubnetMask (ViSession instrumentHandle,
                                                    ViString subnetMask);
ViStatus _VI_FUNC rssmf_GetSYSTemNetworkSubnetMask (ViSession instrumentHandle,
                                                    ViInt32 arraySize,
                                                    ViChar _VI_FAR subnetMask[]);
ViStatus _VI_FUNC rssmf_SetSYSTemNetworkWorkgroup (ViSession instrumentHandle,
                                                   ViString workgroup);
ViStatus _VI_FUNC rssmf_GetSYSTemNetworkWorkgroup (ViSession instrumentHandle,
                                                   ViInt32 arraySize,
                                                   ViChar _VI_FAR workgroup[]);
ViStatus _VI_FUNC rssmf_GetSYSTemNetworkMACAddress (ViSession instrumentHandle,
                                                    ViInt32 arraySize,
                                                    ViChar _VI_FAR MACAddress[]);
ViStatus _VI_FUNC rssmf_GetSYSTemNetwork (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmf_TriggerSourceAllSweeps (ViSession instrumentHandle,
                                                ViInt32 triggerSourceAllSweeps);
ViStatus _VI_FUNC rssmf_TriggerAllSweeps (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmf_SweepReset (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmf_TriggerRFFrequencySweep (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmf_TriggerRFLevelSweep (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmf_SetNoSignalMarkerPolarity (ViSession instrumentHandle,
                                                   ViInt32 markerPolarity);
ViStatus _VI_FUNC rssmf_GetNoSignalMarkerPolarity (ViSession instrumentHandle,
                                                   ViPInt32 markerPolarity);
ViStatus _VI_FUNC rssmf_SetBlankWidth (ViSession instrumentHandle,
                                       ViInt32 blankWidth);
ViStatus _VI_FUNC rssmf_GetBlankWidth (ViSession instrumentHandle,
                                       ViPInt32 blankWidth);
ViStatus _VI_FUNC rssmf_SetAngleUnits (ViSession instrumentHandle,
                                       ViInt32 angleUnits);
ViStatus _VI_FUNC rssmf_GetAngleUnits (ViSession instrumentHandle,
                                       ViPInt32 angleUnits);
ViStatus _VI_FUNC rssmf_SetPowerUnits (ViSession instrumentHandle,
                                       ViInt32 powerUnits);
ViStatus _VI_FUNC rssmf_GetPowerUnits (ViSession instrumentHandle,
                                       ViPInt32 powerUnits);
ViStatus _VI_FUNC rssmf_SetVelocityUnits (ViSession instrumentHandle,
                                          ViInt32 velocityUnits);
ViStatus _VI_FUNC rssmf_GetVelocityUnits (ViSession instrumentHandle,
                                          ViPInt32 velocityUnits);
ViStatus _VI_FUNC rssmf_readToFile (ViSession instrumentHandle, ViString source,
                                    ViString destination);
ViStatus _VI_FUNC rssmf_writeFromFile (ViSession instrumentHandle, ViString source,
                                       ViString destination);
ViStatus _VI_FUNC rssmf_errorCheckState (ViSession instrumentHandle,
                                         ViBoolean stateChecking);
ViStatus _VI_FUNC rssmf_optionCheckState (ViSession instrumentHandle,
                                          ViBoolean stateChecking);
ViStatus _VI_FUNC rssmf_rangeCheckState (ViSession instrumentHandle,
                                         ViBoolean rangeChecking);
ViStatus _VI_FUNC rssmf_writeInstrData (ViSession instrumentHandle,
                                        ViString writeBuffer);
ViStatus _VI_FUNC rssmf_readInstrData (ViSession instrumentHandle,
                                       ViInt32 numberBytesToRead,
                                       ViChar _VI_FAR readBuffer[],
                                       ViPInt32 numBytesRead);
ViStatus _VI_FUNC rssmf_DevicePreset (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmf_reset (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmf_self_test (ViSession instrumentHandle,
                                   ViPInt16 selfTestResult,
                                   ViChar _VI_FAR selfTestMessage[]);
ViStatus _VI_FUNC rssmf_error_query (ViSession instrumentHandle, ViPInt32 errorCode,
                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC rssmf_error_message (ViSession instrumentHandle,
                                       ViStatus statusCode,
                                       ViChar _VI_FAR message[]);
ViStatus _VI_FUNC rssmf_revision_query (ViSession instrumentHandle,
                                        ViChar _VI_FAR instrumentDriverRevision[],
                                        ViChar _VI_FAR firmwareRevision[]);
ViStatus _VI_FUNC rssmf_delay (ViSession instrumentHandle, ViReal64 seconds);

ViStatus _VI_FUNC rssmf_IDQueryResponse (ViSession instrumentHandle,
                                         ViUInt32 bufferSize,
                                         ViChar IDQueryResponse[]);

ViStatus _VI_FUNC rssmf_ProcessAllPreviousCommands (ViSession instrumentHandle);

ViStatus _VI_FUNC rssmf_QueryOPC (ViSession instrumentHandle, ViInt32 *OPC);

ViStatus _VI_FUNC rssmf_close (ViSession instrumentHandle);

#if defined(__cplusplus) || defined(__cplusplus__)
}
#endif

/*****************************************************************************/
/*=== END INCLUDE FILE ======================================================*/
/*****************************************************************************/

#endif

