#include <visa.h>

/*= Useful Macros ===========================================================*/

/* - Basic Macros ---------------------------------------------------------- */

/* Error checking macro */
#define CHECKERR(fCal) if (rssmf_status = (fCal), rssmf_status < VI_SUCCESS) \
    return rssmf_status

/* Error checking macro with jump to the ERROR: label */
#define GOCHECKERR(fCal) if (rssmf_status = (fCal), rssmf_status < VI_SUCCESS) \
                            goto ERROR_LABEL
/* Parameter checking macro */
#define CHECKPARAM(fCal,param) if (fCal != VI_SUCCESS) return VI_ERROR_PARAMETER##param

/* Checking path parameter */
#define CHECKPATH if (rssmf_invalidViInt32Range (instrSession, path, 1, 2) != 0) return rssmf_ParameterError (instrSession, "path");

/* Initialize default function parameters */
#define INIT\
    ViStatus            rssmf_status = VI_SUCCESS; \
    rssmf_instrRange    instrPtr = NULL; \
    CHECKERR (viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr));\
    if (instrPtr == NULL)\
        return VI_ERROR_INSTR_PARAMETER

/* Close function and return */
#define RETURN\
    return rssmf_status;

/* - Additional Macros ----------------------------------------------------- */

#define CHECKOPT(option) if (instrPtr->optionChecking == VI_TRUE)\
                         {\
                            if (instrPtr->instrOptions.option == 0)\
                                return RSSMF_ERROR_INSTRUMENT_OPTION;\
                         }

#define CHECKOPTCONT(option) if (instrPtr->optionChecking == VI_TRUE)\
                         {\
                            if (instrPtr->instrOptions.option == 0)\
                                rssmf_status = RSSMF_ERROR_INSTRUMENT_OPTION;\
                         }
/* Check NULL pointer */
#define CHECKNULL(pointer) if (pointer == NULL) return rssmf_ParameterError(instrSession,#pointer)


#define RS_VAL_TRUNCATE                         1
#define RS_VAL_APPEND                           2

/*****************************************************************************/
/*= INSTRUMENT-DEPENDENT STATUS/RANGE STRUCTURE  ============================*/
/*****************************************************************************/
/* rssmf_stringValPair is used in the rssmf_error_message function           */
/* rssmf_statusDataRanges is used to track session dependent status & ranges */
/*===========================================================================*/
typedef struct  rssmf_stringValPair
{
   ViStatus stringVal;
   ViString stringName;
}  rssmf_tStringValPair;

typedef struct rssmf_instrOptions
{
    int B20:1;
    int B22:1;
    int B29:1;
    int B80:1;
    int B81:1;
    int B103:1;
    int B106:1;
    int K23:1;
    int K24:1;
    int K25:1;
    int K83:1;
  int K27:1;
  int K22:1;
  int K20:1;
  int K4:1;
  int K28:1;
} rssmf_tinstrOptions;

struct rssmf_statusDataRanges
{
    ViChar              instrDriverRevision[256];
    ViBoolean           errorChecking;
    ViBoolean           optionChecking;
  ViBoolean           rangeChecking;
    rssmf_tinstrOptions instrOptions;
	ViChar      parameterErrorMessage[256];
};

typedef struct rssmf_statusDataRanges *rssmf_instrRange;
ViBoolean rssmf_invalidViBooleanRange (ViSession instrSession, ViBoolean val);
ViBoolean rssmf_invalidViInt32Range (ViSession instrSession, ViInt32 val, ViInt32 min, ViInt32 max);
ViBoolean rssmf_invalidViUInt32Range (ViSession instrSession, ViUInt32 val, ViUInt32 min, ViUInt32 max);
ViBoolean rssmf_invalidViReal64Range (ViSession instrSession, ViReal64 val, ViReal64 min,
                                       ViReal64 max);
ViStatus rssmf_checkStatus (ViSession instrSession);
ViStatus rssmf_waitOPC (ViSession instrSession, ViPString command,
                        ViPString instrResp, ViInt32 timeout);
ViStatus rssmf_sendCmd (ViSession instrSession, ViString cmd);
ViStatus rssmf_setViInt32 (ViSession instrSession,
                           ViString cmd,
                           ViInt32 value,
                           ViInt32 min,
                           ViInt32 max,
                           ViString parameterName);
ViStatus rssmf_getViInt32 (ViSession instrSession,
                           ViString cmd,
                           ViInt32 *value,
                           ViString parameterName);
ViStatus rssmf_setViBoolean (ViSession instrSession,
                           ViString cmd,
                           ViBoolean value,
                           ViString parameterName);
ViStatus rssmf_getViBoolean (ViSession instrSession,
                           ViString cmd,
                           ViBoolean *value,
                           ViString parameterName);
ViStatus rssmf_setViBooleanPath (ViSession instrSession,
                           ViString cmd,
                           ViInt32 path,
                           ViBoolean value,
                           ViString parameterName);
ViStatus rssmf_getViBooleanPath (ViSession instrSession,
                           ViString cmd,
                           ViInt32 path,
                           ViBoolean *value,
                           ViString parameterName);
ViStatus rssmf_setViReal64 (ViSession vi,
                            ViString cmd,
                            ViReal64 value,
                            ViReal64 min,
                            ViReal64 max,
                            ViString parameterName);
ViStatus rssmf_setViReal64Path (ViSession instrSession,
                            ViString cmd,
                            ViInt32  path,
                            ViReal64 value,
                            ViReal64 min,
                            ViReal64 max,
                            ViString parameterName);
ViStatus rssmf_getViReal64Path (ViSession instrSession,
                            ViString cmd,
                            ViInt32 path,
                            ViReal64 *value,
                            ViString parameterName);
ViStatus rssmf_getViReal64 (ViSession instrSession,
                            ViString cmd,
                            ViReal64 *value,
                            ViString parameterName);
ViStatus rssmf_setViReal64Units (ViSession instrSession,
                                 ViString cmd,
                                 ViReal64 value,
                                 ViString units,
                                 ViReal64 min,
                                 ViReal64 max,
                                 ViString parameterName);
ViStatus rssmf_setViString (ViSession instrSession,
                            ViString cmd,
                            ViString value,
                            ViString parameterName);
ViStatus rssmf_getViString (ViSession instrSession,
                            ViString cmd,
                            ViString value,
                            ViUInt32 buffer_size,
                            ViString parameterName);
ViStatus rssmf_setViStringQuoted (ViSession instrSession,
                            ViString cmd,
                            ViString quotes,
                            ViString value,
                            ViString parameterName);
ViStatus rssmf_getViStringQuoted (ViSession instrSession,
                                  ViString cmd,
                                  ViString quotes,
                                  ViInt32  arraySize,
                                  ViChar   value[],
                                  ViString parameterName);
ViStatus rssmf_setViStringPath (ViSession instrSession,
                            ViString cmd,
                            ViInt32 path,
                            ViString value,
                            ViString parameterName);
ViStatus rssmf_setEnum (ViSession instrSession,
                        ViString cmd,
                        ViInt32 value,
                        ViString list[],
                        ViString parameterName);
ViStatus rssmf_getEnum (ViSession instrSession,
                        ViString cmd,
                        ViInt32 *value,
                        ViString list[],
                        ViString parameterName);
ViStatus rssmf_setEnumPath (ViSession instrSession,
                        ViString cmd,
                        ViInt32 path,
                        ViInt32 value,
                        ViString list[],
                        ViString parameterName);
ViStatus rssmf_getEnumPath (ViSession instrSession,
                        ViString cmd,
                        ViInt32 path,
                        ViInt32 *value,
                        ViString list[],
                        ViString parameterName);
ViStatus rssmf_setViUInt32 (ViSession instrSession,
                           ViString cmd,
                           ViUInt32 value,
                           ViUInt32 min,
                           ViUInt32 max,
                           ViString parameterName);
ViStatus rssmf_getViUInt32 (ViSession instrSession,
                           ViString cmd,
                           ViUInt32 *value,
                           ViString parameterName);
ViStatus rssmf_checkIndexInList (ViSession instrSession,
								 ViInt32 index,
                                 ViString list[],
								 ViString parameterName);
ViStatus rssmf_getIndexFromString (ViString string,
                                   ViString *list,
                                   ViInt32 *index);
ViStatus rssmf_getCatalog (ViSession instrSession,
                           ViString cmd,
                           ViUInt32 arraySize,
                           ViChar* array,
                           ViString parameterName);
ViStatus rssmf_getViReal64Array (ViSession instrSession,
                            ViString cmd,
                            ViReal64 *value,
                            ViInt32  count,
                            ViString parameterName);
ViStatus rssmf_getViInt32Array (ViSession instrSession,
                            ViString cmd,
                            ViInt32 *value,
                            ViInt32  count,
                            ViString parameterName);
ViStatus rssmf_readDataUnknownLength(ViSession instrSession,
                                     /*@null@*/ViChar **outBuffer,
                                     ViUInt32 *count);
ViStatus rssmf_readDataToFile (ViSession instrSession, ViString cmd,
                           ViString destination);
ViStatus rssmf_ParameterError (ViSession io, ViString parameterName);
ViStatus rssmf_ReadToFile (ViSession io,
                        ViConstString filename,
                        ViUInt64 maxBytesToRead,
                        ViInt32 fileAction);
ViStatus rssmf_WriteFromFile (ViSession instrSession,
                           ViConstString filename,
                           ViUInt64 maxBytesToWrite,
                           ViUInt64 byteOffset);
