/*= R&S SMF Microwave Signal Generator =======================================
 * LabWindows/CVI 8.0 VXIpnp Instrument Driver
 * Original Release: June 2007
 * By: Jiri Kominek
 *
 * Should you have any technical questions please contact the hotline of
 * Rohde & Schwarz Vertriebs-GmbH Rohde & Schwarz Support Center
 *
 * e-mail: CustomerSupport@rohde-schwarz.com
 *
 * Modification History:
 *
 *   see file ChangeLog
 *
 *===========================================================================*/
#include <math.h>
#include <visa.h>
#include <string.h>
#include <stdio.h>
#include <stdlib.h>
#include <ctype.h>
#include "rssmf.h"
#include "rssmf_utility.h"
#include <limits.h>
#include <locale.h>  
#include "time.h"
#if (defined(WIN32) || defined(_WIN32) || defined(__WIN32__) || defined(__NT__))
    #define ANSI
#endif
#ifndef ANSI                /* UNIX compatible */
    #include <sys/timeb.h>
    #include <sys/types.h>
    #include <unistd.h>
    #define Sleep sleep
#else                       /* ANSI compatible */
        #include <windows.h>
#endif
#if defined (_CVI_)
	#include <userint.h>
	#include <utility.h>
#endif

/*= Macros ==================================================================*/

#define CHECKERR_CU(fCal) if (rssmf_status = (fCal), rssmf_status < VI_SUCCESS) \
    return rssmf_initCleanUp (rmSession, instrSession, rssmf_status); else

#define CHECKVIUINT32(io, arg, min, max) if ( rssmf_invalidViUInt32Range (io, arg,min,max)) return rssmf_ParameterError(io,#arg)
#define CHECKVIINT32(io, arg, min, max) if ( rssmf_invalidViInt32Range (io, arg,min,max)) return rssmf_ParameterError(io,#arg)
#define CHECKVIREAL64(io, arg, min, max) if ( rssmf_invalidViReal64Range (io, arg,min,max)) return rssmf_ParameterError(io,#arg)

#define SETPARAMENUM(io,cmd,value,list) rssmf_setEnum (io,cmd,value,list,#value)
#define GETPARAMENUM(io,cmd,value,list) rssmf_getEnum (io,cmd,value,list,#value)
#define SETPARAMENUMPATH(io,cmd,path,value,list) rssmf_setEnumPath (io,cmd,path,value,list,#value)
#define GETPARAMENUMPATH(io,cmd,path,value,list) rssmf_getEnumPath (io,cmd,path,value,list,#value)

#define SETPARAMREAL64(io,cmd,value,min,max) rssmf_setViReal64 (io,cmd,value,min,max,#value)
#define GETPARAMREAL64(io,cmd,value) rssmf_getViReal64 (io,cmd,value,#value)
#define SETPARAMREAL64PATH(io,cmd,path,value,min,max) rssmf_setViReal64Path (io,cmd,path,value,min,max,#value)
#define GETPARAMREAL64PATH(io,cmd,path,value) rssmf_getViReal64Path (io,cmd,path,value,#value)
#define GETPARAMREAL64ARRAY(io,cmd,value,count) rssmf_getViReal64Array (io,cmd,value,count,#value)

#define SETPARAMINT32(io,cmd,value,min,max) rssmf_setViInt32 (io,cmd,value,min,max,#value)
#define GETPARAMINT32(io,cmd,value) rssmf_getViInt32 (io,cmd,value,#value)
#define GETPARAMINT32ARRAY(io,cmd,value,count) rssmf_getViInt32Array (io,cmd,value,count,#value)

#define SETPARAMUINT32(io,cmd,value,min,max) rssmf_setViUInt32 (io,cmd,value,min,max,#value)
#define GETPARAMUINT32(io,cmd,value) rssmf_getViUInt32 (io,cmd,value,#value)

#define SETPARAMBOOL(io,cmd,value) rssmf_setViBoolean (io,cmd,value,#value)
#define GETPARAMBOOL(io,cmd,value) rssmf_getViBoolean (io,cmd,value,#value)
#define SETPARAMBOOLPATH(io,cmd,path,value) rssmf_setViBooleanPath (io,cmd,path,value,#value)
#define GETPARAMBOOLPATH(io,cmd,path,value) rssmf_getViBooleanPath (io,cmd,path,value,#value)

#define SETPARAMSTRINGQUOTED(io,cmd,quotes,value) rssmf_setViStringQuoted (io,cmd,quotes,value,#value)
#define GETPARAMSTRINGQUOTED(io,cmd,quotes,buf_size,value) rssmf_getViStringQuoted (io,cmd,quotes,buf_size,value,#value)

#define SETPARAMSTRING(io,cmd,value) rssmf_setViString (io,cmd,value,#value)
#define GETPARAMSTRING(io,cmd,value,buf_size) rssmf_getViString (io,cmd,value,buf_size,#value)
/*= DEFINES =================================================================*/

#define RSSMF_REVISION          "Rev 2.21.0, 07/2016, CVI 2015" /* Instrument driver revision */
#define BUFFER_SIZE             2048L    /* File I/O buffer size */

#define RSSMF_DEFAULT_TIMEOUT   10000   /* Default Timeout value in ms (10 sec) */

/*****************************************************************************/
/*= INSTRUMENT-DEPENDENT COMMAND ARRAYS =====================================*/
/*****************************************************************************/
static ViString sweepLevelModeArr[] = {"AUTO","MAN","STEP", VI_NULL};
static ViString lfSweepModeArr[] = {"AUTO","STEP","EXT", VI_NULL};
static ViString triggerRFSourceArr[] = {"AUTO","IMM","SING","EXT","BUS", VI_NULL};
static ViString lfOutputModeArr[] = {"CW","SWE", VI_NULL};
static ViString spacingArr[] = {"LIN","LOG", VI_NULL};
static ViString distributionArr[] = {"GAUS","EQU", VI_NULL};
static ViString pulmSourceArr[] = {"INT","EXT","RAND", VI_NULL};
static ViString polarityArr[] = {"NORM","INV", VI_NULL};
static ViString pulmTriggerModeArr[] = {"AUTO","EXT","EGAT", VI_NULL};
static ViString fmModeArr[] = {"NORM","LNO", VI_NULL};
static ViString pmModeArr[] = {"HBAN","HDEV","LNO", VI_NULL};
static ViString variationArr[] = {"DEC","USER",VI_NULL};
static ViString onRecallArr[] = {"INCL","EXCL", VI_NULL};
static ViString slopeArr[] = {"POS","NEG", VI_NULL};
static ViString externalReferenceFreqArr[] = {"5MHZ","10MHZ","13MHZ", VI_NULL};
static ViString roscBandwidthArr[] = {"NARR","WIDE", VI_NULL};
static ViString powerOnStateArr[] = {"OFF","UNCH", VI_NULL};
static ViString attenuatorModeArr[] = {"AUTO","FIX", VI_NULL};
static ViString testCommandsArr[] = {"SSYN","SSYNEX","IQOP3","IQOP6","SATT3",
                                     "SATT6","BBINS","DIRECTLAST", VI_NULL};
static ViString keyboardArr[] = {"US","DE", VI_NULL};
static ViString blankModeArr[] = {"OFF","ON","AUTO", VI_NULL};
static ViString ipAddressModeArr[] = {"STAT","P2P","AUTO", VI_NULL};
static ViString dnsModeArr[] = {"STAT","AUTO",VI_NULL};
static ViString shapeArr[] = {"SINE","SQU","TRI","TRAP", VI_NULL};
static ViString monitoringArr[] = {"OFF","AM","FMPM", VI_NULL};
static ViString externalCouplingArr[] = {"AC","DC", VI_NULL};
static ViString proportionalScaleArr[] = {"S0V5","S1V0", VI_NULL};
static ViString frequencySpacingArr[] = {"LIN","LOG","RAMP", VI_NULL};
static ViString dexcListModeArr[] = {"IMP","EXP", VI_NULL};
static ViString dexcExtensionArr[] = {"TXT","CSV", VI_NULL};
static ViString dexcSeparatorArr[] = {"TAB","SEM","COMM","SPAC", VI_NULL};
static ViString dexcDecimalSeparatorArr[] = {"DOT","COMM", VI_NULL};
static ViString markerPolarityArr[] = {"NORM","INV", VI_NULL};
static ViString lfoBandwidthArr[] = {"BW0M2","BW10", VI_NULL};
static ViString pulmTriggerLevelArr[] = {"TTL","P0V5","M2V5", VI_NULL};
static ViString externalInputImpedanceArr[] = {"G50","G10K",VI_NULL};
static ViString dmSourceArr[] = {"LF1","LF2","EXT1","EXT2","NOIS", VI_NULL};
static ViString askSourceArr[] = {"EXT1","EXT2","PGEN","RAND", VI_NULL};
static ViString roscOutputArr[] = {"INT","EXT", VI_NULL};
static ViString powerResolutionArr[] = {"R01","R1", VI_NULL};
static ViString rfPowerDuringSearchArr[] = {"NORM","MIN", VI_NULL};
static ViString shapeTrapezeArr[] = {"FALL","HIGH","PERIOD","RISE", VI_NULL};
static ViString shapeTriangleArr[] = {"PER","RISE",VI_NULL};
static ViString shapePulseArr[] = {"DCYC","PER","WIDT", VI_NULL};
static ViString regGroupArr[] = {"OPER","QUES", VI_NULL};
static ViString regTypeArr[] = {"COND","EVEN","ENAB","NTR","PTR", VI_NULL};
static ViString frequencyModeArr[] = {"CW","SWE","LIST", VI_NULL};
static ViString extInputImpedanceArr[] = {"G50","G600","G100", VI_NULL};
static ViString pulmModeArr[] = {"SING","DOUB","PTR", VI_NULL};
static ViString chirpTriggerModeArr[] = {"AUTO","EXT","EGAT", VI_NULL};
static ViString chirpTriggerSlopeArr[] = {"POS","NEG", VI_NULL};
static ViString chirpTriggerLevelArr[] = {"TTL","P0V5","M2V5", VI_NULL};
static ViString chirpGatePolarityArr[] = {"INV","NORM", VI_NULL};
static ViString chirpImpedanceArr[] = {"G10K","G50", VI_NULL};
static ViString chirpDirectionArr[] = {"UP","DOWN", VI_NULL};
static ViString angleUnitsArr[] = {"DEG","RAD", VI_NULL};
static ViString powerUnitsArr[] = {"V","DBM", VI_NULL};
static ViString velocityUnitsArr[] = {"MPS","KMH","MPH", VI_NULL};
static ViString frequencySweepShapeArr[] = {"SAWT","TRI", VI_NULL};
static ViString powerFilterModeArr[] = {"AUTO","USER","NSR", VI_NULL};
static ViString powerFrequencyTimingArr[] = {"NORM","FAST","HPR", VI_NULL};
static ViString powerFrequencySpacingArr[] = {"LIN","LOG", VI_NULL};
static ViString powerTimingArr[] = {"NORM","FAST","HPR", VI_NULL};
static ViString senseModeArr[] = {"SING","CONT", VI_NULL};
static ViString sweepModeArr[] = {"FREQ","POW","TIME", VI_NULL};
static ViString sweepHardcopyFormatArr[] = {"BMP","JPG","XPM","PNG", VI_NULL};
static ViString powerSourceArr[] = {"A","USER","B", VI_NULL};
static ViString sensePowerUnitArr[] = {"DBM","DBUV","WATT", VI_NULL};
static ViString ALCOffModeArr[] = {"SHOL", VI_NULL};
static ViString blankWidthArr[] = {"RFBL","TRIG", VI_NULL};
static ViString powerPriorityArr[] = {"AVER","PEAK", VI_NULL};
static ViString powerGateTraceArr[] = {"TRAC1","TRAC2","TRAC3", VI_NULL};
static ViString powerTimeTriggerSourceArr[] = {"AUTO","FREE", VI_NULL};
static ViString listModeArr[] = {"AUTO","STEP", VI_NULL};
static ViString listTriggerSourceArr[] = {"AUTO","SING","EXT", VI_NULL};
static ViString ListAttenuatorModeArr[] = {"NORM","HPOW", VI_NULL};
static ViString calLevelAdjDataArr[] = {"FACT","CUST", VI_NULL};
static ViString hcopImageSizeArr[] = {"320,240","640,480","800,600","1024,768", VI_NULL};
static ViString hcopDeviceArr[] = {"FILE", VI_NULL};
static ViString runModeArr[] = {"SING","CONT", VI_NULL};
static ViString powerFrequencyYScaleAutoArr[] = {"OFF","CEXP","FEXP","CFL","FFL", VI_NULL};
static ViString pulseThresholdBaseArr[] = {"VOLT","POW", VI_NULL};
static ViString pulseThresholdModeArr[] = {"HREF","REF","LREF", VI_NULL};
static ViString traceColorArr[] = {"INV","GRAY","YELL","BLUE","GRE","RED","MAG", VI_NULL};
static ViString traceCopyArr[] = {"REF", VI_NULL};
static ViString traceSourceArr[] = {"SENS1","SENS2","SENS3","REF","NONE", VI_NULL};
static ViString powerSensorDisplayColorArr[] = {"BLAC","WHIT", VI_NULL};
static ViString hcopHeaderArr[] = {"OFF","STAN", VI_NULL};
static ViString hcopOrientationArr[] = {"HOR","VERT", VI_NULL};
static ViString hcopColumnSeparatorArr[] = {"TAB","SEM","COMM","BLAN", VI_NULL};
static ViString powerSensorTypeArr[] = {"NRP","NRVD","HP437","ML2438","P44X", VI_NULL};
static ViString ALCDetectorArr[] = {"INT","DIOD","PMET",VI_NULL};
static ViString OFFattenuatorModeArr[] = {"NORM","ATT",VI_NULL};
static ViString activeMarkerArr[] = {"NONE","M01","M02","M03","M04","M05","M06","M07","M08","M09","M10", VI_NULL};
static ViString sweepShapeArr[] = {"SAWT","TRI", VI_NULL};
static ViString bandwidthArr[] = {"BW0M2","BW10", VI_NULL};
static ViString triggerEventsArr[] = {"AND","OR", VI_NULL};
static ViString externalLevelCorrectionArr[] = {"FACT","CUST", VI_NULL};
static ViString baudrateArr[] = {"2400","4800","9600","19200","38400","57600","115200", VI_NULL};
static ViString parityArr[] = {"NONE","ODD","EVEN", VI_NULL};
static ViString stopBitsArr[] = {"1","2", VI_NULL};
static ViString identificationrArr[] = {"AUTO","USER", VI_NULL};
static ViString sequenceArr[] = {"NORM","SWAP", VI_NULL};
static ViString formatArr[] = {"ASC","PACK", VI_NULL};
static ViString formatStatusRegisterArr[] = {"ASC","BIN","HEX","OCT", VI_NULL};

/*****************************************************************************/
/*= UTILITY ROUTINE DECLARATIONS (Non-Exportable Functions) =================*/
/*****************************************************************************/
ViStatus rssmf_initCleanUp (ViSession openRMSession, ViPSession openInstrSession,
                             ViStatus currentStatus);
ViStatus rssmf_defaultInstrSetup (ViSession openInstrSession);
ViStatus rssmf_SetSweepMode (ViSession instrSession, ViInt32 mode);
ViStatus rssmf_GetSweepMode (ViSession instrSession, ViPInt32 sweepMode);
ViStatus rssmf_SetFrequencySweepTriggerSource (ViSession instrSession, ViInt32 triggerSourceRFFreqSweep);
ViStatus rssmf_GetFrequencySweepTriggerSource (ViSession instrSession, ViPInt32 triggerSourceRFFreqSweep);
ViStatus rssmf_SetFrequencyMode (ViSession instrSession, ViInt32 frequencyMode);
ViStatus rssmf_GetFrequencyMode (ViSession instrSession, ViPInt32 frequencyMode);
ViStatus rssmf_SetSweepLevelMode (ViSession instrSession, ViInt32 sweepLevelMode);
ViStatus rssmf_GetSweepLevelMode (ViSession instrSession, ViPInt32 sweepLevelMode);
ViStatus rssmf_SetLevelSweepTriggerSource (ViSession instrSession, ViInt32 triggerSourceRFLevelSweep);
ViStatus rssmf_GetLevelSweepTriggerSource (ViSession instrSession, ViPInt32 triggerSourceRFLevelSweep);
ViStatus rssmf_SetLevelMode (ViSession instrSession, ViInt32 RFLevelMode);
ViStatus rssmf_GetLevelMode (ViSession instrSession, ViPInt32 RFLevelMode);
ViStatus rssmf_SetSweepLFMode (ViSession instrSession, ViInt32 LFSweepMode);
ViStatus rssmf_GetSweepLFMode (ViSession instrSession, ViPInt32 LFSweepMode);
ViStatus rssmf_SetLFSweepTriggerSource (ViSession instrSession, ViInt32 triggerSourceLFSweep);
ViStatus rssmf_GetLFSweepTriggerSource (ViSession instrSession, ViPInt32 triggerSourceLFSweep);
ViStatus rssmf_SetLFMode (ViSession instrSession, ViInt32 LFOutputMode);
ViStatus rssmf_GetLFMode (ViSession instrSession, ViPInt32 LFOutputMode);
ViStatus rssmf_SetModeLIST (ViSession instrSession, ViInt32 listMode);
ViStatus rssmf_SetLISTTriggerSource (ViSession instrSession,ViInt32 triggerSource);

/*****************************************************************************
 * Function: Initialize
 * Purpose:  This function performs the following initialization actions:
 *           
 *           - Opens a session to the Default Resource Manager resource and a 
 *           session to the specified device using the interface and address 
 *           specified in the Resource_Name control.
 *           
 *           - Performs an identification query on the Instrument.
 *           
 *           - Resets the instrument to a known state.
 *           
 *           - Sends initialization commands to the instrument that set any 
 *           necessary programmatic variables such as Headers Off, Short 
 *           Command form, and Data Transfer Binary to the state necessary for 
 *           the operation of the instrument driver.
 *           
 *           - Returns an Instrument Handle which is used to differentiate 
 *           between different sessions of this instrument driver.
 *           
 *           - Each time this function is invoked a Unique Session is opened.  
 *           It is possible to have more than one session open for the same 
 *           resource.
 *           
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_init(
    ViRsrc  resourceName,
    ViBoolean   idQuery,
    ViBoolean   resetDevice,
    ViSession*  instrSession
)
{
    ViStatus            rssmf_status = VI_SUCCESS;
    ViSession           rmSession = 0;
    ViChar              buffer[BUFFER_SIZE] = "";
    rssmf_instrRange    instrPtr = NULL;

    /* --- Set standard "C" locale --- */
    {
       char *locale;

       locale = setlocale(LC_ALL, "C");
    }
    
    /*- Open instrument session ---------------------------------------------*/
    CHECKERR( viOpenDefaultRM (&rmSession));

    if ((rssmf_status = viOpen (rmSession, resourceName, VI_LOAD_CONFIG,
                                 VI_NULL, instrSession)) < 0)
    {
        (void)viClose (rmSession);
        return rssmf_status;
    }

    /* Determine if the structure has been initialized for the current VISA  */
    /* Session and malloc if it has not.                                     */

    if (instrPtr == NULL)
        instrPtr = calloc (1, sizeof (struct rssmf_statusDataRanges));
        

    CHECKERR( viSetAttribute (*instrSession, VI_ATTR_USER_DATA, (ViAttrState)instrPtr));

    //With remote control via Ethernet, remote control is not automatically
    //set by means of a command. The instrument must be explicitly set to
    //the REMOTE state, e.g. by sending the intf command &GTR
    CHECKERR (viPrintf (*instrSession, "&GTR\n"));

    /*- Configure VISA Formatted I/O ----------------------------------------*/
    CHECKERR( viSetAttribute (*instrSession, VI_ATTR_TMO_VALUE,
                                 RSSMF_DEFAULT_TIMEOUT));
    CHECKERR( viSetBuf (*instrSession, (ViUInt16) (VI_READ_BUF|VI_WRITE_BUF), 4000));
    CHECKERR( viSetAttribute (*instrSession, VI_ATTR_WR_BUF_OPER_MODE,
                                 VI_FLUSH_ON_ACCESS));
    CHECKERR( viSetAttribute (*instrSession, VI_ATTR_RD_BUF_OPER_MODE,
                                 VI_FLUSH_ON_ACCESS));

    /* -------------------------------------------------------------------- */
    /* Drawback of Agilent VISA is patched by adding extra termination      */
    /* character "\n" to each I/O operation                                 */
    /*                                                                      */
    /* VI_ATTR_SEND_END_EN will stay with this attribute set to VI_TRUE     */
    /* -------------------------------------------------------------------- */

    CHECKERR( viSetAttribute (*instrSession, VI_ATTR_SEND_END_EN, VI_TRUE));

    // read/reset ESR which may still indicate device dependent error from 
    // previous handling!
    (void) rssmf_checkStatus(*instrSession);
    
    /*- Identification Query ------------------------------------------------*/
   
     if (idQuery != VI_FALSE)
     {
         CHECKERR( viQueryf (*instrSession, "*IDN?\n","%*[^,],%[^,]",
                                buffer));

         /* Check if instrument is supported or not */
         if (strstr(buffer, "SMF") == NULL)
             return rssmf_initCleanUp (rmSession, instrSession, VI_ERROR_FAIL_ID_QUERY);
     }

        /* Check if instrument is supported or not */
     
    /*- Reset instrument ----------------------------------------------------*/
    if (resetDevice != VI_FALSE)
	{
        CHECKERR( rssmf_reset (*instrSession));
	}
    else  /*- Send Default Instrument Setup ---------------------------------*/
	{
        CHECKERR( rssmf_defaultInstrSetup (*instrSession));
	}

    return rssmf_status;
}

/*****************************************************************************
 * Function: Configure LF Frequency Sweep
 * Purpose:  This function sets parameters of LF frequency sweep.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_confLFFreqSweep(
    ViSession   instrSession,
    ViInt32 mode,
    ViReal64    startFrequency,
    ViReal64    stopFrequency,
    ViInt32 spacing,
    ViReal64    step,
    ViReal64    dwellTime
)
{
    ViStatus    rssmf_status;

    CHECKERR (rssmf_SetLFSweepMode (instrSession, mode));
    CHECKERR (rssmf_SetLFSweepStartFreq (instrSession, startFrequency));
    CHECKERR (rssmf_SetLFSweepStopFreq (instrSession, stopFrequency));
    CHECKERR (rssmf_SetLFSweepSpacing (instrSession, spacing));
    if (spacing == RSSMF_LFOUTPUT_SWEEP_FREQUENCY_SPACING_LINEAR)
    {
        CHECKERR (rssmf_SetLFSweepStepLin (instrSession, step));
    }
    else
    {
        CHECKERR (rssmf_SetLFSweepStepLog (instrSession, step));
    }

    CHECKERR (rssmf_SetLFSweepDwellTime (instrSession, dwellTime));

    RETURN;
}

/*****************************************************************************
 * Function: LF Sweep Trigger
 * Purpose:  This function immediately starts an LF sweep. The MODE setting 
 *           determines which sweep is executed, e.g. 
 *           :SOURce:LFOutput:SWEep:FREQuency:MODE STEP. This function 
 *           corresponds to the manual-control command EXECUTE SINGLE SWEEP. 
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_LFSweepTrigger(
    ViSession   instrSession
)
{
    return rssmf_sendCmd (instrSession, "LFO:SWE:EXEC");
}

/*****************************************************************************
 * Function: Configure LF Sweep Marker
 * Purpose:  This function configures the LF frequency sweep marker.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_ConfigureLFSweepMarker (ViSession instrSession,
                                                ViUInt32 channel,
                                                ViBoolean state,
                                                ViBoolean amplitudeMarker,
                                                ViReal64 frequency,
                                                ViReal64 amplitude,
                                                ViInt32 polarity,
                                                ViInt32 activeMarker)
{
    ViStatus    rssmf_status;

    CHECKERR (rssmf_SetLFSweepMarkerState (instrSession, channel, state));
    CHECKERR (rssmf_SetLFSweepAmplitudeMarkerState (instrSession, channel, amplitudeMarker));
    CHECKERR (rssmf_SetLFSweepMarkerFrequency (instrSession, channel, frequency));
    CHECKERR (rssmf_SetLFSweepAmplitudeMarkerAttenuation (instrSession, amplitude));
    CHECKERR (rssmf_SetLFSweepMarkerPolarity (instrSession, polarity));
    CHECKERR (rssmf_SetLFSweepActiveMarker (instrSession, activeMarker));
    
    RETURN;    
}

/*****************************************************************************
 * Function: Set LF Sweep Mode
 * Purpose:  This function sets the sweep mode.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetLFSweepMode(
    ViSession   instrSession,
    ViInt32 mode
)
{
    ViStatus    rssmf_status;

    switch (mode)
    {
    case RSSMF_SWEEP_MODE_AUTO:
        CHECKERR (rssmf_SetSweepLFMode (instrSession, RSSMF_SWEEP_LOW_MODE_AUTO));
        CHECKERR (rssmf_SetLFSweepTriggerSource (instrSession,
                                                        RSSMF_TRIG_SOURCE_SWEEP_AUTO));
        CHECKERR (rssmf_SetLFMode (instrSession, RSSMF_LFOUTPUT_FREQUENCY_MODE_SWEEP));
        break;
    case RSSMF_SWEEP_MODE_SINGLE:
        CHECKERR (rssmf_SetSweepLFMode (instrSession, RSSMF_SWEEP_LOW_MODE_AUTO));
        CHECKERR (rssmf_SetLFSweepTriggerSource (instrSession, RSSMF_TRIG_SOURCE_SWEEP_SINGLE));
        CHECKERR (rssmf_SetLFMode (instrSession, RSSMF_LFOUTPUT_FREQUENCY_MODE_SWEEP));
        CHECKERR (rssmf_LFSweepTrigger (instrSession));
        break;
    case RSSMF_SWEEP_MODE_STEP:
        CHECKERR (rssmf_SetSweepLFMode (instrSession, RSSMF_SWEEP_LOW_MODE_MAN));
        CHECKERR (rssmf_SetLFMode (instrSession, RSSMF_FREQUENCY_MODE_SWEEP));
        break;
    case RSSMF_SWEEP_MODE_EXT_SINGLE:
        CHECKERR (rssmf_SetLFMode (instrSession, RSSMF_SWEEP_LOW_MODE_AUTO));
        CHECKERR (rssmf_SetLFSweepTriggerSource (instrSession,RSSMF_TRIG_SOURCE_SWEEP_EXTERNAL));
        CHECKERR (rssmf_SetLFMode (instrSession, RSSMF_LFOUTPUT_FREQUENCY_MODE_SWEEP));
        break;
    case RSSMF_SWEEP_MODE_EXT_STEP:
        CHECKERR (rssmf_SetSweepLFMode (instrSession, RSSMF_SWEEP_LOW_MODE_STEP));
        CHECKERR (rssmf_SetLFSweepTriggerSource (instrSession,
                                                        RSSMF_TRIG_SOURCE_SWEEP_EXTERNAL));
        CHECKERR (rssmf_SetLFMode (instrSession, RSSMF_LFOUTPUT_FREQUENCY_MODE_SWEEP));
        break;
    default:
        rssmf_status = rssmf_ParameterError (instrSession, "mode");
    }

    RETURN;
}

/*****************************************************************************
 * Function: Set LF Sweep Source
 * Purpose:  This function selects the source of the LF sweep.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetLFSweepSource(
    ViSession   instrSession,
    ViInt32 source
)
{
    INIT;
    CHECKOPT (B20);
    
    return SETPARAMENUM (instrSession,
                          "LFO:SWE:LFS",
                          source,
                          dmSourceArr);    
}

/*****************************************************************************
 * Function: Get LF Sweep Source
 * Purpose:  This function returns the source of the LF sweep.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetLFSweepSource(
    ViSession   instrSession,
    ViInt32*    source
)
{
    INIT;
    CHECKOPT (B20);
    
    return GETPARAMENUM (instrSession,
                          "LFO:SWE:LFS?",
                          source,
                          dmSourceArr);    
}

/*****************************************************************************
 * Function: Set LF Sweep Start Freq
 * Purpose:  This function sets the start frequency for the LF Sweep mode. 
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetLFSweepStartFreq(
    ViSession   instrSession,
    ViReal64    startFrequency
)
{
    INIT;
    CHECKOPT (B20);

    return SETPARAMREAL64 (instrSession,
                              "LFO:FREQ:STAR",
                              startFrequency,
                              0.1, 10.0e6);
}

/*****************************************************************************
 * Function: Get LF Sweep Start Freq
 * Purpose:  This function Returns the start frequency of the LF Sweep mode. 
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetLFSweepStartFreq(
    ViSession   instrSession,
    ViReal64*   startFrequency
)
{
    INIT;
    CHECKOPT (B20);

    return GETPARAMREAL64 (instrSession,
                              "LFO:FREQ:STAR?",
                              startFrequency);
}

/*****************************************************************************
 * Function: Set LF Sweep Stop Freq
 * Purpose:  This function sets the stop frequency for the LF sweep. 
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetLFSweepStopFreq(
    ViSession   instrSession,
    ViReal64    stopFrequency
)
{
    INIT;
    CHECKOPT (B20);

    return SETPARAMREAL64 (instrSession,
                              "LFO:FREQ:STOP",
                              stopFrequency,
                              0.1, 10.0e6);
}

/*****************************************************************************
 * Function: Get LF Sweep Stop Freq
 * Purpose:  This function returns the stop frequency of the LF sweep. 
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetLFSweepStopFreq(
    ViSession   instrSession,
    ViReal64*   stopFrequency
)
{
    INIT;
    CHECKOPT (B20);

    return GETPARAMREAL64 (instrSession,
                              "LFO:FREQ:STOP?",
                              stopFrequency);
}

/*****************************************************************************
 * Function: Set LF Sweep Shape
 * Purpose:  This function sets the cycle mode for a sweep sequence (shape).
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetLFSweepShape (ViSession instrSession,
                                         ViInt32 shape)
{
	INIT;
    CHECKOPT (B20);

    return SETPARAMENUM (instrSession,
                          "LFO:SWE:SHAP",
                          shape,
                          sweepShapeArr);    
}

/*****************************************************************************
 * Function: Get LF Sweep Shape
 * Purpose:  This function queries the cycle mode for a sweep sequence (shape).
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetLFSweepShape (ViSession instrSession,
                                         ViInt32 *shape)
{
	INIT;
    CHECKOPT (B20);

    return GETPARAMENUM (instrSession,
                          "LFO:SWE:SHAP?",
                          shape,
                          sweepShapeArr);    
}

/*****************************************************************************
 * Function: Set LF Sweep Spacing
 * Purpose:  This function selects linear or logarithmic sweep spacing.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetLFSweepSpacing(
    ViSession   instrSession,
    ViInt32 spacing
)
{
    INIT;
    CHECKOPT (B20);

    return SETPARAMENUM (instrSession,
                          "LFO:SWE:SPAC",
                          spacing,
                          spacingArr);
}

/*****************************************************************************
 * Function: Get LF Sweep Spacing
 * Purpose:  This function returns linear or logarithmic sweep spacing.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetLFSweepSpacing(
    ViSession   instrSession,
    ViInt32*    spacing
)
{
    INIT;
    CHECKOPT (B20);

    return GETPARAMENUM (instrSession,
                          "LFO:SWE:SPAC?",
                          spacing,
                          spacingArr);
}

/*****************************************************************************
 * Function: Set LF Sweep Step Lin
 * Purpose:  This function sets the step width for the linear sweep. 
 *           
 *           This function is linked to the command 
 *           :LFOutput:SWEep[:FREQuency]:POINts as follows:
 *           
 *           The following applies for STARt < STOP:
 *           POINts = (((STOP-STARt) / STEP:LIN) + 1
 *           
 *           If STEP:LIN changes, the value of POINTs is adjusted. The STARt 
 *           and STOP value is retained.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetLFSweepStepLin(
    ViSession   instrSession,
    ViReal64    stepLin
)
{
    INIT;
    CHECKOPT (B20);

    return SETPARAMREAL64 (instrSession,
                              "LFO:SWE:STEP",
                              stepLin,
                              0.0, 0.0);
}

/*****************************************************************************
 * Function: Get LF Sweep Step Lin
 * Purpose:  This function returns the step width for the linear sweep. 
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetLFSweepStepLin(
    ViSession   instrSession,
    ViReal64*   stepLin
)
{
    INIT;
    CHECKOPT (B20);

    return GETPARAMREAL64 (instrSession,
                              "LFO:SWE:STEP?",
                              stepLin);
}

/*****************************************************************************
 * Function: Set LF Sweep Step Log
 * Purpose:  This function specifies the step width factor for logarithmic 
 *           sweeps. The next frequency value of a sweep is calculated (for 
 *           STARt < STOP) using the following formula: 
 *           
 *           New frequency = Old frequency + STEP:LOG x Old frequency
 *           
 *           STEP:LOG therefore gives the fraction of the old frequency. The 
 *           frequency is increased by this fraction for the next sweep step.
 *           
 *           This function is linked to the command 
 *           :LFOutput:SWEep[:FREQuency]:POINts as follows:
 *           
 *           The following applies for logarithmic sweeps and STARt < STOP: 
 *           
 *           POINts = ((log STOP - log STARt) / log STEP:LOG) + 1
 *           
 *           If STEP:LOG changes, the value of POINTs is adjusted. The STARt 
 *           and STOP value is retained.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetLFSweepStepLog(
    ViSession   instrSession,
    ViReal64    stepLog
)
{
    INIT;
    CHECKOPT (B20);

    return SETPARAMREAL64 (instrSession,
                              "LFO:SWE:STEP:LOG",
                              stepLog,
                              0.01, 100.00);
}

/*****************************************************************************
 * Function: Get LF Sweep Step Log
 * Purpose:  This function returns the step width factor for logarithmic 
 *           sweeps.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetLFSweepStepLog(
    ViSession   instrSession,
    ViReal64*   stepLog
)
{
    INIT;
    CHECKOPT (B20);

    return GETPARAMREAL64 (instrSession,
                              "LFO:SWE:STEP:LOG?",
                              stepLog);
}

/*****************************************************************************
 * Function: Set LF Sweep Dwell Time
 * Purpose:  This function sets the dwell time for each frequency step of the 
 *           sweep.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetLFSweepDwellTime(
    ViSession   instrSession,
    ViReal64    dwellTime
)
{
    INIT;
    CHECKOPT (B20);

    return SETPARAMREAL64 (instrSession,
                              "LFO:SWE:DWEL",
                              dwellTime,
                              0.1e-3, 10.0);
}

/*****************************************************************************
 * Function: Get LF Sweep Dwell Time
 * Purpose:  This function returns the dwell time of frequency step of the 
 *           sweep.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetLFSweepDwellTime(
    ViSession   instrSession,
    ViReal64*   dwellTime
)
{
    INIT;
    CHECKOPT (B20);

    return GETPARAMREAL64 (instrSession,
                              "LFO:SWE:DWEL?",
                              dwellTime);
}

/*****************************************************************************
 * Function: Set LF Sweep Manual Step
 * Purpose:  In Sweep mode (:SOUR:LFO:FREQ:MODE SWE) this function sets the 
 *           frequency for the next sweep step in the Step sweep mode 
 *           (:SOUR:LFO:SWE:MODE MAN). Here only frequency values between the 
 *           settings :SOUR:LFO:FREQ:STAR and ...:STOP are permitted. Each 
 *           sweep step is triggered by a separate :SOUR:LFO:FREQ:MAN command.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetLFSweepManualStep(
    ViSession   instrSession,
    ViReal64    manualStep
)
{
    INIT;
    CHECKOPT (B20);

    return SETPARAMREAL64 (instrSession,
                              "LFO:FREQ:MAN",
                              manualStep,
                              0.0, 0.0);
}

/*****************************************************************************
 * Function: Get LF Sweep Manual Step
 * Purpose:  In Sweep mode (:SOUR:LFO:FREQ:MODE SWE) this function returns the 
 *           frequency of the next sweep step in the Step sweep mode 
 *           (:SOUR:LFO:SWE:MODE MAN). Here only frequency values between the 
 *           settings :SOUR:LFO:FREQ:STAR and ...:STOP are permitted. Each 
 *           sweep step is triggered by a separate :SOUR:LFO:FREQ:MAN command.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetLFSweepManualStep(
    ViSession   instrSession,
    ViReal64*   manualStep
)
{
    INIT;
    CHECKOPT (B20);

    return GETPARAMREAL64 (instrSession,
                              "LFO:FREQ:MAN?",
                              manualStep);
}

/*****************************************************************************
 * Function: Set LF Sweep Points
 * Purpose:  This function sets the number of steps in an LF sweep. This 
 *           function is linked to the command :LFOutput:SWEep[:FREQuency]:STEP 
 *           as follows:
 *           
 *           The following applies for linear sweeps and STARt < STOP:     
 *           POINts = ((STOP-STARt) / STEP:LIN) + 1
 *           
 *           The following applies for logarithmic sweeps and STARt < STOP: 
 *           
 *           POINts = ((log STOP - log STARt) / log STEP:LOG) + 1
 *           
 *           If POINTs changes, the value of STEP is adjusted. The STARt and 
 *           STOP value is retained.
 *           
 *           Two separate POINts values are used for linear or logarithmic 
 *           sweep spacing (LFOutput:SWEep[:FREQuency]:SPACing LIN | LOG). This 
 *           function is always effective for the currently set sweep spacing.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetLFSweepPoints(
    ViSession   instrSession,
    ViUInt32    lfSweepPoints
)
{
    INIT;
    CHECKOPT (B20);

    return SETPARAMUINT32 (instrSession,
                             "LFO:SWE:POIN",
                             lfSweepPoints,
                             0, 0);
}

/*****************************************************************************
 * Function: Get LF Sweep Points
 * Purpose:  This function returns the number of steps in an LF sweep.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetLFSweepPoints(
    ViSession   instrSession,
    ViUInt32*   lfSweepPoints
)
{
    INIT;
    CHECKOPT (B20);

    return GETPARAMUINT32 (instrSession,
                             "LFO:SWE:POIN?",
                             lfSweepPoints);
}

/*****************************************************************************
 * Function: Set LF Sweep Marker State
 * Purpose:  This function activates or deactivates the selected marker. 
 *           If the marker is switched on, the signal level at the MARKER 
 *           output changes on reaching the frequency mark.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetLFSweepMarkerState (ViSession instrSession,
                                               ViUInt32 channel, ViBoolean state)
{
    INIT;
    CHECKOPT (B20);

    CHECKVIUINT32 (instrSession, channel, 1, 10);
    
    return SETPARAMBOOLPATH (instrSession,
                                   "SOUR:LFO:SWE:FREQ:MARK%ld:FST",
                                   channel,
                                   state);
}

/*****************************************************************************
 * Function: Get LF Sweep Marker State
 * Purpose:  This function returns the state of the selected marker.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetLFSweepMarkerState (ViSession instrSession,
                                               ViUInt32 channel,
                                               ViBoolean *state)
{
    INIT;
    CHECKOPT (B20);

    CHECKVIUINT32 (instrSession, channel, 1, 10);
    
    return GETPARAMBOOLPATH (instrSession,
                                   "SOUR:LFO:SWE:FREQ:MARK%ld:FST?",
                                   channel,
                                   state);
}

/*****************************************************************************
 * Function: Set LF Sweep Marker Frequency
 * Purpose:  This function sets the frequency of the selected marker. 
 *           If the marker is switched on, the signal level at the MARKER 
 *           output changes on reaching the frequency mark.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetLFSweepMarkerFrequency (ViSession instrSession,
                                                   ViUInt32 channel,
                                                   ViReal64 frequency)
{
    INIT;
    CHECKOPT (B20);

    CHECKVIUINT32 (instrSession, channel, 1, 10);
    
    return SETPARAMREAL64PATH (instrSession,
                                   "SOUR:LFO:SWE:FREQ:MARK%ld:FREQ",
                                   channel,
                                   frequency,
                                   0.0,0.0);
}

/*****************************************************************************
 * Function: Get LF Sweep Marker Frequency
 * Purpose:  This function returns the frequency of the selected marker.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetLFSweepMarkerFrequency (ViSession instrSession,
                                                   ViUInt32 channel,
                                                   ViReal64 *frequency)
{
    INIT;
    CHECKOPT (B20);

    CHECKVIUINT32 (instrSession, channel, 1, 10);
    
    return GETPARAMREAL64PATH (instrSession,
                                   "SOUR:LFO:SWE:FREQ:MARK%ld:FREQ?",
                                   channel,
                                   frequency);
}

/*****************************************************************************
 * Function: Set LF Sweep Amplitude Marker State
 * Purpose:  This function activates or deactivates the selected amplitude 
 *           marker. If activated, the level is reduced by the amplitude 
 *           entered below on reaching the mark.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetLFSweepAmplitudeMarkerState (ViSession instrSession,
                                                        ViUInt32 channel,
                                                        ViBoolean amplitudeMarker)
{
    INIT;
    CHECKOPT (B20);

    CHECKVIUINT32 (instrSession, channel, 1, 10);
    
    return SETPARAMBOOLPATH (instrSession,
                                   "SOUR:LFO:SWE:FREQ:MARK%ld:VST",
                                   channel,
                                   amplitudeMarker);
}

/*****************************************************************************
 * Function: Get LF Sweep Amplitude Marker State
 * Purpose:  This function returns the state of the selected amplitude marker.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetLFSweepAmplitudeMarkerState (ViSession instrSession,
                                                        ViUInt32 channel,
                                                        ViBoolean *amplitudeMarker)
{
    INIT;
    CHECKOPT (B20);

    CHECKVIUINT32 (instrSession, channel, 1, 10);
    
    return GETPARAMBOOLPATH (instrSession,
                                   "SOUR:LFO:SWE:FREQ:MARK%ld:VST?",
                                   channel,
                                   amplitudeMarker);
}

/*****************************************************************************
 * Function: Set LF Sweep Amplitude Marker Attenuation
 * Purpose:  This function sets the amplitude marker attenuation. This value 
 *           is valid for all markers.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetLFSweepAmplitudeMarkerAttenuation (ViSession instrSession,
                                                              ViReal64 amplitude)
{
    INIT;
    CHECKOPT (B20);

    return SETPARAMREAL64 (instrSession,
                              "SOUR:LFO:SWE:FREQ:MARK:AMPL",
                              amplitude,
                              1.0,3.0);
}

/*****************************************************************************
 * Function: Get LF Sweep Amplitude Marker Attenuation
 * Purpose:  This function returns the amplitude marker attenuation. This value 
 *           is valid for all markers.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetLFSweepAmplitudeMarkerAttenuation (ViSession instrSession,
                                                              ViReal64 *amplitude)
{
    INIT;
    CHECKOPT (B20);

    return GETPARAMREAL64 (instrSession,
                              "SOUR:LFO:SWE:FREQ:MARK:AMPL?",
                              amplitude);
}

/*****************************************************************************
 * Function: Set LF Sweep Marker Polarity
 * Purpose:  This function selects the marker output polarity.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetLFSweepMarkerPolarity (ViSession instrSession,
                                                  ViInt32 polarity)
{
    INIT;
    CHECKOPT (B20);

    CHECKVIINT32 (instrSession, polarity, RSSMF_SWEEP_MARKER_POLARITY_NORMAL, RSSMF_SWEEP_MARKER_POLARITY_INVERTED);
    
    return SETPARAMENUM (instrSession,
                          "SOUR:LFO:SWE:FREQ:MARK:OUTP:POL",
                          polarity,
                          polarityArr);
}

/*****************************************************************************
 * Function: Get LF Sweep Marker Polarity
 * Purpose:  This function returns the marker output polarity.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetLFSweepMarkerPolarity (ViSession instrSession,
                                                  ViInt32 *polarity)
{
    INIT;
    CHECKOPT (B20);

    return GETPARAMENUM (instrSession,
                          "SOUR:LFO:SWE:FREQ:MARK:OUTP:POL?",
                          polarity,
                          polarityArr);
}

/*****************************************************************************
 * Function: Set LF Sweep Active Marker
 * Purpose:  This function activates the selected marker. The active marker 
 *           is output with a higher voltage than all other markers.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetLFSweepActiveMarker (ViSession instrSession,
                                                ViInt32 activeMarker)
{
    INIT;
    CHECKOPT (B20);

    CHECKVIINT32 (instrSession, activeMarker, RSSMF_SWEEP_MARKER_ACTIVE_NONE, RSSMF_SWEEP_MARKER_ACTIVE_10);
    
    return SETPARAMENUM (instrSession,
                          "SOUR:LFO:SWE:FREQ:MARK:ACT",
                          activeMarker,
                          activeMarkerArr);
}

/*****************************************************************************
 * Function: Get LF Sweep Active Marker
 * Purpose:  This function returns the active marker.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetLFSweepActiveMarker (ViSession instrSession,
                                                ViInt32 *activeMarker)
{
    INIT;
    CHECKOPT (B20);

    return GETPARAMENUM (instrSession,
                          "SOUR:LFO:SWE:FREQ:MARK:ACT?",
                          activeMarker,
                          activeMarkerArr);
}

/*****************************************************************************
 * Function: Set LF Sweep All Markers Off
 * Purpose:  This function switches off all active frequency markers. 
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetLFSweepAllMarkersOff (ViSession instrSession)
{
    INIT;
    CHECKOPT (B20);

    return rssmf_sendCmd (instrSession, "SOUR:LFO:SWE:FREQ:MARK:AOFF");
}

/*****************************************************************************
 * Function: Set LFGen Bandwidth
 * Purpose:  This function the bandwith for the external feed via the EXT 1
 *           and/or EXT 2 input. Selection 200 kHz und 10 MHz are available.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetLFGenBandwidth (ViSession instrSession,
                                           ViInt32 channel, 
										   ViInt32 bandwidth)
{
    return SETPARAMENUMPATH (instrSession,
                              "SOUR:LFO%ld:BAND",
                              channel,
                              bandwidth,
                              bandwidthArr);
}

/*****************************************************************************
 * Function: Get LFGen Bandwidth
 * Purpose:  This function returns the bandwith for the external feed via the
 *           EXT 1 and/or EXT 2 input. Selection 200 kHz und 10 MHz are available.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetLFGenBandwidth (ViSession instrSession,
                                           ViInt32 channel, ViInt32 *bandwidth)
{
    INIT;
    CHECKOPT (B20);
    
    return GETPARAMENUMPATH (instrSession,
                              "SOUR:LFO%ld:BAND?",
                              channel,
                              bandwidth,
                              bandwidthArr);
}

/*****************************************************************************
 * Function: Set LFGen Frequency
 * Purpose:  This function sets the frequency of the LF signal for CW mode 
 *           (:SOUR::MODE CW mode). In Sweep mode (:SOUR:LFO:FREQ:MODE SWE), 
 *           the frequency is linked to the sweep frequency.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetLFGenFrequency(
    ViSession   instrSession,
    ViInt32 channel,
    ViReal64    frequency
)
{
    INIT;
    
    CHECKOPT (B20);
    
    return SETPARAMREAL64PATH (instrSession,
                                  "SOUR:LFO%ld:FREQ",
                                  channel,
                                  frequency,
                                  0.1, 10.0e6);
}

/*****************************************************************************
 * Function: Get LFGen Frequency
 * Purpose:  This function returns the frequency of the LF signal of CW mode 
 *           (:SOUR::MODE CW mode). In Sweep mode (:SOUR:LFO:FREQ:MODE SWE), 
 *           the frequency is linked to the sweep frequency.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetLFGenFrequency(
    ViSession   instrSession,
    ViInt32 channel,
    ViReal64*   frequency
)
{
    INIT;
    
    CHECKOPT (B20);
    
    return GETPARAMREAL64PATH (instrSession,
                                  "SOUR:LFO%ld:FREQ?",
                                  channel,
                                  frequency);
}

/*****************************************************************************
 * Function: Set LFGen Shape
 * Purpose:  This function selects the shape of the selected LF generator.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetLFGenShape(
    ViSession   instrSession,
    ViInt32 channel,
    ViInt32 shape
)
{
    INIT;
    CHECKOPT (B20);
    
    return SETPARAMENUMPATH (instrSession,
                              "SOUR:LFO%ld:SHAP",
                              channel,
                              shape,
                              shapeArr);
}

/*****************************************************************************
 * Function: Get LFGen Shape
 * Purpose:  This function returns the shape of the selected LF generator.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetLFGenShape(
    ViSession   instrSession,
    ViInt32 channel,
    ViInt32*    shape
)
{
    INIT;
    CHECKOPT (B20);
    
    return GETPARAMENUMPATH (instrSession,
                              "SOUR:LFO%ld:SHAP?",
                              channel,
                              shape,
                              shapeArr);
}

/*****************************************************************************
 * Function: Set LFGen Shape Trapeze
 * Purpose:  This function selects the fall/high/low/rise time for the trapeze 
 *           shape of the selected LF generator.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetLFGenShapeTrapeze(
    ViSession   instrSession,
    ViInt32 channel,
    ViInt32 trapeze,
    ViReal64    time
)
{
    ViChar buffer[BUFFER_SIZE];
    
    INIT;
    CHECKOPT (B20);
    
    CHECKVIINT32 (instrSession, channel, 1, 2);
    CHECKVIINT32 (instrSession, trapeze, 0, 3);
    
    sprintf (buffer, "SOUR:LFO%ld:SHAP:TRAP:%s", channel, shapeTrapezeArr[trapeze]);

    return SETPARAMREAL64 (instrSession,
                              buffer,
                              time,
                              1e-6, 100.0);
}

/*****************************************************************************
 * Function: Get LFGen Shape Trapeze
 * Purpose:  This function returns the fall/high/low/rise time for the trapeze 
 *           shape of the selected LF generator.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetLFGenShapeTrapeze(
    ViSession   instrSession,
    ViInt32 channel,
    ViInt32 trapeze,
    ViReal64*    time
)
{
    ViChar buffer[BUFFER_SIZE];
    
    INIT;
    CHECKOPT (B20);
    
    CHECKVIINT32 (instrSession, channel, 1, 2);
    CHECKVIINT32 (instrSession, trapeze, 0, 3);
    
    sprintf (buffer, "SOUR:LFO%ld:SHAP:TRAP:%s?", channel, shapeTrapezeArr[trapeze]);

    return GETPARAMREAL64 (instrSession,
                              buffer,
                              time);
}

/*****************************************************************************
 * Function: Set LFGen Shape Triangle
 * Purpose:  This function selects the rise and period time for the triangle 
 *           shape of the selected LF generator.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetLFGenShapeTriangle(
    ViSession   instrSession,
    ViInt32 channel,
    ViInt32 triangle,
    ViReal64    time
)
{
    ViChar buffer[BUFFER_SIZE];
    
    INIT;
    CHECKOPT (B20);
    
    CHECKVIINT32 (instrSession, channel, 1, 2);
    CHECKVIINT32 (instrSession, triangle, 0, 1);
    
    sprintf (buffer, "SOUR:LFO%ld:SHAP:TRI:%s", channel, shapeTriangleArr[triangle]);

    return SETPARAMREAL64 (instrSession,
                              buffer,
                              time,
                              1e-6,100.0);
}

/*****************************************************************************
 * Function: Get LFGen Shape Triangle
 * Purpose:  This function queries the rise and period time for the triangle 
 *           shape of the selected LF generator.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetLFGenShapeTriangle(
    ViSession   instrSession,
    ViInt32 channel,
    ViInt32 triangle,
    ViReal64*   time
)
{
    ViChar buffer[BUFFER_SIZE];
    
    INIT;
    CHECKOPT (B20);
    
    CHECKVIINT32 (instrSession, channel, 1, 2);
    CHECKVIINT32 (instrSession, triangle, 0, 1);
    
    sprintf (buffer, "SOUR:LFO%ld:SHAP:TRI:%s?", channel, shapeTriangleArr[triangle]);

    return GETPARAMREAL64 (instrSession,
                              buffer,
                              time);
}

/*****************************************************************************
 * Function: Set LFGen Shape Pulse
 * Purpose:  This function selects the duty cycle, period and width for the 
 *           pulse shape of the selected LF generator.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetLFGenShapePulse(
    ViSession   instrSession,
    ViInt32 channel,
    ViInt32 pulse,
    ViReal64    time
)
{
    ViChar buffer[BUFFER_SIZE] = "";
    ViReal64 min = 0.0;
    ViReal64 max = 0.0;
    
    INIT;
    CHECKOPT (B20);
    
    CHECKVIINT32 (instrSession, channel, 1, 2);
    
    switch (pulse)
    {
        case RSSMF_LFOUTPUT_SHAPE_PULSE_DUTY:
            sprintf (buffer, "SOUR:LFO%ld:SHAP:PULS:DCYC", channel);
            min = 1.0;
            max = 100.0;
            break;
            
        case RSSMF_LFOUTPUT_SHAPE_PULSE_PERIOD:
            sprintf (buffer, "SOUR:LFO%ld:SHAP:PULS:PER", channel);
            min = 1.0e-6;
            max = 100.0;
            break;
            
        case RSSMF_LFOUTPUT_SHAPE_PULSE_WIDTH:
            sprintf (buffer, "SOUR:LFO%ld:SHAP:PULS:WIDT", channel);
            min = 1.0e-6;
            max = 100.0;
            break;
        default:
        	return rssmf_ParameterError (instrSession, "pulse");
    }

    return SETPARAMREAL64 (instrSession,
                              buffer,
                              time,
                              min,max);
}

/*****************************************************************************
 * Function: Get LFGen Shape Pulse
 * Purpose:  This function queries the duty cycle, period and width for the 
 *           pulse shape of the selected LF generator.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetLFGenShapePulse(
    ViSession   instrSession,
    ViInt32 channel,
    ViInt32 pulse,
    ViReal64*   time
)
{
    ViChar buffer[BUFFER_SIZE];
    
    INIT;
    CHECKOPT (B20);
    
    CHECKVIINT32 (instrSession, channel, 1, 2);
    CHECKVIINT32 (instrSession, pulse, 0, 2);
    
    sprintf (buffer, "SOUR:LFO%ld:SHAP:PULS:%s?", channel, shapePulseArr[pulse]);

    return GETPARAMREAL64 (instrSession,
                              buffer,
                              time);
}

/*****************************************************************************
 * Function: Configure Noise Modulation
 * Purpose:  This function sets all parameters of noise modulation.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_confNoise(
    ViSession   instrSession,
    ViReal64    bandwidth,
    ViInt32 distribution
)
{
    ViStatus    rssmf_status;     

    CHECKERR (rssmf_SetNOISEBandwidth (instrSession, bandwidth));    
    return rssmf_SetNOISEDistribution (instrSession, distribution);
}

/*****************************************************************************
 * Function: Set NOISE Bandwidth
 * Purpose:  This function sets the noise level in the system bandwidth for 
 *           enabled bandwidth limitation. Distinct bandwidth settings between 
 *           10 kHz and 10 MHz in 100 kHz steps (range 100 .. 1 MHz), 1 MHz 
 *           (range 1 MHz .. 5 MHz) and 5 MHz (5 MHz … 10 MHz) are possible.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetNOISEBandwidth(
    ViSession   instrSession,
    ViReal64    bandwidth
)
{
    INIT;
    CHECKOPT (B20);

    return SETPARAMREAL64 (instrSession,
                              "NOIS:BWID",
                              bandwidth,
                              100.0e+3,10.0e+6);
}

/*****************************************************************************
 * Function: Get NOISE Bandwidth
 * Purpose:  This function returns the noise level in the system bandwidth for 
 *           enabled bandwidth limitation.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetNOISEBandwidth(
    ViSession   instrSession,
    ViReal64*   bandwidth
)
{
    INIT;
    CHECKOPT (B20);

    return GETPARAMREAL64 (instrSession,
                              "NOIS:BWID?",
                              bandwidth);
}

/*****************************************************************************
 * Function: Set NOISE Distribution
 * Purpose:  This function selects the noise power densitiy distribution of 
 *           the noise.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetNOISEDistribution(
    ViSession   instrSession,
    ViInt32 distribution
)
{
    INIT;
    CHECKOPT (B20);

    return SETPARAMENUM (instrSession,
                          "NOIS:DIST",
                          distribution,
                          distributionArr);
}

/*****************************************************************************
 * Function: Get NOISE Distribution
 * Purpose:  This function returns the noise power densitiy distribution of 
 *           the noise.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetNOISEDistribution(
    ViSession   instrSession,
    ViInt32*    distribution
)
{
    INIT;
    CHECKOPT (B20);

    return GETPARAMENUM (instrSession,
                          "NOIS:DIST?",
                          distribution,
                          distributionArr);
}

/*****************************************************************************
 * Function: Get NOISE Relative Level
 * Purpose:  This function returns the level of the noise signal per Hz in the 
 *           total bandwidth.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetNOISERelativeLevel(
    ViSession   instrSession,
    ViReal64*   relativeLevel
)
{
    INIT;
    CHECKOPT (B20);

    return GETPARAMREAL64 (instrSession,
                              "NOIS:LEV:REL?",
                              relativeLevel);
}

/*****************************************************************************
 * Function: Get NOISE Absolute Level
 * Purpose:  This function returns the level of the noise signal in the system 
 *           bandwidth for enabled bandwidth limitation.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetNOISEAbsoluteLevel(
    ViSession   instrSession,
    ViReal64*   absoluteLevel
)
{
    INIT;
    CHECKOPT (B20);

    return GETPARAMREAL64 (instrSession,
                              "NOIS:LEV?",
                              absoluteLevel);
}

/*===========================================================================*/
/* Function: Set NOISE Bandwidth State
/* Purpose:  This function enabled/disables bandwidth limitation of noise.
/*           
/*           Required Option(s):
/*           R&S SMF-K24
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_SetNOISEBandwidthState(
    ViSession   instrSession,
    ViBoolean   bandwidthState
)
{
    INIT;
    CHECKOPT (K24);

    return SETPARAMBOOL (instrSession,
                               "SOUR:NOIS:BWID:STAT",
                               bandwidthState);
}

/*===========================================================================*/
/* Function: Get NOISE Bandwidth State
/* Purpose:  This function returns the bandwidth limitation of noise.
/*           
/*           Required Option(s):
/*           R&S SMF-K24
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetNOISEBandwidthState(
    ViSession   instrSession,
    ViBoolean*  bandwidthState
)
{
    INIT;
    CHECKOPT (K24);

    return GETPARAMBOOL (instrSession,
                               "SOUR:NOIS:BWID:STAT?",
                               bandwidthState);
}

/*****************************************************************************
 * Function: Configure LF Output
 * Purpose:  This function sets parameters of LF Output.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_confLFOutput(
    ViSession   instrSession,
    ViInt32 channel,
    ViBoolean   state,
    ViInt32 source,
    ViReal64    outputVoltage
)
{
    INIT;
    CHECKOPT (B20);
    
    CHECKVIINT32 (instrSession, channel, 1, 2);
    
    CHECKERR (rssmf_sendCmd (instrSession, "SOUR:LFO:FREQ:MODE FIX"));
    
    CHECKERR (rssmf_SetLFOutputState (instrSession, state));
    CHECKERR (rssmf_SetLFOutputSource (instrSession, channel, source));
    CHECKERR (rssmf_SetLFOutputVoltage (instrSession, channel, outputVoltage));
    
    RETURN;
}

/*****************************************************************************
 * Function: Set LF Output Monitoring
 * Purpose:  This function selects the LF output monitoring mode. The settings 
 *           for the LF output are synchronized to amplitude modulation or 
 *           frequency/phase modulation settings.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetLFOutputMonitoring(
    ViSession   instrSession,
    ViInt32 monitoring
)
{
    INIT;

    return SETPARAMENUM (instrSession,
                          "LFO:MON:MODE",
                          monitoring,
                          monitoringArr);
}

/*****************************************************************************
 * Function: Set LF Output DC Offset
 * Purpose:  This function sets the DC offset at the LF output.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetLFOutputDCOffset(
    ViSession   instrSession,
    ViReal64    dcOffset
)
{
    INIT;
    CHECKOPT (B20);

    return SETPARAMREAL64 (instrSession,
                              "SOUR:LFO:OFFS",
                              dcOffset,
                              -4.0,4.0);
}

/*****************************************************************************
 * Function: Get LF Output Monitoring
 * Purpose:  This function queries the LF output monitoring mode.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetLFOutputMonitoring(
    ViSession   instrSession,
    ViInt32*    monitoring
)
{
    INIT;

    return GETPARAMENUM (instrSession,
                          "LFO:MON:MODE?",
                          monitoring,
                          monitoringArr);
}

/*****************************************************************************
 * Function: Get LF Output DC Offset
 * Purpose:  This function queries the DC offset at the LF output.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetLFOutputDCOffset(
    ViSession   instrSession,
    ViReal64*   dcOffset
)
{
    INIT;
    CHECKOPT (B20);

    return GETPARAMREAL64 (instrSession,
                              "SOUR:LFO:OFFS?",
                              dcOffset);
}

/*****************************************************************************
 * Function: Set LF Output State
 * Purpose:  This function activates/deactivates the LF output.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetLFOutputState(
    ViSession   instrSession,
    ViBoolean   lfOutputState
)
{
    INIT;
    CHECKOPT (B20);

    return SETPARAMBOOL (instrSession,
                               "LFO",
                               lfOutputState);
}

/*****************************************************************************
 * Function: Get LF Output State
 * Purpose:  This function returns state the LF output.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetLFOutputState(
    ViSession   instrSession,
    ViBoolean*  lfOutputState
)
{
    INIT;
    CHECKOPT (B20);

    return GETPARAMBOOL (instrSession,
                               "LFO?",
                               lfOutputState);
}

/*****************************************************************************
 * Function: Set LF Output Source
 * Purpose:  This function selects the internal source to be used for the LF 
 *           Output signal.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetLFOutputSource(
    ViSession   instrSession,
    ViInt32 channel,
    ViInt32 source
)
{
    INIT;
    CHECKOPT (B20);
    
    return SETPARAMENUMPATH (instrSession,
                              "SOUR:LFO%ld:SOUR",
                              channel,
                              source,
                              dmSourceArr);
}

/*****************************************************************************
 * Function: Get LF Output Source
 * Purpose:  This function returns the internal source to be used for the LF 
 *           Output signal.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetLFOutputSource(
    ViSession   instrSession,
    ViInt32 channel,
    ViInt32*    source
)
{
    INIT;
    CHECKOPT (B20);
    
    return GETPARAMENUMPATH (instrSession,
                              "SOUR:LFO%ld:SOUR?",
                              channel,
                              source,
                              dmSourceArr);
}

/*****************************************************************************
 * Function: Set LF Output Voltage
 * Purpose:  This function sets the output voltage of the LF output.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetLFOutputVoltage(
    ViSession   instrSession,
    ViInt32 channel,
    ViReal64    outputVoltage
)
{
    INIT;
    CHECKOPT (B20);
    
    return SETPARAMREAL64PATH (instrSession,
                                  "SOUR:LFO%ld:VOLT",
                                  channel,
                                  outputVoltage,
                                  0.0,6.0);
}

/*****************************************************************************
 * Function: Get LF Output Voltage
 * Purpose:  This function returns the output voltage of the LF output.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetLFOutputVoltage(
    ViSession   instrSession,
    ViInt32 channel,
    ViReal64*   outputVoltage
)
{
    INIT;
    CHECKOPT (B20);
    
    return GETPARAMREAL64PATH (instrSession,
                                  "SOUR:LFO%ld:VOLT?",
                                  channel,
                                  outputVoltage);
}                                        

/*****************************************************************************
 * Function: Configure LF Level Sweep Mode
 * Purpose:  This function configures the LF output level sweep mode.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_ConfigureLFLevelSweepMode(
    ViSession   instrSession,
    ViInt32 mode,
    ViInt32 source,
    ViReal64    startLevel,
    ViReal64    stopLevel,
    ViReal64    step,
    ViReal64    dwellTime
)
{
    ViStatus rssmf_status;
    
    CHECKERR (rssmf_SetLFLevelSweepMode (instrSession, mode));
    CHECKERR (rssmf_SetLFLevelSweepSource (instrSession, source));
    CHECKERR (rssmf_SetLFLevelSweepStartLevel (instrSession, startLevel));
    CHECKERR (rssmf_SetLFLevelSweepStopLevel (instrSession, stopLevel));
    CHECKERR (rssmf_SetLFLevelSweepStep (instrSession, step));
    CHECKERR (rssmf_SetLFLevelSweepDwellTime (instrSession, dwellTime));
    
    return rssmf_status;
}

/*****************************************************************************
 * Function: LF Level Sweep Trigger
 * Purpose:  This function immediately starts an LF level sweep. The MODE 
 *           setting determines which sweep is executed, e.g. 
 *           :SOURce:LFOutput:SWEep:VOLTage:MODE STEP. This function 
 *           corresponds to the manual-control command EXECUTE SINGLE SWEEP. 
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_LFLevelSweepTrigger(
    ViSession   instrSession
)
{
    INIT;

    return rssmf_sendCmd (instrSession,"SOUR:LFO:SWE:VOLT:EXEC");
}

/*****************************************************************************
 * Function: Configure LF Level Sweep Marker
 * Purpose:  This function configures the level sweep marker. 
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_ConfigureLFLevelSweepMarker (ViSession instrSession,
                                                     ViUInt32 channel,
                                                     ViBoolean state,
                                                     ViReal64 level,
                                                     ViInt32 polarity,
                                                     ViInt32 activeMarker)
{
    ViStatus    rssmf_status;

    CHECKERR (rssmf_SetLFLevelSweepMarkerState (instrSession, channel, state));
    CHECKERR (rssmf_SetLFLevelSweepMarkerLevel (instrSession, channel, level));    
    CHECKERR (rssmf_SetLFLevelSweepMarkerPolarity (instrSession, polarity));
    CHECKERR (rssmf_SetLFLevelSweepActiveMarker (instrSession, activeMarker));    
    RETURN;    
}

/*****************************************************************************
 * Function: Set LF Level Sweep Mode
 * Purpose:  This function sets the sweep mode.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetLFLevelSweepMode(
    ViSession   instrSession,
    ViInt32 mode
)
{
    ViStatus    rssmf_status;

    switch (mode)
    {
    case RSSMF_SWEEP_MODE_AUTO:
        CHECKERR (rssmf_SetSweepLFMode (instrSession, RSSMF_SWEEP_LOW_MODE_AUTO));
        CHECKERR (rssmf_SetLFSweepTriggerSource (instrSession,
                                                        RSSMF_TRIG_SOURCE_SWEEP_AUTO));
        CHECKERR (rssmf_SetLFMode (instrSession, RSSMF_LFOUTPUT_FREQUENCY_MODE_SWEEP));
        break;
    case RSSMF_SWEEP_MODE_SINGLE:
        CHECKERR (rssmf_SetSweepLFMode (instrSession, RSSMF_SWEEP_LOW_MODE_AUTO));
        CHECKERR (rssmf_SetLFSweepTriggerSource (instrSession, RSSMF_TRIG_SOURCE_SWEEP_SINGLE));
        CHECKERR (rssmf_SetLFMode (instrSession, RSSMF_LFOUTPUT_FREQUENCY_MODE_SWEEP));
        CHECKERR (rssmf_LFSweepTrigger (instrSession));
        break;
    case RSSMF_SWEEP_MODE_STEP:
        CHECKERR (rssmf_SetSweepLFMode (instrSession, RSSMF_SWEEP_LOW_MODE_MAN));
        CHECKERR (rssmf_SetLFMode (instrSession, RSSMF_FREQUENCY_MODE_SWEEP));
        break;
    case RSSMF_SWEEP_MODE_EXT_SINGLE:
        CHECKERR (rssmf_SetLFMode (instrSession, RSSMF_SWEEP_LOW_MODE_AUTO));
        CHECKERR (rssmf_SetLFSweepTriggerSource (instrSession,RSSMF_TRIG_SOURCE_SWEEP_EXTERNAL));
        CHECKERR (rssmf_SetLFMode (instrSession, RSSMF_LFOUTPUT_FREQUENCY_MODE_SWEEP));
        break;
    case RSSMF_SWEEP_MODE_EXT_STEP:
        CHECKERR (rssmf_SetSweepLFMode (instrSession, RSSMF_SWEEP_LOW_MODE_STEP));
        CHECKERR (rssmf_SetLFSweepTriggerSource (instrSession,
                                                        RSSMF_TRIG_SOURCE_SWEEP_EXTERNAL));
        CHECKERR (rssmf_SetLFMode (instrSession, RSSMF_LFOUTPUT_FREQUENCY_MODE_SWEEP));
        break;
    default:
        rssmf_status = rssmf_ParameterError (instrSession, "mode");
    }

    RETURN;
}

/*****************************************************************************
 * Function: Set LF Level Sweep Source
 * Purpose:  This function selects the source of the LF level sweep.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetLFLevelSweepSource(
    ViSession   instrSession,
    ViInt32 source
)
{
    INIT;
    CHECKOPT (B20);

    return SETPARAMENUM (instrSession,
                          "SOUR:LFO:SWE:VOLT:LFS",
                          source,
                          dmSourceArr);
}

/*****************************************************************************
 * Function: Get LF Level Sweep Source
 * Purpose:  This function queries the source of the LF level sweep.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetLFLevelSweepSource(
    ViSession   instrSession,
    ViInt32*    source
)
{
    INIT;
    CHECKOPT (B20);

    return GETPARAMENUM (instrSession,
                          "SOUR:LFO:SWE:VOLT:LFS?",
                          source,
                          dmSourceArr);
}

/*****************************************************************************
 * Function: Set LF Level Sweep Start Level
 * Purpose:  This function sets the start level in sweep mode.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetLFLevelSweepStartLevel(
    ViSession   instrSession,
    ViReal64    startLevel
)
{
    INIT;
    CHECKOPT (B20);

    return SETPARAMREAL64 (instrSession,
                              "SOUR:LFO:VOLT:STAR",
                              startLevel,
                              0.0,0.0);
}

/*****************************************************************************
 * Function: Get LF Level Sweep Start Level
 * Purpose:  This function queries the start level in sweep mode.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetLFLevelSweepStartLevel(
    ViSession   instrSession,
    ViReal64*   startLevel
)
{
    INIT;
    CHECKOPT (B20);

    return GETPARAMREAL64 (instrSession,
                              "SOUR:LFO:VOLT:STAR?",
                              startLevel);
}

/*****************************************************************************
 * Function: Set LF Level Sweep Stop Level
 * Purpose:  This function sets the stop level in sweep mode.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetLFLevelSweepStopLevel(
    ViSession   instrSession,
    ViReal64    stopLevel
)
{
    INIT;
    CHECKOPT (B20);

    return SETPARAMREAL64 (instrSession,
                              "SOUR:LFO:VOLT:STOP",
                              stopLevel,
                              0.0,0.0);
}

/*****************************************************************************
 * Function: Get LF Level Sweep Stop Level
 * Purpose:  This function sets the stop level in sweep mode.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetLFLevelSweepStopLevel(
    ViSession   instrSession,
    ViReal64*    stopLevel
)
{
    INIT;
    CHECKOPT (B20);

    return GETPARAMREAL64 (instrSession,
                              "SOUR:LFO:VOLT:STOP?",
                              stopLevel);
}

/*****************************************************************************
 * Function: Set LF Level Sweep Step
 * Purpose:  This function sets step width for the level setting
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetLFLevelSweepStep(
    ViSession   instrSession,
    ViReal64    step
)
{
    INIT;
    CHECKOPT (B20);

    return SETPARAMREAL64 (instrSession,
                              "SOUR:LFO:SWE:VOLT:STEP",
                              step,
                              0.0,6.0);
}

/*****************************************************************************
 * Function: Get LF Level Sweep Step
 * Purpose:  This function queries step width for the level setting
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetLFLevelSweepStep(
    ViSession   instrSession,
    ViReal64*   step
)
{
    INIT;
    CHECKOPT (B20);

    return GETPARAMREAL64 (instrSession,
                              "SOUR:LFO:SWE:VOLT:STEP?",
                              step);
}

/*****************************************************************************
 * Function: Set LF Level Sweep Count
 * Purpose:  This function sets the number of LF Level sweep steps.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetLFLevelSweepCount(
    ViSession   instrSession,
    ViUInt32    count
)
{
    INIT;
    CHECKOPT (B20);

    return SETPARAMUINT32 (instrSession,
                              "SOUR:LFO:SWE:VOLT:POIN",
                              count,
                              1,16777215);
}

/*****************************************************************************
 * Function: Get LF Level Sweep Count
 * Purpose:  This function queries the number of LF Level sweep steps.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetLFLevelSweepCount(
    ViSession   instrSession,
    ViUInt32*   count
)
{
    INIT;
    CHECKOPT (B20);

    return GETPARAMUINT32 (instrSession,
                              "SOUR:LFO:SWE:VOLT:POIN?",
                              count);
}

/*****************************************************************************
 * Function: Set LF Level Sweep Shape
 * Purpose:  This function sets the cycle mode for a sweep sequence (shape).
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetLFLevelSweepShape (ViSession instrSession,
                                              ViInt32 shape)
{
    INIT;
    CHECKOPT (B20);

    return SETPARAMENUM (instrSession,
                          "SOUR:LFO:SWE:VOLT:SHAP",
                          shape,
                          sweepShapeArr);
}

/*****************************************************************************
 * Function: Get LF Level Sweep Shape
 * Purpose:  This function sets the cycle mode for a sweep sequence (shape).
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetLFLevelSweepShape (ViSession instrSession,
                                              ViInt32 *shape)
{
    INIT;
    CHECKOPT (B20);

    return GETPARAMENUM (instrSession,
                          "SOUR:LFO:SWE:VOLT:SHAP?",
                          shape,
                          sweepShapeArr);
}

/*****************************************************************************
 * Function: Set LF Level Sweep Dwell Time
 * Purpose:  This function sets the dwell time for each level step of the 
 *           sweep.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetLFLevelSweepDwellTime(
    ViSession   instrSession,
    ViReal64    dwellTime
)
{
    INIT;
    CHECKOPT (B20);

    return SETPARAMREAL64 (instrSession,
                              "SOUR:LFO:SWE:VOLT:DWEL",
                              dwellTime,
                              0.1e-3,100.0);
}

/*****************************************************************************
 * Function: Get LF Level Sweep Dwell Time
 * Purpose:  This function queries the dwell time for each level step of the 
 *           sweep.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetLFLevelSweepDwellTime(
    ViSession   instrSession,
    ViReal64*   dwellTime
)
{
    INIT;
    CHECKOPT (B20);

    return GETPARAMREAL64 (instrSession,
                              "SOUR:LFO:SWE:VOLT:DWEL?",
                              dwellTime);
}

/*****************************************************************************
 * Function: Set LF Level Sweep Manual Step
 * Purpose:  In Sweep mode (:SOUR:LFO:VOLT:MODE SWE) this function sets the 
 *           frequency for the next sweep step in the Step sweep mode 
 *           (:SOUR:LFO:SWE:VOLT:MODE MAN). Here only level values between the 
 *           settings :SOUR:LFO:VOLT:STAR and ...:STOP are permitted. Each 
 *           sweep step is triggered by a separate :SOUR:LFO:VOLT:MAN command.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetLFLevelSweepManualStep(
    ViSession   instrSession,
    ViReal64    manualLFSweep
)
{
    INIT;
    CHECKOPT (B20);

    return SETPARAMREAL64 (instrSession,
                              "SOUR:LFO:VOLT:MAN",
                              manualLFSweep,
                              0.0,0.0);
}

/*****************************************************************************
 * Function: Get LF Level Sweep Manual Step
 * Purpose:  In Sweep mode (:SOUR:LFO:VOLT:MODE SWE) this function queries the 
 *           frequency for the next sweep step in the Step sweep mode 
 *           (:SOUR:LFO:SWE:VOLT:MODE MAN).
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetLFLevelSweepManualStep(
    ViSession   instrSession,
    ViReal64*   manualLFSweep
)
{
    INIT;
    CHECKOPT (B20);

    return GETPARAMREAL64 (instrSession,
                              "SOUR:LFO:VOLT:MAN?",
                              manualLFSweep);
}

/*****************************************************************************
 * Function: Set LF Level Sweep Marker State
 * Purpose:  This function switches on or off the selected marker. If the 
 *           marker is switched on, the signal level at the MARKER output 
 *           changes on reaching the voltage mark. 
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetLFLevelSweepMarkerState (ViSession instrSession,
                                                    ViUInt32 channel,
                                                    ViBoolean state)
{
    INIT;
    CHECKOPT (B20);

    CHECKVIUINT32 (instrSession, channel, 1, 10);
    
    return SETPARAMBOOLPATH (instrSession,
                                   "SOUR:LFO:SWE:VOLT:MARK%ld:VST",
                                   channel,
                                   state);
}

/*****************************************************************************
 * Function: Get LF Level Sweep Marker State
 * Purpose:  This function returns the state of the selected marker. 
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetLFLevelSweepMarkerState (ViSession instrSession,
                                                    ViUInt32 channel,
                                                    ViBoolean *state)
{
    INIT;
    CHECKOPT (B20);

    CHECKVIUINT32 (instrSession, channel, 1, 10);
    
    return GETPARAMBOOLPATH (instrSession,
                                   "SOUR:LFO:SWE:VOLT:MARK%ld:VST?",
                                   channel,
                                   state);
}

/*****************************************************************************
 * Function: Set LF Level Sweep Marker Level
 * Purpose:  This function sets the voltage mark for the selected marker. 
 *           If the marker is switched on, the signal level at the MARKER 
 *           output changes on reaching the voltage mark. 
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetLFLevelSweepMarkerLevel (ViSession instrSession,
                                                    ViUInt32 channel,
                                                    ViReal64 level)
{
    INIT;
    CHECKOPT (B20);

    CHECKVIUINT32 (instrSession, channel, 1, 10);
    
    return SETPARAMREAL64PATH (instrSession,
                                   "SOUR:LFO:SWE:VOLT:MARK%ld:VOLT",
                                   channel,
                                   level,
                                   0.0,0.0);
}

/*****************************************************************************
 * Function: Get LF Level Sweep Marker Level
 * Purpose:  This function returns the voltage mark for the selected marker. 
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetLFLevelSweepMarkerLevel (ViSession instrSession,
                                                    ViUInt32 channel,
                                                    ViReal64 *level)
{
    INIT;
    CHECKOPT (B20);

    CHECKVIUINT32 (instrSession, channel, 1, 10);
    
    return GETPARAMREAL64PATH (instrSession,
                                   "SOUR:LFO:SWE:VOLT:MARK%ld:VOLT?",
                                   channel,
                                   level);
}

/*****************************************************************************
 * Function: Set LF Level Sweep Marker Polarity
 * Purpose:  This function selects the marker output polarity. 
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetLFLevelSweepMarkerPolarity (ViSession instrSession,
                                                       ViInt32 polarity)
{
    INIT;
    CHECKOPT (B20);

    CHECKVIINT32 (instrSession, polarity, RSSMF_SWEEP_MARKER_POLARITY_NORMAL, RSSMF_SWEEP_MARKER_POLARITY_INVERTED);
    
    return SETPARAMENUM (instrSession,
                          "SOUR:LFO:SWE:VOLT:MARK:OUTP:POL",
                          polarity,
                          polarityArr);
}

/*****************************************************************************
 * Function: Get LF Level Sweep Marker Polarity
 * Purpose:  This function returns the marker output polarity. 
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetLFLevelSweepMarkerPolarity (ViSession instrSession,
                                                       ViInt32 *polarity)
{
    INIT;
    CHECKOPT (B20);

    return GETPARAMENUM (instrSession,
                          "SOUR:LFO:SWE:VOLT:MARK:OUTP:POL?",
                          polarity,
                          polarityArr);
}

/*****************************************************************************
 * Function: Set LF Level Sweep Active Marker
 * Purpose:  This function  activates the selected marker. The active marker 
 *           is output with a higher voltage than all other markers. 
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetLFLevelSweepActiveMarker (ViSession instrSession,
                                                     ViInt32 activeMarker)
{
    INIT;
    CHECKOPT (B20);

    CHECKVIINT32 (instrSession, activeMarker, RSSMF_SWEEP_MARKER_ACTIVE_NONE, RSSMF_SWEEP_MARKER_ACTIVE_10);
    
    return SETPARAMENUM (instrSession,
                          "SOUR:LFO:SWE:VOLT:MARK:ACT",
                          activeMarker,
                          activeMarkerArr);
}

/*****************************************************************************
 * Function: Get LF Level Sweep Active Marker
 * Purpose:  This function  returns the active marker.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetLFLevelSweepActiveMarker (ViSession instrSession,
                                                     ViInt32 *activeMarker)
{
    INIT;
    CHECKOPT (B20);

    return GETPARAMENUM (instrSession,
                          "SOUR:LFO:SWE:VOLT:MARK:ACT?",
                          activeMarker,
                          activeMarkerArr);
}

/*****************************************************************************
 * Function: Set LF Level Sweep All Markers Off
 * Purpose:  This function switches off all markers of level sweep.  
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetLFLevelSweepAllMarkersOff (ViSession instrSession)
{
    INIT;
    CHECKOPT (B20);

    return rssmf_sendCmd (instrSession, "SOUR:LFO:SWE:VOLT:MARK:AOFF");
}

/*****************************************************************************
 * Function: Configure External Input
 * Purpose:  This function configures parameteres of external feed via EXT 1 
 *           and/or EXT 2 input.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_ConfigureExternalInput(
    ViSession   instrSession,
    ViInt32 input,
    ViInt32 coupling,
    ViInt32 impedance,
    ViInt32 bandwidth
)
{
    INIT;
    CHECKOPT (B20);
    
    CHECKERR (rssmf_SetExternalInputCoupling (instrSession, input, coupling));
    CHECKERR (rssmf_SetExternalInputImpedance (instrSession, input, impedance));
    CHECKERR (rssmf_SetExternalInputBandwidth (instrSession, input, bandwidth));

    RETURN;
}

/*****************************************************************************
 * Function: Set External Input Coupling
 * Purpose:  This function selects the coupling mode for external feed via EXT 
 *           1 and/or EXT 2 input.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetExternalInputCoupling(
    ViSession   instrSession,
    ViInt32 input,
    ViInt32 coupling
)
{
    ViChar buffer[BUFFER_SIZE];
    
    INIT;
    CHECKOPT (B20);
    
    sprintf (buffer, "SOUR:INP:MOD:COUP%ld", input);

    return SETPARAMENUM (instrSession,
                          buffer,
                          coupling,
                          externalCouplingArr);
}

/*****************************************************************************
 * Function: Get External Input Coupling
 * Purpose:  This function queries the coupling mode for external feed via EXT 
 *           1 and/or EXT 2 input.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetExternalInputCoupling(
    ViSession   instrSession,
    ViInt32 input,
    ViInt32*    coupling
)
{
    ViChar buffer[BUFFER_SIZE];
    
    INIT;
    CHECKOPT (B20);
    
    sprintf (buffer, "SOUR:INP:MOD:COUP%ld?", input);

    return GETPARAMENUM (instrSession,
                          buffer,
                          coupling,
                          externalCouplingArr);
}

/*****************************************************************************
 * Function: Set External Input Impedance
 * Purpose:  This function selects impedance for external feed via EXT 1 
 *           and/or EXT 2 input.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetExternalInputImpedance(
    ViSession   instrSession,
    ViInt32 input,
    ViInt32 impedance
)
{
    INIT;
    CHECKOPT (B20);

    return SETPARAMENUMPATH (instrSession,
                              "SOUR:INP:MOD:IMP%ld",
                              input,
                              impedance,
                              extInputImpedanceArr);
}

/*****************************************************************************
 * Function: Get External Input Impedance
 * Purpose:  This function queries impedance for external feed via EXT 1 
 *           and/or EXT 2 input.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetExternalInputImpedance(
    ViSession   instrSession,
    ViInt32 input,
    ViInt32*    impedance
)
{
    INIT;
    CHECKOPT (B20);

    return GETPARAMENUMPATH (instrSession,
                              "INP:MOD:IMP%ld?",
                              input,
                              impedance,
                              extInputImpedanceArr);
}

/*****************************************************************************
 * Function: Set External Input Bandwidth
 * Purpose:  This function selects the bandwith for the external feed via the 
 *           EXT 1 and/or EXT 2 input.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetExternalInputBandwidth(
    ViSession   instrSession,
    ViInt32 input,
    ViInt32 bandwidth
)
{
    INIT;
    CHECKOPT (B20);

    return SETPARAMENUMPATH (instrSession,
                              "SOUR:LFO%ld:BAND",
                              input,
                              bandwidth,
                              lfoBandwidthArr);
}

/*****************************************************************************
 * Function: Get External Input Bandwidth
 * Purpose:  This function queries the bandwith for the external feed via the 
 *           EXT 1 and/or EXT 2 input.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetExternalInputBandwidth(
    ViSession   instrSession,
    ViInt32 input,
    ViInt32*    bandwidth
)
{
    INIT;
    CHECKOPT (B20);

    return GETPARAMENUMPATH (instrSession,
                              "SOUR:LFO%ld:BAND?",
                              input,
                              bandwidth,
                              lfoBandwidthArr);
}

/*****************************************************************************
 * Function: Set All Modulations State
 * Purpose:  This function switches the modulations on and off. A subsequent 
 *           call to this function with argument state = ON restores the status 
 *           that was active before the last switch-off. MOD OFF is displayed 
 *           in the info line of the header next to the Level field.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetAllModulationsState(
    ViSession   instrSession,
    ViBoolean   state
)
{
    INIT;

    return SETPARAMBOOL (instrSession,
                               "SOUR:MOD:STAT",
                               state);
}

/*****************************************************************************
 * Function: Configure Pulse Modulation
 * Purpose:  This function sets the parameters of pulse modulation.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_confPulm(
    ViSession   instrSession,
    ViBoolean   state,
    ViInt32 source,
    ViInt32 externalPolarity,
    ViInt32 videoPolarity
)
{
    ViStatus    rssmf_status;

    CHECKERR (rssmf_SetPULMState (instrSession, state));
    
    CHECKERR (rssmf_SetPULMSource (instrSession, source));    
    if (source == RSSMF_PULM_SOURCE_EXTERNAL)
    {
        CHECKERR (rssmf_SetPULMExternalPolarity (instrSession, externalPolarity));    }

    CHECKERR (rssmf_SetPULMVideoPolarity (instrSession, videoPolarity));    
    return rssmf_status;
}

/*****************************************************************************
 * Function: Configure Pulse Generator
 * Purpose:  This function configures the parameters of pulse generator.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_confPulmGen (ViSession instrSession,
                                     ViBoolean pulseOutputState,
                                     ViReal64 pulsePeriod, ViReal64 pulseWidth,
                                     ViReal64 pulseDelay,
                                     ViBoolean doublePulseState,
                                     ViReal64 doublePulseDelay,
                                     ViInt32 outputPolarity)
{
    INIT;
    CHECKOPT (K23);

    if (pulseWidth > pulsePeriod)
       	return rssmf_ParameterError (instrSession, "pulseWidth,pulsePeriod");
    
    if ((doublePulseState != VI_FALSE) && ((pulseWidth + doublePulseDelay) > pulsePeriod))
       	return rssmf_ParameterError (instrSession, "doublePulseDelay");
    
    if ((doublePulseState != VI_FALSE) && ((doublePulseDelay + 20.e-9) < pulseWidth))
       	return rssmf_ParameterError (instrSession, "doublePulseDelay");

    CHECKERR (rssmf_SetPULMGeneratorOutputState (instrSession, pulseOutputState));
    CHECKERR (rssmf_SetPULMPeriod (instrSession, pulsePeriod));
    CHECKERR (rssmf_SetPULMWidth (instrSession, pulseWidth));
    CHECKERR (rssmf_SetPULMDelay (instrSession, pulseDelay));
    CHECKERR (rssmf_SetPULMDoubleDelay (instrSession, doublePulseDelay));
    CHECKERR (rssmf_SetPULMDoubleState (instrSession, doublePulseState));
    CHECKERR (rssmf_SetPULMOutputPolarity (instrSession, outputPolarity));
    
    RETURN;
}

/*****************************************************************************
 * Function: Set PULM State
 * Purpose:  This function activates/deactivates the pulse modulation.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetPULMState(
    ViSession   instrSession,
    ViBoolean   state
)
{
    INIT;

    return SETPARAMBOOL (instrSession,
                               "SOUR:PULM:STAT",
                               state);
}

/*****************************************************************************
 * Function: Get PULM State
 * Purpose:  This function returns the pulse modulation state.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetPULMState(
    ViSession   instrSession,
    ViBoolean*  state
)
{
    INIT;

    return GETPARAMBOOL (instrSession,
                               "SOUR:PULM:STAT?",
                               state);
}

/*****************************************************************************
 * Function: Set PULM Source
 * Purpose:  This function selects the source for pulse modulation. 
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetPULMSource(
    ViSession   instrSession,
    ViInt32 source
)
{
    INIT;

    return SETPARAMENUM (instrSession,
                          "PULM:SOUR",
                          source,
                          pulmSourceArr);
}

/*****************************************************************************
 * Function: Get PULM Source
 * Purpose:  This function returns the source for pulse modulation. 
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetPULMSource(
    ViSession   instrSession,
    ViInt32*    source
)
{
    INIT;

    return GETPARAMENUM (instrSession,
                          "PULM:SOUR?",
                          source,
                          pulmSourceArr);
}

/*****************************************************************************
 * Function: Set PULM External Polarity
 * Purpose:  This function sets the polarity between modulating and modulated 
 *           signal. This function is only effective for an external modulation 
 *           signal.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetPULMExternalPolarity(
    ViSession   instrSession,
    ViInt32 polarity
)
{
    INIT;

    return SETPARAMENUM (instrSession,
                          "PULM:POL",
                          polarity,
                          polarityArr);
}

/*****************************************************************************
 * Function: Get PULM External Polarity
 * Purpose:  This function returns the polarity between modulating and 
 *           modulated signal. This function is only effective for an external 
 *           modulation signal.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetPULMExternalPolarity(
    ViSession   instrSession,
    ViInt32*    polarity
)
{
    INIT;

    return GETPARAMENUM (instrSession,
                          "PULM:POL?",
                          polarity,
                          polarityArr);
}

/*****************************************************************************
 * Function: Set PULM Video Polarity
 * Purpose:  This function sets the polarity between modulating and modulated 
 *           signal. This function is only effective for an internal modulation 
 *           signal.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetPULMVideoPolarity(
    ViSession   instrSession,
    ViInt32 polarity
)
{
    INIT;

    return SETPARAMENUM (instrSession,
                          "SOUR:PULM:OUTP:VID:POL",
                          polarity,
                          polarityArr);
}

/*****************************************************************************
 * Function: Get PULM Video Polarity
 * Purpose:  This function queries the polarity between modulating and 
 *           internal modulated signal.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetPULMVideoPolarity(
    ViSession   instrSession,
    ViInt32*    polarity
)
{
    INIT;

    return GETPARAMENUM (instrSession,
                          "SOUR:PULM:OUTP:VID:POL?",
                          polarity,
                          polarityArr);
}

/*****************************************************************************
 * Function: Set PULM Sync To Internal Clock
 * Purpose:  When enabled, the external modulation signal is synchronized to
 *           the internal 200MHz reference before it is passed to the pulse
 *           modulator. Since most instrument capabilities are timed by the
 *           same reference, the edges of the modulation signal can be
 *           synchronized e.g. to RF or to pulse modulator outputs if
 *           instrument is set up accordingly.
 *           When disabled, the signal is passed asynchronously to the
 *           modulator.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetPULMSyncToInternalClock (ViSession instrSession,
                                                    ViBoolean synchronizeToInternalClock)
{
    return SETPARAMBOOL (instrSession,
                               "PULM:SYNC",
                               synchronizeToInternalClock);
}

/*****************************************************************************
 * Function: Get PULM Sync To Internal Clock
 * Purpose:  Returns whether the external modulation signal is synchronized 
 *           to the internal 200MHz reference before it is passed to the pulse
 *           modulator
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetPULMSyncToInternalClock (ViSession instrSession,
                                                    ViBoolean *synchronizeToInternalClock)
{
    return GETPARAMBOOL (instrSession,
                               "PULM:SYNC?",
                               synchronizeToInternalClock);
}

/*****************************************************************************
 * Function: Set PULM Period
 * Purpose:  This function sets the period of the generated pulse. The period 
 *           determines the repetition frequency of the internal signal.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetPULMPeriod(
    ViSession   instrSession,
    ViReal64    period
)
{
    INIT;
    CHECKOPT (K23);

    return SETPARAMREAL64 (instrSession,
                              "PULM:PER",
                              period,
                              100.0e-9,85.0);
}

/*****************************************************************************
 * Function: Get PULM Period
 * Purpose:  This function returns the period of the generated pulse.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetPULMPeriod(
    ViSession   instrSession,
    ViReal64*   period
)
{
    INIT;
    CHECKOPT (K23);

    return GETPARAMREAL64 (instrSession,
                              "PULM:PER?",
                              period);
}

/*****************************************************************************
 * Function: Set PULM Width
 * Purpose:  This function sets the width of the generated pulse. The width 
 *           determines the pulse length.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetPULMWidth(
    ViSession   instrSession,
    ViReal64    pulseWidth
)
{
    INIT;
    CHECKOPT (K23);

    return SETPARAMREAL64 (instrSession,
                              "PULM:WIDT",
                              pulseWidth,
                              5.0e-9,100.0);
}

/*****************************************************************************
 * Function: Get PULM Width
 * Purpose:  This function returns the width of the generated pulse.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetPULMWidth(
    ViSession   instrSession,
    ViReal64*   pulseWidth
)
{
    INIT;
    CHECKOPT (K23);

    return GETPARAMREAL64 (instrSession,
                              "PULM:WIDT?",
                              pulseWidth);
}

/*****************************************************************************
 * Function: Set PULM Delay
 * Purpose:  This function sets the pulse delay. The pulse delay determines 
 *           the time that elapses after a trigger event before pulse 
 *           modulation starts. The pulse delay is not effective for double 
 *           pulse generation.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetPULMDelay(
    ViSession   instrSession,
    ViReal64    pulseDelay
)
{
    INIT;
    CHECKOPT (K23);

    return SETPARAMREAL64 (instrSession,
                              "PULM:DEL",
                              pulseDelay,
                              10.0e-9,100.0);
}

/*****************************************************************************
 * Function: Get PULM Delay
 * Purpose:  This function returns the pulse delay. 
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetPULMDelay(
    ViSession   instrSession,
    ViReal64*   pulseDelay
)
{
    INIT;
    CHECKOPT (K23);

    return GETPARAMREAL64 (instrSession,
                              "PULM:DEL?",
                              pulseDelay);
}

/*****************************************************************************
 * Function: Set PULM Double State
 * Purpose:  This function enables/disables double pulse generation. The two 
 *           pulses are generated in one pulse period.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetPULMDoubleState(
    ViSession   instrSession,
    ViBoolean   doublePulseState
)
{
    INIT;
    CHECKOPT (K23);

    return SETPARAMBOOL (instrSession,
                               "SOUR:PULM:DOUBLE:STAT",
                               doublePulseState);
}

/*****************************************************************************
 * Function: Get PULM Double State
 * Purpose:  This function returns the double pulse modulation state.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetPULMDoubleState(
    ViSession   instrSession,
    ViBoolean*  doublePulseState
)
{
    INIT;
    CHECKOPT (K23);

    return GETPARAMBOOL (instrSession,
                               "SOUR:PULM:DOUBLE:STAT?",
                               doublePulseState);
}

/*****************************************************************************
 * Function: Set PULM Double Delay
 * Purpose:  This function sets the delay from the start of the first pulse to 
 *           the start of the second pulse.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetPULMDoubleDelay(
    ViSession   instrSession,
    ViReal64    doublePulseDelay
)
{
    INIT;
    CHECKOPT (K23);

    return SETPARAMREAL64 (instrSession,
                              "PULM:DOUBLE:DEL",
                              doublePulseDelay,
                              20.0e-9,1.0);
}

/*****************************************************************************
 * Function: Get PULM Double Delay
 * Purpose:  This function returns the delay from the start of the first pulse 
 *           to the start of the second pulse.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetPULMDoubleDelay(
    ViSession   instrSession,
    ViReal64*   doublePulseDelay
)
{
    INIT;
    CHECKOPT (K23);

    return GETPARAMREAL64 (instrSession,
                              "PULM:DOUBLE:DEL?",
                              doublePulseDelay);
}

/*****************************************************************************
 * Function: Set PULM Double Width
 * Purpose:  This function sets the width of the second pulse in case of
 *       double pulse generation.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetPULMDoubleWidth(
    ViSession   instrSession,
    ViReal64    doubleWidth
)
{
    INIT;
    CHECKOPT (K23);

    return SETPARAMREAL64 (instrSession,
                              "PULM:DOUB:WIDTH",
                              doubleWidth,
                              5.0e-9,100.0);
}

/*****************************************************************************
 * Function: Get PULM Double Width
 * Purpose:  This function returns the width of the second pulse in case of
 *       kdouble pulse generation.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetPULMDoubleWidth(
    ViSession   instrSession,
    ViReal64*   doubleWidth
)
{
    INIT;
    CHECKOPT (K23);

    return GETPARAMREAL64 (instrSession,
                              "PULM:DOUB:WIDTH?",
                              doubleWidth);
}

/*****************************************************************************
 * Function: Set PULM Generator Output State
 * Purpose:  This function activates/deactivates the pulse generator output.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetPULMGeneratorOutputState(
    ViSession   instrSession,
    ViBoolean   outputState
)
{
    INIT;
    
    return SETPARAMBOOL (instrSession,
                               "SOUR:PGEN:OUTP:STAT",
                               outputState);
}

/*****************************************************************************
 * Function: Get PULM Generator Output State
 * Purpose:  This function queries state of pulse generator output.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetPULMGeneratorOutputState(
    ViSession   instrSession,
    ViBoolean*  outputState
)
{
    INIT;
    
    return GETPARAMBOOL (instrSession,
                               "SOUR:PGEN:OUTP:STAT?",
                               outputState);
}

/*****************************************************************************
 * Function: Set PULM Output Polarity
 * Purpose:  This function sets the polarity of the output signal (PULSE OUT 
 *           connector).
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetPULMOutputPolarity(
    ViSession   instrSession,
    ViInt32 polarity
)
{
    INIT;
    CHECKOPT (K23);

    return SETPARAMENUM (instrSession,
                          "SOUR:PGEN:OUTP:POL",
                          polarity,
                          polarityArr);
}

/*****************************************************************************
 * Function: Get PULM Output Polarity
 * Purpose:  This function queries the polarity of the output signal (PULSE 
 *           OUT connector).
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetPULMOutputPolarity(
    ViSession   instrSession,
    ViInt32*    polarity
)
{
    INIT;
    CHECKOPT (K23);

    return GETPARAMENUM (instrSession,
                          "SOUR:PGEN:OUTP:POL?",
                          polarity,
                          polarityArr);
}

/*===========================================================================*/
/* Function: PULM Pulse Train Catalog
/* Purpose:  This function requests a list of available pulse train files. 
/*           The individual pulse train files are separated by commas.  
/*           
/*           The files are stored with the fixed file extensions *.pulstrn 
/*           in a directory of the user's choice. The directory applicable to 
/*           the commands is defined with the command MMEMory:CDIR.
/*           
/*           Note(s):
/*           
/*           (1) This function is only available with option R&S SMF-K27.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_PULMPulseTrainCatalog(
    ViSession   instrSession,
    ViString    directoryPath,
    ViInt32 arraySize,
    ViChar _VI_FAR  catalogList[]
)
{
    ViChar buffer[BUFFER_SIZE];

    if (!directoryPath)
        strncpy (buffer, "SOUR:PULM:TRA:CAT?;*OPC?", (size_t)BUFFER_SIZE);
    else
        sprintf (buffer, "SOUR:PULM:TRA:CAT? '%s'", directoryPath);

    return rssmf_getCatalog (instrSession,
                             buffer,
                             (ViUInt32) arraySize,
                             catalogList, "catalogList");
}

/*===========================================================================*/
/* Function: PULM Delete Pulse Train File
/* Purpose:  This function deletes the specified pulse train file.
/*           
/*           The files are stored with the fixed file extensions *.pulstrn 
/*           in a directory of the user's choice. The directory applicable to 
/*           the command is defined with the command MMEMory:CDIR. To access 
/*           the files in this directory, only the file name has to be given 
/*           without the path and the file extension. 
/*           
/*           Note(s):
/*           
/*           (1) This function is only available with option R&S SMF-K27.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_PULMDeletePulseTrainFile(
    ViSession   instrSession,
    ViString    fileName
)
{
    INIT;
    CHECKOPT (K27);
    
    return SETPARAMSTRINGQUOTED (instrSession,
                              "SOUR:PULM:TRA:DEL",
                              "'",
                              fileName);
}

/*===========================================================================*/
/* Function: PULM Select Pulse Train File
/* Purpose:  This function selects the specified pulse train file. If a new 
/*           file is to be created, the name can be entered here. The file is 
/*           created if it does not yet exist. The file selected here is 
/*           available for the further processing steps (editing) and is used 
/*           in the instrument when the pulse train mode is activated. 
/*           
/*           The files are stored with the fixed file extensions *.pulstrn 
/*           in a directory of the user's choice. The directory applicable to 
/*           the command is defined with the command MMEMory:CDIR. 
/*           
/*           *RST does not affect data lists.
/*           
/*           Note(s):
/*           (1) This function is only available with option R&S SMF-K27.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_PULMSelectPulseTrainFile(
    ViSession   instrSession,
    ViString    fileName
)
{
    INIT;
    CHECKOPT (K27);
    
    return SETPARAMSTRINGQUOTED (instrSession,
                              "SOUR:PULM:TRA:SEL",
                              "'",
                              fileName);
}

/*===========================================================================*/
/* Function: Get PULM Pulse Train Length
/* Purpose:  Queries the length (in points) of the repetition component of the 
/*           selected list.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPULMPulseTrainLength (ViSession instrSession,
                                                 ViInt32 *pulseTrainLength)
{
    INIT;
    CHECKOPT (K27);

    return GETPARAMINT32 (instrSession,
                             "PULM:TRA:REP:POIN?",
                             pulseTrainLength);
}

/*===========================================================================*/
/* Function: Set PULM Mode
/* Purpose:  This function selects the mode for pulse generation.
/*           
/*           Note(s):
/*           
/*           (1) This function is only available with option R&S SMF-K23, 
/*           parameter PTRain is only available with option R&S SMF-K27.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPULMMode(
    ViSession   instrSession,
    ViInt32 mode
)
{
    INIT;
    CHECKOPT (K23);
    
    if (mode == RSSMF_PULM_MODE_PTR)
        CHECKOPT (K27);

    return SETPARAMENUM (instrSession,
                          "SOUR:PULM:MODE",
                          mode,
                          pulmModeArr);
}

/*===========================================================================*/
/* Function: Get PULM Mode
/* Purpose:  This function returns the mode for pulse generation.
/*           
/*           Note(s):
/*           
/*           (1) This function is only available with option R&S SMF-K23, 
/*           parameter PTRain is only available with option R&S SMF-K27.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPULMMode(
    ViSession   instrSession,
    ViInt32*    mode
)
{
    INIT;
    CHECKOPT (K23);

    return GETPARAMENUM (instrSession,
                          "SOUR:PULM:MODE?",
                          mode,
                          pulmModeArr);
}

/*===========================================================================*/
/* Function: Set PULM Train Offtime
/* Purpose:  This function fills the Offtime part of the selected file with 
/*           data. The data can be given either as a list of numbers (list 
/*           can be of any length and list entries must be separated by 
/*           commas) or as binary block data. When block data is transferred, 
/*           8 (4) bytes are always interpreted as a floating-point number 
/*           with double accuracy (see the command FORMat:DATA). The maximum 
/*           length is 1023 values.
/*           
/*           *RST does not affect data lists. 
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPULMTrainOfftime(
    ViSession   instrSession,
    ViInt32 arraySize,
    ViReal64 _VI_FAR    offtime[]
)
{
    ViChar* pbuffer;
    ViChar* p2buf;
    ViInt32 i;
    INIT;
    
    CHECKOPT(K27);
    CHECKNULL (offtime);

    p2buf = pbuffer = malloc((size_t)  arraySize*20 + 30);
    p2buf += sprintf(pbuffer, ":SOUR:PULM:TRA:OFFT ");

    for (i = 0; i < arraySize; i++)
        p2buf += sprintf (p2buf, "%f,", offtime[i]);

    *--p2buf = '\0';

    CHECKERR (rssmf_sendCmd (instrSession, pbuffer));
    free (pbuffer);
    
    return rssmf_status;
}

/*===========================================================================*/
/* Function: Get PULM Train Offtime
/* Purpose:  This function returns the Offtime part of the selected file 
/*           with data. The data can be given either as a list of numbers 
/*           (list can be of any length and list entries must be separated by 
/*           commas) or as binary block data. When block data is transferred, 
/*           8 (4) bytes are always interpreted as a floating-point number 
/*           with double accuracy (see the command FORMat:DATA). The maximum 
/*           length is 1023 values.
/*           
/*           *RST does not affect data lists. 
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPULMTrainOfftime(
    ViSession   instrSession,
    ViInt32 arraySize,
    ViReal64 _VI_FAR    offtime[]
)
{
    INIT;
    CHECKOPT(K27);
    
    return GETPARAMREAL64ARRAY (instrSession,
                                   "SOUR:PULM:TRA:OFFT?",
                                   offtime,
                                   arraySize);
}

/*===========================================================================*/
/* Function: Get Train Offtime Points
/* Purpose:  This function queries queries the length (in points) of the 
/*           offtime component of the selected list. 
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetTrainOfftimePoints(
    ViSession   instrSession,
    ViInt32*    numberofOfftimePoints
)
{
    INIT;
    CHECKOPT(K27);
    
    return GETPARAMINT32 (instrSession,
                             "SOUR:PULM:TRA:OFFT:POIN?",
                             numberofOfftimePoints);    
}

/*===========================================================================*/
/* Function: Set PULM Train Ontime
/* Purpose:  This function fills the Ontime part of the selected file with 
/*           data. The data can be given either as a list of numbers (list 
/*           can be of any length and list entries must be separated by 
/*           commas) or as binary block data. When block data is transferred, 
/*           8 (4) bytes are always interpreted as a floating-point number 
/*           with double accuracy (see the command FORMat:DATA). The maximum 
/*           length is 1023 values.
/*           
/*           *RST does not affect data lists. 
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPULMTrainOntime(
    ViSession   instrSession,
    ViInt32 arraySize,
    ViReal64 _VI_FAR    ontime[]
)
{
    ViChar* pbuffer;
    ViChar* p2buf;
    ViInt32 i;
    INIT;
    
    CHECKOPT(K27);
    CHECKNULL (ontime);

    p2buf = pbuffer = malloc((size_t)  arraySize*20 + 30);
    p2buf += sprintf(pbuffer, ":SOUR:PULM:TRA:ONT ");

    for (i = 0; i < arraySize; i++)
        p2buf += sprintf (p2buf, "%f,", ontime[i]);

    *--p2buf = '\0';

    CHECKERR (rssmf_sendCmd (instrSession, pbuffer));
    free (pbuffer);
    
    return rssmf_status;
}

/*===========================================================================*/
/* Function: Get PULM Train Ontime
/* Purpose:  This function returns the Ontime part of the selected file with 
/*           data. The data can be given either as a list of numbers (list 
/*           can be of any length and list entries must be separated by 
/*           commas) or as binary block data. When block data is transferred, 
/*           8 (4) bytes are always interpreted as a floating-point number 
/*           with double accuracy (see the command FORMat:DATA). The maximum 
/*           length is 1023 values.
/*           
/*           *RST does not affect data lists. 
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPULMTrainOntime(
    ViSession   instrSession,
    ViInt32 arraySize,
    ViReal64 _VI_FAR    ontime[]
)
{
    INIT;
    CHECKOPT(K27);
    
    return GETPARAMREAL64ARRAY (instrSession,
                                   "SOUR:PULM:TRA:ONT?",
                                   ontime,
                                   arraySize);
}

/*===========================================================================*/
/* Function: Get Train Ontime Points
/* Purpose:  This function queries queries the length (in points) of the 
/*           ontime component of the selected list. 
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetTrainOntimePoints(
    ViSession   instrSession,
    ViInt32*    numberofOntimePoints
)
{
    INIT;
    CHECKOPT(K27);
    
    return GETPARAMINT32 (instrSession,
                             "SOUR:PULM:TRA:ONT:POIN?",
                             numberofOntimePoints);    
}

/*===========================================================================*/
/* Function: Set PULM Train Repetition
/* Purpose:  This function sets the number of repetitions for each
/*           ontime/offtime value pair. The maximum length is 1023 values. 
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPULMTrainRepetition (ViSession instrSession,
                                       ViInt32 arraySize, ViInt32 repetition[])
{
    ViChar* pbuffer;
    ViChar* p2buf;
    ViInt32 i;
    INIT;
    
    CHECKOPT(K27);
    CHECKNULL (repetition);

    p2buf = pbuffer = malloc((size_t)  arraySize*20 + 30);
    p2buf += sprintf(pbuffer, ":SOUR:PULM:TRA:REP ");

    for (i = 0; i < arraySize; i++)
        p2buf += sprintf (p2buf, "%ld,", repetition[i]);

    *--p2buf = '\0';

    CHECKERR (rssmf_sendCmd (instrSession, pbuffer));
    free (pbuffer);
    
    return rssmf_status;
}

/*===========================================================================*/
/* Function: Get PULM Train Repetition
/* Purpose:  This function returns the number of repetitions for each
/*           ontime/offtime value pair. The maximum length is 1023 values. 
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPULMTrainRepetition (ViSession instrSession,
                                       ViInt32 arraySize, ViInt32 repetition[])
{
    INIT;
    CHECKOPT(K27);
    
    return GETPARAMINT32ARRAY (instrSession,
                                   "SOUR:PULM:TRA:REP?",
                                   repetition,
                                   arraySize);
}

/*===========================================================================
 * Function: Set PULM Train Import Export List Mode
 * Purpose:  This function selects if pulse train lists should be imported or 
 *           exported.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPULMTrainImportExportListMode (ViSession instrSession,
                                                          ViInt32 listMode)
{
    return SETPARAMENUM (instrSession,
                          "SOUR:PULM:TRA:DEXC:MODE",
                          listMode,
                          dexcListModeArr);
}

/*===========================================================================
 * Function: Get PULM Train Import Export List Mode
 * Purpose:  This function returns whether pulse train lists is imported or 
 *           exported.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPULMTrainImportExportListMode (ViSession instrSession,
                                                          ViInt32 *listMode)
{
    return GETPARAMENUM (instrSession,
                          "SOUR:PULM:TRA:DEXC:MODE?",
                          listMode,
                          dexcListModeArr);
}

/*===========================================================================
 * Function: Set PULM Train Import Export List File
 * Purpose:  This function calls the File Manager for selecting the pulse train 
 *           list to be exported (source) into an ASCII file or the destination 
 *           for the ASCII file to be imported (destination) in. 
 *           
 *           The list mode files are stored with the fixed file extensions 
 *           *.lsw in a directory of the user's choice. The directory 
 *           applicable to the commands is defined with the command 
 *           MMEMory:CDIR. A path can also be specified, in which case the 
 *           files are stored or loaded in the specified directory.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPULMTrainImportExportListFile (ViSession instrSession,
                                                          ViString sourceFile)
{
    return SETPARAMSTRINGQUOTED (instrSession,
                                    "SOUR:PULM:TRA:DEXC:SEL",
                                    "'",
                                    sourceFile);
}

/*===========================================================================
 * Function: Get PULM Train Import Export List File
 * Purpose:  This function calls the File Manager for querying the pulse
 *           train list to be exported (source) into an ASCII file or the
 *           destination for the ASCII file to be imported (destination) in.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPULMTrainImportExportListFile (ViSession instrSession,
                                                          ViChar sourceFile[])
{
    return GETPARAMSTRING (instrSession,
                              "SOUR:PULM:TRA:DEXC:SEL?",
                              sourceFile,
                              128);
}

/*===========================================================================
 * Function: PULM Train Import Export Execute
 * Purpose:  This function starts the export or import of the selected file. 
 *           
 *           When import is selected, the ASCII file is imported as pulse 
 *           train list.
 *           
 *           When export is selected, the pulse train list is exported into 
 *           the selected ASCII file.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_PULMTrainImportExportExecute (ViSession instrSession)
{
    return rssmf_sendCmd (instrSession, "SOUR:PULM:TRA:DEXC:EXEC");
}

/*===========================================================================
 * Function: Set PULM Train Import Export ASCII File
 * Purpose:  This function calls the File Manager for selecting the ASCII 
 *           file to be imported into a pulse train list (source) or the ASCII 
 *           file the pulse train list is exported (destination) in.
 *           
 *           The ASCII files are stored with the fixed file extensions *.txt 
 *           or *.csv in a directory of the user's choice. The directory 
 *           applicable to the commands is defined with the command 
 *           MMEMory:CDIR.  A path can also be specified, in which case the 
 *           files are stored or loaded in the specified directory.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPULMTrainImportExportASCIIFile (ViSession instrSession,
                                                           ViString ASCIISourceFile)
{
    return SETPARAMSTRINGQUOTED (instrSession,
                                    "SOUR:PULM:TRA:DEXC:AFIL:SEL",
                                    "'",
                                    ASCIISourceFile);
}

/*===========================================================================
 * Function: Get PULM Train Import Export ASCII File
 * Purpose:  This function calls the File Manager for querying the ASCII file
 *           to be imported into a pulse train list (source) or the ASCII
 *           file the pulse train list is exported (destination) in.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPULMTrainImportExportASCIIFile (ViSession instrSession,
                                                           ViChar ASCIISourceFile[])
{
    return GETPARAMSTRING (instrSession,
                              "SOUR:PULM:TRA:DEXC:AFIL:SEL?",
                              ASCIISourceFile,
                              128);
}

/*===========================================================================
 * Function: Set PULM Train Import Export ASCII Extension
 * Purpose:  This function selects the file extension of the ASCII file to 
 *           be imported or exported. Selection TXT (text file) or CSV (Excel 
 *           file) is available. 
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPULMTrainImportExportASCIIExtension (ViSession instrSession,
                                                                ViInt32 extension)
{
    return SETPARAMENUM (instrSession,
                          "SOUR:PULM:TRA:DEXC:AFIL:EXT",
                          extension,
                          dexcExtensionArr);
}

/*===========================================================================
 * Function: Get PULM Train Import Export ASCII Extension
 * Purpose:  This function queries the selected file extension of the ASCII
 *           file to be imported or exported. Selection TXT (text file) or
 *           CSV (Excel file) is available.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPULMTrainImportExportASCIIExtension (ViSession instrSession,
                                                                ViInt32 *extension)
{
    return GETPARAMENUM (instrSession,
                          "SOUR:PULM:TRA:DEXC:AFIL:EXT?",
                          extension,
                          dexcExtensionArr);
}

/*===========================================================================
 * Function: Set PULM Train Import Export ASCII Column Separator
 * Purpose:  This function selects the separator between the frequency and 
 *           level column of the ASCII table. 
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPULMTrainImportExportASCIIColumnSeparator (ViSession instrSession,
                                                                      ViInt32 separator)
{
    return SETPARAMENUM (instrSession,
                          "SOUR:PULM:TRA:DEXC:AFIL:SEP:COL",
                          separator,
                          dexcSeparatorArr);
}

/*===========================================================================
 * Function: Get PULM Train Import Export ASCII Column Separator
 * Purpose:  This function returns the separator between the frequency and 
 *           level column of the ASCII table. 
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPULMTrainImportExportASCIIColumnSeparator (ViSession instrSession,
                                                                      ViInt32 *separator)
{
    return GETPARAMENUM (instrSession,
                          "SOUR:PULM:TRA:DEXC:AFIL:SEP:COL?",
                          separator,
                          dexcSeparatorArr);
}

/*===========================================================================
 * Function: Set PULM Train Import Export ASCII Decimal Separator
 * Purpose:  This function selects the decimal separator used in the ASCII 
 *           data between '.' (decimal point) and ',' (comma) with 
 *           floating-point numerals.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPULMTrainImportExportASCIIDecimalSeparator (ViSession instrSession,
                                                                       ViInt32 decimalSeparator)
{
    return SETPARAMENUM (instrSession,
                          "SOUR:PULM:TRA:DEXC:AFIL:SEP:DEC",
                          decimalSeparator,
                          dexcDecimalSeparatorArr);
}

/*===========================================================================
 * Function: Get PULM Train Import Export ASCII Decimal Separator
 * Purpose:  This function returns the decimal separator used in the ASCII 
 *           data between '.' (decimal point) and ',' (comma) with 
 *           floating-point numerals.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPULMTrainImportExportASCIIDecimalSeparator (ViSession instrSession,
                                                                       ViInt32 *decimalSeparator)
{
    return GETPARAMENUM (instrSession,
                          "SOUR:PULM:TRA:DEXC:AFIL:SEP:DEC?",
                          decimalSeparator,
                          dexcDecimalSeparatorArr);
}

/*===========================================================================
 * Function: PULM Train Import Export Catalog
 * Purpose:  This function requests a list of available ASCII files for 
 *           export/import of pulse train data. The individual files are 
 *           separated by commas.
 *            
 *           The ASCII files are stored with the fixed file extensions *.txt 
 *           or *.csv in a directory of the user's choice. The directory 
 *           applicable to the commands is defined with the command 
 *           MMEMory:CDIR.  A path can also be specified, in which case the 
 *           files in the specified directory are read.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_PULMTrainImportExportCatalog (ViSession instrSession,
                                                      ViInt32 arraySize,
                                                      ViChar catalogList[])
{
    return rssmf_getCatalog (instrSession,
                             ":PULM:TRA:DEXC:AFIL:CAT?;*OPC?",
                             arraySize,
                             catalogList,"catalogList");

}

/*****************************************************************************
 * Function: Configure Pulse Modulation Trigger
 * Purpose:  This function configures pulse modulation trigger.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_confPulmTrigger(
    ViSession   instrSession,
    ViInt32 triggerLevel,
    ViInt32 externalInputImpedance,
    ViInt32 triggerMode,
    ViInt32 extTriggerInputSlope,
    ViInt32 gateInputPolarity
)
{
    INIT;
    
    CHECKERR (rssmf_SetPULMTriggerLevel (instrSession, triggerLevel));
    
    CHECKERR (rssmf_SetPULMExternalInputImpedance (instrSession, externalInputImpedance));    
    CHECKERR (rssmf_SetPULMTriggerMode (instrSession, triggerMode));    
    CHECKERR (rssmf_SetPULMExtTriggerInputSlope (instrSession, extTriggerInputSlope));    
    CHECKERR (rssmf_SetPULMGateInputPolarity (instrSession, gateInputPolarity));
    RETURN;
}

/*****************************************************************************
 * Function: Set PULM Trigger Level
 * Purpose:  This function selects the external trigger level.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetPULMTriggerLevel(
    ViSession   instrSession,
    ViInt32 triggerLevel
)
{
    INIT;

    return SETPARAMENUM (instrSession,
                          "SOUR:PULM:TRIG:EXT:LEV",
                          triggerLevel,
                          pulmTriggerLevelArr);
}

/*****************************************************************************
 * Function: Get PULM Trigger Level
 * Purpose:  This function queries the external trigger level.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetPULMTriggerLevel(
    ViSession   instrSession,
    ViInt32*    triggerLevel
)
{
    INIT;

    return GETPARAMENUM (instrSession,
                          "SOUR:PULM:TRIG:EXT:LEV?",
                          triggerLevel,
                          pulmTriggerLevelArr);
}

/*****************************************************************************
 * Function: Set PULM External Input Impedance
 * Purpose:  This function selects the impedance for external pulse trigger.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetPULMExternalInputImpedance(
    ViSession   instrSession,
    ViInt32 externalInputImpedance
)
{
    INIT;

    return SETPARAMENUM (instrSession,
                          "SOUR:PULM:TRIG:EXT:IMP",
                          externalInputImpedance,
                          externalInputImpedanceArr);
}

/*****************************************************************************
 * Function: Get PULM External Input Impedance
 * Purpose:  This function queries the impedance for external pulse trigger.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetPULMExternalInputImpedance(
    ViSession   instrSession,
    ViInt32* externalInputImpedance
)
{
    INIT;

    return GETPARAMENUM (instrSession,
                          "SOUR:PULM:TRIG:EXT:IMP?",
                          externalInputImpedance,
                          externalInputImpedanceArr);
}

/*****************************************************************************
 * Function: Set PULM Trigger Mode
 * Purpose:  This function selects the trigger mode for pulse modulation.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetPULMTriggerMode(
    ViSession   instrSession,
    ViInt32 triggerMode
)
{
    INIT;

    return SETPARAMENUM (instrSession,
                          "PULM:TRIG:MODE",
                          triggerMode,
                          pulmTriggerModeArr);
}

/*****************************************************************************
 * Function: Get PULM Trigger Mode
 * Purpose:  This function returns the trigger mode for pulse modulation.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetPULMTriggerMode(
    ViSession   instrSession,
    ViInt32*    triggerMode
)
{
    INIT;

    return GETPARAMENUM (instrSession,
                          "PULM:TRIG:MODE?",
                          triggerMode,
                          pulmTriggerModeArr);
}

/*****************************************************************************
 * Function: Set PULM Ext Trigger Input Slope
 * Purpose:  This function sets the active slope of an externally applied 
 *           trigger signal at the TRIGGER input (BNC connector at the rear of 
 *           the instrument).
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetPULMExtTriggerInputSlope(
    ViSession   instrSession,
    ViInt32 extTriggerInputSlope
)
{
    INIT;

    return SETPARAMENUM (instrSession,
                          "SOUR:PULM:TRIG:EXT:SLOP",
                          extTriggerInputSlope,
                          slopeArr);
}

/*****************************************************************************
 * Function: Get PULM Ext Trigger Input Slope
 * Purpose:  This function queries the active slope of an externally applied 
 *           trigger signal at the TRIGGER input (BNC connector at the rear of 
 *           the instrument).
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetPULMExtTriggerInputSlope(
    ViSession   instrSession,
    ViInt32*    extTriggerInputSlope
)
{
    INIT;

    return GETPARAMENUM (instrSession,
                          "SOUR:PULM:TRIG:EXT:SLOP?",
                          extTriggerInputSlope,
                          slopeArr);
}

/*****************************************************************************
 * Function: Set PULM Gate Input Polarity
 * Purpose:  This function selects the active level of the gate signal.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetPULMGateInputPolarity(
    ViSession   instrSession,
    ViInt32 polarity
)
{
    INIT;

    return SETPARAMENUM (instrSession,
                          "PULM:TRIG:EXT:GATE:POL",
                          polarity,
                          polarityArr);
}

/*****************************************************************************
 * Function: Get PULM Gate Input Polarity
 * Purpose:  This function queries the active level of the gate signal.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetPULMGateInputPolarity(
    ViSession   instrSession,
    ViInt32*    polarity
)
{
    INIT;

    return GETPARAMENUM (instrSession,
                          "PULM:TRIG:EXT:GATE:POL?",
                          polarity,
                          polarityArr);
}

/*****************************************************************************
 * Function: Configure AM
 * Purpose:  This function sets available parameters of amplitude modulation.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_configAM(
    ViSession   instrSession,
    ViInt32 channel,
    ViBoolean   amState,
    ViInt32 amSource,
    ViReal64    amDepth,
    ViBoolean   scanState,
    ViReal64    amSensitivity,
    ViReal64    ratio
)
{
    INIT;
    
    /* scan state overrides AM state. Turn off AM state on both channels if scanState == VI_TRUE */
    if (scanState != VI_FALSE)
    {
        (void) rssmf_SetAMState (instrSession, 1, VI_FALSE);
        (void) rssmf_SetAMState (instrSession, 2, VI_FALSE);
    }
    else
    {
        CHECKERR (rssmf_SetAMState (instrSession, channel, amState));
    }
    
    CHECKERR (rssmf_SetAMScanState (instrSession, scanState));    
    CHECKERR (rssmf_SetAMSource (instrSession, channel, amSource));    
    CHECKERR (rssmf_SetAMDepth (instrSession, channel, amDepth));    
    CHECKERR (rssmf_SetAMSensitivity (instrSession, channel, amSensitivity));    
    CHECKERR (rssmf_SetAMRatio (instrSession, ratio));
    RETURN;
}

/*****************************************************************************
 * Function: Set AM State
 * Purpose:  This function activates/deactivates amplitude modulation.   
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetAMState(
    ViSession   instrSession,
    ViInt32 channel,
    ViBoolean   amState
)
{
    INIT;
    CHECKOPT (B20);
    
    return SETPARAMBOOLPATH (instrSession,
                                   "SOUR:AM%ld:STAT",
                                   channel,
                                   amState);
}

/*****************************************************************************
 * Function: Get AM State
 * Purpose:  This function returns the state of the amplitude modulation.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetAMState(
    ViSession   instrSession,
    ViInt32 channel,
    ViBoolean*  amState
)
{
    INIT;
    CHECKOPT (B20);
    
    return GETPARAMBOOLPATH (instrSession,
                                   "SOUR:AM%ld:STAT?",
                                   channel,
                                   amState);
}

/*****************************************************************************
 * Function: Set AM Source
 * Purpose:  This function selects the modulation source for amplitude 
 *           modulation. The external signal is input at the EXT 1 and/or EXT 2 
 *           connector. Internal and external modulation source can be selected 
 *           at the same time.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetAMSource(
    ViSession   instrSession,
    ViInt32 channel,
    ViInt32 amSource
)
{
    INIT;
    CHECKOPT (B20);
    
    return SETPARAMENUMPATH (instrSession,
                              "SOUR:AM%ld:SOUR",
                              channel,
                              amSource,
                              dmSourceArr);
}

/*****************************************************************************
 * Function: Get AM Source
 * Purpose:  This function queries the modulation source for amplitude 
 *           modulation.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetAMSource(
    ViSession   instrSession,
    ViInt32 channel,
    ViInt32*    amSource
)
{
    INIT;
    CHECKOPT (B20);
    
    return GETPARAMENUMPATH (instrSession,
                              "SOUR:AM%ld:SOUR?",
                              channel,
                              amSource,
                              dmSourceArr);
}

/*****************************************************************************
 * Function: Set AM Depth
 * Purpose:  This function sets the modulation depth of the amplitude 
 *           modulation in percent.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetAMDepth(
    ViSession   instrSession,
    ViInt32 channel,
    ViReal64    amDepth
)
{
    INIT;
    CHECKOPT (B20);
    
    return SETPARAMREAL64PATH (instrSession,
                                  "SOUR:AM%ld",
                                  channel,
                                  amDepth,
                                  0.0,100.0);
}

/*****************************************************************************
 * Function: Get AM Depth
 * Purpose:  This function queries the modulation depth of the amplitude 
 *           modulation in percent.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetAMDepth(
    ViSession   instrSession,
    ViInt32 channel,
    ViReal64*   amDepth
)
{
    INIT;
    CHECKOPT (B20);
    
    return GETPARAMREAL64PATH (instrSession,
                                  "SOUR:AM%ld?",
                                  channel,
                                  amDepth);
}

/*****************************************************************************
 * Function: Set AM Sensitivity
 * Purpose:  This function sets the input sensitivity of the EXT input in 
 *           db/V. Function is available for scan state ON only.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetAMSensitivity(
    ViSession   instrSession,
    ViInt32 channel,
    ViReal64    amSensitivity
)
{
    INIT;
    CHECKOPT (B20);
    
    return SETPARAMREAL64PATH (instrSession,
                                  "SOUR:AM%ld:SENS",
                                  channel,
                                  amSensitivity,
                                  -10.0,10.0);
}

/*****************************************************************************
 * Function: Get AM Sensitivity
 * Purpose:  This function queries the input sensitivity of the EXT input in 
 *           db/V. Function is available for scan state ON only.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetAMSensitivity(
    ViSession   instrSession,
    ViInt32 channel,
    ViReal64*   amSensitivity
)
{
    INIT;
    CHECKOPT (B20);
    
    return GETPARAMREAL64PATH (instrSession,
                                  "SOUR:AM%ld:SENS?",
                                  channel,
                                  amSensitivity);
}

/*****************************************************************************
 * Function: Set AM Scan State
 * Purpose:  This function activates/deactivates amplitude modulation scan.   
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetAMScanState(
    ViSession   instrSession,
    ViBoolean   scanState
)
{
    INIT;
    CHECKOPT (B20);

    return SETPARAMBOOL (instrSession,
                               "SOUR:AM:SCAN:STAT",
                               scanState);
}

/*****************************************************************************
 * Function: Get AM Scan State
 * Purpose:  This queries state of amplitude modulation scan.   
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetAMScanState(
    ViSession   instrSession,
    ViBoolean*  scanState
)
{
    INIT;
    CHECKOPT (B20);

    return GETPARAMBOOL (instrSession,
                               "SOUR:AM:SCAN:STAT?",
                               scanState);
}

/*****************************************************************************
 * Function: Set AM Ratio
 * Purpose:  This function sets the path 1/path 2 ratio in percent.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetAMRatio(
    ViSession   instrSession,
    ViReal64    ratio
)
{
    INIT;
    CHECKOPT (B20);

    return SETPARAMREAL64 (instrSession,
                              "SOUR:AM:RAT",
                              ratio,
                              0.0,100.0);
}

/*****************************************************************************
 * Function: Get AM Ratio
 * Purpose:  This function queries the path 1/path 2 ratio in percent.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetAMRatio(
    ViSession   instrSession,
    ViReal64*   ratio
)
{
    INIT;
    CHECKOPT (B20);

    return GETPARAMREAL64 (instrSession,
                              "SOUR:AM:RAT?",
                              ratio);
}

/*****************************************************************************
 * Function: Configure Frequency Modulation
 * Purpose:  This function sets the parameters of frequency modulation.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_confFM(
    ViSession   instrSession,
    ViInt32 channel,
    ViBoolean   state,
    ViInt32 fmSource,
    ViReal64    deviation,
    ViReal64    ratio,
    ViInt32 mode
)
{
    INIT;
    CHECKOPT (B20);
    
    CHECKERR (rssmf_SetFMState (instrSession, channel, state));
    
    CHECKERR (rssmf_SetFMSource (instrSession, channel, fmSource));    
    CHECKERR (rssmf_SetFMDeviation (instrSession, channel, deviation));    
    CHECKERR (rssmf_SetFMRatio (instrSession, ratio));    
    CHECKERR (rssmf_SetFMMode (instrSession, mode));
    RETURN;
}

/*****************************************************************************
 * Function: Set FM State
 * Purpose:  This function activates/deactivates frequency modulation.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetFMState(
    ViSession   instrSession,
    ViInt32 channel,
    ViBoolean   state
)
{
    INIT;
    CHECKOPT (B20);
    
    return SETPARAMBOOLPATH (instrSession,
                                   "SOUR:FM%ld:STAT",
                                   channel,
                                   state);
}

/*****************************************************************************
 * Function: Get FM State
 * Purpose:  This function queries state of frequency modulation.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetFMState(
    ViSession   instrSession,
    ViInt32 channel,
    ViBoolean*  state
)
{
    INIT;
    CHECKOPT (B20);
    
    return GETPARAMBOOLPATH (instrSession,
                                   "SOUR:FM%ld:STAT?",
                                   channel,
                                   state);
}

/*****************************************************************************
 * Function: Set FM Source
 * Purpose:  This function selects the modulation source for frequency 
 *           modulation.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetFMSource(
    ViSession   instrSession,
    ViInt32 channel,
    ViInt32 fmSource
)
{
    INIT;
    CHECKOPT (B20);
    
    return SETPARAMENUMPATH (instrSession,
                              "SOUR:FM%ld:SOUR",
                              channel,
                              fmSource,
                              dmSourceArr);
}

/*****************************************************************************
 * Function: Get FM Source
 * Purpose:  This function queries the modulation source for frequency 
 *           modulation.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetFMSource(
    ViSession   instrSession,
    ViInt32 channel,
    ViInt32*    fmSource
)
{
    INIT;
    CHECKOPT (B20);
    
    return GETPARAMENUMPATH (instrSession,
                              "SOUR:FM%ld:SOUR?",
                              channel,
                              fmSource,
                              dmSourceArr);
}

/*****************************************************************************
 * Function: Set FM Deviation
 * Purpose:  This function sets the deviation of the FM signal.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetFMDeviation(
    ViSession   instrSession,
    ViInt32     channel,
    ViReal64    deviation
)
{
    INIT;
    CHECKOPT (B20);
    
    return SETPARAMREAL64PATH (instrSession,
                                  "SOUR:FM%ld:DEV",
                                  channel,
                                  deviation,
                                  0.0,50.0e6);
}

/*****************************************************************************
 * Function: Get FM Deviation
 * Purpose:  This function returns the the modulation depth in Hz.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetFMDeviation(
    ViSession   instrSession,
    ViInt32     channel,
    ViReal64*   externalDeviation
)
{
    INIT;
    CHECKOPT (B20);
    
    return GETPARAMREAL64PATH (instrSession,
                                  "SOUR:FM%ld:DEV?",
                                  channel,
                                  externalDeviation);
}

/*****************************************************************************
 * Function: Set FM Ratio
 * Purpose:  This function sets the path 1/path 2 ratio in percent.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetFMRatio(
    ViSession   instrSession,
    ViReal64    ratio
)
{
    INIT;
    CHECKOPT (B20);

    return SETPARAMREAL64 (instrSession,
                              "SOUR:FM:RAT",
                              ratio,
                              0.0,100.0);
}

/*****************************************************************************
 * Function: Get FM Ratio
 * Purpose:  This function queries the path 1/path 2 ratio in percent.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetFMRatio(
    ViSession   instrSession,
    ViReal64*   ratio
)
{
    INIT;
    CHECKOPT (B20);

    return GETPARAMREAL64 (instrSession,
                              "SOUR:FM:RAT?",
                              ratio);
}

/*****************************************************************************
 * Function: Set FM Mode
 * Purpose:  This function selects the mode for the frequency modulation.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetFMMode(
    ViSession   instrSession,
    ViInt32 mode
)
{
    INIT;
    CHECKOPT (B20);

    return SETPARAMENUM (instrSession,
                          "FM:MODE",
                          mode,
                          fmModeArr);
}

/*****************************************************************************
 * Function: Get FM Mode
 * Purpose:  This function selects the mode for the frequency modulation.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetFMMode(
    ViSession   instrSession,
    ViInt32*    mode
)
{
    INIT;
    CHECKOPT (B20);

    return GETPARAMENUM (instrSession,
                          "FM:MODE?",
                          mode,
                          fmModeArr);
}

/*****************************************************************************
 * Function: Configure Phase Modulation
 * Purpose:  This function sets the parameters of phase modulation.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_confPM(
    ViSession   instrSession,
    ViInt32 channel,
    ViBoolean   state,
    ViInt32 pmSource,
    ViReal64    deviation,
    ViReal64    ratio,
    ViInt32 mode
)
{
    INIT;
    CHECKOPT (B20);
    
    CHECKERR (rssmf_SetPMState (instrSession, channel, state));
    
    CHECKERR (rssmf_SetPMSource (instrSession, channel, pmSource));    
    CHECKERR (rssmf_SetPMDeviation (instrSession, channel, deviation));    
    CHECKERR (rssmf_SetPMRatio (instrSession, ratio));    
    CHECKERR (rssmf_SetPMMode (instrSession, mode));
    RETURN;
}

/*****************************************************************************
 * Function: Set PM State
 * Purpose:  This function activates/deactivates phase modulation.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetPMState(
    ViSession   instrSession,
    ViInt32 channel,
    ViBoolean   state
)
{
    INIT;
    CHECKOPT (B20);
    
    return SETPARAMBOOLPATH (instrSession,
                                   "SOUR:PM%ld:STAT",
                                   channel,
                                   state);
}

/*****************************************************************************
 * Function: Get PM State
 * Purpose:  This function queries the state of phase modulation.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetPMState(
    ViSession   instrSession,
    ViInt32 channel,
    ViBoolean*  state
)
{
    INIT;
    CHECKOPT (B20);
    
    return GETPARAMBOOLPATH (instrSession,
                                   "SOUR:PM%ld:STAT?",
                                   channel,
                                   state);
}

/*****************************************************************************
 * Function: Set PM Source
 * Purpose:  This function selects the modulation source for phase modulation.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetPMSource(
    ViSession   instrSession,
    ViInt32 channel,
    ViInt32 pmSource
)
{
    INIT;
    CHECKOPT (B20);
    
    return SETPARAMENUMPATH (instrSession,
                              "SOUR:PM%ld:SOUR",
                              channel,
                              pmSource,
                              dmSourceArr);
}

/*****************************************************************************
 * Function: Get PM Source
 * Purpose:  This function queries the modulation source for phase modulation.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetPMSource(
    ViSession   instrSession,
    ViInt32 channel,
    ViInt32*    pmSource
)
{
    INIT;
    CHECKOPT (B20);
    
    return GETPARAMENUMPATH (instrSession,
                              "SOUR:PM%ld:SOUR?",
                              channel,
                              pmSource,
                              dmSourceArr);
}

/*****************************************************************************
 * Function: Set PM Deviation
 * Purpose:  This function sets the the modulation depth in RAD.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetPMDeviation(
    ViSession   instrSession,
    ViInt32 channel,
    ViReal64    deviation
)
{
    INIT;
    CHECKOPT (B20);
    
    return SETPARAMREAL64PATH (instrSession,
                                  "SOUR:PM%ld:DEV",
                                  channel,
                                  deviation,
                                  0.0,100.0);
}

/*****************************************************************************
 * Function: Get PM Deviation
 * Purpose:  This function queries the the modulation depth in RAD.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetPMDeviation(
    ViSession   instrSession,
    ViInt32     channel,
    ViReal64*   deviation
)
{
    INIT;
    CHECKOPT (B20);
    
    return GETPARAMREAL64PATH (instrSession,
                                  "SOUR:PM%ld:DEV?",
                                  channel,
                                  deviation);
}

/*****************************************************************************
 * Function: Set PM Ratio
 * Purpose:  This function sets the path 1/path 2 ratio in percent.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetPMRatio(
    ViSession   instrSession,
    ViReal64    ratio
)
{
    INIT;
    CHECKOPT (B20);

    return SETPARAMREAL64 (instrSession,
                              "SOUR:PM:RAT",
                              ratio,
                              0.0,100.0);
}

/*****************************************************************************
 * Function: Get PM Ratio
 * Purpose:  This function queries the path 1/path 2 ratio in percent.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetPMRatio(
    ViSession   instrSession,
    ViReal64*   ratio
)
{
    INIT;
    CHECKOPT (B20);

    return GETPARAMREAL64 (instrSession,
                              "SOUR:PM:RAT?",
                              ratio);
}

/*****************************************************************************
 * Function: Set PM Mode
 * Purpose:  This function selects the mode for the phase modulation.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetPMMode(
    ViSession   instrSession,
    ViInt32 mode
)
{
    INIT;
    CHECKOPT (B20);

    return SETPARAMENUM (instrSession,
                          "PM:MODE",
                          mode,
                          pmModeArr);
}

/*****************************************************************************
 * Function: Get PM Mode
 * Purpose:  This function queries the mode for the phase modulation.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetPMMode(
    ViSession   instrSession,
    ViInt32*    mode
)
{
    INIT;
    CHECKOPT (B20);

    return GETPARAMENUM (instrSession,
                          "PM:MODE?",
                          mode,
                          pmModeArr);
}

/*****************************************************************************
 * Function: Set DM External Inputs Polarity
 * Purpose:  This function sets the polarity the polarity of the external 
 *           modulation signal.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetDMExternalInputsPolarity(
    ViSession   instrSession,
    ViInt32 channel,
    ViInt32 polarity
)
{
    INIT;
    CHECKOPT (B20);
    
    return SETPARAMENUMPATH (instrSession,
                              "SOUR:DM:EXT:POL%ld",
                              channel,
                              polarity,
                              polarityArr);
}

/*****************************************************************************
 * Function: Get DM External Inputs Polarity
 * Purpose:  This function queries the polarity the polarity of the external 
 *           modulation signal.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetDMExternalInputsPolarity(
    ViSession   instrSession,
    ViInt32 channel,
    ViInt32*    polarity
)
{
    INIT;
    CHECKOPT (B20);
    
    return GETPARAMENUMPATH (instrSession,
                              "SOUR:DM:EXT:POL%ld?",
                              channel,
                              polarity,
                              polarityArr);
}

/*****************************************************************************
 * Function: Configure ASK
 * Purpose:  This function sets available parameters of ASK modulation.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_configASK(
    ViSession   instrSession,
    ViBoolean   askState,
    ViInt32 askSource,
    ViReal64    askDepth
)
{
    INIT;
    CHECKOPT (B20);
    
    CHECKERR (rssmf_SetASKState (instrSession, askState));
    
    CHECKERR (rssmf_SetASKSource (instrSession, askSource));    
    CHECKERR (rssmf_SetASKDepth (instrSession, askDepth));
    RETURN;
}

/*****************************************************************************
 * Function: Set ASK State
 * Purpose:  This function activates/deactivates ASK modulation.   
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetASKState(
    ViSession   instrSession,
    ViBoolean   askState
)
{
    INIT;
    CHECKOPT (B20);

    return SETPARAMBOOL (instrSession,
                               "SOUR:DM:ASK:STAT",
                               askState);
}

/*****************************************************************************
 * Function: Get ASK State
 * Purpose:  This function queries state of ASK modulation.   
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetASKState(
    ViSession   instrSession,
    ViBoolean*  askState
)
{
    INIT;
    CHECKOPT (B20);

    return GETPARAMBOOL (instrSession,
                               "SOUR:DM:ASK:STAT?",
                               askState);
}

/*****************************************************************************
 * Function: Set ASK Source
 * Purpose:  This function selects the modulation source for ASK modulation.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetASKSource(
    ViSession   instrSession,
    ViInt32 askSource
)
{
    INIT;
    CHECKOPT (B20);

    return SETPARAMENUM (instrSession,
                          "SOUR:DM:ASK:SOUR",
                          askSource,
                          askSourceArr);
}

/*****************************************************************************
 * Function: Get ASK Source
 * Purpose:  This function queries the modulation source for ASK modulation.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetASKSource(
    ViSession   instrSession,
    ViInt32*    askSource
)
{
    INIT;
    CHECKOPT (B20);

    return GETPARAMENUM (instrSession,
                          "SOUR:DM:ASK:SOUR?",
                          askSource,
                          askSourceArr);
}

/*****************************************************************************
 * Function: Set ASK Depth
 * Purpose:  This function sets the modulation depth of the ASK modulation in 
 *           percent.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetASKDepth(
    ViSession   instrSession,
    ViReal64    askDepth
)
{
    INIT;
    CHECKOPT (B20);

    return SETPARAMREAL64 (instrSession,
                              "SOUR:DM:ASK:DEPT",
                              askDepth,
                              0.0,100.0);
}

/*****************************************************************************
 * Function: Get ASK Depth
 * Purpose:  This function qeuries the modulation depth of the ASK modulation 
 *           in percent.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetASKDepth(
    ViSession   instrSession,
    ViReal64*   askDepth
)
{
    INIT;
    CHECKOPT (B20);

    return GETPARAMREAL64 (instrSession,
                              "SOUR:DM:ASK:DEPT?",
                              askDepth);
}

/*****************************************************************************
 * Function: Configure FSK
 * Purpose:  This function configures FSK modulation parameters.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_configFSK(
    ViSession   instrSession,
    ViBoolean   fskState,
    ViInt32 fskSource,
    ViReal64    fskDeviation
)
{
    INIT;
    CHECKOPT (B20);
    
    CHECKERR (rssmf_SetFSKState (instrSession, fskState));
    
    CHECKERR (rssmf_SetFSKSource (instrSession, fskSource));    
    CHECKERR (rssmf_SetFSKDeviation (instrSession, fskDeviation));    

    RETURN;
}

/*****************************************************************************
 * Function: Set FSK State
 * Purpose:  This function activates/deactivates FSK modulation.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetFSKState(
    ViSession   instrSession,
    ViBoolean   fskState
)
{
    INIT;
    CHECKOPT (B20);

    return SETPARAMBOOL (instrSession,
                               "SOUR:DM:FSK:STAT",
                               fskState);
}

/*****************************************************************************
 * Function: Get FSK State
 * Purpose:  This function queries state of FSK modulation.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetFSKState(
    ViSession   instrSession,
    ViBoolean*  fskState
)
{
    INIT;
    CHECKOPT (B20);

    return GETPARAMBOOL (instrSession,
                               "SOUR:DM:FSK:STAT?",
                               fskState);
}

/*****************************************************************************
 * Function: Set FSK Source
 * Purpose:  This function selects the modulation source for FSK modulation.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetFSKSource(
    ViSession   instrSession,
    ViInt32 fskSource
)
{
    INIT;
    CHECKOPT (B20);

    return SETPARAMENUM (instrSession,
                          "SOUR:DM:FSK:SOUR",
                          fskSource,
                          askSourceArr);
}

/*****************************************************************************
 * Function: Get FSK Source
 * Purpose:  This function queries the modulation source for FSK modulation.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetFSKSource(
    ViSession   instrSession,
    ViInt32*    fskSource
)
{
    INIT;
    CHECKOPT (B20);

    return GETPARAMENUM (instrSession,
                          "SOUR:DM:FSK:SOUR?",
                          fskSource,
                          askSourceArr);
}

/*****************************************************************************
 * Function: Set FSK Deviation
 * Purpose:  This function sets the modulation deviation of the FSK 
 *           modulation.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetFSKDeviation(
    ViSession   instrSession,
    ViReal64    fskDeviation
)
{
    INIT;
    CHECKOPT (B20);

    return SETPARAMREAL64 (instrSession,
                              "SOUR:DM:FSK:DEV",
                              fskDeviation,
                              0.0,50.0e6);
}

/*****************************************************************************
 * Function: Get FSK Deviation
 * Purpose:  This function queries the modulation deviation of the FSK 
 *           modulation.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetFSKDeviation(
    ViSession   instrSession,
    ViReal64*   fskDeviation
)
{
    INIT;
    CHECKOPT (B20);

    return GETPARAMREAL64 (instrSession,
                              "SOUR:DM:FSK:DEV?",
                              fskDeviation);
}

/*****************************************************************************
 * Function: Configure PSK
 * Purpose:  This function configures PSK modulation parameters.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_configPSK(
    ViSession   instrSession,
    ViBoolean   pskState,
    ViInt32 pskSource,
    ViReal64    pskDeviation
)
{
    INIT;
    CHECKOPT (B20);
    
    CHECKERR (rssmf_SetPSKState (instrSession, pskState));
    
    CHECKERR (rssmf_SetPSKSource (instrSession, pskSource));    
    CHECKERR (rssmf_SetPSKDeviation (instrSession, pskDeviation));           
    RETURN;
}

/*****************************************************************************
 * Function: Set PSK State
 * Purpose:  This function activates/deactivates PSK modulation.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetPSKState(
    ViSession   instrSession,
    ViBoolean   pskState
)
{
    INIT;
    CHECKOPT (B20);

    return SETPARAMBOOL (instrSession,
                               "SOUR:DM:PSK:STAT",
                               pskState);
}

/*****************************************************************************
 * Function: Get PSK State
 * Purpose:  This function queries state of PSK modulation.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetPSKState(
    ViSession   instrSession,
    ViBoolean*  pskState
)
{
    INIT;
    CHECKOPT (B20);

    return GETPARAMBOOL (instrSession,
                               "SOUR:DM:PSK:STAT?",
                               pskState);
}

/*****************************************************************************
 * Function: Set PSK Source
 * Purpose:  This function selects the modulation source for PSK modulation.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetPSKSource(
    ViSession   instrSession,
    ViInt32 pskSource
)
{
    INIT;
    CHECKOPT (B20);

    return SETPARAMENUM (instrSession,
                          "SOUR:DM:PSK:SOUR",
                          pskSource,
                          askSourceArr);
}

/*****************************************************************************
 * Function: Get PSK Source
 * Purpose:  This function queries the modulation source for PSK modulation.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetPSKSource(
    ViSession   instrSession,
    ViInt32*    pskSource
)
{
    INIT;
    CHECKOPT (B20);

    return GETPARAMENUM (instrSession,
                          "SOUR:DM:PSK:SOUR?",
                          pskSource,
                          askSourceArr);
}

/*****************************************************************************
 * Function: Set PSK Deviation
 * Purpose:  This function sets the modulation deviation of the PSK 
 *           modulation.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetPSKDeviation(
    ViSession   instrSession,
    ViReal64    pskDeviation
)
{
    INIT;
    CHECKOPT (B20);

    return SETPARAMREAL64 (instrSession,
                              "SOUR:DM:PSK:DEV",
                              pskDeviation,
                              0.0,100.0);
}

/*****************************************************************************
 * Function: Get PSK Deviation
 * Purpose:  This function queries the modulation deviation of the PSK 
 *           modulation.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetPSKDeviation(
    ViSession   instrSession,
    ViReal64*   pskDeviation
)
{
    INIT;
    CHECKOPT (B20);

    return GETPARAMREAL64 (instrSession,
                              "SOUR:DM:PSK:DEV?",
                              pskDeviation);
}

/*===========================================================================*/
/* Function: Configure CHIRP
/* Purpose:  This function configures the generation of modulation chirps.
/*           
/*           Note(s):
/*           
/*           (1) This function is only available with option R&S SMF-K20/23, 
/*           K20/22 and interface board 1400.0530.02 or 1400.0552.02
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_confCHIRP(
    ViSession   instrSession,
    ViBoolean   chripState,
    ViInt32 direction,
    ViReal64    bandwidth,
    ViReal64    pulsePeriod,
    ViReal64    pulseWidth,
    ViInt32 triggerMode,
    ViInt32 triggerSlope,
    ViInt32 impedance
)
{
    INIT;
    
    CHECKOPTCONT (K20);

    if (rssmf_status != VI_SUCCESS)
    {
        rssmf_status = VI_SUCCESS;
        CHECKOPTCONT (K23);
        if (rssmf_status != VI_SUCCESS)
        {
            rssmf_status = VI_SUCCESS;
            CHECKOPT (K22);
        }
    }
    
    CHECKERR (rssmf_SetCHIRPState (instrSession, chripState));
    
    CHECKERR (rssmf_SetCHIRPDirection (instrSession, direction));    
    CHECKERR (rssmf_SetCHIRPBandwidth (instrSession, bandwidth));    
    CHECKERR (rssmf_SetCHIRPPulsePeriod (instrSession, pulsePeriod));    
    CHECKERR (rssmf_SetCHIRPPulseWidth (instrSession, pulseWidth));    
    CHECKERR (rssmf_SetCHIRPTriggerMode (instrSession, triggerMode));    
    CHECKERR (rssmf_SetCHIRPTriggerSlope (instrSession, triggerSlope));    
    CHECKERR (rssmf_SetCHIRPExternalImpedance (instrSession, impedance));

    return rssmf_status;
    
    
}

/*===========================================================================*/
/* Function: Configure CHIRP Trigger
/* Purpose:  This function configures the trigger for modulation chirp. 
/*           
/*           Note(s):
/*           
/*           (1) This function is only available with option R&S SMF-K20/22, 
/*           R&S SMF-K20/23 and interface board 1400.0530.02 or 1400.0552.02
/*           
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_confCHIRPTrigger(
    ViSession   instrSession,
    ViInt32 triggerSlope,
    ViInt32 gatePolarity,
    ViInt32 impedance,
    ViInt32 triggerMode,
    ViInt32 triggerLevel
)
{
    INIT;
    
    CHECKOPTCONT (K20);

    if (rssmf_status != VI_SUCCESS)
    {
        rssmf_status = VI_SUCCESS;
        CHECKOPTCONT (K23);
        if (rssmf_status != VI_SUCCESS)
        {
            rssmf_status = VI_SUCCESS;
            CHECKOPT (K22);
        }
    }
    
    CHECKERR (rssmf_SetCHIRPTriggerSlope (instrSession, triggerSlope));
    
    CHECKERR (rssmf_SetCHIRPGatePolarity (instrSession, gatePolarity));    
    CHECKERR (rssmf_SetCHIRPExternalImpedance (instrSession, impedance));    
    CHECKERR (rssmf_SetCHIRPTriggerMode (instrSession, triggerMode));    
    CHECKERR (rssmf_SetCHIRPTriggerLevel (instrSession, triggerLevel));
    return rssmf_status;
}

/*===========================================================================*/
/* Function: Set CHIRP Trigger Mode
/* Purpose:  This function selects the trigger mode for modulation chirp. 
/*           
/*           Note(s):
/*           
/*           (1) This function is only available with option R&S SMF-K20/22 
/*           and interface board 1400.0530.02 or 1400.0552.02
/*           
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_SetCHIRPTriggerMode(
    ViSession   instrSession,
    ViInt32 triggerMode
)
{
    INIT;
    
    CHECKOPTCONT (K20);

    if (rssmf_status != VI_SUCCESS)
    {
        rssmf_status = VI_SUCCESS;
        CHECKOPTCONT (K22);
    }
    
    return SETPARAMENUM (instrSession,
                          "SOUR:CHIR:TRIG:MODE",
                          triggerMode,
                          chirpTriggerModeArr);
}

/*===========================================================================*/
/* Function: Get CHIRP Trigger Mode
/* Purpose:  This function returns the trigger mode for modulation chirp. 
/*           
/*           Note(s):
/*           
/*           (1) This function is only available with option R&S SMF-K20/22 
/*           and interface board 1400.0530.02 or 1400.0552.02
/*           
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetCHIRPTriggerMode(
    ViSession   instrSession,
    ViInt32*    triggerMode
)
{
    INIT;
    
    CHECKOPTCONT (K20);

    if (rssmf_status != VI_SUCCESS)
    {
        rssmf_status = VI_SUCCESS;
        CHECKOPTCONT (K22);
    }
    
    return GETPARAMENUM (instrSession,
                          "SOUR:CHIR:TRIG:MODE?",
                          triggerMode,
                          chirpTriggerModeArr);
}

/*===========================================================================*/
/* Function: Set CHIRP Trigger Slope
/* Purpose:  This function sets the active slope of an externally applied 
/*           trigger signal at the PULSE EXT input (BNC connector at the rear 
/*           of the instrument).
/*           
/*           Note(s):
/*           
/*           (1) This function is only available with option R&S SMF-K20/22 
/*           and interface board 1400.0530.02 or 1400.0552.02
/*           
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_SetCHIRPTriggerSlope(
    ViSession   instrSession,
    ViInt32 triggerSlope
)
{
    INIT;
    
    CHECKOPTCONT (K20);

    if (rssmf_status != VI_SUCCESS)
    {
        rssmf_status = VI_SUCCESS;
        CHECKOPTCONT (K22);
    }
    
    return SETPARAMENUM (instrSession,
                          "SOUR:CHIR:TRIG:EXT:SLOP",
                          triggerSlope,
                          chirpTriggerSlopeArr);
}

/*===========================================================================*/
/* Function: Get CHIRP Trigger Slope
/* Purpose:  This function return the active slope of an externally applied 
/*           trigger signal at the PULSE EXT input (BNC connector at the rear 
/*           of the instrument).
/*           
/*           Note(s):
/*           
/*           (1) This function is only available with option R&S SMF-K20/22 
/*           and interface board 1400.0530.02 or 1400.0552.02
/*           
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetCHIRPTriggerSlope(
    ViSession   instrSession,
    ViInt32*    triggerSlope
)
{
    INIT;
    
    CHECKOPTCONT (K20);

    if (rssmf_status != VI_SUCCESS)
    {
        rssmf_status = VI_SUCCESS;
        CHECKOPTCONT (K22);
    }
    
    return GETPARAMENUM (instrSession,
                          "SOUR:CHIR:TRIG:EXT:SLOP?",
                          triggerSlope,
                          chirpTriggerSlopeArr);
}

/*===========================================================================*/
/* Function: Set CHIRP Trigger Level
/* Purpose:  This function selects the external trigger level. 
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_SetCHIRPTriggerLevel(
    ViSession   instrSession,
    ViInt32 triggerLevel
)
{
    INIT;
    
    return SETPARAMENUM (instrSession,
                          "SOUR:CHIR:TRIG:EXT:LEV",
                          triggerLevel,
                          chirpTriggerLevelArr);
}

/*===========================================================================*/
/* Function: Get CHIRP Trigger Level
/* Purpose:  This function resturns the external trigger level. 
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetCHIRPTriggerLevel(
    ViSession   instrSession,
    ViInt32*    triggerLevel
)
{
    INIT;
    
    return GETPARAMENUM (instrSession,
                          "SOUR:CHIR:TRIG:EXT:LEV?",
                          triggerLevel,
                          chirpTriggerLevelArr);
}

/*===========================================================================*/
/* Function: Set CHIRP Gate Polarity
/* Purpose:  This function selects the active level of the gate signal.
/*           
/*           Note(s):
/*           
/*           (1) This function is only available with option R&S SMF-K20/23 
/*           and interface board 1400.0530.02 or 1400.0552.02
/*           
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_SetCHIRPGatePolarity(
    ViSession   instrSession,
    ViInt32 gatePolarity
)
{
    INIT;
    
    CHECKOPTCONT (K20);

    if (rssmf_status != VI_SUCCESS)
    {
        rssmf_status = VI_SUCCESS;
        CHECKOPTCONT (K23);
    }
    
    return SETPARAMENUM (instrSession,
                          "SOUR:CHIR:TRIG:EXT:GATE:POL",
                          gatePolarity,
                          chirpGatePolarityArr);
}

/*===========================================================================*/
/* Function: Get CHIRP Gate Polarity
/* Purpose:  This function returns the active level of the gate signal.
/*           
/*           Note(s):
/*           
/*           (1) This function is only available with option R&S SMF-K20/23 
/*           and interface board 1400.0530.02 or 1400.0552.02
/*           
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetCHIRPGatePolarity(
    ViSession   instrSession,
    ViInt32*    gatePolarity
)
{
    INIT;
    
    CHECKOPTCONT (K20);

    if (rssmf_status != VI_SUCCESS)
    {
        rssmf_status = VI_SUCCESS;
        CHECKOPTCONT (K23);
    }
    
    return GETPARAMENUM (instrSession,
                          "SOUR:CHIR:TRIG:EXT:GATE:POL?",
                          gatePolarity,
                          chirpGatePolarityArr);
}

/*===========================================================================*/
/* Function: Set CHIRP External Impedance
/* Purpose:  This function set the impedance for external feed via the PULSE 
/*           EXT input 
/*           
/*           Note(s):
/*           
/*           (1) This function is only available with option R&S SMF-K20/22 
/*           and interface board 1400.0530.02 or 1400.0552.02
/*           
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_SetCHIRPExternalImpedance(
    ViSession   instrSession,
    ViInt32 impedance
)
{
    INIT;
    
    CHECKOPTCONT (K20);

    if (rssmf_status != VI_SUCCESS)
    {
        rssmf_status = VI_SUCCESS;
        CHECKOPTCONT (K23);
    }
    
    return SETPARAMENUM (instrSession,
                          "SOUR:CHIR:TRIG:EXT:IMP",
                          impedance,
                          chirpImpedanceArr);
}

/*===========================================================================*/
/* Function: Get CHIRP External Impedance
/* Purpose:  This function returns the impedance for external feed via the 
/*           PULSE EXT input 
/*           
/*           Note(s):
/*           
/*           (1) This function is only available with option R&S SMF-K20/22 
/*           and interface board 1400.0530.02 or 1400.0552.02
/*           
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetCHIRPExternalImpedance(
    ViSession   instrSession,
    ViInt32*    impedance
)
{
    INIT;
    
    CHECKOPTCONT (K20);

    if (rssmf_status != VI_SUCCESS)
    {
        rssmf_status = VI_SUCCESS;
        CHECKOPTCONT (K22);
    }
    
    return GETPARAMENUM (instrSession,
                          "SOUR:CHIR:TRIG:EXT:IMP?",
                          impedance,
                          chirpImpedanceArr);
}

/*===========================================================================*/
/* Function: Set CHIRP Direction
/* Purpose:  This function selects the direction of the chirp modulation. 
/*           
/*           Note(s):
/*           
/*           (1) This function is only available with option R&S SMF-K20/22 
/*           and interface board 1400.0530.02 or 1400.0552.02
/*           
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_SetCHIRPDirection(
    ViSession   instrSession,
    ViInt32 direction
)
{
    INIT;
    
    CHECKOPTCONT (K20);

    if (rssmf_status != VI_SUCCESS)
    {
        rssmf_status = VI_SUCCESS;
        CHECKOPTCONT (K22);
    }
    
    return SETPARAMENUM (instrSession,
                          "SOUR:CHIR:DIR",
                          direction,
                          chirpDirectionArr);
}

/*===========================================================================*/
/* Function: Get CHIRP Direction
/* Purpose:  This function returns the direction of the chirp modulation. 
/*           
/*           Note(s):
/*           
/*           (1) This function is only available with option R&S SMF-K20/22 
/*           and interface board 1400.0530.02 or 1400.0552.02
/*           
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetCHIRPDirection(
    ViSession   instrSession,
    ViInt32*    direction
)
{
    INIT;
    
    CHECKOPTCONT (K20);

    if (rssmf_status != VI_SUCCESS)
    {
        rssmf_status = VI_SUCCESS;
        CHECKOPTCONT (K22);
    }
    
    return GETPARAMENUM (instrSession,
                          "SOUR:CHIR:DIR?",
                          direction,
                          chirpDirectionArr);
}

/*===========================================================================*/
/* Function: Set CHIRP State
/* Purpose:  This function activates/deactivates the generation of 
/*           modulation chirps.
/*           
/*           Note(s):
/*           
/*           (1) This function is only available with option R&S SMF-K20/23 
/*           and interface board 1400.0530.02 or 1400.0552.02
/*           
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_SetCHIRPState(
    ViSession   instrSession,
    ViBoolean   chripState
)
{
    INIT;
    
    CHECKOPTCONT (K20);

    if (rssmf_status != VI_SUCCESS)
    {
        rssmf_status = VI_SUCCESS;
        CHECKOPTCONT (K23);
    }
    
    return SETPARAMBOOL (instrSession,
                               "SOUR:CHIR:STAT",
                               chripState);
}

/*===========================================================================*/
/* Function: Get CHIRP State
/* Purpose:  This function returns the generation of modulation chirps 
/*           state.
/*           
/*           Note(s):
/*           
/*           (1) This function is only available with option R&S SMF-K20/23 
/*           and interface board 1400.0530.02 or 1400.0552.02
/*           
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetCHIRPState(
    ViSession   instrSession,
    ViBoolean*  chripState
)
{
    INIT;
    
    CHECKOPTCONT (K20);

    if (rssmf_status != VI_SUCCESS)
    {
        rssmf_status = VI_SUCCESS;
        CHECKOPTCONT (K23);
    }
    
    return GETPARAMBOOL (instrSession,
                               "SOUR:CHIR:STAT?",
                               chripState);
}

/*===========================================================================*/
/* Function: Set CHIRP Bandwidth
/* Purpose:  This function sets the modulation bandwidth of the modulation 
/*           chirp in Hz. The maximal  bandwidth depends on the RF frequency 
/*           set and the selected modulation mode (see data sheet).
/*           
/*           Note(s):
/*           
/*           (1) This function is only available with option R&S SMF-K20/23 
/*           and interface board 1400.0530.02 or 1400.0552.02
/*           
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_SetCHIRPBandwidth(
    ViSession   instrSession,
    ViReal64    bandwidth
)
{
    INIT;
    
    CHECKOPTCONT (K20);

    if (rssmf_status != VI_SUCCESS)
    {
        rssmf_status = VI_SUCCESS;
        CHECKOPTCONT (K23);
    }
    
    return SETPARAMREAL64 (instrSession,
                              "SOUR:CHIR:BAND",
                              bandwidth,
                              0.0, 80.0e6);
}

/*===========================================================================*/
/* Function: Get CHIRP Bandwidth
/* Purpose:  This function returns the modulation bandwidth of the 
/*           modulation chirp in Hz. The maximal  bandwidth depends on the RF 
/*           frequency set and the selected modulation mode (see data sheet).
/*            
/*           Note(s):
/*           
/*           (1) This function is only available with option R&S SMF-K20/23 
/*           and interface board 1400.0530.02 or 1400.0552.02
/*           
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetCHIRPBandwidth(
    ViSession   instrSession,
    ViReal64*   bandwidth
)
{
    INIT;
    
    CHECKOPTCONT (K20);

    if (rssmf_status != VI_SUCCESS)
    {
        rssmf_status = VI_SUCCESS;
        CHECKOPTCONT (K23);
    }
    
    return GETPARAMREAL64 (instrSession,
                              "SOUR:CHIR:BAND?",
                              bandwidth);
}

/*===========================================================================*/
/* Function: Set CHIRP Pulse Period
/* Purpose:  This function sets the period of the generated modulation 
/*           chirp. The period determines the repetition frequency of the 
/*           internal signal. 
/*           
/*           Note(s):
/*           
/*           (1) This function is only available with option R&S SMF-K20/23 
/*           and interface board 1400.0530.02 or 1400.0552.02
/*           
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_SetCHIRPPulsePeriod(
    ViSession   instrSession,
    ViReal64    pulsePeriod
)
{
    INIT;
    
    CHECKOPTCONT (K20);

    if (rssmf_status != VI_SUCCESS)
    {
        rssmf_status = VI_SUCCESS;
        CHECKOPTCONT (K23);
    }
    
    return SETPARAMREAL64 (instrSession,
                              "SOUR:CHIR:PULS:PER",
                              pulsePeriod,
                              200.0e-9, 100.0);
}

/*===========================================================================*/
/* Function: Get CHIRP Pulse Period
/* Purpose:  This function sets the period of the generated modulation 
/*           chirp. The period determines the repetition frequency of the 
/*           internal signal. 
/*            
/*           Note(s):
/*           
/*           (1) This function is only available with option R&S SMF-K20/23 
/*           and interface board 1400.0530.02 or 1400.0552.02
/*           
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetCHIRPPulsePeriod(
    ViSession   instrSession,
    ViReal64*   pulsePeriod
)
{
    INIT;
    
    CHECKOPTCONT (K20);

    if (rssmf_status != VI_SUCCESS)
    {
        rssmf_status = VI_SUCCESS;
        CHECKOPTCONT (K23);
    }
    
    return GETPARAMREAL64 (instrSession,
                              "SOUR:CHIR:PULS:PER?",
                              pulsePeriod);
}

/*===========================================================================*/
/* Function: Set CHIRP Pulse Width
/* Purpose:  This function sets the width of the generated pulse. The pulse 
/*           width must be at least 1us less than the set pulse period. 
/*           
/*           Note(s):
/*           
/*           (1) This function is only available with option R&S SMF-K20/23 
/*           and interface board 1400.0530.02 or 1400.0552.02
/*           
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_SetCHIRPPulseWidth(
    ViSession   instrSession,
    ViReal64    pulseWidth
)
{
    INIT;
    
    CHECKOPTCONT (K20);

    if (rssmf_status != VI_SUCCESS)
    {
        rssmf_status = VI_SUCCESS;
        CHECKOPTCONT (K23);
    }
    
    return SETPARAMREAL64 (instrSession,
                              "SOUR:CHIR:PULS:WIDT",
                              pulseWidth,
                              100.0e-9, 100.0);
}

/*===========================================================================*/
/* Function: Get CHIRP Pulse Width
/* Purpose:  This function returns the width of the generated pulse. The 
/*           pulse width must be at least 1us less than the set pulse period. 
/*           
/*           Note(s):
/*           
/*           (1) This function is only available with option R&S SMF-K20/23 
/*           and interface board 1400.0530.02 or 1400.0552.02
/*           
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetCHIRPPulseWidth(
    ViSession   instrSession,
    ViReal64*   pulseWidth
)
{
    INIT;
    
    CHECKOPTCONT (K20);

    if (rssmf_status != VI_SUCCESS)
    {
        rssmf_status = VI_SUCCESS;
        CHECKOPTCONT (K23);
    }
    
    return GETPARAMREAL64 (instrSession,
                              "SOUR:CHIR:PULS:WIDT?",
                              pulseWidth);
}

/*===========================================================================*/
/* Function: Get CHIRP Compression Ratio
/* Purpose:  This function queries the pulse compression ratio, i.e. the 
/*           product of pulse width (s) and bandwidth (Hz). Pulse compression 
/*           increases the range resolution as well as the signal to noise 
/*           ratio of pulsed signals.
/*           
/*           Note(s):
/*           
/*           (1) This function is only available with option R&S SMF-K20/23 
/*           and interface board 1400.0530.02 or 1400.0552.02
/*           
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetCHIRPCompressionRatio(
    ViSession   instrSession,
    ViReal64*   compressionRatio
)
{
    INIT;
    
    CHECKOPTCONT (K20);

    if (rssmf_status != VI_SUCCESS)
    {
        rssmf_status = VI_SUCCESS;
        CHECKOPTCONT (K23);
    }
    
    return GETPARAMREAL64 (instrSession,
                              "SOUR:CHIR:COMP:RAT?",
                              compressionRatio);
}

/*****************************************************************************
 * Function: Set Output State
 * Purpose:  This function activates and deactivates the RF output.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetOutputState(
    ViSession   instrSession,
    ViBoolean   rfOutputState
)
{
    INIT;

    return SETPARAMBOOL (instrSession,
                               "OUTP:STAT",
                               rfOutputState);
}

/*****************************************************************************
 * Function: Get Output State
 * Purpose:  This function returns state of the RF output.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetOutputState(
    ViSession   instrSession,
    ViBoolean*  rfOutputState
)
{
    INIT;

    return GETPARAMBOOL (instrSession,
                               "OUTP:STAT?",
                               rfOutputState);
}

/*****************************************************************************
 * Function: Configure RF Frequency
 * Purpose:  This function selects Fixed frequency mode and sets the frequency 
 *           and frequency offset of the RF output signal for CW mode 
 *           (:SOURce:FREQuency:MODE CW). 
 *           
 *           As with the FREQ value entered in the display, the OFFSet value 
 *           is also taken into consideration with this function. The specified 
 *           value range is therefore only effective if OFFSet is set to 0. The 
 *           value range for other OFFset values can be calculated using the 
 *           following formula:
 *           
 *           300 kHz + OFFSet ... RFmax + OFFSet
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_confRFFreq(
    ViSession   instrSession,
    ViReal64    frequency,
    ViReal64    offset,
    ViReal64    multiplier,
    ViBoolean   variationActive,
    ViReal64    variationStep
)
{
    ViStatus    rssmf_status;
    ViChar      buffer[BUFFER_SIZE];
    
    CHECKVIREAL64 (instrSession, offset, -50.0e9, 50.0e9);

    CHECKVIREAL64 (instrSession, multiplier, 0.001, 10000.0);

    CHECKERR (rssmf_sendCmd (instrSession, "SOUR:FREQ:MODE FIX"));

    sprintf (buffer, ":FREQ %f;:FREQ:MULT %f;:FREQ:OFFS %f", frequency, multiplier, offset);

    CHECKERR (rssmf_sendCmd (instrSession, buffer));

    CHECKERR (rssmf_SetRFVariationActive (instrSession, variationActive));
    if (variationActive == VI_TRUE)
    {
        CHECKERR (rssmf_SetRFVariationStep (instrSession, variationStep));
	}

    RETURN;
}

/*****************************************************************************
 * Function: Set RF Frequency
 * Purpose:  This function sets the frequency of the RF output signal for CW 
 *           mode (:SOURce:FREQuency:MODE CW). In Sweep mode 
 *           (:SOURce:FREQuency:MODE SWEep), this value is linked to the 
 *           current sweep frequency. 
 *           
 *           In addition to a numerical value, it is also possible to specify 
 *           UP and DOWN. The frequency is then increased or decreased by the 
 *           value which is set under [SOURce:]FREQuency:STEP. 
 *           
 *           As with the FREQ value entered in the display, the OFFSet value 
 *           is also taken into consideration with this function. The specified 
 *           value range is therefore only effective if OFFSet is set to 0. The 
 *           value range for other OFFset values can be calculated using the 
 *           following formula:
 *           
 *           300 kHz + OFFSet ... RFmax + OFFSet
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetRFFrequency(
    ViSession   instrSession,
    ViReal64    frequency
)
{
    INIT;

    return SETPARAMREAL64 (instrSession,
                              "SOUR:FREQ",
                              frequency,
                              0.0, 0.0);
}

/*****************************************************************************
 * Function: Get RF Frequency
 * Purpose:  This function returns the frequency of the RF output signal for 
 *           CW mode (:SOURce:FREQuency:MODE CW). In Sweep mode 
 *           (:SOURce:FREQuency:MODE SWEep), this value is linked to the 
 *           current sweep frequency. 
 *           
 *           In addition to a numerical value, it is also possible to specify 
 *           UP and DOWN. The frequency is then increased or decreased by the 
 *           value which is set under [SOURce:]FREQuency:STEP. 
 *           
 *           As with the FREQ value entered in the display, the OFFSet value 
 *           is also taken into consideration with this function. The specified 
 *           value range is therefore only effective if OFFSet is set to 0. The 
 *           value range for other OFFset values can be calculated using the 
 *           following formula:
 *           
 *           300 kHz + OFFSet ... RFmax + OFFSet
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetRFFrequency(
    ViSession   instrSession,
    ViReal64*   frequency
)
{
    INIT;

    return GETPARAMREAL64 (instrSession,
                              "SOUR:FREQ?",
                              frequency);
}

/*****************************************************************************
 * Function: Set RF Frequency Offset
 * Purpose:  This function sets the frequency offset of a downstream 
 *           instrument, e.g. a mixer (see section RF Frequency and Phase - 
 *           Frequency - Phase). If a frequency offset is entered, the 
 *           frequency entered with SOURce:FREQuency:... no longer corresponds 
 *           to the RF output frequency. The following correlation applies:
 *           
 *           SOURce:FREQuency:... = RF output frequency  + 
 *           SOURce:FREQuency:OFFSet.
 *           
 *           Entering an offset does not change the RF output frequency, but 
 *           rather the query value of SOURce:FREQuency:...
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetRFFrequencyOffset(
    ViSession   instrSession,
    ViReal64    frequencyOffset
)
{
    INIT;

    return SETPARAMREAL64 (instrSession,
                              "SOUR:FREQ:OFFS",
                              frequencyOffset,
                              -50e9,50e9);
}

/*****************************************************************************
 * Function: Get RF Frequency Offset
 * Purpose:  This function returns the frequency offset of a downstream 
 *           instrument, e.g. a mixer (see section RF Frequency and Phase - 
 *           Frequency - Phase). If a frequency offset is entered, the 
 *           frequency entered with SOURce:FREQuency:... no longer corresponds 
 *           to the RF output frequency. The following correlation applies:
 *           
 *           SOURce:FREQuency:... = RF output frequency  + 
 *           SOURce:FREQuency:OFFSet.
 *           
 *           Entering an offset does not change the RF output frequency, but 
 *           rather the query value of SOURce:FREQuency:...
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetRFFrequencyOffset(
    ViSession   instrSession,
    ViReal64*   frequencyOffset
)
{
    INIT;

    return GETPARAMREAL64 (instrSession,
                              "SOUR:FREQ:OFFS?",
                              frequencyOffset);
}

/*****************************************************************************
 * Function: Set RF Frequency Multiplier
 * Purpose:  This function sets the value for the multiplication factor of a 
 *           subsequent downstream instrument.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetRFFrequencyMultiplier(
    ViSession   instrSession,
    ViReal64    multiplier
)
{
    INIT;

    return SETPARAMREAL64 (instrSession,
                              "SOUR:FREQ:MULT",
                              multiplier,
                              0.001, 10000.0);
}

/*****************************************************************************
 * Function: Get RF Frequency Multiplier
 * Purpose:  This function queries the value for the multiplication factor of 
 *           a subsequent downstream instrument.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetRFFrequencyMultiplier(
    ViSession   instrSession,
    ViReal64*   multiplier
)
{
    INIT;

    return GETPARAMREAL64 (instrSession,
                              "SOUR:FREQ:MULT?",
                              multiplier);
}

/*****************************************************************************
 * Function: Set RF Variation Active
 * Purpose:  This function activates (USER) or deactivates (DECimal) the 
 *           user-defined step width used when varying the frequency value with 
 *           the frequency values UP/DOWN. This function is linked to the 
 *           function Variation Active for manual control, i.e. the function 
 *           also activates/deactives the user-defined step width used when 
 *           varying the frequency value with the rotary knob.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetRFVariationActive(
    ViSession   instrSession,
    ViBoolean   variationActive
)
{
    INIT;

    return SETPARAMENUM (instrSession,
                           "SOUR:FREQ:STEP:MODE",
                           (ViInt32) variationActive,
                           variationArr);
}

/*****************************************************************************
 * Function: Get RF Variation Active
 * Purpose:  This function queries the frequency step mode. This function is 
 *           linked to the function Variation Active for manual control, i.e. 
 *           the function also activates/deactives the user-defined step width 
 *           used when varying the frequency value with the rotary knob.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetRFVariationActive(
    ViSession   instrSession,
    ViBoolean*  variationActive
)
{
    ViStatus    rssmf_status;
    ViInt32     variation = 0;
    
    CHECKERR (GETPARAMENUM (instrSession,
                             "SOUR:FREQ:STEP:MODE?",
                             &variation,
                             variationArr));
    if (variationActive != NULL)
        *variationActive = (ViBoolean)((variation == 1)? 1 : 0);

    return rssmf_status;
}

/*****************************************************************************
 * Function: Set RF Variation Step
 * Purpose:  This function sets the step width for the frequency setting if 
 *           the frequency values UP/DOWN are used and variation mode 
 *           :SOUR:FREQ:STEP:MODE USER is selected. This function is linked to  
 *           Variation Step for manual control, i.e. the command also sets the 
 *           step width of the rotary knob for Variation Active on.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetRFVariationStep(
    ViSession   instrSession,
    ViReal64    variationStep
)
{
    INIT;

    return SETPARAMREAL64 (instrSession,
                              "SOUR:FREQ:STEP",
                              variationStep,
                              0.0, 0.0);
}

/*****************************************************************************
 * Function: Get RF Variation Step
 * Purpose:  This function returns the step width of the frequency setting if 
 *           the frequency values UP/DOWN are used and variation mode 
 *           :SOUR:FREQ:STEP:MODE USER is selected. This function is linked to  
 *           Variation Step for manual control, i.e. the command also sets the 
 *           step width of the rotary knob for Variation Active on.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetRFVariationStep(
    ViSession   instrSession,
    ViReal64*   variationStep
)
{
    INIT;

    return GETPARAMREAL64 (instrSession,
                              "SOUR:FREQ:STEP?",
                              variationStep);
}

/*****************************************************************************
 * Function: Set RF Frequency on Recall
 * Purpose:  This function determines whether the current frequency setting is 
 *           retained or whether the stored frequency setting is adopted when 
 *           an instrument configuration is loaded.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetRFFrequencyonRecall(
    ViSession   instrSession,
    ViInt32 rfFrequencyonRecall
)
{
    INIT;

    return SETPARAMENUM (instrSession,
                          "SOUR:FREQ:RCL",
                          rfFrequencyonRecall,
                          onRecallArr);
}

/*****************************************************************************
 * Function: Get RF Frequency on Recall
 * Purpose:  This function returns whether the current frequency setting is 
 *           retained or whether the stored frequency setting is adopted when 
 *           an instrument configuration is loaded.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetRFFrequencyonRecall(
    ViSession   instrSession,
    ViInt32*    rfFrequencyonRecall
)
{
    INIT;

    return GETPARAMENUM (instrSession,
                          "SOUR:FREQ:RCL?",
                          rfFrequencyonRecall,
                          onRecallArr);
}

/*============================================================================
 * Function: rssmf_SetRFDeltaPhase
 * Purpose:  This function specifies the phase variation relative to the
 *           current phase. The variation can be specified in RADians.
 *===========================================================================*/

ViStatus _VI_FUNC rssmf_SetRFDeltaPhase (ViSession instrSession,
                                         ViReal64  deltaPhase)
{
    return SETPARAMREAL64 (instrSession,
                              "SOUR:PHAS",
                              deltaPhase,
                              -359.9,359.9);
}

/*============================================================================
 * Function: rssmf_GetRFDeltaPhase
 * Purpose:  This function returns the phase variation relative to the
 *           current phase. The variation can be specified in RADians.
 *===========================================================================*/

ViStatus _VI_FUNC rssmf_GetRFDeltaPhase (ViSession instrSession,
                                         ViReal64* deltaPhase)
{
    return GETPARAMREAL64 (instrSession,
                              "SOUR:PHAS?",
                              deltaPhase);
}

/*============================================================================
 * Function: rssmf_ResetRFDeltaPhaseDisplay
 * Purpose:  This function adopts the phase set with SOURce:PHASe:ADJust as
 *           the current phase.
 *===========================================================================*/

ViStatus _VI_FUNC rssmf_ResetRFDeltaPhaseDisplay (ViSession instrSession)
{
    return rssmf_sendCmd (instrSession, "SOUR:PHAS:REF");
}

/*****************************************************************************
 * Function: Configure Frequency Sweep
 * Purpose:  This function sets the frequency parameters of sweep.
 *           
 *           This function is linked to the commands [SOURce:]FREQuency:STARt 
 *           and [SOURce:]FREQuency:STOP, i.e. changing these values causes the 
 *           CENTer value to change, and vice versa:
 *           
 *           CENTer = (STARt + STOP)/2. 
 *           
 *           As with the Frequency value entered in the header, the OFFSet 
 *           value is also taken into consideration with this function. The 
 *           specified value range is therefore only effective if OFFSet is set 
 *           to 0. The value range for other OFFset values can be calculated 
 *           using the following formula:
 *           
 *           300 kHz + OFFSet ... RFmax + OFFSet
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_confFrequencySweep(
    ViSession   instrSession,
    ViInt32 mode,
    ViInt32 frequencySetting,
    ViReal64    centerFrequency,
    ViReal64    span,
    ViReal64    startFrequency,
    ViReal64    stopFrequency,
    ViInt32 spacing,
    ViReal64    step,
    ViReal64    dwellTime
)
{
    ViStatus rssmf_status;
    
    CHECKERR (rssmf_SetFrequencySweepMode (instrSession, mode));
    switch (frequencySetting)
    {
        case RSSMF_FREQ_CENTER_SPAN:
            CHECKERR (rssmf_SetFrequencySweepCenterFreq (instrSession, centerFrequency));        
            CHECKERR (rssmf_SetFrequencySweepSpan (instrSession, span));
			break;
        case RSSMF_FREQ_START_STOP:
            CHECKERR (rssmf_SetFrequencySweepStartFreq (instrSession, startFrequency));        
            CHECKERR (rssmf_SetFrequencySweepStopFreq (instrSession, stopFrequency));
			break;
    }
    
    CHECKERR (rssmf_SetFrequencySweepSpacing (instrSession, spacing));    
    if (spacing == RSSMF_FREQ_SWEEP_SPACING_LIN)
    {
        CHECKERR (rssmf_SetFrequencySweepStepLin (instrSession, step));
	}
    else
    {
        CHECKERR (rssmf_SetFrequencySweepStepLog (instrSession, step));
	}
    
    CHECKERR (rssmf_SetFrequencySweepDwellTime (instrSession, dwellTime));
    
    return rssmf_status;
    
}

/*****************************************************************************
 * Function: Frequency Sweep Execute
 * Purpose:  This function triggers a sweep.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_FrequencySweepExecute(
    ViSession   instrSession
)
{
    INIT;

    return rssmf_sendCmd (instrSession, "SOUR:SWE:FREQ:EXEC");
}

/*****************************************************************************
 * Function: Set Instrument Trigger Input Slope
 * Purpose:  This function sets the active slope of an externally applied 
 *           trigger signal at the INST TRIG inputs (BNC connector at the rear 
 *           of the instrument). The setting is effective for both inputs at 
 *           the same time.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetInstrumentTriggerInputSlope(
    ViSession   instrSession,
    ViInt32 inputTriggerSlope
)
{
    INIT;

    return SETPARAMENUM (instrSession,
                          "INP:TRIG:SLOP",
                          inputTriggerSlope,
                          slopeArr);
}

/*****************************************************************************
 * Function: Configure Frequency Sweep Marker
 * Purpose:  This function configures the frequency sweep marker.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_ConfigureFrequencySweepMarker (ViSession instrSession,
                                                       ViUInt32 channel,
                                                       ViBoolean state,
                                                       ViBoolean amplitudeMarker,
                                                       ViReal64 frequency,
                                                       ViReal64 amplitude,
                                                       ViInt32 polarity,
                                                       ViInt32 activeMarker)
{
    ViStatus    rssmf_status;

    CHECKERR (rssmf_SetFrequencySweepMarkerState (instrSession, channel, state));
    
    CHECKERR (rssmf_SetFrequencySweepAmplitudeMarkerState (instrSession, channel, amplitudeMarker));    
    CHECKERR (rssmf_SetFrequencySweepMarkerFrequency (instrSession, channel, frequency));
    CHECKERR (rssmf_SetFrequencySweepAmplitudeMarkerAttenuation (instrSession, amplitude));
    CHECKERR (rssmf_SetFrequencySweepMarkerPolarity (instrSession, polarity));    
    CHECKERR (rssmf_SetFrequencySweepActiveMarker (instrSession, activeMarker));    
    RETURN;    
}

/*****************************************************************************
 * Function: Set Frequency Sweep Mode
 * Purpose:  This function sets the sweep mode.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetFrequencySweepMode(
    ViSession   instrSession,
    ViInt32 mode
)

{
ViStatus    rssmf_status;

    switch (mode)
    {
    case RSSMF_SWEEP_MODE_AUTO:
        CHECKERR (rssmf_SetSweepMode (instrSession, RSSMF_SWEEP_LOW_MODE_AUTO));
        CHECKERR (rssmf_SetFrequencySweepTriggerSource (instrSession,
                                                        RSSMF_TRIG_SOURCE_SWEEP_AUTO));
        CHECKERR (rssmf_SetFrequencyMode (instrSession, RSSMF_LFOUTPUT_FREQUENCY_MODE_SWEEP));
        break;
    case RSSMF_SWEEP_MODE_SINGLE:
        CHECKERR (rssmf_SetSweepMode (instrSession, RSSMF_SWEEP_LOW_MODE_AUTO));
        CHECKERR (rssmf_SetFrequencySweepTriggerSource (instrSession, RSSMF_TRIG_SOURCE_SWEEP_SINGLE));
        CHECKERR (rssmf_SetFrequencyMode (instrSession, RSSMF_LFOUTPUT_FREQUENCY_MODE_SWEEP));
        CHECKERR (rssmf_LFSweepTrigger (instrSession));
        break;
    case RSSMF_SWEEP_MODE_STEP:
        CHECKERR (rssmf_SetSweepMode (instrSession, RSSMF_SWEEP_LOW_MODE_MAN));
        CHECKERR (rssmf_SetFrequencyMode (instrSession, RSSMF_FREQUENCY_MODE_SWEEP));
        break;
    case RSSMF_SWEEP_MODE_EXT_SINGLE:
        CHECKERR (rssmf_SetFrequencyMode (instrSession, RSSMF_SWEEP_LOW_MODE_AUTO));
        CHECKERR (rssmf_SetLFSweepTriggerSource (instrSession,RSSMF_TRIG_SOURCE_SWEEP_EXTERNAL));
        CHECKERR (rssmf_SetSweepMode (instrSession, RSSMF_LFOUTPUT_FREQUENCY_MODE_SWEEP));
        break;
    case RSSMF_SWEEP_MODE_EXT_STEP:
        CHECKERR (rssmf_SetSweepMode (instrSession, RSSMF_SWEEP_LOW_MODE_STEP));
        CHECKERR (rssmf_SetFrequencySweepTriggerSource (instrSession,
                                                        RSSMF_TRIG_SOURCE_SWEEP_EXTERNAL));
        CHECKERR (rssmf_SetFrequencyMode (instrSession, RSSMF_LFOUTPUT_FREQUENCY_MODE_SWEEP));
        break;
    default:
        rssmf_status = rssmf_ParameterError (instrSession, "mode");
    }

    RETURN;
    
}

/*****************************************************************************
 * Function: Set Frequency Sweep Start Freq
 * Purpose:  This function sets the start frequency for the sweep mode. STARt 
 *           can be greater than STOP.
 *           
 *           This function is linked to the commands [SOUR]:FREQ:CENT and 
 *           [SOUR]:FREQ:SPAN, i.e. changing these values causes the STARt 
 *           value to change, and vice versa:
 *           
 *           STARt = (CENTer - SPAN/2). 
 *           
 *           As with the Frequency value entered in the header, the OFFSet 
 *           value is also taken into consideration with this function. The 
 *           specified value range is therefore only effective if OFFSet is set 
 *           to 0. The value range for other OFFset values can be calculated 
 *           using the following formula (see also section Frequency - Phase 
 *           Menu):
 *           
 *           300 kHz + OFFSet ... RFmax + OFFSet
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetFrequencySweepStartFreq(
    ViSession   instrSession,
    ViReal64    startFrequency
)
{
    INIT;

    return SETPARAMREAL64 (instrSession,
                              "SOUR:FREQ:STAR",
                              startFrequency,
                              0.0, 0.0);
}

/*****************************************************************************
 * Function: Get Frequency Sweep Start Freq
 * Purpose:  This function returns the start frequency of the sweep mode. 
 *           STARt can be greater than STOP.
 *           
 *           This function is linked to the commands [SOUR]:FREQ:CENT and 
 *           [SOUR]:FREQ:SPAN, i.e. changing these values causes the STARt 
 *           value to change, and vice versa:
 *           
 *           STARt = (CENTer - SPAN/2). 
 *           
 *           As with the Frequency value entered in the header, the OFFSet 
 *           value is also taken into consideration with this function. The 
 *           specified value range is therefore only effective if OFFSet is set 
 *           to 0. The value range for other OFFset values can be calculated 
 *           using the following formula (see also section Frequency - Phase 
 *           Menu"):
 *           
 *           300 kHz + OFFSet ... RFmax + OFFSet
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetFrequencySweepStartFreq(
    ViSession   instrSession,
    ViReal64*   startFrequency
)
{
    INIT;

    return GETPARAMREAL64 (instrSession,
                              "SOUR:FREQ:STAR?",
                              startFrequency);
}

/*****************************************************************************
 * Function: Set Frequency Sweep Stop Freq
 * Purpose:  This function sets the stop frequency for the sweep mode. STOP 
 *           can be less than STARt.
 *           
 *           This function is linked to the commands [SOUR]:FREQ:CENt and 
 *           [SOUR]:FREQ:SPAN, i.e. changing these values causes the STARt 
 *           value to change, and vice versa:
 *           
 *           STOP = (CENTer + SPAN/2). 
 *           
 *           As with the Frequency value entered in the header, the OFFSet 
 *           value is also taken into consideration with this command. The 
 *           specified value range is therefore only effective if OFFSet is set 
 *           to 0. The value range for other OFFset values can be calculated 
 *           using the following formula (see also section Frequency - Phase 
 *           Menu"):
 *           
 *           300 kHz  + OFFSet ... RFmax + OFFSet
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetFrequencySweepStopFreq(
    ViSession   instrSession,
    ViReal64    stopFrequency
)
{
    INIT;

    return SETPARAMREAL64 (instrSession,
                              "SOUR:FREQ:STOP",
                              stopFrequency,
                              0.0, 0.0);
}

/*****************************************************************************
 * Function: Get Frequency Sweep Stop Freq
 * Purpose:  This function returns the stop frequency of the sweep mode. STOP 
 *           can be less than STARt.
 *           
 *           This function is linked to the commands [SOUR]:FREQ:CENt and 
 *           [SOUR]:FREQ:SPAN, i.e. changing these values causes the STARt 
 *           value to change, and vice versa:
 *           
 *           STOP = (CENTer + SPAN/2). 
 *           
 *           As with the Frequency value entered in the header, the OFFSet 
 *           value is also taken into consideration with this command. The 
 *           specified value range is therefore only effective if OFFSet is set 
 *           to 0. The value range for other OFFset values can be calculated 
 *           using the following formula (see also section Frequency - Phase 
 *           Menu"):
 *           
 *           300 kHz  + OFFSet ... RFmax + OFFSet
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetFrequencySweepStopFreq(
    ViSession   instrSession,
    ViReal64*   stopFrequency
)
{
    INIT;

    return GETPARAMREAL64 (instrSession,
                              "SOUR:FREQ:STOP?",
                              stopFrequency);
}

/*****************************************************************************
 * Function: Set Frequency Sweep Center Freq
 * Purpose:  This function sets the center frequency of the sweep. This 
 *           setting in combination with the span setting 
 *           ([SOURce:]FREQuency:SPAN) defines the sweep range.
 *           
 *           This function is linked to the commands [SOURce:]FREQuency:STARt 
 *           and [SOURce:]FREQuency:STOP, i.e. changing these values causes the 
 *           CENTer value to change, and vice versa:
 *           
 *           CENTer = (STARt + STOP)/2. 
 *           
 *           As with the Frequency value entered in the header, the OFFSet 
 *           value is also taken into consideration with this function. The 
 *           specified value range is therefore only effective if OFFSet is set 
 *           to 0. The value range for other OFFset values can be calculated 
 *           using the following formula:
 *           
 *           300 kHz + OFFSet ... RFmax + OFFSet
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetFrequencySweepCenterFreq(
    ViSession   instrSession,
    ViReal64    centerFrequency
)
{
    INIT;

    return SETPARAMREAL64 (instrSession,
                              "SOUR:FREQ:CENT",
                              centerFrequency,
                              0.0, 0.0);
}

/*****************************************************************************
 * Function: Get Frequency Sweep Center Freq
 * Purpose:  This function returns the center frequency of the sweep. This 
 *           setting in combination with the span setting 
 *           ([SOURce:]FREQuency:SPAN) defines the sweep range.
 *           
 *           This function is linked to the commands [SOURce:]FREQuency:STARt 
 *           and [SOURce:]FREQuency:STOP, i.e. changing these values causes the 
 *           CENTer value to change, and vice versa:
 *           
 *           CENTer = (STARt + STOP)/2. 
 *           
 *           As with the Frequency value entered in the header, the OFFSet 
 *           value is also taken into consideration with this function. The 
 *           specified value range is therefore only effective if OFFSet is set 
 *           to 0. The value range for other OFFset values can be calculated 
 *           using the following formula:
 *           
 *           300 kHz + OFFSet ... RFmax +OFFSet
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetFrequencySweepCenterFreq(
    ViSession   instrSession,
    ViReal64*   centerFrequency
)
{
    INIT;

    return GETPARAMREAL64 (instrSession,
                              "SOUR:FREQ:CENT?",
                              centerFrequency);
}

/*****************************************************************************
 * Function: Set Frequency Sweep Span
 * Purpose:  This function specifies the span for the sweep. This setting in 
 *           combination with the center frequency setting ([SOUR]:FREQ:CENT) 
 *           defines the sweep range.
 *           
 *           This function is linked to the commands [SOUR]:FREQ:STAR and 
 *           [SOUR]:FREQ:STOP, i.e. changing these values causes the SPAN value 
 *           to change, and vice versa:
 *           
 *           SPAN = (STOP - STARt)
 *           
 *           Negative values for SPAN are permitted; STARt > STOP then 
 *           applies.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetFrequencySweepSpan(
    ViSession   instrSession,
    ViReal64    span
)
{
    INIT;

    return SETPARAMREAL64 (instrSession,
                              "SOUR:FREQ:SPAN",
                              span,
                              0.0, 0.0);
}

/*****************************************************************************
 * Function: Get Frequency Sweep Span
 * Purpose:  This function returns the span of the sweep. This setting in 
 *           combination with the center frequency setting ([SOUR]:FREQ:CENT) 
 *           defines the sweep range.
 *           
 *           This function is linked to the commands [SOUR]:FREQ:STAR and 
 *           [SOUR]:FREQ:STOP, i.e. changing these values causes the SPAN value 
 *           to change, and vice versa:
 *           
 *           SPAN = (STOP - STARt)
 *           
 *           Negative values for SPAN are permitted; STARt > STOP then 
 *           applies.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetFrequencySweepSpan(
    ViSession   instrSession,
    ViReal64*   span
)
{
    INIT;

    return GETPARAMREAL64 (instrSession,
                              "SOUR:FREQ:SPAN?",
                              span);
}

/*****************************************************************************
 * Function: Set Frequency Sweep Spacing
 * Purpose:  This function selects linear, logarithmic or ramp sweep spacing.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetFrequencySweepSpacing(
    ViSession   instrSession,
    ViInt32 spacing
)
{
    INIT;
    
    if (spacing == RSSMF_FREQ_SWEEP_SPACING_RAMP)
        CHECKOPT (K4);

    return SETPARAMENUM (instrSession,
                          "SOUR:SWE:SPAC",
                          spacing,
                          frequencySpacingArr);
}

/*****************************************************************************
 * Function: Get Frequency Sweep Spacing
 * Purpose:  This function returns linear or logarithmic sweep spacing.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetFrequencySweepSpacing(
    ViSession   instrSession,
    ViInt32*    spacing
)
{
    INIT;

    return GETPARAMENUM (instrSession,
                          "SOUR:SWE:SPAC?",
                          spacing,
                          frequencySpacingArr);
}

/*****************************************************************************
 * Function: Set Frequency Sweep Step Lin
 * Purpose:  This function sets the step width for linear sweeps.
 *           
 *           This function is linked to the command :SWEep[:FREQuency]:POINts 
 *           as follows:
 *           
 *           POINts = (SPAN / STEP:LIN) + 1
 *           
 *           If STEP:LIN changes, the value of POINTs is adjusted. The STARt 
 *           and STOP value is retained.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetFrequencySweepStepLin(
    ViSession   instrSession,
    ViReal64    stepLin
)
{
    INIT;

    return SETPARAMREAL64 (instrSession,
                              "SOUR:SWE:STEP",
                              stepLin,
                              0.0, 0.0);
}

/*****************************************************************************
 * Function: Get Frequency Sweep Step Lin
 * Purpose:  This function returns the step width for linear sweeps.
 *           
 *           This function is linked to the command :SWEep[:FREQuency]:POINts 
 *           as follows:
 *           
 *           POINts = (SPAN / STEP:LIN) + 1
 *           
 *           If STEP:LIN changes, the value of POINTs is adjusted. The STARt 
 *           and STOP value is retained.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetFrequencySweepStepLin(
    ViSession   instrSession,
    ViReal64*   stepLin
)
{
    INIT;

    return GETPARAMREAL64 (instrSession,
                              "SOUR:SWE:STEP?",
                              stepLin);
}

/*****************************************************************************
 * Function: Set Frequency Sweep Step Log
 * Purpose:  This function specifies the step width factor for logarithmic 
 *           sweeps. The next frequency value of a sweep is calculated (for 
 *           STARt < STOP) using the following formula:
 *           
 *           New frequency = Old frequency + STEP:LOG x Old frequency
 *           
 *           STEP:LOG therefore gives the fraction of the old frequency. The 
 *           frequency is increased by this fraction for the next sweep step. 
 *           Usually STEP:LOG is given in percent, whereby the suffix PCT must 
 *           always be used.
 *           
 *           This function is linked to the command :SWEep[:FREQuency]:POINts 
 *           for STARt < STOP as follows:
 *           
 *           POINts = ((log STOP - log STARt) / log STEP:LOG) + 1
 *           
 *           If STEP:LOG changes, the value of POINTs is adjusted. The STARt 
 *           and STOP value is retained.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetFrequencySweepStepLog(
    ViSession   instrSession,
    ViReal64    stepLog
)
{
    INIT;

    return SETPARAMREAL64 (instrSession,
                              "SOUR:SWE:STEP:LOG",
                              stepLog,
                              0.01, 100.0);
}

/*****************************************************************************
 * Function: Get Frequency Sweep Step Log
 * Purpose:  This function returns the step width factor for logarithmic 
 *           sweeps. The next frequency value of a sweep is calculated (for 
 *           STARt < STOP) using the following formula:
 *           
 *           New frequency = Old frequency + STEP:LOG x Old frequency
 *           
 *           STEP:LOG therefore gives the fraction of the old frequency. The 
 *           frequency is increased by this fraction for the next sweep step. 
 *           Usually STEP:LOG is given in percent, whereby the suffix PCT must 
 *           always be used.
 *           
 *           This function is linked to the command :SWEep[:FREQuency]:POINts 
 *           for STARt < STOP as follows:
 *           
 *           POINts = ((log STOP - log STARt) / log STEP:LOG) + 1
 *           
 *           If STEP:LOG changes, the value of POINTs is adjusted. The STARt 
 *           and STOP value is retained.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetFrequencySweepStepLog(
    ViSession   instrSession,
    ViReal64*   stepLog
)
{
    INIT;

    return GETPARAMREAL64 (instrSession,
                              "SOUR:SWE:STEP:LOG?",
                              stepLog);
}

/*****************************************************************************
 * Function: Set Frequency Sweep Time
 * Purpose:  This function sets the sweep time for ramp sweep.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetFrequencySweepTime (ViSession instrSession,
                                               ViReal64 time)
{
    INIT;

	CHECKOPT (K4);

	return SETPARAMREAL64 (instrSession,
                              "SOUR:SWE:FREQ:TIME",
                              time,
                              0.0, 0.0);
}

/*****************************************************************************
 * Function: Get Frequency Sweep Time
 * Purpose:  This function returns the sweep time for ramp sweep.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetFrequencySweepTime (ViSession instrSession,
                                               ViReal64 *time)
{
    INIT;

	CHECKOPT (K4);

	return GETPARAMREAL64 (instrSession,
                              "SOUR:SWE:FREQ:TIME?",
                              time);
}

/*****************************************************************************
 * Function: Set Frequency Sweep Ramp Time
 * Purpose:  Sets the sweep time for ramp sweep.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetFrequencySweepRampTime (ViSession instrSession,
                                                   ViReal64 rampTime)
{
    return SETPARAMREAL64 (instrSession,
                              "SOUR:SWE:FREQ:TIME",
                              rampTime,
                              0.0, 0.0);
}

/*****************************************************************************
 * Function: Get Frequency Sweep Ramp Time
 * Purpose:  Queries the sweep time for ramp sweep.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetFrequencySweepRampTime (ViSession instrSession,
                                                   ViReal64 *rampTime)
{
    return GETPARAMREAL64 (instrSession,
                              "SOUR:SWE:FREQ:TIME?",
                              rampTime);
}

/*****************************************************************************
 * Function: Set Frequency Sweep Dwell Time
 * Purpose:  This function sets the time taken for each frequency step of the 
 *           sweep.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetFrequencySweepDwellTime(
    ViSession   instrSession,
    ViReal64    dwellTime
)
{
    return SETPARAMREAL64 (instrSession,
                              "SOUR:SWE:DWEL",
                              dwellTime,
                              3.0e-3, 10.0);
}

/*****************************************************************************
 * Function: Get Frequency Sweep Dwell Time
 * Purpose:  This function returns the time taken for each frequency step of 
 *           the sweep.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetFrequencySweepDwellTime(
    ViSession   instrSession,
    ViReal64*   dwellTime
)
{
    return GETPARAMREAL64 (instrSession,
                              "SOUR:SWE:DWEL?",
                              dwellTime);
}

/*****************************************************************************
 * Function: Set Frequency Sweep Manual Step
 * Purpose:  In Sweep mode (:SOUR:FREQ:MODE SWE) this function sets the 
 *           frequency for the next sweep step in the Step sweep mode 
 *           (:SOUR:SWE:MODE MAN). Here only frequency values between the 
 *           settings [SOUR]:FREQ:STAR and ...:STOP are permitted. Each sweep 
 *           step is triggered by a separate :SOUR:FREQ:MAN command.
 *           
 *           As with the Frequency value entered in the header, the OFFSet 
 *           value is also taken into consideration with this function. The 
 *           specified value range is therefore only effective if OFFSet is set 
 *           to 0. The value range for other OFFset values can be calculated 
 *           using the following formula (see also section RF Frequency and 
 *           Phase - Frequency - Phase).
 *           
 *           STARt + OFFSet ... STOP + OFFSet
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetFrequencySweepManualStep(
    ViSession   instrSession,
    ViReal64    manualStep
)
{
    INIT;

    return SETPARAMREAL64 (instrSession,
                              "SOUR:FREQ:MAN",
                              manualStep,
                              0.0, 0.0);
}

/*****************************************************************************
 * Function: Get Frequency Sweep Manual Step
 * Purpose:  In Sweep mode (:SOUR:FREQ:MODE SWE) this function returns the 
 *           frequency for the next sweep step in the Step sweep mode 
 *           (:SOUR:SWE:MODE MAN). Here only frequency values between the 
 *           settings [SOUR]:FREQ:STAR and ...:STOP are permitted. Each sweep 
 *           step is triggered by a separate :SOUR:FREQ:MAN command.
 *           
 *           As with the Frequency value entered in the header, the OFFSet 
 *           value is also taken into consideration with this function. The 
 *           specified value range is therefore only effective if OFFSet is set 
 *           to 0. The value range for other OFFset values can be calculated 
 *           using the following formula (see also section RF Frequency and 
 *           Phase - Frequency - Phase).
 *           
 *           STARt + OFFSet ... STOP + OFFSet
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetFrequencySweepManualStep(
    ViSession   instrSession,
    ViReal64*   manualStep
)
{
    INIT;

    return GETPARAMREAL64 (instrSession,
                              "SOUR:FREQ:MAN?",
                              manualStep);
}

/*****************************************************************************
 * Function: Set Frequency Sweep Points
 * Purpose:  This function sets the number of steps in an RF sweep. This 
 *           function is linked to the command :SWEep[:FREQuency]:STEP as 
 *           follows:
 *           
 *           The following applies for linear sweeps: 
 *                 POINts = (SPAN / STEP:LIN) + 1
 *           
 *           The following applies for logarithmic sweeps and STARt < STOP:
 *                 POINts = ((log STOP - log STARt) / log STEP:LOG) + 1
 *           
 *           If POINTs changes, the value of STEP is adjusted. The STARt and 
 *           STOP value is retained.
 *           
 *           Two separate POINts values are used for linear or logarithmic 
 *           sweep spacing (:SWEep[:FREQuency]:SPACing LIN | LOG). This 
 *           function is always effective for the currently set sweep spacing.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetFrequencySweepPoints(
    ViSession   instrSession,
    ViInt32 frequencySweepPoints
)
{
    INIT;

    return SETPARAMINT32 (instrSession,
                             "SOUR:SWE:POIN",
                             frequencySweepPoints,
                             0, 0);
}

/*****************************************************************************
 * Function: Get Frequency Sweep Points
 * Purpose:  This function returns the number of steps in an RF sweep. This 
 *           function is linked to the command :SWEep[:FREQuency]:STEP as 
 *           follows:
 *           
 *           The following applies for linear sweeps: 
 *                 POINts = (SPAN / STEP:LIN) + 1
 *           
 *           The following applies for logarithmic sweeps and STARt < STOP:
 *                 POINts = ((log STOP - log STARt) / log STEP:LOG) + 1
 *           
 *           If POINTs changes, the value of STEP is adjusted. The STARt and 
 *           STOP value is retained.
 *           
 *           Two separate POINts values are used for linear or logarithmic 
 *           sweep spacing (:SWEep[:FREQuency]:SPACing LIN | LOG). This 
 *           function is always effective for the currently set sweep spacing.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetFrequencySweepPoints(
    ViSession   instrSession,
    ViInt32*    frequencySweepPoints
)
{
    INIT;

    return GETPARAMINT32 (instrSession,
                             "SOUR:SWE:POIN?",
                             frequencySweepPoints);
}

/*****************************************************************************
 * Function: Get Instrument Trigger Input Slope
 * Purpose:  This function returns the active slope of an externally applied 
 *           trigger signal at the INST TRIG inputs (BNC connector at the rear 
 *           of the instrument). The setting is effective for both inputs at 
 *           the same time.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetInstrumentTriggerInputSlope(
    ViSession   instrSession,
    ViInt32*    inputTriggerSlope
)
{
    INIT;

    return GETPARAMENUM (instrSession,
                          "INP:TRIG:SLOP?",
                          inputTriggerSlope,
                          slopeArr);
}

/*===========================================================================*/
/* Function: Set Frequency Sweep Shape
/* Purpose:  This function sets the cycle mode for a sweep sequence (shape).
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_SetFrequencySweepShape(
    ViSession   instrSession,
    ViInt32 shape
)
{
    INIT;

    return SETPARAMENUM (instrSession,
                          "SOUR:SWE:FREQ:SHAP",
                          shape,
                          frequencySweepShapeArr);
}

/*===========================================================================*/
/* Function: Get Frequency Sweep Shape
/* Purpose:  This function returns the cycle mode for a sweep sequence 
/*           (shape).
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetFrequencySweepShape(
    ViSession   instrSession,
    ViInt32*    shape
)
{
    INIT;

    return GETPARAMENUM (instrSession,
                          "SOUR:SWE:FREQ:SHAP?",
                          shape,
                          frequencySweepShapeArr);
}

/*****************************************************************************
 * Function: Set Frequency Sweep Marker State
 * Purpose:  This function switches on or off the selected marker. If the 
 *           marker is switched on, the signal level at the MARKER output 
 *           changes on reaching the frequency mark.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetFrequencySweepMarkerState (ViSession instrSession,
                                                      ViUInt32 channel,
                                                      ViBoolean state)
{
    INIT;
    CHECKOPT (B20);

    CHECKVIUINT32 (instrSession, channel, 1, 10);
    
    return SETPARAMBOOLPATH (instrSession,
                                   "SOUR:SWE:FREQ:MARK%ld:FST",
                                   channel,
                                   state);
}

/*****************************************************************************
 * Function: Get Frequency Sweep Marker State
 * Purpose:  This function returns the state of the selected marker.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetFrequencySweepMarkerState (ViSession instrSession,
                                                      ViUInt32 channel,
                                                      ViBoolean *state)
{
    INIT;
    CHECKOPT (B20);

    CHECKVIUINT32 (instrSession, channel, 1, 10);
    
    return GETPARAMBOOLPATH (instrSession,
                                   "SOUR:SWE:FREQ:MARK%ld:FST?",
                                   channel,
                                   state);
}

/*****************************************************************************
 * Function: Set Frequency Sweep Marker State
 * Purpose:  This function sets the frequency of the selected marker. If the 
 *           marker is switched on, the signal level at the MARKER output 
 *           changes on reaching the frequency mark.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetFrequencySweepMarkerFrequency (ViSession instrSession,
                                                          ViUInt32 channel,
                                                          ViReal64 frequency)
{
    INIT;
    CHECKOPT (B20);

    CHECKVIUINT32 (instrSession, channel, 1, 10);
    
    return SETPARAMREAL64PATH (instrSession,
                                   "SOUR:SWE:FREQ:MARK%ld:FREQ",
                                   channel,
                                   frequency,
                                   0.0,0.0);
}

/*****************************************************************************
 * Function: Get Frequency Sweep Marker State
 * Purpose:  This function returns the frequency of the selected marker.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetFrequencySweepMarkerFrequency (ViSession instrSession,
                                                          ViUInt32 channel,
                                                          ViReal64 *frequency)
{
    INIT;
    CHECKOPT (B20);

    CHECKVIUINT32 (instrSession, channel, 1, 10);
    
    return GETPARAMREAL64PATH (instrSession,
                                   "SOUR:SWE:FREQ:MARK%ld:FREQ?",
                                   channel,
                                   frequency);
}

/*****************************************************************************
 * Function: Set Frequency Sweep Amplitude Marker State
 * Purpose:  This function activates or deactivates the selected amplitude 
 *           marker. If activated, the level is reduced by the amplitude 
 *           entered below on reaching the mark.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetFrequencySweepAmplitudeMarkerState (ViSession instrSession,
                                                               ViUInt32 channel,
                                                               ViBoolean amplitudeMarker)
{
    INIT;
    CHECKOPT (B20);

    CHECKVIUINT32 (instrSession, channel, 1, 10);
    
    return SETPARAMBOOLPATH (instrSession,
                                   "SOUR:SWE:FREQ:MARK%ld:PST",
                                   channel,
                                   amplitudeMarker);
}

/*****************************************************************************
 * Function: Get Frequency Sweep Amplitude Marker State
 * Purpose:  This function returns the state of the selected amplitude marker.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetFrequencySweepAmplitudeMarkerState (ViSession instrSession,
                                                               ViUInt32 channel,
                                                               ViBoolean *amplitudeMarker)
{
    INIT;
    CHECKOPT (B20);

    CHECKVIUINT32 (instrSession, channel, 1, 10);
    
    return GETPARAMBOOLPATH (instrSession,
                                   "SOUR:SWE:FREQ:MARK%ld:PST?",
                                   channel,
                                   amplitudeMarker);
}

/*****************************************************************************
 * Function: Set Frequency Sweep Amplitude Marker Attenuation
 * Purpose:  This function sets the amplitude marker attenuation. This value
 *           is valid for all markers.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetFrequencySweepAmplitudeMarkerAttenuation (ViSession instrSession,
                                                                     ViReal64 amplitude)
{
    INIT;
    CHECKOPT (B20);

    return SETPARAMREAL64 (instrSession,
                              "SOUR:SWE:FREQ:MARK:AMPL",
                              amplitude,
                              0.0,3.0);
}

/*****************************************************************************
 * Function: Get Frequency Sweep Amplitude Marker Attenuation
 * Purpose:  This function returns the amplitude marker attenuation.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetFrequencySweepAmplitudeMarkerAttenuation (ViSession instrSession,
                                                                     ViReal64 *amplitude)
{
    INIT;
    CHECKOPT (B20);

    return GETPARAMREAL64 (instrSession,
                              "SOUR:SWE:FREQ:MARK:AMPL?",
                              amplitude);
}

/*****************************************************************************
 * Function: Set Frequency Sweep Marker Polarity 
 * Purpose:  This function selects the marker output polarity. 
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetFrequencySweepMarkerPolarity (ViSession instrSession,
                                                         ViInt32 polarity)
{
    INIT;
    CHECKOPT (B20);

    CHECKVIINT32 (instrSession, polarity, RSSMF_SWEEP_MARKER_POLARITY_NORMAL, RSSMF_SWEEP_MARKER_POLARITY_INVERTED);
    
    return SETPARAMENUM (instrSession,
                          "SOUR:SWE:FREQ:MARK:OUTP:POL",
                          polarity,
                          polarityArr);
}

/*****************************************************************************
 * Function: Get Frequency Sweep Marker Polarity 
 * Purpose:  This function returns the marker output polarity. 
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetFrequencySweepMarkerPolarity (ViSession instrSession,
                                                         ViInt32 *polarity)
{
    INIT;
    CHECKOPT (B20);

    return GETPARAMENUM (instrSession,
                          "SOUR:SWE:FREQ:MARK:OUTP:POL?",
                          polarity,
                          polarityArr);
}

/*****************************************************************************
 * Function: Set Frequency Sweep Active Marker
 * Purpose:  This function activates the selected marker. The active marker
 *           is output with a higher voltage than all other markers. 
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetFrequencySweepActiveMarker (ViSession instrSession,
                                                       ViInt32 activeMarker)
{
    INIT;
    CHECKOPT (B20);

    CHECKVIINT32 (instrSession, activeMarker, RSSMF_SWEEP_MARKER_ACTIVE_NONE, RSSMF_SWEEP_MARKER_ACTIVE_10);
    
    return SETPARAMENUM (instrSession,
                          "SOUR:SWE:FREQ:MARK:ACT",
                          activeMarker,
                          activeMarkerArr);
}

/*****************************************************************************
 * Function: Get Frequency Sweep Active Marker
 * Purpose:  This function returns the active marker. 
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetFrequencySweepActiveMarker (ViSession instrSession,
                                                       ViInt32 *activeMarker)
{
    INIT;
    CHECKOPT (B20);

    return GETPARAMENUM (instrSession,
                          "SOUR:SWE:FREQ:MARK:ACT?",
                          activeMarker,
                          activeMarkerArr);
}

/*****************************************************************************
 * Function: Set Frequency Sweep All Markers Off
 * Purpose:  This function switches off all active frequency markers.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetFrequencySweepAllMarkersOff (ViSession instrSession)
{
    INIT;
    CHECKOPT (B20);

    return rssmf_sendCmd (instrSession, "SOUR:SWE:FREQ:MARK:AOFF");
}

/*****************************************************************************
 * Function: Set Frequency Sweep Marker Transfer
 * Purpose:  This function copies the frequency value of marker 1 to the
 *           start frequency of the sweep and the frequency value of marker 2 
 *           to the stop frequency of the sweep.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetFrequencySweepMarkerTransfer (ViSession instrSession)
{
    INIT;
    CHECKOPT (B20);

    return rssmf_sendCmd (instrSession, "SOUR:SWE:FREQ:MARK:XFER");
}

/*============================================================================
 * Function: Configure List
 * Purpose:  This function sets all parameters of selected list. If list with
 *           specified name does not exists it will be created.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_confList (ViSession instrSession, ViString listName,
                                  ViInt32 listMode, ViInt32 arraySize,
                                  ViReal64 frequencyValues[],
                                  ViReal64 powerValues[], ViReal64 dwellTime)
{
    ViStatus    rssmf_status;

    CHECKERR (rssmf_SetLISTSelectList (instrSession, listName));
    CHECKERR (rssmf_SetLISTFrequencyValues(instrSession, arraySize, frequencyValues));
    CHECKERR (rssmf_SetLISTPowerValues(instrSession, arraySize, powerValues));
    CHECKERR (rssmf_SetLISTDwellTime(instrSession, dwellTime));
    CHECKERR (rssmf_SetLISTMode(instrSession, listMode));
    RETURN;
}

/*============================================================================
 * Function: LIST Catalog
 * Purpose:  This function requests a list of available lists. The individual
 *           lists are separated by commas.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_LISTCatalog (ViSession instrSession,
                                     ViString directoryPath, ViInt32 arraySize,
                                     ViChar catalogList[])
{
    ViStatus    rssmf_status;
    ViChar      buffer[BUFFER_SIZE];

    if (!directoryPath)
        sprintf (buffer, ":LIST:CAT?;*OPC?");
    else
        sprintf (buffer, ":LIST:CAT? '%s';*OPC?", directoryPath);

    CHECKERR (rssmf_getCatalog (instrSession,
                                     buffer,
                                     (ViUInt32) arraySize,
                                     catalogList, "catalogList"));

    return rssmf_status;
}

/*============================================================================
 * Function: LIST Delete List
 * Purpose:  This function deletes the specified list.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_LISTDeleteList (ViSession instrSession,
                                        ViString listName)
{
    return SETPARAMSTRINGQUOTED (instrSession,
                              ":LIST:DEL",
                              "'",
                              listName);
}

/*============================================================================
 * Function: LIST Delete All
 * Purpose:  This function deletes all lists in the set directory. The List
 *           mode must be deactivated beforehand to ensure that no lists are
 *           selected when this function is called (:SOUR:FREQ:MODE CW or SWE).
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_LISTDeleteAll (ViSession instrSession)
{
    return rssmf_sendCmd (instrSession, ":LIST:DEL:ALL");
}

/*============================================================================
 * Function: LIST Reset List
 * Purpose:  This function resets the list to the starting point.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_LISTResetList (ViSession instrSession)
{
    return rssmf_sendCmd (instrSession, ":SOUR:LIST:RES");
}

/*============================================================================
 * Function: LIST Trigger Execute
 * Purpose:  This function immediately starts the processing of a list in list
 *           mode. It corresponds to the manual-control command Execute Single.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_LISTTriggerExecute (ViSession instrSession)
{
    return rssmf_sendCmd (instrSession, "SOUR:LIST:TRIG:EXEC");
}

/*============================================================================
 * Function: Set LIST Mode
 * Purpose:  This function sets the list mode.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_SetLISTMode (ViSession instrSession,
                                     ViInt32 listMode)
{
    ViStatus    rssmf_status;

    switch (listMode)
    {
    case RSSMF_SWEEP_MODE_AUTO:
        CHECKERR (rssmf_SetModeLIST (instrSession, RSSMF_LIST_SWEEP_MODE_AUTO));
        CHECKERR (rssmf_SetLISTTriggerSource (instrSession,
                                              RSSMF_LIST_TRIGGER_SOURCE_AUTO));
        CHECKERR (rssmf_SetFrequencyMode (instrSession, RSSMF_FREQUENCY_MODE_LIST));
        break;
    case RSSMF_SWEEP_MODE_SINGLE:
        CHECKERR (rssmf_SetModeLIST (instrSession, RSSMF_LIST_SWEEP_MODE_AUTO));
        CHECKERR (rssmf_SetLISTTriggerSource (instrSession,
                                                        RSSMF_LIST_TRIGGER_SOURCE_SINGLE));
        CHECKERR (rssmf_SetFrequencyMode (instrSession, RSSMF_FREQUENCY_MODE_LIST));
        CHECKERR (rssmf_LISTTriggerExecute (instrSession));
        break;
    case RSSMF_SWEEP_MODE_STEP:
        CHECKERR (rssmf_SetModeLIST (instrSession, RSSMF_LIST_SWEEP_MODE_STEP));
        CHECKERR (rssmf_SetFrequencyMode (instrSession, RSSMF_FREQUENCY_MODE_LIST));
        CHECKERR (rssmf_SetLISTTriggerSource (instrSession,
                                                        RSSMF_LIST_TRIGGER_SOURCE_SINGLE));
        break;
    case RSSMF_SWEEP_MODE_EXT_SINGLE:
        CHECKERR (rssmf_SetModeLIST (instrSession, RSSMF_LIST_SWEEP_MODE_AUTO));
        CHECKERR (rssmf_SetLISTTriggerSource (instrSession,
                                              RSSMF_LIST_TRIGGER_SOURCE_EXTERNAL));
        CHECKERR (rssmf_SetFrequencyMode (instrSession, RSSMF_FREQUENCY_MODE_LIST));
        break;
    case RSSMF_SWEEP_MODE_EXT_STEP:
        CHECKERR (rssmf_SetModeLIST (instrSession, RSSMF_LIST_SWEEP_MODE_STEP));
        CHECKERR (rssmf_SetLISTTriggerSource (instrSession,
                                              RSSMF_LIST_TRIGGER_SOURCE_EXTERNAL));
        CHECKERR (rssmf_SetFrequencyMode (instrSession, RSSMF_FREQUENCY_MODE_LIST));
        break;
    default:
        rssmf_status = rssmf_ParameterError (instrSession, "listMode");
    }

    RETURN;
}

/*============================================================================
 * Function: Set LIST Dwell Time
 * Purpose:  This function sets the time for which the instrument retains a
 *           setting.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_SetLISTDwellTime (ViSession instrSession,
                                          ViReal64 dwellTime)
{
    return SETPARAMREAL64 (instrSession,
                              ":SOUR:LIST:DWEL",
                              dwellTime,
                              1.0e-3, 1.0);
}

/*============================================================================
 * Function: Get LIST Dwell Time
 * Purpose:  This function Returns the time for which the instrument retains a
 *           setting.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_GetLISTDwellTime (ViSession instrSession,
                                          ViReal64 *dwellTime)
{
    return GETPARAMREAL64 (instrSession,
                                  ":SOUR:LIST:DWEL?",
                                  dwellTime);
}

/*============================================================================
 * Function: Set LIST Select List
 * Purpose:  This function selects the specified list. If a new list is to be
 *           created, the name can be entered here. The list is created if it
 *           does not yet exist. The list selected here is available for the
 *           further processing steps (editing) and is used in the instrument
 *           when the List mode is activated.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_SetLISTSelectList (ViSession instrSession,
                                           ViString listName)
{
    return SETPARAMSTRINGQUOTED (instrSession,
                                    ":SOUR:LIST:SEL",
                                    "'",
                                    listName);
}

/*============================================================================
 * Function: Get LIST Select List
 * Purpose:  This function queries name of the selected list.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_GetLISTSelectList (ViSession instrSession,
                                           ViChar listName[])
{
    ViStatus    rssmf_status;
    CHECKERR (GETPARAMSTRING (instrSession,
                                  "SOUR:LIST:SEL?",
                                  listName,
                                  128));

    return (rssmf_status < VI_SUCCESS) ? rssmf_status : VI_SUCCESS;
}

/*============================================================================
 * Function: Set LIST Frequency Values
 * Purpose:  This function fills the FREQuency part of the selected list with
 *           data. The data can be given either as a list of numbers (list can
 *           be of any length and list entries must be separated by commas) or
 *           as binary block data. When block data is transferred, 8 (4) bytes
 *           are always interpreted as a floating-point number with double
 *           accuracy (see the command FORMat:DATA).
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_SetLISTFrequencyValues (ViSession instrSession,
                                                ViInt32 arraySize,
                                                ViReal64 frequencyValues[])
{
    ViChar* pbuffer;
    ViChar* p2buf;
    ViInt32 i;
    ViStatus    rssmf_status;

    CHECKNULL (frequencyValues);

    p2buf = pbuffer = malloc((size_t)  arraySize*20 + 30);
    p2buf += sprintf(pbuffer, ":FORM ASC;:SOUR:LIST:FREQ ");

    for (i = 0; i < arraySize; i++)
        p2buf += sprintf (p2buf, "%f,", frequencyValues[i]);

    *--p2buf = '\0';

    CHECKERR (rssmf_sendCmd (instrSession, pbuffer));
    free (pbuffer);
    
    return rssmf_status;
}

/*============================================================================
 * Function: Get LIST Frequency Values
 * Purpose:  This function queries the FREQuency part of the selected list.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_GetLISTFrequencyValues (ViSession instrSession,
                                                ViInt32 arraySize,
                                                ViReal64 frequencyValues[])
{
    return GETPARAMREAL64ARRAY (instrSession,
                                   ":FORM ASC;:LIST:FREQ?",
                                   frequencyValues,
                                   arraySize);
}

/*============================================================================
 * Function:Get LIST Frequency Points
 * Purpose:  This function queries the length (in points) of the FREQuency
 *           component of the selected list.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_GetLISTFrequencyPoints (ViSession instrSession,
                                                ViInt32 *number_ofFrequencyPoints)
{
    return GETPARAMINT32 (instrSession,
                             ":LIST:FREQ:POIN?",
                             number_ofFrequencyPoints);
}

/*============================================================================
 * Function: Set LIST Power Values
 * Purpose:  This function fills the Level part of the selected list with
 *           data. The data can be given either as a list of numbers (list can
 *           be of any length and list entries must be separated by commas) or
 *           as binary block data. When block data is transferred, 8 (4) bytes
 *           are always interpreted as a floating-point number with double
 *           accuracy (see the command FORMat:DATA).
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_SetLISTPowerValues (ViSession instrSession,
                                            ViInt32 arraySize,
                                            ViReal64 powerValues[])
{
    ViChar* pbuffer;
    ViChar* p2buf;
    ViInt32 i;
    ViStatus    rssmf_status;


    CHECKNULL (powerValues);
    
    p2buf = pbuffer = malloc((size_t)arraySize*20 + 30);
    p2buf += sprintf(pbuffer, ":FORM ASC;:SOUR:LIST:POW ");

    for (i = 0; i < arraySize; i++)
        p2buf += sprintf (p2buf, "%fdBm,", powerValues[i]);

    *--p2buf = '\0';

    CHECKERR (rssmf_sendCmd (instrSession, pbuffer));
    free (pbuffer);
    
    return rssmf_status;
}

/*============================================================================
 * Function: Get LIST Power Values
 * Purpose:  This function queries the Level part of the selected list.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_GetLISTPowerValues (ViSession instrSession,
                                            ViInt32 arraySize,
                                            ViReal64 powerValues[])
{
    return GETPARAMREAL64ARRAY (instrSession,
                                   ":FORM ASC;:LIST:POW?",
                                   powerValues,
                                   arraySize);
}

/*============================================================================
 * Function: Get LIST Power Points
 * Purpose:  This function queries the length (in points) of the LEVel part of
 *           the selected list.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_GetLISTPowerPoints (ViSession instrSession,
                                            ViInt32 *number_ofPowerPoints)
{
    return GETPARAMINT32 (instrSession,
                             ":LIST:POW:POIN?",
                             number_ofPowerPoints);
}

/*============================================================================
 * Function: Set Mode LIST
 * Purpose:  This function specifies how the list is to be processed (similar
 *           to SOURce:SWEep:MODE).
 *===========================================================================*/
ViStatus rssmf_SetModeLIST (ViSession instrSession,
                            ViInt32 listMode)
{
    return SETPARAMENUM (instrSession,
                          "SOUR:LIST:MODE",
                          listMode,
                          listModeArr);
}

/*============================================================================
 * Function: Set LIST Trigger Source
 * Purpose:  This function sets the trigger source for the LIST mode.
 *===========================================================================*/
ViStatus rssmf_SetLISTTriggerSource (ViSession instrSession,
                                     ViInt32 triggerSource)
{
    return SETPARAMENUM (instrSession,
                          "SOUR:LIST:TRIG:SOUR",
                          triggerSource,
                          listTriggerSourceArr);
}

/*============================================================================
 * Function: Set LIST Attenuator Mode
 * Purpose:  This function selects the ranges of level settings for the list
 *           mode. The level settings are either performed in the low level
 *           or in the high level ranges.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_SetLISTAttenuatorMode (ViSession instrSession,
                                               ViInt32 attenuatorMode)
{
    return SETPARAMENUM (instrSession,
                          "SOUR:LIST:POW:AMOD",
                          attenuatorMode,
                          ListAttenuatorModeArr);
}

/*============================================================================
 * Function: Get LIST Attenuator Mode
 * Purpose:  This function returns the ranges of level settings for the list
 *           mode. The level settings are either performed in the low level
 *           or in the high level ranges.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_GetLISTAttenuatorMode (ViSession instrSession,
                                               ViInt32 *attenuatorMode)
{
    return GETPARAMENUM (instrSession,
                          "SOUR:LIST:POW:AMOD?",
                          attenuatorMode,
                          ListAttenuatorModeArr);
}

/*============================================================================
 * Function: Set LIST Step Index
 * Purpose:  This function sets the index for step mode. After the trigger
 *           signal the frequency and level settings of the selected index
 *           are processed in List mode.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_SetLISTStepIndex (ViSession instrSession,
                                          ViInt32 stepIndex)
{
  return SETPARAMINT32 (instrSession, 
                         "SOUR:LIST:IND",
               stepIndex,
               0, 0);
}

/*============================================================================
 * Function: Get LIST Step Index
 * Purpose:  This function returns the index for step mode. After the trigger
 *           signal the frequency and level settings of the selected index
 *           are processed in List mode.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_GetLISTStepIndex (ViSession instrSession,
                                          ViInt32 *stepIndex)
{
  return GETPARAMINT32 (instrSession, 
                         "SOUR:LIST:IND?",
               stepIndex);
}

/*============================================================================
 * Function: Set LIST Start Index
 * Purpose:  This function sets the start index of the index range which
 *           defines a subgroup of frequency/level value pairs in the current
 *           list. Only the values in the set index range (:LIST:INDex:STARt
 *           ... :LIST:INDex:STOP) are processed in List mode.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_SetLISTStartIndex (ViSession instrSession,
                                           ViInt32 startIndex)
{
  return SETPARAMINT32 (instrSession, 
                         "SOUR:LIST:IND:STAR",
               startIndex,
               0, 0);
}

/*============================================================================
 * Function: Get LIST Start Index
 * Purpose:  This function returns the start index of the index range which
 *           defines a subgroup of frequency/level value pairs in the current
 *           list. Only the values in the set index range (:LIST:INDex:STARt
 *           ... :LIST:INDex:STOP) are processed in List mode.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_GetLISTStartIndex (ViSession instrSession,
                                           ViInt32 *startIndex)
{
  return GETPARAMINT32 (instrSession, 
                         "SOUR:LIST:IND:STAR?",
               startIndex);
}

/*============================================================================
 * Function: Set LIST Stop Index
 * Purpose:  This function sets the stop index of the index range which
 *           defines a subgroup of frequency/level value pairs in the current
 *           list. Only the values in the set index range (:LIST:INDex:STARt
 *           ... :LIST:INDex:STOP) are processed in List mode.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_SetLISTStopIndex (ViSession instrSession,
                                          ViInt32 stopIndex)
{
  return SETPARAMINT32 (instrSession, 
                         "SOUR:LIST:IND:STOP",
               stopIndex,
               0, 0);
}

/*============================================================================
 * Function: Get LIST Stop Index
 * Purpose:  This function returns the stop index of the index range which
 *           defines a subgroup of frequency/level value pairs in the current
 *           list. Only the values in the set index range (:LIST:INDex:STARt
 *           ... :LIST:INDex:STOP) are processed in List mode.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_GetLISTStopIndex (ViSession instrSession,
                                          ViInt32 *stopIndex)
{
  return GETPARAMINT32 (instrSession, 
                         "SOUR:LIST:IND:STOP?",
               stopIndex);
}

/*============================================================================
 * Function: Learn LIST Mode Data
 * Purpose:  This function learns the selected list, i.e. it determines the
 *           hardware setting for the entire list. The data determined in
 *           this way is stored together with the list. When the list is
 *           activated for the first time, these settings are calculated
 *           automatically.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_LearnLISTModeData (ViSession instrSession)
{
  return rssmf_sendCmd (instrSession, "SOUR:LIST:LEAR");    
}

/*===========================================================================
 * Function: Set LIST Import Export List Mode
 * Purpose:  This function sets the dexchange list mode.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_SetLISTImportExportListMode (ViSession instrSession,
                                                     ViInt32 listMode)
{
    return SETPARAMENUM (instrSession,
                          "SOUR:LIST:DEXC:MODE",
                          listMode,
                          dexcListModeArr);
}

/*===========================================================================
 * Function: Get LIST Import Export List Mode
 * Purpose:  This function returns the dexchange list mode.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_GetLISTImportExportListMode (ViSession instrSession,
                                                     ViInt32 *listMode)
{
    return GETPARAMENUM (instrSession,
                          "SOUR:LIST:DEXC:MODE?",
                          listMode,
                          dexcListModeArr);
}

/*===========================================================================
 * Function: Set LIST Import Export List File
 * Purpose:  This function calls the File Manager for selecting the list 
 *           mode list to be exported (source) into an ASCII file or the 
 *           destination for the ASCII file to be imported (destination) in. 
 *           
 *           The list mode files are stored with the fixed file extensions 
 *           *.lsw in a directory of the user's choice. The directory 
 *           applicable to the commands is defined with the command 
 *           MMEMory:CDIR. A path can also be specified in command 
 *           SOUR:LIST:DEXC:SEL, in which case the files are stored or loaded 
 *           in the specified directory.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_SetLISTImportExportListFile (ViSession instrSession,
                                                     ViString sourceFile)
{
    return SETPARAMSTRINGQUOTED (instrSession,
                                    "SOUR:LIST:DEXC:SEL",
                                    "'",
                                    sourceFile);
}

/*===========================================================================
 * Function: Get LIST Import Export List File
 * Purpose:  This function calls the File Manager for querying the list mode 
 *           list to be exported (source) into an ASCII file or the 
 *           destination for the ASCII file to be imported (destination) in.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_GetLISTImportExportListFile (ViSession instrSession,
                                                     ViChar sourceFile[])
{
    return GETPARAMSTRING (instrSession,
                              "SOUR:LIST:DEXC:SEL?",
                              sourceFile,
                              128);
}

/*===========================================================================
 * Function: Import Export Execute
 * Purpose:  This function starts the export or import of the selected file. 
 *           
 *           When import is selected, the ASCII file is imported as list 
 *           mode list.
 *           
 *           When export is selected, the list mode list is exported into 
 *           the selected ASCII file.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_ImportExportExecute (ViSession instrSession)
{
    return rssmf_sendCmd (instrSession, "SOUR:LIST:DEXC:EXEC");
}

/*===========================================================================
 * Function: Set LIST Import Export ASCII File
 * Purpose:  This function calls the File Manager for selecting the ASCII 
 *           file to be imported into a list mode list (source) or the ASCII 
 *           file the list mode list is exported (destination) in.
 *           
 *           The ASCII files are stored with the fixed file extensions *.txt 
 *           or *.csv in a directory of the user's choice. The directory 
 *           applicable to the commands is defined with the command 
 *           MMEMory:CDIR.  A path can also be specified in command 
 *           SOUR:LIST:DEXC:AFIL:SEL, in which case the files are stored or 
 *           loaded in the specified directory.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_SetLISTImportExportASCIIFile (ViSession instrSession,
                                                      ViString ASCIISourceFile)
{
    return SETPARAMSTRINGQUOTED (instrSession,
                                    "SOUR:LIST:DEXC:AFIL:SEL",
                                    "'",
                                    ASCIISourceFile);
}

/*===========================================================================
 * Function: Get LIST Import Export ASCII File
 * Purpose:  This function calls the File Manager for querying the ASCII 
 *           file to be imported into a list mode list (source) or the ASCII 
 *           file the list mode list is exported (destination) in.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_GetLISTImportExportASCIIFile (ViSession instrSession,
                                                      ViChar ASCIISourceFile[])
{
    return GETPARAMSTRING (instrSession,
                              "SOUR:LIST:DEXC:AFIL:SEL?",
                              ASCIISourceFile,
                              128);
}

/*===========================================================================
 * Function: Set LIST Import Export ASCII Extension
 * Purpose:  This function selects the file extension of the ASCII file to 
 *           be imported or exported. Selection TXT (text file) or CSV (Excel 
 *           file) is available. 
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_SetLISTImportExportASCIIExtension (ViSession instrSession,
                                                           ViInt32 extension)
{
    return SETPARAMENUM (instrSession,
                          "SOUR:LIST:DEXC:AFIL:EXT",
                          extension,
                          dexcExtensionArr);
}

/*===========================================================================
 * Function: Get LIST Import Export ASCII Extension
 * Purpose:  This function queries the selected file extension of the ASCII 
 *           file to be imported or exported. Selection TXT (text file) or 
 *           CSV (Excel file) is available. 
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_GetLISTImportExportASCIIExtension (ViSession instrSession,
                                                           ViInt32 *extension)
{
    return GETPARAMENUM (instrSession,
                          "SOUR:LIST:DEXC:AFIL:EXT?",
                          extension,
                          dexcExtensionArr);
}

/*===========================================================================
 * Function: Set LIST Import Export ASCII Column Separator
 * Purpose:  This function selects the separator between the frequency and 
 *           level column of the ASCII table. 
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_SetLISTImportExportASCIIColumnSeparator (ViSession instrSession,
                                                                 ViInt32 separator)
{
    return SETPARAMENUM (instrSession,
                          "SOUR:LIST:DEXC:AFIL:SEP:COL",
                          separator,
                          dexcSeparatorArr);
}

/*===========================================================================
 * Function: Get LIST Import Export ASCII Column Separator
 * Purpose:  This function queries the selected separator between the 
 *           frequency and level column of the ASCII table. 
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_GetLISTImportExportASCIIColumnSeparator (ViSession instrSession,
                                                                 ViInt32 *separator)
{
    return GETPARAMENUM (instrSession,
                          "SOUR:LIST:DEXC:AFIL:SEP:COL?",
                          separator,
                          dexcSeparatorArr);
}

/*===========================================================================
 * Function: Set LIST Import Export ASCII Column Decimal Separator
 * Purpose:  This function selects the decimal separator used in the ASCII 
 *           data between '.' (decimal point) and ',' (comma) with 
 *           floating-point numerals.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_SetLISTImportExportASCIIColumnDecimalSeparator (ViSession instrSession,
                                                                        ViInt32 decimalSeparator)
{
    return SETPARAMENUM (instrSession,
                          "SOUR:LIST:DEXC:AFIL:SEP:DEC",
                          decimalSeparator,
                          dexcDecimalSeparatorArr);
}

/*===========================================================================
 * Function: Get LIST Import Export ASCII Column Decimal Separator
 * Purpose:  This function displays the selected decimal separator used in 
 *           the ASCII data - '.' (decimal point) and ',' (comma) with 
 *           floating-point numerals.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_GetLISTImportExportASCIIColumnDecimalSeparator (ViSession instrSession,
                                                                        ViInt32 *decimalSeparator)
{
    return GETPARAMENUM (instrSession,
                          "SOUR:LIST:DEXC:AFIL:SEP:DEC?",
                          decimalSeparator,
                          dexcDecimalSeparatorArr);
}

/*===========================================================================
 * Function: LIST Import Export Catalog
 * Purpose:  This function requests a list of available ASCII files for 
 *           export/import of list mode data. The individual files are 
 *           separated by commas.
 *            
 *           The ASCII files are stored with the fixed file extensions *.txt 
 *           or *.csv in a directory of the user's choice. The directory 
 *           applicable to the commands is defined with the command 
 *           MMEMory:CDIR.  A path can also be specified in command 
 *           SOUR:LIST:DEXC:AFIL:CAT?, in which case the files in the 
 *           specified directory are read.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_LISTImportExportCatalog (ViSession instrSession,
                                                 ViInt32 arraySize,
                                                 ViChar catalogList[])
{
    return rssmf_getCatalog (instrSession,
                             ":LIST:DEXC:AFIL:CAT?;*OPC?",
                             arraySize,
                             catalogList,"catalogList");

}

/*****************************************************************************
 * Function: Configure External Reference
 * Purpose:  This function configures reference oscillator for external or 
 *           internal reference.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_confRosc(
    ViSession   instrSession,
    ViInt32 roscSource,
    ViInt32 externalReferenceFrequency,
    ViInt32 roscSynchronizationBandwidth,
    ViInt32 roscOutput,
    ViBoolean   efcState,
    ViBoolean   adjustmentActive,
    ViInt32 adjustmentFrequency
)
{
    INIT;
    
    /* for internal, source has to be set at first, for external, it has to set at last */
	if (roscSource == RSSMF_ROSC_SOURCE_INTERNAL)
	{
	    CHECKERR (rssmf_SetROSCSource (instrSession, roscSource));
	}
	CHECKERR (rssmf_SetROSCExternalReferenceFrequency (instrSession, externalReferenceFrequency));    
    CHECKERR (rssmf_SetROSCSynchronizationBandwidth (instrSession, roscSynchronizationBandwidth));    
    CHECKERR (rssmf_SetROSCAdjustmentActive (instrSession, adjustmentActive));    
    CHECKERR (rssmf_SetROSCAdjustmentFrequency (instrSession, adjustmentFrequency));    
    CHECKERR (rssmf_SetROSCEFCState (instrSession, efcState));    
    CHECKERR (rssmf_SetROSCOutput (instrSession, roscOutput));
	if (roscSource == RSSMF_ROSC_SOURCE_EXTERNAL)
	{
	    CHECKERR (rssmf_SetROSCSource (instrSession, roscSource));
	}
    
    RETURN;
}

/*****************************************************************************
 * Function: Set ROSC Source
 * Purpose:  This function selects between internal and external reference 
 *           frequency.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetROSCSource(
    ViSession   instrSession,
    ViInt32 roscSource
)
{
    INIT;

    return SETPARAMENUM (instrSession,
                          "SOUR:ROSC:SOUR",
                          roscSource,
                          roscOutputArr);
}

/*****************************************************************************
 * Function: Get ROSC Source
 * Purpose:  This function returns reference frequency source.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetROSCSource(
    ViSession   instrSession,
    ViInt32*    roscSource
)
{
    INIT;

    return GETPARAMENUM (instrSession,
                          "SOUR:ROSC:SOUR?",
                          roscSource,
                          roscOutputArr);
}

/*============================================================================
 * Function: Set ROSC RF Output
 * Purpose:  This function determines if the RF output is switched off in
 *           case of a missing external reference signal for selection
 *           external source. If enabled, this setting ensures that no
 *           improper RF signal due to the missing external reference signal
 *           is output and used for measurements. In addition to the error
 *           message "Ext Ref missing", message "RF output deactivated' is
 *           generated
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_SetROSCRFOutput (ViSession instrSession,
                                         ViBoolean RFOutput)
{
  return SETPARAMBOOL (instrSession,
                           "SOUR:ROSC:EXT:RFOF",
                 RFOutput);
}

/*============================================================================
 * Function: Get ROSC RF Output
 * Purpose:  This function returns whether the RF output is switched off in
 *           case of a missing external reference signal for selection
 *           external source.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_GetROSCRFOutput (ViSession instrSession,
                                         ViBoolean *RFOutput)
{
  return GETPARAMBOOL (instrSession,
                           "SOUR:ROSC:EXT:RFOF?",
                 RFOutput);
}

/*****************************************************************************
 * Function: Set ROSC External Reference Frequency
 * Purpose:  This function informs the instrument of the frequency of the 
 *           external reference.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetROSCExternalReferenceFrequency(
    ViSession   instrSession,
    ViInt32 externalReferenceFreq
)
{
    INIT;

    return SETPARAMENUM (instrSession,
                          "SOUR:ROSC:EXT:FREQ",
                          externalReferenceFreq,
                          externalReferenceFreqArr);
}

/*****************************************************************************
 * Function: Get ROSC External Reference Frequency
 * Purpose:  This function returns frequency of the external reference.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetROSCExternalReferenceFrequency(
    ViSession   instrSession,
    ViInt32*    externalReferenceFreq
)
{
    INIT;

    return GETPARAMINT32 (instrSession,
                             "SOUR:ROSC:EXT:FREQ?",
                              externalReferenceFreq);
}

/*****************************************************************************
 * Function: Set ROSC Synchronization Bandwidth
 * Purpose:  This function selects the synchronization bandwidth for an 
 *           external reference signal.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetROSCSynchronizationBandwidth(
    ViSession   instrSession,
    ViInt32 roscSynchronizationBandwidth
)
{
    INIT;

    return SETPARAMENUM (instrSession,
                          "SOUR:ROSC:EXT:SBAN",
                          roscSynchronizationBandwidth,
                          roscBandwidthArr);
}

/*****************************************************************************
 * Function: Get ROSC Synchronization Bandwidth
 * Purpose:  This function returns the synchronization bandwidth for an 
 *           external reference signal.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetROSCSynchronizationBandwidth(
    ViSession   instrSession,
    ViInt32*    roscSynchronizationBandwidth
)
{
    INIT;

    return GETPARAMENUM (instrSession,
                          "SOUR:ROSC:EXT:SBAN?",
                          roscSynchronizationBandwidth,
                          roscBandwidthArr);
}

/*****************************************************************************
 * Function: Set ROSC Output
 * Purpose:  This function selects the output for the reference oscillator 
 *           signal. The external output is only available in case that the 
 *           external reference frequency is 10 MHz.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetROSCOutput(
    ViSession   instrSession,
    ViInt32 roscOutput
)
{
    INIT;

    return SETPARAMENUM (instrSession,
                          "SOUR:ROSC:OUTP:SOUR",
                          roscOutput,
                          roscOutputArr);
}

/*****************************************************************************
 * Function: Get ROSC Output
 * Purpose:  This function queries the output for the reference oscillator 
 *           signal.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetROSCOutput(
    ViSession   instrSession,
    ViInt32*    roscOutput
)
{
    INIT;

    return GETPARAMENUM (instrSession,
                          "SOUR:ROSC:OUTP:SOUR?",
                          roscOutput,
                          roscOutputArr);
}

/*****************************************************************************
 * Function: Set ROSC EFC State
 * Purpose:  This function activates/deactivates the electronic frequency 
 *           control.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetROSCEFCState(
    ViSession   instrSession,
    ViBoolean   efcState
)
{
    INIT;

    return SETPARAMBOOL (instrSession,
                               "SOUR:ROSC:EFC:STAT",
                               efcState);
}

/*****************************************************************************
 * Function: Get ROSC EFC State
 * Purpose:  This function queries state of the electronic frequency control.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetROSCEFCState(
    ViSession   instrSession,
    ViBoolean*  efcState
)
{
    INIT;

    return GETPARAMBOOL (instrSession,
                               "SOUR:ROSC:EFC:STAT?",
                               efcState);
}

/*****************************************************************************
 * Function: Set ROSC Adjustment Active
 * Purpose:  This function determines whether the calibrated (OFF) or a 
 *           user-defined (ON) adjustment value is used for fine adjustment of 
 *           the frequency. With STATe ON, the instrument is no longer in the 
 *           calibrated state.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetROSCAdjustmentActive(
    ViSession   instrSession,
    ViBoolean   adjustmentActive
)
{
    INIT;

    return SETPARAMBOOL (instrSession,
                               "SOUR:ROSC:ADJ",
                               adjustmentActive);
}

/*****************************************************************************
 * Function: Get ROSC Adjustment Active
 * Purpose:  This function determines whether the calibrated (OFF) or a 
 *           user-defined (ON) adjustment value is used for fine adjustment of 
 *           the frequency. With STATe ON, the instrument is no longer in the 
 *           calibrated state.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetROSCAdjustmentActive(
    ViSession   instrSession,
    ViBoolean*  adjustmentActive
)
{
    INIT;

    return GETPARAMBOOL (instrSession,
                               "SOUR:ROSC:ADJ?",
                               adjustmentActive);
}

/*****************************************************************************
 * Function: Set ROSC Adjustment Frequency
 * Purpose:  This function specifies the frequency correction value 
 *           (adjustment value). A detailed definition is given in  section  RF 
 *           Reference Frequency - Reference Oscillator.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetROSCAdjustmentFrequency(
    ViSession   instrSession,
    ViInt32 adjustmentFreq
)
{
    INIT;

    return SETPARAMINT32 (instrSession,
                             "SOUR:ROSC:ADJ:VAL",
                             adjustmentFreq,
                             0,4095);
}

/*****************************************************************************
 * Function: Get ROSC Adjustment Frequency
 * Purpose:  This function returns the frequency correction value (adjustment 
 *           value). A detailed definition is given in  section  RF Reference 
 *           Frequency - Reference Oscillator.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetROSCAdjustmentFrequency(
    ViSession   instrSession,
    ViInt32*    adjustmentFreq
)
{
    INIT;

    return GETPARAMINT32 (instrSession,
                             "SOUR:ROSC:ADJ:VAL?",
                             adjustmentFreq);
}

/*===========================================================================*/
/* Function: Configure Power Sense
/* Purpose:  This function configure the power sense (NRP-Z Power View)
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_confPowerSense(
    ViSession   instrSession,
    ViInt32 sense,
    ViBoolean   initPowerMeas,
    ViInt32 unit,
    ViBoolean   permanentDisplay,
    ViInt32 source,
    ViReal64    frequency,
    ViInt32 filterMode,
    ViBoolean   useSParameters
)
{
    ViStatus rssmf_status;
	useSParameters;
    
    CHECKERR (rssmf_SetInitiatePowerMeasurement (instrSession, sense, initPowerMeas));
    
    CHECKERR (rssmf_SetPowerUnit (instrSession, sense, unit));    
    CHECKERR (rssmf_SetPowerDisplayPermanentState (instrSession, sense, permanentDisplay));    
    CHECKERR (rssmf_SetPowerSource (instrSession, sense, source));    
    if (source == RSSMF_SENSE_POWER_SOURCE_USER)
    {
        CHECKERR (rssmf_SetPowerFrequency (instrSession, sense, frequency));    }
    
    CHECKERR (rssmf_SetPowerFilterMode (instrSession, sense, filterMode));    
    return rssmf_status;
}

/*===========================================================================*/
/* Function: Configure Power Response Measurement
/* Purpose:  This function configure the power sense response measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_confPowerResponseMeasurement(
    ViSession   instrSession,
    ViInt32 sense,
    ViInt32 sweepMode,
    ViReal64    start,
    ViReal64    stop,
    ViInt32 timing,
    ViInt32 steps,
    ViInt32 spacing
)
{
    ViStatus rssmf_status;
    
    CHECKERR (rssmf_SetPowerSweepMode (instrSession, sense, sweepMode));
    
    switch (sweepMode)
    {
    case RSSMF_SENSE_POWER_SWEEP_MODE_FREQ: 
        CHECKERR (rssmf_SetPowerSweepFrequencyStart (instrSession, sense, start));        
        CHECKERR (rssmf_SetPowerSweepFrequencyStop (instrSession, sense, stop));        
        CHECKERR (rssmf_SetPowerSweepFrequencyTiming (instrSession, sense, timing));        
        CHECKERR (rssmf_SetPowerSweepFrequencySteps (instrSession, sense, steps));        
        CHECKERR (rssmf_SetPowerSweepFrequencySpacing (instrSession, sense, spacing));
		break;
        
    case RSSMF_SENSE_POWER_SWEEP_MODE_POW:
        CHECKERR (rssmf_SetPowerSweepPowerStart (instrSession, sense, start));        
        CHECKERR (rssmf_SetPowerSweepPowerStop (instrSession, sense, stop));        
        CHECKERR (rssmf_SetPowerSweepPowerTiming (instrSession, sense, timing));        
        CHECKERR (rssmf_SetPowerSweepPowerSteps (instrSession, sense, steps));        
        CHECKVIINT32 (instrSession, spacing, 0, 0);
        CHECKERR (rssmf_SetPowerSweepPowerSpacing (instrSession, sense, spacing));
		break;
    case RSSMF_SENSE_POWER_SWEEP_MODE_TIME:
        CHECKERR (rssmf_SetPowerSweepTimeStart (instrSession, sense, start));        
        CHECKERR (rssmf_SetPowerSweepTimeStop (instrSession, sense, stop));        
        CHECKERR (rssmf_SetPowerSweepTimeSteps (instrSession, sense, steps));        
        CHECKVIINT32 (instrSession, spacing, 0, 0);
        CHECKERR (rssmf_SetPowerSweepTimeSpacing (instrSession, sense, spacing));
		break;
    default:
        rssmf_status = rssmf_ParameterError (instrSession, "sweepMode");
    }
    
    return rssmf_status;
}

/*===========================================================================*/
/* Function: Configure Power Response Measurement Diagram
/* Purpose:  This function configure the power sense response measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_confPowerResponseMeasurementDiagram(
    ViSession   instrSession,
    ViInt32 sense,
    ViReal64    frequencyYScaleMinimum,
    ViReal64    frequencyYScaleMaximum,
    ViReal64    powerYScaleMinimum,
    ViReal64    powerYScaleMaximum,
    ViInt32 senseMode
)
{
    ViStatus rssmf_status;
    
    CHECKERR (rssmf_SetPowerSweepFrequencyYScaleMinimum (instrSession, sense, frequencyYScaleMinimum));
    
    CHECKERR (rssmf_SetPowerSweepFrequencyYScaleMaximum (instrSession, sense, frequencyYScaleMaximum));    
    CHECKERR (rssmf_SetPowerSweepPowerYScaleMinimum (instrSession, sense, powerYScaleMinimum));    
    CHECKERR (rssmf_SetPowerSweepPowerYScaleMaximum (instrSession, sense, powerYScaleMaximum));    
    CHECKERR (rssmf_SetPowerSweepSenseMode (instrSession, sense, senseMode));    
    return rssmf_status;
}

/*===========================================================================*/
/* Function: Power Zero
/* Purpose:  This function activates the autozero function. Zeroing is 
/*           required in regular interval (at least once a day)and if the 
/*           temperature has varied more than about 5 °C, if the sensor has 
/*           been replaced or if measurements of signals with very low power 
/*           are to be performed. The sensor must be disconnected from all 
/*           power sources before starting the autozero function.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_PowerZero(
    ViSession   instrSession,
    ViInt32 sense
)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "SENS%ld:POW:ZERO", sense);

    return rssmf_sendCmd (instrSession, buffer);
}

/*===========================================================================
 * Function: Set Power Display Permanent Priority
 * Purpose:  The function selects which power measurement result (average or
 *           peak power) is indicated when permanent display is active. 
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPowerDisplayPermanentPriority (ViSession instrSession,
                                                 ViInt32 trace, ViInt32 priority)
{
    ViChar buffer[BUFFER_SIZE];
    
  CHECKVIINT32 (instrSession, trace, 1, 3);
    
  sprintf (buffer, "SENS%ld:POW:DISP:PERM:PRI", trace);
  
    return SETPARAMENUM (instrSession,
                          buffer,
                          priority,
              powerPriorityArr);
}

/*===========================================================================
 * Function: Get Power Display Permanent Priority
 * Purpose:  The function returns which power measurement result (average or
 *           peak power) is indicated when permanent display is active. 
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerDisplayPermanentPriority (ViSession instrSession,
                                                 ViInt32 trace,
                                                 ViInt32 *priority)
{
    ViChar buffer[BUFFER_SIZE];
    
  CHECKVIINT32 (instrSession, trace, 1, 3);
    
  sprintf (buffer, "SENS%ld:POW:DISP:PERM:PRI?", trace);
  
    return GETPARAMENUM (instrSession,
                          buffer,
                          priority,
              powerPriorityArr);
}

/*===========================================================================*/
/* Function: Configure Power Filter
/* Purpose:  This function selects the filter mode. For mode NSR selects 
/*           noise content and noise timeout.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_confPowerFilter(
    ViSession   instrSession,
    ViInt32 sense,
    ViInt32 filterMode,
    ViReal64    noiseContent,
    ViReal64    timeout
)
{
    ViStatus rssmf_status;
    
    CHECKERR (rssmf_SetPowerFilterMode (instrSession, sense, filterMode));
    
    CHECKERR (rssmf_SetPowerFilterFixedNoiseContent (instrSession, sense, noiseContent));    
    CHECKERR (rssmf_SetPowerFilterFixedNoiseTimeout (instrSession, sense, timeout));
    return rssmf_status;
}

/*===========================================================================*/
/* Function: Set Power Filter Length
/* Purpose:  This function selects the filter length for user filter mode
/*           (:SENSe<[1]...3>:POWer:FILTer:TYPE USER). As the filter length 
/*           works as a multiplier for the time window, a constant filter 
/*           length results in a constant measurement time. Values 1 and 2^n 
/*           are setable. In remote control, when using command READ to 
/*           retrieve the measurement result, the time window is fixed to 20 
/*           ms. 
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPowerFilterLength(
    ViSession   instrSession,
    ViInt32 sense,
    ViInt32 filterLength
)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "SENS%ld:POW:FILT:LENG:USER", sense);

    return SETPARAMINT32 (instrSession, 
                             buffer,
                             filterLength,
                             1, 65536);
}

/*===========================================================================*/
/* Function: Get Power Filter Length
/* Purpose:  This function selects the filter length for user filter mode. 
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerFilterLength(
    ViSession   instrSession,
    ViInt32 sense,
    ViInt32*    filterLength
)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "SENS%ld:POW:FILT:LENG:USER?", sense);

    return GETPARAMINT32 (instrSession, 
                             buffer,
                             filterLength);
}

/*===========================================================================*/
/* Function: Set Power Filter Mode
/* Purpose:  This function selects the filter mode. The filter length is the 
/*           multiplier for the time window and thus directly influences the 
/*           measurement time. 
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPowerFilterMode(
    ViSession   instrSession,
    ViInt32 sense,
    ViInt32 filterMode
)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "SENS%ld:POW:FILT:TYPE", sense);

    return SETPARAMENUM (instrSession, 
                          buffer,
                          filterMode,
                          powerFilterModeArr);
}

/*===========================================================================*/
/* Function: Get Power Filter Mode
/* Purpose:  This function queriess the filter mode for user filter mode. 
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerFilterMode(
    ViSession   instrSession,
    ViInt32 sense,
    ViInt32*    filterMode
)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "SENS%ld:POW:FILT:TYPE?", sense);

    return GETPARAMENUM (instrSession, 
                          buffer,
                          filterMode,
                          powerFilterModeArr);
}

/*===========================================================================*/
/* Function: Set Power Filter Fixed Noise Content
/* Purpose:  This function sets the noise content for fixed noise filter 
/*           mode (:SENSe:POWer:FILTer:TYPE NSRation). This value determines 
/*           the proportion of intrinsic noise in the measured result.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPowerFilterFixedNoiseContent(
    ViSession   instrSession,
    ViInt32 sense,
    ViReal64    noiseContent
)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "SENS%ld:POW:FILT:NSR", sense);

    return SETPARAMREAL64 (instrSession, 
                              buffer,
                              noiseContent,
                              0.0001, 1.0);
}

/*===========================================================================*/
/* Function: Get Power Filter Fixed Noise Content
/* Purpose:  This function returns the noise content for fixed noise filter 
/*           mode.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerFilterFixedNoiseContent(
    ViSession   instrSession,
    ViInt32 sense,
    ViReal64*   noiseContent
)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "SENS%ld:POW:FILT:NSR?", sense);

    return GETPARAMREAL64 (instrSession, 
                              buffer,
                              noiseContent);
}

/*===========================================================================*/
/* Function: Set Power Filter Fixed Noise Timeout
/* Purpose:  This function sets the timeout for fixed noise filter mode 
/*           (:SENSe:POWer:FILTer:TYPE NSRation). This value ensures limited 
/*           settling times.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPowerFilterFixedNoiseTimeout(
    ViSession   instrSession,
    ViInt32 sense,
    ViReal64    timeout
)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "SENS%ld:POW:FILT:NSR:MTIM", sense);

    return SETPARAMREAL64 (instrSession, 
                              buffer,
                              timeout,
                              1.0, 999.99);
}

/*===========================================================================*/
/* Function: Get Power Filter Fixed Noise Timeout
/* Purpose:  This function returns the timeout for fixed noise filter mode.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerFilterFixedNoiseTimeout(
    ViSession   instrSession,
    ViInt32 sense,
    ViReal64*   timeout
)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "SENS%ld:POW:FILT:NSR:MTIM?", sense);

    return GETPARAMREAL64 (instrSession, 
                              buffer,
                              timeout);
}

/*===========================================================================*/
/* Function: Get Power Filter Length Auto
/* Purpose:  This function returns the filter length automatically set 
/*           value.
/*           
/*           Example:
/*            SENS1:FILT:TYPE AUTO
/*            selects auto filter mode for the power sensor connected to the 
/*            
/*            SENSOR connector.
/*           
/*            SENS1:FILT:LENG:AUTO?
/*            queries the automatically set filter length.
/*           
/*            Response: 1024
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerFilterLengthAuto(
    ViSession   instrSession,
    ViInt32 sense,
    ViInt32*    filterLengthAuto
)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "SENS%ld:POW:FILT:LENG:AUTO?", sense);

    return GETPARAMINT32 (instrSession, 
                             buffer,
                             filterLengthAuto);
}

/*===========================================================================*/
/* Function: Power Filter Search Once
/* Purpose:  This function the search for the optimum filter length for the 
/*           current measurement conditions. The found filter length can be 
/*           retrieved with command :SENSe:POWer:FILTer:LENGth:USER?. This 
/*           command is only available for user filter mode 
/*           (:SENSe:POWer:FILTer:TYPE USER).
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_PowerFilterSearchOnce(
    ViSession   instrSession,
    ViInt32 sense
)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "SENS%ld:POW:FILT:SONC", sense);

    return rssmf_sendCmd (instrSession, buffer);
}

/*===========================================================================
 * Function: Set Power Sensor Gate State
 * Purpose:  The function activates gate settings for the selected trace. The
 *           measurement is started with command SENS:POW:SWE:INIT (function
 *           rssmf_StartPowerSensorMeasurement). Both gates are active at one
 *           time.
 *           
 *           Required Option(s):
 *           R&S SMF-K28
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPowerSensorGateState (ViSession instrSession,
                                                 ViBoolean state)
{
    INIT;
    
    CHECKOPT (K28);
    
    return SETPARAMBOOL (instrSession,
                               "CALC:POW:SWE:TIME:GATE:STAT",
                               state);
}

/*===========================================================================
 * Function: Get Power Sensor Gate State
 * Purpose:  The function returns the state of the gate settings for the
 *           selected trace.
 *           
 *           Required Option(s):
 *           R&S SMF-K28
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerSensorGateState (ViSession instrSession,
                                                 ViBoolean *state)
{
    INIT;
    
    CHECKOPT (K28);
    
    return GETPARAMBOOL (instrSession,
                               "CALC:POW:SWE:TIME:GATE:STAT?",
                               state);
}

/*===========================================================================
 * Function: Set Power Sensor Gate Start
 * Purpose:  The function sets the start time of the selected gate.
 *           
 *           Required Option(s):
 *           R&S SMF-K28
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPowerSensorGateStart (ViSession instrSession,
                                                 ViInt32 gate, ViReal64 start)
{
    ViChar buffer[BUFFER_SIZE];
    
    INIT;
    
    CHECKOPT (K28);
    
    CHECKVIINT32 (instrSession, gate, 1, 2);
    
    sprintf (buffer, "CALC:POW:SWE:TIME:GATE%ld:STAR", gate);
    
    return SETPARAMREAL64 (instrSession,
                              buffer,
                              start,
                              0.0, 0.0);
}

/*===========================================================================
 * Function: Get Power Sensor Gate Start
 * Purpose:  The function returns the start time of the selected gate.
 *           
 *           Required Option(s):
 *           R&S SMF-K28
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerSensorGateStart (ViSession instrSession,
                                                 ViInt32 gate, ViReal64 *start)
{
    ViChar buffer[BUFFER_SIZE];
    
    INIT;
    
    CHECKOPT (K28);
    
    CHECKVIINT32 (instrSession, gate, 1, 2);
    
    sprintf (buffer, "CALC:POW:SWE:TIME:GATE%ld:STAR?", gate);
    
    return GETPARAMREAL64 (instrSession,
                              buffer,
                              start);
}

/*===========================================================================
 * Function: Set Power Sensor Gate Stop
 * Purpose:  The function sets the stop time of the selected gate.
 *           
 *           Required Option(s):
 *           R&S SMF-K28
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPowerSensorGateStop (ViSession instrSession,
                                                ViInt32 gate, ViReal64 stop)
{
    ViChar buffer[BUFFER_SIZE];
    
    INIT;
    
    CHECKOPT (K28);
    
    CHECKVIINT32 (instrSession, gate, 1, 2);
    
    sprintf (buffer, "CALC:POW:SWE:TIME:GATE%ld:STOP", gate);
    
    return SETPARAMREAL64 (instrSession,
                              buffer,
                              stop,
                              0.0, 0.0);
}

/*===========================================================================
 * Function: Get Power Sensor Gate Stop
 * Purpose:  The function retruns the stop time of the selected gate.
 *           
 *           Required Option(s):
 *           R&S SMF-K28
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerSensorGateStop (ViSession instrSession,
                                                ViInt32 gate, ViReal64 *stop)
{
    ViChar buffer[BUFFER_SIZE];
    
    INIT;
    
    CHECKOPT (K28);
    
    CHECKVIINT32 (instrSession, gate, 1, 2);
    
    sprintf (buffer, "CALC:POW:SWE:TIME:GATE%ld:STOP?", gate);
    
    return GETPARAMREAL64 (instrSession,
                              buffer,
                              stop);
}

/*===========================================================================
 * Function: Set Power Sensor Gate Trace
 * Purpose:  The function selects the trace for time gated measurement. Both
 *           gates are assigned to the same trace.
 *           
 *           Required Option(s):
 *           R&S SMF-K28
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPowerSensorGateTrace (ViSession instrSession,
                                                 ViInt32 trace)
{
    INIT;
    
    CHECKOPT (K28);
    
    return SETPARAMENUM (instrSession,
                          "CALC:POW:SWE:TIME:GATE:FEED",
                          trace,
                          powerGateTraceArr);
}

/*===========================================================================
 * Function: Get Power Sensor Gate Trace
 * Purpose:  The function returns the trace for time gated measurement. 
 *           
 *           Required Option(s):
 *           R&S SMF-K28
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerSensorGateTrace (ViSession instrSession,
                                                 ViInt32 *trace)
{
    INIT;
    
    CHECKOPT (K28);
    
    return GETPARAMENUM (instrSession,
                          "CALC:POW:SWE:TIME:GATE:FEED?",
                          trace,
                          powerGateTraceArr);
}

/*===========================================================================
 * Function: Get Power Sensor Gate Average Power
 * Purpose:  The function queries the average power value of the time gated
 *           measurement.
 *           
 *           Required Option(s):
 *           R&S SMF-K28
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerSensorGateAveragePower (ViSession instrSession,
                                                        ViInt32 gate,
                                                        ViReal64 *averagePower)
{
    ViChar buffer[BUFFER_SIZE];
    
    INIT;
    
    CHECKOPT (K28);
    
    CHECKVIINT32 (instrSession, gate, 1, 2);
    
    sprintf (buffer, "CALC:POW:SWE:TIME:GATE%ld:AVER?", gate);
    
    return GETPARAMREAL64 (instrSession,
                              buffer,
                              averagePower);
}

/*===========================================================================
 * Function: Get Power Sensor Gate Peak Power
 * Purpose:  The function queries the peak power value of the time gated
 *           measurement.
 *           
 *           Required Option(s):
 *           R&S SMF-K28
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerSensorGatePeakPower (ViSession instrSession,
                                                     ViInt32 gate,
                                                     ViReal64 *peakPower)
{
    ViChar buffer[BUFFER_SIZE];
    
    INIT;
    
    CHECKOPT (K28);
    
    CHECKVIINT32 (instrSession, gate, 1, 2);
    
    sprintf (buffer, "CALC:POW:SWE:TIME:GATE%ld:MAX?", gate);
    
    return GETPARAMREAL64 (instrSession,
                              buffer,
                              peakPower);
}

/*===========================================================================*/
/* Function: Power Sweep Initiate
/* Purpose:  This function starts the response measurement with NRP power 
/*           sensor 
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_PowerSweepInitiate(
    ViSession   instrSession,
    ViInt32 sense,
    ViInt32 timeout
)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "SENS%ld:POW:SWE:INIT;*OPC?", sense);
    
    CHECKERR (rssmf_waitOPC (instrSession, buffer, buffer, timeout));
    
    return rssmf_status; //rssmf_sendCmd (instrSession, buffer);
}

/*===========================================================================*/
/* Function: Power Sweep Abort
/* Purpose:  This function aborts the response measurement with NRP power 
/*           sensors.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_PowerSweepAbort(
    ViSession   instrSession,
    ViInt32 sense
)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "SENS%ld:POW:SWE:ABOR", sense);

    return rssmf_sendCmd (instrSession, buffer);
}

/*===========================================================================*/
/* Function: Configure Power Sweep Frequency Separate Frequency Range
/* Purpose:  The function configures using of Separate Frequency.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_confPowerSweepFrequencySeparateFrequencyRange (ViSession instrSession,
                                                                       ViInt32 sense,
                                                                       ViBoolean state,
                                                                       ViReal64 separateFrequencyStart,
                                                                       ViReal64 separateFrequencyStop)
{
    ViStatus rssmf_status;
    
    CHECKERR (rssmf_SetPowerSweepFrequencySeparateFrequencyRange (instrSession, sense, state));
    
    CHECKERR (rssmf_SetPowerSweepFrequencySeparateFrequencyStart (instrSession, sense, separateFrequencyStart));   
    CHECKERR (rssmf_SetPowerSweepFrequencySeparateFrequencyStop (instrSession, sense, separateFrequencyStop));  
    return rssmf_status;    
}

/*===========================================================================*/
/* Function: Set Power Sweep Frequency Start
/* Purpose:  This function enters the start frequency for the frequency 
/*           response measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPowerSweepFrequencyStart(
    ViSession   instrSession,
    ViInt32 sense,
    ViReal64    frequencyStart
)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "SENS%ld:POW:SWE:FREQ:STAR", sense);

    return SETPARAMREAL64 (instrSession, 
                              buffer,
                              frequencyStart,
                              1.0e9,22.0e9);
}

/*===========================================================================*/
/* Function: Get Power Sweep Frequency Start
/* Purpose:  This function returns the start frequency for the frequency 
/*           response measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerSweepFrequencyStart(
    ViSession   instrSession,
    ViInt32 sense,
    ViReal64*   frequencyStart
)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "SENS%ld:POW:SWE:FREQ:STAR?", sense);

    return GETPARAMREAL64 (instrSession, 
                              buffer,
                              frequencyStart);
}

/*===========================================================================*/
/* Function: Set Power Sweep Frequency Stop
/* Purpose:  This function enters the stop frequency for the frequency 
/*           response measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPowerSweepFrequencyStop(
    ViSession   instrSession,
    ViInt32 sense,
    ViReal64    frequencyStop
)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "SENS%ld:POW:SWE:FREQ:STOP", sense);

    return SETPARAMREAL64 (instrSession, 
                              buffer,
                              frequencyStop,
                              1.0e9,22.0e9);
}

/*===========================================================================*/
/* Function: Get Power Sweep Frequency Stop
/* Purpose:  This function returns the stop frequency for the frequency 
/*           response measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerSweepFrequencyStop(
    ViSession   instrSession,
    ViInt32 sense,
    ViReal64*   frequencyStop
)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "SENS%ld:POW:SWE:FREQ:STOP?", sense);

    return GETPARAMREAL64 (instrSession, 
                              buffer,
                              frequencyStop);
}

/*===========================================================================*/
/* Function: Set Power Sweep Frequency Slope
/* Purpose:  This function sets the polarity of the active slope for the
/*           trigger signals.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPowerSweepFrequencySlope (ViSession instrSession,
                                                     ViInt32 sense,
                                                     ViInt32 triggerSlope)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "SENS%ld:POW:SWE:TIME:SENS:TRIG:SLOP", sense);

    return SETPARAMENUM (instrSession, 
                          buffer,
                          triggerSlope,
                          slopeArr);
}

/*===========================================================================*/
/* Function: Get Power Sweep Frequency Slope
/* Purpose:  This function returns the polarity of the active slope for the
/*           trigger signals.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerSweepFrequencySlope (ViSession instrSession,
                                                     ViInt32 sense,
                                                     ViInt32 *triggerSlope)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "SENS%ld:POW:SWE:TIME:SENS:TRIG:SLOP?", sense);

    return GETPARAMENUM (instrSession, 
                          buffer,
                          triggerSlope,
                          slopeArr);
}

/*===========================================================================*/
/* Function: Set Power Sweep Frequency Timing
/* Purpose:  This function selects the timing mode of the measurement. 
/*           Selection FAST leads to a fast measurement with a short 
/*           integration times for each measurement step, NORMal leads to a 
/*           longer but more precise measurement due to a higher integration 
/*           time for each step.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPowerSweepFrequencyTiming(
    ViSession   instrSession,
    ViInt32 sense,
    ViInt32 frequencyTiming
)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "SENS%ld:POW:SWE:FREQ:TIM:MODE", sense);

    return SETPARAMENUM (instrSession, 
                          buffer,
                          frequencyTiming,
                          powerFrequencyTimingArr);
}

/*===========================================================================*/
/* Function: Get Power Sweep Frequency Timing
/* Purpose:  This function returns the timing mode of the measurement. 
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerSweepFrequencyTiming(
    ViSession   instrSession,
    ViInt32 sense,
    ViInt32*    frequencyTiming
)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "SENS%ld:POW:SWE:FREQ:TIM:MODE?", sense);

    return GETPARAMENUM (instrSession, 
                          buffer,
                          frequencyTiming,
                          powerFrequencyTimingArr);
}

/*===========================================================================*/
/* Function: Set Power Sweep Frequency Spacing
/* Purpose:  This function selects the spacing for the frequency response 
/*           measurement. 
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPowerSweepFrequencySpacing(
    ViSession   instrSession,
    ViInt32 sense,
    ViInt32 frequencySpacing
)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "SENS%ld:POW:SWE:FREQ:SPAC:MODE", sense);

    return SETPARAMENUM (instrSession, 
                          buffer,
                          frequencySpacing,
                          powerFrequencySpacingArr);
}

/*===========================================================================*/
/* Function: Get Power Sweep Frequency Spacing
/* Purpose:  This function returns the spacing for the frequency response 
/*           measurement. 
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerSweepFrequencySpacing(
    ViSession   instrSession,
    ViInt32 sense,
    ViInt32*    frequencySpacing
)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "SENS%ld:POW:SWE:FREQ:SPAC:MODE?", sense);

    return GETPARAMENUM (instrSession, 
                          buffer,
                          frequencySpacing,
                          powerFrequencySpacingArr);
}

/*===========================================================================*/
/* Function: Set Power Sweep Frequency Steps
/* Purpose:  This function enters the number of measurement steps for the 
/*           frequency response measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPowerSweepFrequencySteps(
    ViSession   instrSession,
    ViInt32 sense,
    ViInt32 frequencySteps
)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "SENS%ld:POW:SWE:FREQ:STEP", sense);

    return SETPARAMINT32 (instrSession, 
                             buffer,
                             frequencySteps,
                             10,1000);
}

/*===========================================================================*/
/* Function: Get Power Sweep Frequency Steps
/* Purpose:  This function returns the number of measurement steps for the 
/*           frequency response measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerSweepFrequencySteps(
    ViSession   instrSession,
    ViInt32 sense,
    ViInt32*    frequencySteps
)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "SENS%ld:POW:SWE:FREQ:STEP?", sense);

    return GETPARAMINT32 (instrSession, 
                             buffer,
                             frequencySteps);
}

/*===========================================================================*/
/* Function: Set Power Sweep Frequency Y Scale Minimum
/* Purpose:  This function sets the minimum value for the y axis of the 
/*           measurement diagram.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPowerSweepFrequencyYScaleMinimum(
    ViSession   instrSession,
    ViInt32 sense,
    ViReal64    yScaleMinimum
)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    CHECKVIREAL64 (instrSession, yScaleMinimum, -200.0,100.0);
    
    sprintf (buffer, "SENS%ld:POW:SWE:FREQ:YSC:MIN %f", sense, yScaleMinimum);

    return rssmf_sendCmd (instrSession, buffer);
}

/*===========================================================================*/
/* Function: Get Power Sweep Frequency Y Scale Minimum
/* Purpose:  This function returns the minimum value for the y axis of the 
/*           measurement diagram.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerSweepFrequencyYScaleMinimum(
    ViSession   instrSession,
    ViInt32 sense,
    ViReal64*   yScaleMinimum
)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "SENS%ld:POW:SWE:FREQ:YSC:MIN?", sense);

    return GETPARAMREAL64 (instrSession, 
                              buffer,
                              yScaleMinimum);
}

/*===========================================================================*/
/* Function: Set Power Sweep Frequency Y Scale Maximum
/* Purpose:  This function sets the maximum value for the y axis of the 
/*           measurement diagram.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPowerSweepFrequencyYScaleMaximum(
    ViSession   instrSession,
    ViInt32 sense,
    ViReal64    yScaleMaximum
)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    CHECKVIREAL64 (instrSession, yScaleMaximum, -200.0, 100.0);
    
    sprintf (buffer, "SENS%ld:POW:SWE:FREQ:YSC:MAX %f", sense, yScaleMaximum);

    return rssmf_sendCmd (instrSession, buffer);
}

/*===========================================================================*/
/* Function: Get Power Sweep Frequency Y Scale Maximum
/* Purpose:  This function returns the maximum value for the y axis of the 
/*           measurement diagram.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerSweepFrequencyYScaleMaximum(
    ViSession   instrSession,
    ViInt32 sense,
    ViReal64*   yScaleMaximum
)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "SENS%ld:POW:SWE:FREQ:YSC:MAX?", sense);

    return GETPARAMREAL64 (instrSession, 
                              buffer,
                              yScaleMaximum);
}

/*===========================================================================*/
/* Function: Set Power Sweep Frequency Execution
/* Purpose:  This function selects single or continuous mode in power
/*           analysis.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPowerSweepFrequencyExecution (ViSession instrSession,
                                                         ViInt32 execution)
{
  return SETPARAMENUM (instrSession,
                          "SENS:SWE:FREQ:RMOD",
                          execution,
                          runModeArr);
}

/*===========================================================================*/
/* Function: Get Power Sweep Frequency Execution
/* Purpose:  This function returns single or continuous mode in power
/*           analysis.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerSweepFrequencyExecution (ViSession instrSession,
                                                         ViInt32 *execution)
{
  return GETPARAMENUM (instrSession,
                          "SENS:SWE:FREQ:RMOD?",
                          execution,
                          runModeArr);
}

/*===========================================================================*/
/* Function: Set Power Sweep Frequency Y Auto Scale
/* Purpose:  This function activates/deactivates autoscaling of the Y axis of
/*       the diagram.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPowerSweepFrequencyYAutoScale (ViSession instrSession,
                                                          ViInt32 autoScale)
{
  return SETPARAMENUM (instrSession,
                          "SENS:POW:SWE:FREQ:YSC:AUTO",
                          autoScale,
                          powerFrequencyYScaleAutoArr);
}

/*===========================================================================*/
/* Function: Get Power Sweep Frequency Y Auto Scale
/* Purpose:  This function returns the state of the autoscaling of the Y axis of
/*       the diagram.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerSweepFrequencyYAutoScale (ViSession instrSession,
                                                          ViInt32 *autoScale)
{
  return GETPARAMENUM (instrSession,
                          "SENS:POW:SWE:FREQ:YSC:AUTO?",
                          autoScale,
                          powerFrequencyYScaleAutoArr);
}

/*===========================================================================*/
/* Function: Reset Power Sweep Frequency Y Scale
/* Purpose:  This function resets the Y scale to suitable values after the
/*       use of auto scaling in the expanding mode. For this mode, the
/*       scale might get expanded because of temporarily high power
/*       values. The reset function resets the diagram in such a way that
/*       it matches smaller power values again.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_ResetPowerSweepFrequencyYScale (ViSession instrSession)
{
  return rssmf_sendCmd (instrSession, "SENS:POW:SWE:FREQ:YSC:AUTO:RES");   
}

/*===========================================================================*/
/* Function: Set Power Sweep Frequency Separate Frequency Range
/* Purpose:  The function activates the use of a frequency range for the
/*       power measurement that is different to the set signal generator
/*       frequency range. The separate frequency range is entered  with
/*       commands SENS:SWE:FREQ:SENS:STAR  and SENS:SWE:FREQ:SENS:STop.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPowerSweepFrequencySeparateFrequencyRange (ViSession instrSession,
                                                                      ViInt32 sense,
                                                                      ViBoolean state)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "SENS%ld:POW:SWE:FREQ:SENS:SRAN:STAT", sense);
  
  return SETPARAMBOOL (instrSession, 
                               buffer,
                               state);    
}

/*===========================================================================*/
/* Function: Get Power Sweep Frequency Separate Frequency Range
/* Purpose:  The function displays the use of a frequency range for the
/*       power measurement that is different to the set signal generator
/*       frequency range. The separate frequency range is entered  with
/*       commands SENS:SWE:FREQ:SENS:STAR  and SENS:SWE:FREQ:SENS:STop.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerSweepFrequencySeparateFrequencyRange (ViSession instrSession,
                                                                      ViInt32 sense,
                                                                      ViBoolean *state)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "SENS%ld:POW:SWE:FREQ:SENS:SRAN:STAT?", sense);
  
  return GETPARAMBOOL (instrSession, 
                               buffer,
                               state);    
}

/*===========================================================================*/
/* Function: Set Power Sweep Frequency Separate Frequency Start
/* Purpose:  This function enters the start frequency for the frequency power
/*       analysis with separate frequencies
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPowerSweepFrequencySeparateFrequencyStart (ViSession instrSession,
                                                                      ViInt32 sense,
                                                                      ViReal64 separateFrequencyStart)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "SENS%ld:POW:SWE:FREQ:SENS:SRAN:STAR", sense);
  
  return SETPARAMREAL64 (instrSession, 
                               buffer,
                               separateFrequencyStart,
                 0,
                 22.0e12);
}

/*===========================================================================*/
/* Function: Get Power Sweep Frequency Separate Frequency Start
/* Purpose:  This function displays the start frequency for the frequency power
/*       analysis with separate frequencies
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerSweepFrequencySeparateFrequencyStart (ViSession instrSession,
                                                                      ViInt32 sense,
                                                                      ViReal64 *separateFrequencyStart)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "SENS%ld:POW:SWE:FREQ:SENS:SRAN:STAR?", sense);
  
  return GETPARAMREAL64 (instrSession, 
                               buffer,
                               separateFrequencyStart);
}

/*===========================================================================*/
/* Function: Set Power Sweep Frequency Separate Frequency Stop
/* Purpose:  This function enters the stop frequency for the frequency power
/*       analysis with separate frequencies.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPowerSweepFrequencySeparateFrequencyStop (ViSession instrSession,
                                                                     ViInt32 sense,
                                                                     ViReal64 separateFrequencyStop)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "SENS%ld:POW:SWE:FREQ:SENS:SRAN:STOP", sense);
  
  return SETPARAMREAL64 (instrSession, 
                               buffer,
                               separateFrequencyStop,
                 0,
                 22.0e12);    
}

/*===========================================================================*/
/* Function: Get Power Sweep Frequency Separate Frequency Stop
/* Purpose:  This function displays the stop frequency for the frequency power
/*       analysis with separate frequencies.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerSweepFrequencySeparateFrequencyStop (ViSession instrSession,
                                                                     ViInt32 sense,
                                                                     ViReal64 *separateFrequencyStop)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "SENS%ld:POW:SWE:FREQ:SENS:SRAN:STOP?", sense);
  
  return GETPARAMREAL64 (instrSession, 
                               buffer,
                               separateFrequencyStop);    
}

/*****************************************************************************
 * Function: Set Power Sweep Frequency Reference X Values
 * Purpose:  This function sets the x values of the two reference points, i.e. 
 *           "Frequency X (Point A)" and "Frequency X (Point B)" in "Frequency"
 *           measurement.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetPowerSweepFrequencyReferenceXValues (ViSession instrSession,
                                                                ViReal64 frequencyXPointA,
                                                                ViReal64 frequencyXPointB)
{
    ViChar      buffer[BUFFER_SIZE] = "";
    
    sprintf (buffer, "SENS:POW:SWE:FREQ:REF:DATA:XVAL %.12lG,%.12lG", frequencyXPointA, frequencyXPointB);

    return rssmf_sendCmd (instrSession, buffer);
}

/*****************************************************************************
 * Function: Get Power Sweep Frequency Reference X Values
 * Purpose:  This function returns the x values of the two reference points, i.e. 
 *           "Frequency X (Point A)" and "Frequency X (Point B)" in "Frequency"
 *           measurement.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetPowerSweepFrequencyReferenceXValues (ViSession instrSession,
                                                                ViReal64 *frequencyXPointA,
                                                                ViReal64 *frequencyXPointB)
{
    ViStatus    rssmf_status = VI_SUCCESS;
    ViReal64    tempArr[2] = {0.0,0.0};
    
    rssmf_status =  GETPARAMREAL64ARRAY (instrSession,
                                            "SENS:POW:SWE:FREQ:REF:DATA:XVAL?",
                                            tempArr,
                                            2);
    
    *frequencyXPointA = tempArr[0];
    *frequencyXPointB = tempArr[1];
    
    return rssmf_status;
}

/*****************************************************************************
 * Function: Set Power Sweep Frequency Reference Y Values
 * Purpose:  This function sets the y values of the two reference points, i.e. 
 *           "Power X (Point A)" and "Power X (Point B)" in "Frequency"
 *           measurement.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetPowerSweepFrequencyReferenceYValues (ViSession instrSession,
                                                                ViReal64 powerYPointA,
                                                                ViReal64 powerYPointB)
{
    ViChar      buffer[BUFFER_SIZE] = "";
    
    sprintf (buffer, "SENS:POW:SWE:FREQ:REF:DATA:YVAL %.12lG,%.12lG", powerYPointA, powerYPointB);

    return rssmf_sendCmd (instrSession, buffer);
}

/*****************************************************************************
 * Function: Get Power Sweep Frequency Reference Y Values
 * Purpose:  This function returns the y values of the two reference points, i.e. 
 *           "Power X (Point A)" and "Power X (Point B)" in "Frequency"
 *           measurement.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetPowerSweepFrequencyReferenceYValues (ViSession instrSession,
                                                                ViReal64 *powerYPointA,
                                                                ViReal64 *powerYPointB)
{
    ViStatus    rssmf_status = VI_SUCCESS;
    ViReal64    tempArr[2] = {0.0,0.0};
    
    rssmf_status =  GETPARAMREAL64ARRAY (instrSession,
                                            "SENS:POW:SWE:FREQ:REF:DATA:YVAL?",
                                            tempArr,
                                            2);
    
    *powerYPointA = tempArr[0];
    *powerYPointB = tempArr[1];
    
    return rssmf_status;
}

/*****************************************************************************
 * Function: Generate Power Sweep Frequency Reference Curve
 * Purpose:  This function generates a reference curve for "Frequency"
 *           measurement. 
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GeneratePowerSweepFrequencyReferenceCurve (ViSession instrSession)
{
    INIT;
    
    return rssmf_sendCmd (instrSession, "SENS:POW:SWE:FREQ:REF:DATA:COPY");
}

/*===========================================================================*/
/* Function: Configure Power vs Power Sweep Separate Frequency Range
/* Purpose:  The function configures using of Separate Frequency for power
/*       vs. power measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_confPowerSweepPowerSeparateFrequencyRange (ViSession instrSession,
                                                                   ViInt32 sense,
                                                                   ViBoolean state,
                                                                   ViReal64 separateFrequency)
{
    ViStatus rssmf_status;
    
    CHECKERR (rssmf_SetPowerSweepPowerSeparateFrequencyState (instrSession, sense, state));
    
    CHECKERR (rssmf_SetPowerSweepPowerSeparateFrequency (instrSession, sense, separateFrequency));   
    return rssmf_status;
}

/*===========================================================================*/
/* Function: Set Power Sweep Power Start
/* Purpose:  This function sets the start level for the power versus power 
/*           measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPowerSweepPowerStart(
    ViSession   instrSession,
    ViInt32 sense,
    ViReal64    powerStart
)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    CHECKVIREAL64 (instrSession, powerStart, -140.0, 30.0);
    
    sprintf (buffer, "SENS%ld:POW:SWE:POW:STAR %f", sense, powerStart);

    return rssmf_sendCmd (instrSession, buffer);
}

/*===========================================================================*/
/* Function: Get Power Sweep Power Start
/* Purpose:  This function returns the start level for the power versus 
/*           power measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerSweepPowerStart(
    ViSession   instrSession,
    ViInt32 sense,
    ViReal64*   powerStart
)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "SENS%ld:POW:SWE:POW:STAR?", sense);

    return GETPARAMREAL64 (instrSession, 
                              buffer,
                              powerStart);
}

/*===========================================================================*/
/* Function: Set Power Sweep Power Stop
/* Purpose:  This function sets the stop level for the power versus power 
/*           measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPowerSweepPowerStop(
    ViSession   instrSession,
    ViInt32 sense,
    ViReal64    powerStop
)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    CHECKVIREAL64 (instrSession, powerStop, -140.0, 30.0);
    
    sprintf (buffer, "SENS%ld:POW:SWE:POW:STOP %f", sense, powerStop);

    return rssmf_sendCmd (instrSession, buffer);
}

/*===========================================================================*/
/* Function: Get Power Sweep Power Stop
/* Purpose:  This function returns the stop level for the power versus power 
/*           measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerSweepPowerStop(
    ViSession   instrSession,
    ViInt32 sense,
    ViReal64*   powerStop
)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "SENS%ld:POW:SWE:POW:STOP?", sense);

    return GETPARAMREAL64 (instrSession, 
                              buffer,
                              powerStop);
}

/*===========================================================================*/
/* Function: Set Power Sweep Power Spacing
/* Purpose:  This function selects the sweep spacing for the power versus 
/*           power measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPowerSweepPowerSpacing(
    ViSession   instrSession,
    ViInt32 sense,
    ViInt32 powerSpacing
)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "SENS%ld:POW:SWE:POW:SPAC:MODE", sense);

    return SETPARAMENUM (instrSession, 
                          buffer,
                          powerSpacing,
                          powerFrequencySpacingArr);
}

/*===========================================================================*/
/* Function: Get Power Sweep Power Spacing
/* Purpose:  This function returns the sweep spacing for the power versus 
/*           power measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerSweepPowerSpacing(
    ViSession   instrSession,
    ViInt32 sense,
    ViInt32*    powerSpacing
)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "SENS%ld:POW:SWE:POW:SPAC:MODE?", sense);

    return GETPARAMENUM (instrSession, 
                          buffer,
                          powerSpacing,
                          powerFrequencySpacingArr);
}

/*===========================================================================*/
/* Function: Set Power Sweep Power Timing
/* Purpose:  This function selects the timing mode of the measurement. 
/*           Selection FAST leads to a fast measurement with a short 
/*           integration times for each measurement step, NORMal leads to a 
/*           longer but more precise measurement due to a higher integration 
/*           time for each step.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPowerSweepPowerTiming(
    ViSession   instrSession,
    ViInt32 sense,
    ViInt32 powerTiming
)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "SENS%ld:POW:SWE:POW:TIM:MODE", sense);

    return SETPARAMENUM (instrSession, 
                          buffer,
                          powerTiming,
                          powerTimingArr);
}

/*===========================================================================*/
/* Function: Get Power Sweep Power Timing
/* Purpose:  This function returns the timing mode of the measurement. 
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerSweepPowerTiming(
    ViSession   instrSession,
    ViInt32 sense,
    ViInt32*    powerTiming
)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "SENS%ld:POW:SWE:POW:TIM:MODE?", sense);

    return GETPARAMENUM (instrSession, 
                          buffer,
                          powerTiming,
                          powerTimingArr);
}

/*===========================================================================*/
/* Function: Set Power Sweep Power Steps
/* Purpose:  This function enters the number of measurement steps for the 
/*           power versus power measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPowerSweepPowerSteps(
    ViSession   instrSession,
    ViInt32 sense,
    ViInt32 powerSteps
)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "SENS%ld:POW:SWE:POW:STEP", sense);

    return SETPARAMINT32 (instrSession, 
                             buffer,
                             powerSteps,
                             10,1000);
}

/*===========================================================================*/
/* Function: Get Power Sweep Power Steps
/* Purpose:  This function returns the number of measurement steps for the 
/*           power versus power measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerSweepPowerSteps(
    ViSession   instrSession,
    ViInt32 sense,
    ViInt32*    powerSteps
)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "SENS%ld:POW:SWE:POW:STEP?", sense);

    return GETPARAMINT32 (instrSession, 
                             buffer,
                             powerSteps);
}

/*===========================================================================*/
/* Function: Set Power Sweep Power Y Scale Minimum
/* Purpose:  This function sets the minimum value for the y axis of the 
/*           measurement diagram.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPowerSweepPowerYScaleMinimum(
    ViSession   instrSession,
    ViInt32 sense,
    ViReal64    yScaleMinimum
)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    CHECKVIREAL64 (instrSession, yScaleMinimum, -200.0, 100.0);
    
    sprintf (buffer, "SENS%ld:POW:SWE:POW:YSC:MIN %f", sense, yScaleMinimum);

    return rssmf_sendCmd (instrSession, buffer);
}

/*===========================================================================*/
/* Function: Get Power Sweep Power Y Scale Minimum
/* Purpose:  This function returns the minimum value for the y axis of the 
/*           measurement diagram.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerSweepPowerYScaleMinimum(
    ViSession   instrSession,
    ViInt32 sense,
    ViReal64*   yScaleMinimum
)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "SENS%ld:POW:SWE:POW:YSC:MIN?", sense);

    return GETPARAMREAL64 (instrSession, 
                              buffer,
                              yScaleMinimum);
}

/*===========================================================================*/
/* Function: Set Power Sweep Power Y Scale Maximum
/* Purpose:  This function sets the maximum value for the y axis of the 
/*           measurement diagram.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPowerSweepPowerYScaleMaximum(
    ViSession   instrSession,
    ViInt32 sense,
    ViReal64    yScaleMaximum
)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    CHECKVIREAL64 (instrSession, yScaleMaximum, -200.0, 100.0);
    
    sprintf (buffer, "SENS%ld:POW:SWE:POW:YSC:MAX %f", sense, yScaleMaximum);

    return rssmf_sendCmd (instrSession, buffer);
}

/*===========================================================================*/
/* Function: Get Power Sweep Power Y Scale Maximum
/* Purpose:  This function returns the maximum value for the y axis of the 
/*           measurement diagram.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerSweepPowerYScaleMaximum(
    ViSession   instrSession,
    ViInt32 sense,
    ViReal64*   yScaleMaximum
)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "SENS%ld:POW:SWE:POW:YSC:MAX?", sense);

    return GETPARAMREAL64 (instrSession, 
                              buffer,
                              yScaleMaximum);
}

/*===========================================================================*/
/* Function: Set Power Sweep Time Y Scale Minimum
/* Purpose:  This function sets the minimum value for the y axis of the 
/*           measurement diagram.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPowerSweepTimeYScaleMinimum (ViSession instrSession,
                                                        ViInt32 sense,
                                                        ViReal64 yScaleMinimum)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "SENS%ld:POW:SWE:TIME:YSC:MIN", sense);

    return SETPARAMREAL64 (instrSession, 
                              buffer,
                yScaleMinimum,
                -200.0, 100.0);
}

/*===========================================================================*/
/* Function: Get Power Sweep Time Y Scale Minimum
/* Purpose:  This function returns the minimum value for the y axis of the 
/*           measurement diagram.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerSweepTimeYScaleMinimum (ViSession instrSession,
                                                        ViInt32 sense,
                                                        ViReal64 *yScaleMinimum)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "SENS%ld:POW:SWE:TIME:YSC:MIN?", sense);

    return GETPARAMREAL64 (instrSession, 
                              buffer,
                yScaleMinimum);
}

/*===========================================================================*/
/* Function: Set Power Sweep Time Y Scale Maximum
/* Purpose:  This function sets the maximum value for the y axis of the 
/*           measurement diagram.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPowerSweepTimeYScaleMaximum (ViSession instrSession,
                                                        ViInt32 sense,
                                                        ViReal64 yScaleMaximum)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "SENS%ld:POW:SWE:TIME:YSC:MAX", sense);

    return SETPARAMREAL64 (instrSession, 
                              buffer,
                yScaleMaximum,
                -200.0, 100.0);
}

/*===========================================================================*/
/* Function: Get Power Sweep Time Y Scale Maximum
/* Purpose:  This function returns the maximum value for the y axis of the 
/*           measurement diagram.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerSweepTimeYScaleMaximum (ViSession instrSession,
                                                        ViInt32 sense,
                                                        ViReal64 *yScaleMaximum)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "SENS%ld:POW:SWE:TIME:YSC:MAX?", sense);

    return GETPARAMREAL64 (instrSession, 
                              buffer,
                yScaleMaximum);
}

/*===========================================================================*/
/* Function: Set Power Sweep Time Execution
/* Purpose:  This function selects single or continuous mode in power
/*           analysis.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPowerSweepTimeExecution (ViSession instrSession,
                                                    ViInt32 execution)
{
  return SETPARAMENUM (instrSession,
                          "SENS:SWE:TIME:RMOD",
                          execution,
                          runModeArr);
}

/*===========================================================================*/
/* Function: Get Power Sweep Time Execution
/* Purpose:  This function returns single or continuous mode in power
/*           analysis.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerSweepTimeExecution (ViSession instrSession,
                                                    ViInt32 *execution)
{
  return GETPARAMENUM (instrSession,
                          "SENS:SWE:TIME:RMOD?",
                          execution,
                          runModeArr);
}

/*===========================================================================*/
/* Function: Set Power Sweep Time Y Auto Scale
/* Purpose:  This function activates/deactivates autoscaling of the Y axis of
/*       the diagram.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPowerSweepTimeYAutoScale (ViSession instrSession,
                                                     ViInt32 autoScale)
{
  return SETPARAMENUM (instrSession,
                          "SENS:POW:SWE:TIME:YSC:AUTO",
                          autoScale,
                          powerFrequencyYScaleAutoArr);
}

/*===========================================================================*/
/* Function: Get Power Sweep Time Y Auto Scale
/* Purpose:  This function returns autoscaling of the Y axis of
/*       the diagram.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerSweepTimeYAutoScale (ViSession instrSession,
                                                     ViInt32 *autoScale)
{
  return GETPARAMENUM (instrSession,
                          "SENS:POW:SWE:TIME:YSC:AUTO?",
                          autoScale,
                          powerFrequencyYScaleAutoArr);
}

/*===========================================================================*/
/* Function: Reset Power Sweep Time Y Scale
/* Purpose:  This function resets the Y scale to suitable values after the
/*       use of auto scaling in the expanding mode. For this mode, the
/*       scale might get expanded because of temporarily high power
/*       values. The reset function resets the diagram in such a way that
/*       it matches smaller power values again.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_ResetPowerSweepTimeYScale (ViSession instrSession)
{
  return rssmf_sendCmd (instrSession, "SENS:POW:SWE:TIME:YSC:AUTO:RES");   
}

/*===========================================================================*/
/* Function: Set Power vs Time Sweep Separate Frequency State
/* Purpose:  The function activates/deactivates the use of a different
/*       frequency for the power measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPowerSweepTimeSeparateFrequencyState (ViSession instrSession,
                                                                 ViInt32 sense,
                                                                 ViBoolean state)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "SENS%ld:POW:SWE:TIME:SENS:SFR:STAT", sense);
  
  return SETPARAMBOOL (instrSession, 
                               buffer,
                               state); 
}

/*===========================================================================*/
/* Function: Get Power vs Time Sweep Separate Frequency State
/* Purpose:  The function returns the usage of a different
/*       frequency for the power measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerSweepTimeSeparateFrequencyState (ViSession instrSession,
                                                                 ViInt32 sense,
                                                                 ViBoolean *state)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "SENS%ld:POW:SWE:TIME:SENS:SFR:STAT?", sense);
  
  return GETPARAMBOOL (instrSession, 
                               buffer,
                               state); 
}

/*===========================================================================*/
/* Function: Set Power vs Time Sweep Separate Frequency
/* Purpose:  This function enters the separate frequency used for power vs.
/*       time measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPowerSweepTimeSeparateFrequency (ViSession instrSession,
                                                            ViInt32 sense,
                                                            ViReal64 separateFrequency)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "SENS%ld:POW:SWE:TIME:SENS:SFR", sense);

  return SETPARAMREAL64 (instrSession, 
                               buffer,
                               separateFrequency,
                 0,
                 22.0e12);
}

/*===========================================================================*/
/* Function: Get Power vs Time Sweep Separate Frequency
/* Purpose:  This function returns the separate frequency used for power vs.
/*       time measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerSweepTimeSeparateFrequency (ViSession instrSession,
                                                            ViInt32 sense,
                                                            ViReal64 *separateFrequency)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "SENS%ld:POW:SWE:TIME:SENS:SFR?", sense);

  return GETPARAMREAL64 (instrSession, 
                               buffer,
                               separateFrequency);
}

/*****************************************************************************
 * Function: Set Power Sweep Time Reference X Values
 * Purpose:  This function sets the x values of the two reference points, i.e. 
 *           "Time X (Point A)" and "Time X (Point B)" in "Time" measurement.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetPowerSweepTimeReferenceXValues (ViSession instrSession,
                                                           ViReal64 timeXPointA,
                                                           ViReal64 timeXPointB)
{
    ViChar      buffer[BUFFER_SIZE] = "";
    
    sprintf (buffer, "SENS:POW:SWE:TIME:REF:DATA:XVAL %.12lG,%.12lG", timeXPointA, timeXPointB);

    return rssmf_sendCmd (instrSession, buffer);
}

/*****************************************************************************
 * Function: Get Power Sweep Time Reference X Values
 * Purpose:  This function returns the x values of the two reference points, i.e. 
 *           "Time X (Point A)" and "Time X (Point B)" in "Time" measurement.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetPowerSweepTimeReferenceXValues (ViSession instrSession,
                                                           ViReal64 *timeXPointA,
                                                           ViReal64 *timeXPointB)
{
    ViStatus    rssmf_status = VI_SUCCESS;
    ViReal64    tempArr[2] = {0.0,0.0};
    
    rssmf_status =  GETPARAMREAL64ARRAY (instrSession,
                                            "SENS:POW:SWE:TIME:REF:DATA:XVAL?",
                                            tempArr,
                                            2);
    
    *timeXPointA = tempArr[0];
    *timeXPointB = tempArr[1];
    
    return rssmf_status;
}

/*****************************************************************************
 * Function: Set Power Sweep Time Reference Y Values
 * Purpose:  This function sets the y values of the two reference points, i.e. 
 *           "Power X (Point A)" and "Power X (Point B)" in "Time" measurement.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetPowerSweepTimeReferenceYValues (ViSession instrSession,
                                                           ViReal64 powerYPointA,
                                                           ViReal64 powerYPointB)
{
    ViChar      buffer[BUFFER_SIZE] = "";
    
    sprintf (buffer, "SENS:POW:SWE:TIME:REF:DATA:YVAL %.12lG,%.12lG", powerYPointA, powerYPointB);

    return rssmf_sendCmd (instrSession, buffer);
}

/*****************************************************************************
 * Function: Get Power Sweep Time Reference Y Values
 * Purpose:  This function returns the y values of the two reference points, i.e. 
 *           "Power X (Point A)" and "Power X (Point B)" in "Time" measurement.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetPowerSweepTimeReferenceYValues (ViSession instrSession,
                                                           ViReal64 *powerYPointA,
                                                           ViReal64 *powerYPointB)
{
    ViStatus    rssmf_status = VI_SUCCESS;
    ViReal64    tempArr[2] = {0.0,0.0};
    
    rssmf_status =  GETPARAMREAL64ARRAY (instrSession,
                                            "SENS:POW:SWE:TIME:REF:DATA:YVAL?",
                                            tempArr,
                                            2);
    
    *powerYPointA = tempArr[0];
    *powerYPointB = tempArr[1];
    
    return rssmf_status;
}

/*****************************************************************************
 * Function: Get Power Sweep Time Reference Number Of Points
 * Purpose:  This function reads the number of points from the reference
 *           curve in "Time" measurement.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetPowerSweepTimeReferenceNumberOfPoints (ViSession instrSession,
                                                                  ViReal64 *numberOfPoints)
{
    INIT;
    
    return GETPARAMREAL64 (instrSession,
                              "SENS:POW:SWE:TIME:REF:DATA:POIN?",
                              numberOfPoints);
}

/*****************************************************************************
 * Function: Generate Power Sweep Time Reference Curve
 * Purpose:  This function generates a reference curve for "Time" measurement.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GeneratePowerSweepTimeReferenceCurve (ViSession instrSession)
{
    INIT;
    
    return rssmf_sendCmd (instrSession, "SENS:POW:SWE:TIME:REF:DATA:COPY");
}

/*===========================================================================*/
/* Function: Set Power Sweep Trace State
/* Purpose:  The function activates/deactivates the selected trace.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPowerSweepTraceState (ViSession instrSession,
                                                 ViInt32 trace, ViBoolean state)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, trace, 1, 3);
    
    sprintf (buffer, "TRAC%ld:POW:SWE:STAT", trace);

    return SETPARAMBOOL (instrSession, 
                              buffer,
                              state);
}

/*===========================================================================*/
/* Function: Get Power Sweep Trace State
/* Purpose:  The function returns the selected trace state.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerSweepTraceState (ViSession instrSession,
                                                 ViInt32 trace, ViBoolean *state)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, trace, 1, 3);
    
    sprintf (buffer, "TRAC%ld:POW:SWE:STAT?", trace);

    return GETPARAMBOOL (instrSession, 
                              buffer,
                              state);    
}

/*===========================================================================*/
/* Function: Set Power Sweep Trace Color
/* Purpose:  The function defines the color of each trace.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPowerSweepTraceColor (ViSession instrSession,
                                                 ViInt32 trace, ViInt32 color)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, trace, 1, 3);
    
    sprintf (buffer, "TRAC%ld:POW:SWE:COL", trace);

    return SETPARAMENUM (instrSession, 
                              buffer,
                              color,
                traceColorArr);    
}

/*===========================================================================*/
/* Function: Get Power Sweep Trace Color
/* Purpose:  The function returns the color of each trace.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerSweepTraceColor (ViSession instrSession,
                                                 ViInt32 trace, ViInt32 *color)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, trace, 1, 3);
    
    sprintf (buffer, "TRAC%ld:POW:SWE:COL?", trace);

    return GETPARAMENUM (instrSession, 
                              buffer,
                              color,
                traceColorArr);    
}

/*===========================================================================*/
/* Function: Copy Power Sweep Trace
/* Purpose:  The function stores the selected trace data as reference trace.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_copyPowerSweepTrace (ViSession instrSession,
                                             ViInt32 trace, ViInt32 copyMode)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, trace, 1, 3);
    
    sprintf (buffer, "TRAC%ld:POW:SWE:COPY", trace);

    return SETPARAMENUM (instrSession, 
                              buffer,
                              copyMode,
                traceCopyArr);    
}

/*===========================================================================*/
/* Function: Get Power Sweep Trace Data Points
/* Purpose:  This function queries the number of measurement points of the
/*       selected trace of the current power analysis.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerSweepTraceDataPoints (ViSession instrSession,
                                                      ViInt32 trace,
                                                      ViInt32 *dataPoints)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, trace, 1, 3);
    
    sprintf (buffer, "TRAC%ld:POW:SWE:DATA:POIN?", trace);

    return GETPARAMINT32 (instrSession, 
                             buffer,
                             dataPoints);
}

/*===========================================================================*/
/* Function: Get Power Sweep Trace X Values
/* Purpose:  This function queries the x-axis values - frequency, power or
/*       time values -  of the selected trace of the current power
/*       analysis.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerSweepTraceXValues (ViSession instrSession,
                                                   ViInt32 trace,
                                                   ViInt32 arraySize,
                                                   ViReal64 xValues[])
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, trace, 1, 3);
    
    sprintf (buffer, "TRAC%ld:POW:SWE:DATA:XVAL?", trace);

    return GETPARAMREAL64ARRAY (instrSession,
                  buffer,
                                   xValues,
                                   arraySize);
}

/*===========================================================================*/
/* Function: Get Power Sweep Trace Y Values
/* Purpose:  This function queries the measurement (y-axis) values of the
/*       selected trace of the current power analysis.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerSweepTraceYValues (ViSession instrSession,
                                                   ViInt32 trace,
                                                   ViInt32 arraySize,
                                                   ViReal64 yValues[])
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, trace, 1, 3);
    
    sprintf (buffer, "TRAC%ld:POW:SWE:DATA:YVAL?", trace);

    return GETPARAMREAL64ARRAY (instrSession,
                                   buffer,
                                   yValues,
                                   arraySize);
}

/*===========================================================================*/
/* Function: Set Power Sweep Trace Source
/* Purpose:  The function defines the source for the data trace.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPowerSweepTraceSource (ViSession instrSession,
                                                  ViInt32 trace, ViInt32 source)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, trace, 1, 3);
    
    sprintf (buffer, "TRAC%ld:POW:SWE:FEED", trace);

    return SETPARAMENUM (instrSession, 
                              buffer,
                              source,
                traceSourceArr); 
}

/*===========================================================================*/
/* Function: Get Power Sweep Trace Source
/* Purpose:  The function returns the source for the data trace.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerSweepTraceSource (ViSession instrSession,
                                                  ViInt32 trace, ViInt32 *source)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, trace, 1, 3);
    
    sprintf (buffer, "TRAC%ld:POW:SWE:FEED?", trace);

    return GETPARAMENUM (instrSession, 
                              buffer,
                              source,
                traceSourceArr); 
}

/*===========================================================================*/
/* Function: Get Power Sweep Trace Pulse Data Analysis State 
/* Purpose:  The function queries the state of pulse data analysis.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerSweepTracePulseDataAnalysisState (ViSession instrSession,
                                                                  ViInt32 trace,
                                                                  ViBoolean *state)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    CHECKOPT (K28);

    CHECKVIINT32 (instrSession, trace, 1, 3);

    sprintf (buffer, "TRAC%ld:POW:SWE:PULS:STAT?", trace);
                             
    return GETPARAMBOOL (instrSession, 
                              buffer,
                              state);
}

/*===========================================================================*/
/* Function: Get Power Sweep Trace Pulse Threshold Base
/* Purpose:  The function queries how the threshold parameters are calculated.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerSweepTracePulseThresholdBase (ViSession instrSession,
                                                              ViInt32 trace,
                                                              ViInt32 *base)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    CHECKOPT (K28);
    
    CHECKVIINT32 (instrSession, trace, 1, 3);

    sprintf (buffer, "TRAC%ld:POW:SWE:PULS:THR:BASE?", trace);
  
    return GETPARAMENUM (instrSession, 
                              buffer,
                              base,
                pulseThresholdBaseArr);
}

/*===========================================================================*/
/* Function: Get Power Sweep Trace Pulse Threshold Reference Level
/* Purpose:  The function returns threshold level.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerSweepTracePulseThresholdReferenceLevel (ViSession instrSession,
                                                                        ViInt32 trace,
                                                                        ViInt32 mode,
                                                                        ViReal64 *referenceLevel)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    CHECKOPT (K28);
    
    CHECKVIINT32 (instrSession, trace, 1, 3);
    CHECKVIINT32 (instrSession, mode, 0, 2);

    sprintf (buffer, "TRAC%ld:POW:SWE:PULS:THR:POW:%s?", trace,pulseThresholdModeArr[mode]);
  
    return GETPARAMREAL64 (instrSession, 
                              buffer,
                              referenceLevel);
}

/*===========================================================================*/
/* Function: Set Power Sweep Sense Mode
/* Purpose:  This function selects single or contimuous mode for response 
/*           measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPowerSweepSenseMode(
    ViSession   instrSession,
    ViInt32 sense,
    ViInt32 senseMode
)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "SENS%ld:POW:SWE:RMOD", sense);

    return SETPARAMENUM (instrSession, 
                          buffer,
                          senseMode,
                          senseModeArr);
}

/*===========================================================================*/
/* Function: Get Power Sweep Sense Mode
/* Purpose:  This function returns single or contimuous mode for response 
/*           measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerSweepSenseMode(
    ViSession   instrSession,
    ViInt32 sense,
    ViInt32*    senseMode
)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "SENS%ld:POW:SWE:RMOD?", sense);

    return GETPARAMENUM (instrSession, 
                          buffer,
                          senseMode,
                          senseModeArr);
}

/*===========================================================================*/
/* Function: Set Power Sweep Mode
/* Purpose:  This function selects power versus frequency measurement 
/*           (frequency response) or power vs power measurment (power sweep, 
/*           AM/AM) 
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPowerSweepMode(
    ViSession   instrSession,
    ViInt32 sense,
    ViInt32 sweepMode
)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "SENS%ld:POW:SWE:MODE", sense);

    return SETPARAMENUM (instrSession, 
                          buffer,
                          sweepMode,
                          sweepModeArr);
}

/*===========================================================================*/
/* Function: Get Power Sweep Mode
/* Purpose:  This function returns power versus frequency measurement 
/*           (frequency response) or power vs power measurment (power sweep, 
/*           AM/AM) 
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerSweepMode(
    ViSession   instrSession,
    ViInt32 sense,
    ViInt32*    sweepMode
)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "SENS%ld:POW:SWE:MODE?", sense);

    return GETPARAMENUM (instrSession, 
                          buffer,
                          sweepMode,
                          sweepModeArr);
}

/*===========================================================================*/
/* Function: Get Power Sweep Data Points
/* Purpose:  This function queries the number of measurement points of the 
/*           current response measurement. 
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerSweepDataPoints(
    ViSession   instrSession,
    ViInt32 sense,
    ViInt32*    dataPoints
)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "TRAC%ld:POW:SWE:DATA:POIN?", sense);

    return GETPARAMINT32 (instrSession, 
                             buffer,
                             dataPoints);
}

/*===========================================================================*/
/* Function: Get Power Sweep Data X Values
/* Purpose:  This function queries the measurement results - frequency or 
/*           power values - of the current response measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerSweepDataXValues (ViSession instrSession,
                                                  ViInt32 sense,
                                                  ViInt32 arraySize,
                                                  ViReal64 dataXValues[])
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "TRAC%ld:POW:SWE:DATA:XVAL?", sense);

    return GETPARAMREAL64ARRAY (instrSession,
                                   buffer,
                                   dataXValues,
                                   arraySize);
}

/*===========================================================================*/
/* Function: Get Power Sweep Data Y Values
/* Purpose:  This function queries the power values of the current response 
/*           measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerSweepDataYValues (ViSession instrSession,
                                                  ViInt32 sense,
                                                  ViInt32 arraySize,
                                                  ViReal64 dataYValues[])
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "TRAC%ld:POW:SWE:DATA:YVAL?", sense);

    return GETPARAMREAL64ARRAY (instrSession,
                                   buffer,
                                   dataYValues,
                                   arraySize);
}

/*===========================================================================*/
/* Function: Configure Diagram Display
/* Purpose:  This function configures the diagram display. 
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_confDiagramDisplay (ViSession instrSession,
                                            ViBoolean grid,
                                            ViInt32 backgroundColor)
{
    ViStatus rssmf_status;
    
    CHECKERR (rssmf_SetDiagramGrid (instrSession, grid));
    
    CHECKERR (rssmf_SetDiagramBackgroundColor (instrSession, backgroundColor));   
    return rssmf_status;
}

/*===========================================================================*/
/* Function: Set Diagram Grid
/* Purpose:  This function activates/deactivates the indication of a grid in
/*       the diagram area.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_SetDiagramGrid (ViSession instrSession,
                                        ViBoolean grid)
{
    INIT;
    return SETPARAMBOOL (instrSession, 
                               "DISP:WIND:POW:SWE:GRID:STAT",
                               grid);
}

/*===========================================================================*/
/* Function: Get Diagram Grid
/* Purpose:  This function returns the indication of a grid in the diagram
/*       area.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetDiagramGrid (ViSession instrSession,
                                        ViBoolean *grid)
{
    INIT;
    return GETPARAMBOOL (instrSession, 
                               "DISP:WIND:POW:SWE:GRID:STAT?",
                               grid);
}

/*===========================================================================*/
/* Function: Set Diagram Background Color
/* Purpose:  This function defines the background color of the measurement
/*       diagram. The background color is also effective for the hardcopy
/*       of the diagram
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_SetDiagramBackgroundColor (ViSession instrSession,
                                                   ViInt32 backgroundColor)
{
    INIT;
    return SETPARAMENUM (instrSession, 
                          "DISP:WIND:POW:SWE:BACK:COL",
                          backgroundColor,
              powerSensorDisplayColorArr);
}

/*===========================================================================*/
/* Function: Get Diagram Background Color
/* Purpose:  This function returns the background color of the measurement
/*       diagram. The background color is also effective for the hardcopy
/*       of the diagram
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetDiagramBackgroundColor (ViSession instrSession,
                                                   ViInt32 *backgroundColor)
{
    INIT;
    return GETPARAMENUM (instrSession, 
                          "DISP:WIND:POW:SWE:BACK:COL?",
                          backgroundColor,
              powerSensorDisplayColorArr);
}

/*===========================================================================*/
/* Function: Set Power Sweep Hardcopy LNG Format
/* Purpose:  This function selects the bitmap graphic format for the 
/*           screenshot of the power analysis trace.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPowerSweepHardcopyLNGFormat(
    ViSession   instrSession,
    ViInt32 sense,
    ViInt32 sweepHardcopyFormat
)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "SENS%ld:POW:SWE:HCOP:DEV:LANG", sense);

    return SETPARAMENUM (instrSession, 
                          buffer,
                          sweepHardcopyFormat,
                          sweepHardcopyFormatArr);
}

/*===========================================================================*/
/* Function: Get Power Sweep Hardcopy LNG Format
/* Purpose:  This function returns the bitmap graphic format for the 
/*           screenshot of the power analysis trace.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerSweepHardcopyLNGFormat(
    ViSession   instrSession,
    ViInt32 sense,
    ViInt32*    sweepHardcopyFormat
)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "SENS%ld:POW:SWE:HCOP:DEV:LANG?", sense);

    return GETPARAMENUM (instrSession, 
                          buffer,
                          sweepHardcopyFormat,
                          sweepHardcopyFormatArr);
}

/*===========================================================================*/
/* Function: Set Power Sweep Hardcopy File
/* Purpose:  This function stores the Hardcopy in the selected output format 
/*           into a file.
/*           
/*           Example:
/*            SENS:SWE:HCOP:DEV:LANG BMP
/*            selects output format *,bmp.
/*           
/*            MMEM:DIR 'var/nrp_sweep'
/*            sets the directory 
/*           
/*            SENS:SWE:HCOP:FILE 'trace1'
/*            triggers a hardcopy of the current trace and stores it in the  
/*            
/*            file trace1.bmp in the set directory. The measurement diagram 
/*            has to be visible in the foreground. 
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPowerSweepHardcopyFile(
    ViSession   instrSession,
    ViString    fileName
)
{
    INIT;
    
    return SETPARAMSTRINGQUOTED (instrSession, 
                              "SENS:POW:SWE:HCOP:FILE",
                              "'",
                              fileName);
}

/*===========================================================================*/
/* Function: Get Power Sweep Hardcopy File
/* Purpose:  This function returns name of the Hardcopy file.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerSweepHardcopyFile(
    ViSession   instrSession,
    ViChar _VI_FAR  fileName[]
)
{
    INIT;
    
    return GETPARAMSTRING (instrSession, 
                              "SENS:POW:SWE:HCOP:FILE?",
                              fileName,
                              1024);
}

/*===========================================================================*/
/* Function: Set Power Sweep Power Execution
/* Purpose:  This function selects single or continuous mode in power
/*           analysis.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPowerSweepPowerExecution (ViSession instrSession,
                                                     ViInt32 execution)
{
  return SETPARAMENUM (instrSession,
                          "SENS:SWE:POW:RMOD",
                          execution,
                          runModeArr);
}

/*===========================================================================*/
/* Function: Get Power Sweep Power Execution
/* Purpose:  This function returns single or continuous mode in power
/*           analysis.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerSweepPowerExecution (ViSession instrSession,
                                                     ViInt32 *execution)
{
  return GETPARAMENUM (instrSession,
                          "SENS:SWE:POW:RMOD?",
                          execution,
                          runModeArr);
}

/*===========================================================================*/
/* Function: Set Power Sweep Power Y Auto Scale
/* Purpose:  This function activates/deactivates autoscaling of the Y axis of
/*       the diagram.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPowerSweepPowerYAutoScale (ViSession instrSession,
                                                      ViInt32 autoScale)
{
  return SETPARAMENUM (instrSession,
                          "SENS:POW:SWE:POW:YSC:AUTO",
                          autoScale,
                          powerFrequencyYScaleAutoArr);
}

/*===========================================================================*/
/* Function: Get Power Sweep Power Y Auto Scale
/* Purpose:  This function returns autoscaling of the Y axis of
/*       the diagram.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerSweepPowerYAutoScale (ViSession instrSession,
                                                      ViInt32 *autoScale)
{
  return GETPARAMENUM (instrSession,
                          "SENS:POW:SWE:POW:YSC:AUTO?",
                          autoScale,
                          powerFrequencyYScaleAutoArr);
}

/*===========================================================================*/
/* Function: Reset Power Sweep Power Y Scale
/* Purpose:  This function resets the Y scale to suitable values after the
/*       use of auto scaling in the expanding mode. For this mode, the
/*       scale might get expanded because of temporarily high power
/*       values. The reset function resets the diagram in such a way that
/*       it matches smaller power values again.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_ResetPowerSweepPowerYScale (ViSession instrSession)
{
  return rssmf_sendCmd (instrSession, "SENS:POW:SWE:POW:YSC:AUTO:RES");   
}

/*===========================================================================*/
/* Function: Set Power vs Power Sweep Separate Frequency State
/* Purpose:  The function activates/deactivates the use of a different
/*       frequency for the power measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPowerSweepPowerSeparateFrequencyState (ViSession instrSession,
                                                                  ViInt32 sense,
                                                                  ViBoolean state)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "SENS%ld:POW:SWE:POW:SENS:SFR:STAT", sense);
  
  return SETPARAMBOOL (instrSession, 
                               buffer,
                               state); 
}

/*===========================================================================*/
/* Function: Get Power vs Power Sweep Separate Frequency State
/* Purpose:  The function returns the use of a different
/*       frequency for the power measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerSweepPowerSeparateFrequencyState (ViSession instrSession,
                                                                  ViInt32 sense,
                                                                  ViBoolean *state)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "SENS%ld:POW:SWE:POW:SENS:SFR:STAT?", sense);
  
  return GETPARAMBOOL (instrSession, 
                               buffer,
                               state); 
}

/*===========================================================================*/
/* Function: Set Power vs Time Sweep Separate Frequency
/* Purpose:  This function enters the separate frequency used for power vs.
/*       time measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPowerSweepPowerSeparateFrequency (ViSession instrSession,
                                                             ViInt32 sense,
                                                             ViReal64 separateFrequency)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "SENS%ld:POW:SWE:POW:SENS:SFR", sense);

  return SETPARAMREAL64 (instrSession, 
                               buffer,
                               separateFrequency,
                 0,
                 22.0e12);
}

/*===========================================================================*/
/* Function: Get Power vs Time Sweep Separate Frequency
/* Purpose:  This function returns the separate frequency used for power vs.
/*       time measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerSweepPowerSeparateFrequency (ViSession instrSession,
                                                             ViInt32 sense,
                                                             ViReal64 *separateFrequency)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "SENS%ld:POW:SWE:POW:SENS:SFR?", sense);

  return GETPARAMREAL64 (instrSession, 
                               buffer,
                               separateFrequency);
}

/*****************************************************************************
 * Function: Set Power Sweep Power Reference X Values
 * Purpose:  This function sets the x values of the two reference points, i.e. 
 *           "Power X (Point A)" and "Power X (Point B)" in "Power"
 *           measurement.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetPowerSweepPowerReferenceXValues (ViSession instrSession,
                                                            ViReal64 powerXPointA,
                                                            ViReal64 powerXPointB)
{
    ViChar      buffer[BUFFER_SIZE] = "";
    
    sprintf (buffer, "SENS:POW:SWE:POW:REF:DATA:XVAL %.12lG,%.12lG", powerXPointA, powerXPointB);

    return rssmf_sendCmd (instrSession, buffer);
}

/*****************************************************************************
 * Function: Get Power Sweep Power Reference X Values
 * Purpose:  This function returns the x values of the two reference points, i.e. 
 *           "Power X (Point A)" and "Power X (Point B)" in "Power"
 *           measurement.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetPowerSweepPowerReferenceXValues (ViSession instrSession,
                                                            ViReal64 *powerXPointA,
                                                            ViReal64 *powerXPointB)
{
    ViStatus    rssmf_status = VI_SUCCESS;
    ViReal64    tempArr[2] = {0.0,0.0};
    
    rssmf_status =  GETPARAMREAL64ARRAY (instrSession,
                                            "SENS:POW:SWE:POW:REF:DATA:XVAL?",
                                            tempArr,
                                            2);
    
    *powerXPointA = tempArr[0];
    *powerXPointB = tempArr[1];
    
    return rssmf_status;
}

/*****************************************************************************
 * Function: Set Power Sweep Power Reference Y Values
 * Purpose:  This function sets the y values of the two reference points, i.e. 
 *           "Power Y (Point A)" and "Power Y (Point B)" in "Power"
 *           measurement.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetPowerSweepPowerReferenceYValues (ViSession instrSession,
                                                            ViReal64 powerYPointA,
                                                            ViReal64 powerYPointB)
{
    ViChar      buffer[BUFFER_SIZE] = "";
    
    sprintf (buffer, "SENS:POW:SWE:POW:REF:DATA:YVAL %.12lG,%.12lG", powerYPointA, powerYPointB);

    return rssmf_sendCmd (instrSession, buffer);
}

/*****************************************************************************
 * Function: Get Power Sweep Power Reference Y Values
 * Purpose:  This function retuns the y values of the two reference points, i.e. 
 *           "Power Y (Point A)" and "Power Y (Point B)" in "Power"
 *           measurement.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetPowerSweepPowerReferenceYValues (ViSession instrSession,
                                                            ViReal64 *powerYPointA,
                                                            ViReal64 *powerYPointB)
{
    ViStatus    rssmf_status = VI_SUCCESS;
    ViReal64    tempArr[2] = {0.0,0.0};
    
    rssmf_status =  GETPARAMREAL64ARRAY (instrSession,
                                            "SENS:POW:SWE:POW:REF:DATA:YVAL?",
                                            tempArr,
                                            2);
    
    *powerYPointA = tempArr[0];
    *powerYPointB = tempArr[1];
    
    return rssmf_status;
}

/*****************************************************************************
 * Function: Get Power Sweep Power Reference Number Of Points
 * Purpose:  This function reads the number of points from the reference
 *           curve in "Power" measurement.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetPowerSweepPowerReferenceNumberOfPoints (ViSession instrSession,
                                                                   ViReal64 *numberOfPoints)
{
    INIT;
    
    return GETPARAMREAL64 (instrSession,
                              "SENS:POW:SWE:POW:REF:DATA:POIN?",
                              numberOfPoints);
}

/*****************************************************************************
 * Function: Generate Power Sweep Power Reference Curve
 * Purpose:  This function generates a reference curve for "Power"
 *           measurement.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GeneratePowerSweepPowerReferenceCurve (ViSession instrSession)
{
    INIT;
    
    return rssmf_sendCmd (instrSession, "SENS:POW:SWE:POW:REF:DATA:COPY");
}

/*===========================================================================*/
/* Function: Configure Power vs Time Sweep Separate Frequency Range
/* Purpose:  The function configures using of Separate Frequency for power
/*       vs. time measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_confPowerSweepTimeSeparateFrequencyRange (ViSession instrSession,
                                                                  ViInt32 sense,
                                                                  ViBoolean state,
                                                                  ViReal64 separateFrequency)
{
    ViStatus rssmf_status;
    
    CHECKERR (rssmf_SetPowerSweepTimeSeparateFrequencyState (instrSession, sense, state));
    
    CHECKERR (rssmf_SetPowerSweepTimeSeparateFrequency (instrSession, sense, separateFrequency));   
    return rssmf_status;
}

/*===========================================================================*/
/* Function: Set Power Sweep Time Pulse Data Analysis State
/* Purpose:  The function activates/deactivates pulse data analysis. The
/*       measurement is started with command INITiate.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPowerSweepTimePulseDataAnalysisState (ViSession instrSession,
                                                                 ViInt32 sense,
                                                                 ViBoolean state)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    CHECKOPT (K28);

    CHECKVIINT32 (instrSession, sense, 1, 3);

    sprintf (buffer, "SENS%ld:POW:SWE:TIME:SENS:PULS:STAT", sense);
  
    return SETPARAMBOOL (instrSession, 
                              buffer,
                              state);
}

/*===========================================================================*/
/* Function: Get Power Sweep Time Pulse Data Analysis State
/* Purpose:  The function returns pulse data analysis state.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerSweepTimePulseDataAnalysisState (ViSession instrSession,
                                                                 ViInt32 sense,
                                                                 ViBoolean *state)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    CHECKOPT (K28);
    
    CHECKVIINT32 (instrSession, sense, 1, 3);

    sprintf (buffer, "SENS%ld:POW:SWE:TIME:SENS:PULS:STAT?", sense);
  
    return GETPARAMBOOL (instrSession, 
                              buffer,
                              state);
}

/*===========================================================================*/
/* Function: Set Power Sweep Time Pulse Threshold Base
/* Purpose:  The function selects how the threshold parameters for pulse
/*       analysis are calculated.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPowerSweepTimePulseThresholdBase (ViSession instrSession,
                                                             ViInt32 sense,
                                                             ViInt32 base)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    CHECKOPT (K28);
    
    CHECKVIINT32 (instrSession, sense, 1, 3);

    sprintf (buffer, "SENS%ld:POW:SWE:TIME:SENS:PULS:THR:BASE", sense);
  
    return SETPARAMENUM (instrSession, 
                              buffer,
                              base,
                pulseThresholdBaseArr);
}

/*===========================================================================*/
/* Function: Get Power Sweep Time Pulse Threshold Base
/* Purpose:  The function returns how the threshold parameters for pulse
/*       analysis are calculated.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerSweepTimePulseThresholdBase (ViSession instrSession,
                                                             ViInt32 sense,
                                                             ViInt32 *base)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    CHECKOPT (K28);
    
    CHECKVIINT32 (instrSession, sense, 1, 3);

    sprintf (buffer, "SENS%ld:POW:SWE:TIME:SENS:PULS:THR:BASE?", sense);
  
    return GETPARAMENUM (instrSession, 
                              buffer,
                              base,
                pulseThresholdBaseArr);
}

/*===========================================================================*/
/* Function: Set Power Sweep Time Pulse Threshold Reference Level
/* Purpose:  The function selects reference level in terms of percentage of
/*       the overall pulse level
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPowerSweepTimePulseThresholdReferenceLevel (ViSession instrSession,
                                                                       ViInt32 sense,
                                                                       ViInt32 mode,
                                                                       ViReal64 referenceLevel)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    CHECKOPT (K28);
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    CHECKVIINT32 (instrSession, mode, 0, 2);

    sprintf (buffer, "SENS%ld:POW:SWE:TIME:SENS:PULS:THR:POW:%s", sense,pulseThresholdModeArr[mode]);
  
    return SETPARAMREAL64 (instrSession, 
                              buffer,
                              referenceLevel,
                0,100);    
}

/*===========================================================================*/
/* Function: Get Power Sweep Time Pulse Threshold Reference Level
/* Purpose:  The function returns reference level in terms of percentage of
/*       the overall pulse level
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerSweepTimePulseThresholdReferenceLevel (ViSession instrSession,
                                                                       ViInt32 sense,
                                                                       ViInt32 mode,
                                                                       ViReal64 *referenceLevel)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    CHECKOPT (K28);
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    CHECKVIINT32 (instrSession, mode, 0, 2);

    sprintf (buffer, "SENS%ld:POW:SWE:TIME:SENS:PULS:THR:POW:%s?", sense,pulseThresholdModeArr[mode]);
  
    return GETPARAMREAL64 (instrSession, 
                              buffer,
                              referenceLevel);    
}

/*===========================================================================
 * Function: Set Power Sweep Time Trigger Source
 * Purpose:  The function selects if the measurement is free running or
 *           starts only after a trigger event. 
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPowerSweepTimeTriggerSource (ViSession instrSession,
                                                        ViInt32 sense,
                                                        ViInt32 source)
{
    ViChar buffer[BUFFER_SIZE];
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "SENS%ld:POW:SWE:TIME:SENS:TRIG:SOUR", sense);
    
    return SETPARAMENUM (instrSession,
                          buffer,
                          source,
                          powerTimeTriggerSourceArr);
}

/*===========================================================================
 * Function: Get Power Sweep Time Trigger Source
 * Purpose:  The function returns if the measurement is free running or starts 
 *           only after a trigger event. 
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerSweepTimeTriggerSource (ViSession instrSession,
                                                        ViInt32 sense,
                                                        ViInt32 *source)
{
    ViChar buffer[BUFFER_SIZE];
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "SENS%ld:POW:SWE:TIME:SENS:TRIG:SOUR?", sense);
    
    return GETPARAMENUM (instrSession,
                          buffer,
                          source,
                          powerTimeTriggerSourceArr);
}

/*===========================================================================*/
/* Function: Set Power Sweep Time Trigger Drop Out Time
/* Purpose:  This function determines the minimum time for which the signal
/*       must be below (above) the power level defined by level and
/*       hysteresis before triggering can occur again.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPowerSweepTimeTriggerDropOutTime (ViSession instrSession,
                                                             ViInt32 sense,
                                                             ViReal64 dropOutTime)
{
    ViChar buffer[BUFFER_SIZE];
  INIT;   
    CHECKVIINT32 (instrSession, sense, 1, 3);

    sprintf (buffer, "SENS%ld:POW:SWE:TIME:SENS:TRIG:DTIM", sense);
   
    return SETPARAMREAL64 (instrSession, 
                          buffer,
                          dropOutTime,
              0,10);
}

/*===========================================================================*/
/* Function: Get Power Sweep Time Trigger Drop Out Time
/* Purpose:  This function returns the minimum time for which the signal must
/*       be below (above) the power level defined by level and hysteresis
/*       before triggering can occur again.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerSweepTimeTriggerDropOutTime (ViSession instrSession,
                                                             ViInt32 sense,
                                                             ViReal64 *dropOutTime)
{
    ViChar buffer[BUFFER_SIZE];
  INIT;   
    CHECKVIINT32 (instrSession, sense, 1, 3);

    sprintf (buffer, "SENS%ld:POW:SWE:TIME:SENS:TRIG:DTIM?", sense);
   
    return GETPARAMREAL64 (instrSession, 
                          buffer,
                          dropOutTime);
}

/*===========================================================================*/
/* Function: Set Power Sweep Time Trigger Hysteresis
/* Purpose:  This function sets the hysteresis of the internal trigger
/*       threshold. Hysteresis is the magnitude (in dB) the trigger
/*       signal level must drop below the trigger threshold (positive
/*       trigger slope) before triggering can occur again.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPowerSweepTimeTriggerHysteresis (ViSession instrSession,
                                                            ViInt32 sense,
                                                            ViReal64 hysteresis)
{
    ViChar buffer[BUFFER_SIZE];
  INIT;   
    CHECKVIINT32 (instrSession, sense, 1, 3);

    sprintf (buffer, "SENS%ld:POW:SWE:TIME:SENS:TRIG:HYST", sense);
   
    return SETPARAMREAL64 (instrSession, 
                          buffer,
                          hysteresis,
              -10,10);
}

/*===========================================================================*/
/* Function: Get Power Sweep Time Trigger Hysteresis
/* Purpose:  This function returns the hysteresis of the internal trigger
/*       threshold. Hysteresis is the magnitude (in dB) the trigger
/*       signal level must drop below the trigger threshold (positive
/*       trigger slope) before triggering can occur again.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerSweepTimeTriggerHysteresis (ViSession instrSession,
                                                            ViInt32 sense,
                                                            ViReal64 *hysteresis)
{
    ViChar buffer[BUFFER_SIZE];
  INIT;   
    CHECKVIINT32 (instrSession, sense, 1, 3);

    sprintf (buffer, "SENS%ld:POW:SWE:TIME:SENS:TRIG:HYST?", sense);
   
    return GETPARAMREAL64 (instrSession, 
                          buffer,
                          hysteresis);
}

/*===========================================================================*/
/* Function: Set Power Sweep Time Trigger Threshold
/* Purpose:  This function sets the trigger threshold.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPowerSweepTimeTriggerThreshold (ViSession instrSession,
                                                           ViInt32 sense,
                                                           ViReal64 threshold)
{
    ViChar buffer[BUFFER_SIZE];
  INIT;   
    CHECKVIINT32 (instrSession, sense, 1, 3);

    sprintf (buffer, "SENS%ld:POW:SWE:TIME:SENS:TRIG:LEV", sense);
   
    return SETPARAMREAL64 (instrSession, 
                          buffer,
                          threshold,
              -200,100);
}

/*===========================================================================*/
/* Function: Get Power Sweep Time Trigger Threshold
/* Purpose:  This function returns the trigger threshold.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerSweepTimeTriggerThreshold (ViSession instrSession,
                                                           ViInt32 sense,
                                                           ViReal64 *threshold)
{
    ViChar buffer[BUFFER_SIZE];
  INIT;   
    CHECKVIINT32 (instrSession, sense, 1, 3);

    sprintf (buffer, "SENS%ld:POW:SWE:TIME:SENS:TRIG:LEV?", sense);
   
    return GETPARAMREAL64 (instrSession, 
                          buffer,
                          threshold);
}

/*===========================================================================*/
/* Function: Set Power Sweep Time Trigger Auto Set
/* Purpose:  The function determines and sets the trigger level. The
/*       hysteresis and drop out time are not influenced.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPowerSweepTimeTriggerAutoSet (ViSession instrSession,
                                                         ViInt32 sense,
                                                         ViInt32 timeout)
{
    ViChar    buffer[BUFFER_SIZE];
  INIT;   
    
  CHECKVIINT32 (instrSession, sense, 1, 3);
  
  sprintf (buffer, "SENS%ld:POW:SWE:TIME:SENS:TRIG:AUTO ONCE;*OPC?", sense);
   
    CHECKERR (rssmf_waitOPC (instrSession, buffer, buffer, timeout));
    
    return rssmf_status; //return rssmf_sendCmd (instrSession, buffer);
}

/*===========================================================================*/
/* Function: Set Power Sweep Time Start
/* Purpose:  This function enters the start time for the power versus time 
/*           measurement. Value 0 defines the trigger point. By choosing a 
/*           negative time value, the trace can be shifted in the diagram. 
/*           It is possible, that the measurement cannot be performed over 
/*           the complete time range because of limitations due to sensor 
/*           settings. In this case, an error message is output.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPowerSweepTimeStart (ViSession instrSession, ViInt32 sense,
                                       ViReal64 timeStart)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
  CHECKOPT (K28);
  
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "SENS%ld:POW:SWE:TIME:STAR", sense);

    return SETPARAMREAL64 (instrSession, 
                              buffer,
                              timeStart,
                              -1.0,1.0);
}

/*===========================================================================*/
/* Function: Get Power Sweep Time Start
/* Purpose:  This function returns the start time for the power versus time 
/*           measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerSweepTimeStart (ViSession instrSession, ViInt32 sense,
                                       ViReal64 *timeStart)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKOPT (K28);
  
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "SENS%ld:POW:SWE:TIME:STAR?", sense);

    return GETPARAMREAL64 (instrSession, 
                              buffer,
                              timeStart);
}

/*===========================================================================*/
/* Function: Set Power Sweep Time Stop
/* Purpose:  This function enters the stop time for the power versus time
/*           measurement
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPowerSweepTimeStop (ViSession instrSession, ViInt32 sense,
                                      ViReal64 timeStop)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKOPT (K28);
  
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "SENS%ld:POW:SWE:TIME:STOP", sense);

    return SETPARAMREAL64 (instrSession, 
                              buffer,
                              timeStop,
                              0.0,2.0);
}

/*===========================================================================*/
/* Function: Get Power Sweep Time Stop
/* Purpose:  This function returns the stop time for the power versus time
/*           measurement
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerSweepTimeStop (ViSession instrSession, ViInt32 sense,
                                      ViReal64 *timeStop)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKOPT (K28);
  
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "SENS%ld:POW:SWE:TIME:STOP?", sense);

    return GETPARAMREAL64 (instrSession, 
                              buffer,
                              timeStop);
}

/*===========================================================================*/
/* Function: Set Power Sweep Time Trigger Events
/* Purpose:  This function determines, whether the measurement data
/*           processing starts with a trigger event in one of the sensors
/*           (Logical OR), or whether all channels have to be triggered
/*           (logical AND). Each sensor evaluates a trigger event according
/*           to its setting independently. This function supports the
/*           internal or external trigger modes with multi-channel time
/*           measurements.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPowerSweepTimeTriggerEvents (ViSession instrSession,
                                                        ViInt32 sense,
                                                        ViInt32 triggerEvents)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKOPT (K28);
  
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "SENS%ld:POW:SWE:TIME:TEV", sense);

    return SETPARAMENUM (instrSession, 
                          buffer,
                          triggerEvents,
                          triggerEventsArr);
}

/*===========================================================================*/
/* Function: Get Power Sweep Time Trigger Events
/* Purpose:  This function returns the measurement data processing starts
/*           with a trigger event in one of the sensors (Logical OR), or
/*           whether all channels have to be triggered (logical AND).
/*           xternal trigger modes with multi-channel time
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerSweepTimeTriggerEvents (ViSession instrSession,
                                                        ViInt32 sense,
                                                        ViInt32 *triggerEvents)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKOPT (K28);
  
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "SENS%ld:POW:SWE:TIME:TEV?", sense);

    return GETPARAMENUM (instrSession, 
                          buffer,
                          triggerEvents,
                          triggerEventsArr);
}

/*===========================================================================*/
/* Function: Set Power Sweep Time Spacing
/* Purpose:  This function sets the sweep spacing for the power versus time
/*           measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPowerSweepTimeSpacing (ViSession instrSession,
                                                  ViInt32 sense,
                                                  ViInt32 timeSpacing)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKOPT (K28);
  
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "SENS%ld:POW:SWE:TIME:SPAC:MODE", sense);

    return SETPARAMENUM (instrSession, 
                          buffer,
                          timeSpacing,
                          powerFrequencySpacingArr);
}

/*===========================================================================*/
/* Function: Get Power Sweep Time Spacing
/* Purpose:  This function returns the sweep spacing for the power versus time
/*           measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerSweepTimeSpacing (ViSession instrSession,
                                                  ViInt32 sense,
                                                  ViInt32 *timeSpacing)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKOPT (K28);
  
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "SENS%ld:POW:SWE:TIME:SPAC:MODE?", sense);

    return GETPARAMENUM (instrSession, 
                          buffer,
                          timeSpacing,
                          powerFrequencySpacingArr);
}

/*===========================================================================
 * Function: Set Power Sweep Time Averaging Factor
 * Purpose:  Selects the averaging factor in time mode. The count
 *           number determines how many measurement cycles are used to form a
 *           measurement result. Higher averaging counts reduce noise but
 *           increase the measurement time. Averaging requires a stable
 *           trigger event so that the measurement cycles have the same
 *           timing.
 *           
 *           Required Option(s):
 *           R&S SMF-K28 
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPowerSweepTimeAveragingFactor (ViSession instrSession,
                                                     ViInt32 averagingFactor)
{
    INIT;
    
    CHECKOPT (K28);
    
    return SETPARAMINT32 (instrSession,
                             "SENS:POW:SWE:TIME:AVER:COUN",
                             averagingFactor,
                             1, 1024);
}

/*===========================================================================
 * Function: Get Power Sweep Time Averaging Factor
 * Purpose:  Queries the averaging factor in time mode.
 *           
 *           Required Option(s):
 *           R&S SMF-K28 
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerSweepTimeAveragingFactor (ViSession instrSession,
                                                     ViInt32 *averagingFactor)
{
    INIT;
    
    CHECKOPT (K28);
    
    return GETPARAMINT32 (instrSession,
                             "SENS:POW:SWE:TIME:AVER:COUN?",
                             averagingFactor);
}

/*===========================================================================*/
/* Function: Set Power Sweep Time Step
/* Purpose:  This function enters the number of measurement steps for the 
/*           power versus time measurement. Value 0 defines the trigger point. 
/*           It is possible, that the measurement cannot be performed over the 
/*           complete time range because of limitations due to sensor settings. 
/*           In this case, an error message is output.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPowerSweepTimeSteps (ViSession instrSession, ViInt32 sense,
                                       ViInt32 timeSteps)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKOPT (K28);
  
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "SENS%ld:POW:SWE:TIME:STEP", sense);

    return SETPARAMINT32 (instrSession, 
                             buffer,
                             timeSteps,
                             10,1000);
}

/*===========================================================================*/
/* Function: Get Power Sweep Time Step
/* Purpose:  This function returns the number of measurement steps for the 
/*           power versus time measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerSweepTimeSteps (ViSession instrSession, ViInt32 sense,
                                       ViInt32 *timeSteps)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKOPT (K28);
  
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "SENS%ld:POW:SWE:TIME:STEP?", sense);

    return GETPARAMINT32 (instrSession, 
                             buffer,
                             timeSteps);
}

/*===========================================================================
 * Function: Set Power Time Trigger Source
 * Purpose:  The function selects if the measurement is free running or
 *           starts only after a trigger event. 
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPowerTimeTriggerSource (ViSession instrSession,
                                          ViInt32 sense, ViInt32 source)
{
    ViChar buffer[BUFFER_SIZE];
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
  sprintf (buffer, "SENS%ld:POW:SWE:TIME:SENS:TRIG:SOUR", sense);
    
  return SETPARAMENUM (instrSession,
                          buffer,
                          source,
                          powerTimeTriggerSourceArr);
}

/*===========================================================================
 * Function: Get Power Time Trigger Source
 * Purpose:  The function returns if the measurement is free running or starts 
 *           only after a trigger event. 
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerTimeTriggerSource (ViSession instrSession,
                                          ViInt32 sense, ViInt32 *source)
{
    ViChar buffer[BUFFER_SIZE];
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
  sprintf (buffer, "SENS%ld:POW:SWE:TIME:SENS:TRIG:SOUR?", sense);
    
  return GETPARAMENUM (instrSession,
                          buffer,
                          source,
                          powerTimeTriggerSourceArr);
}

/*===========================================================================
 * Function: Set Power Display Indication
 * Purpose:  Switches the indication of the selected type on or off.
 *           
 *           Required Option(s):
 *           R&S SMF-K28
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPowerDisplayIndication (ViSession instrSession,
                                                   ViInt32 trace, ViInt32 type,
                                                   ViBoolean indication)
{
    ViChar buffer[BUFFER_SIZE];
    
    INIT;
    
    CHECKOPT (K28);
    
    switch (type)
    {
        case RSSMF_SENSE_POWER_DISP_PULS_ALL:
            sprintf (buffer, "TRAC%ld:SWE:MEAS:PULS:ALL:DISP:ANN", trace);
        break;
        case RSSMF_SENSE_POWER_DISP_STAN:
            sprintf (buffer, "TRAC:SWE:MEAS:STAN:DISP:ANN");
        break;
        case RSSMF_SENSE_POWER_DISP_MARK:
            sprintf (buffer, "TRAC:SWE:MEAS:MARK:DISP:ANN");
        break;
        case RSSMF_SENSE_POWER_DISP_GATE:
            sprintf (buffer, "TRAC:SWE:MEAS:GATE:DISP:ANN");
        break;
        case RSSMF_SENSE_POWER_DISP_PULS:
            sprintf (buffer, "TRAC:SWE:MEAS:PULS:DISP:ANN");
        break;
        case RSSMF_SENSE_POWER_DISP_FULL_SCR:
            sprintf (buffer, "TRAC:SWE:MEAS:FULL:DISP:ANN");
        break;

        case RSSMF_SENSE_POWER_DISP_POWER_AVER:
            sprintf (buffer, "TRAC%ld:SWE:MEAS:POW:AVER:DISP:ANN", trace);
        break;
        case RSSMF_SENSE_POWER_DISP_POWER_HREF:
            sprintf (buffer, "TRAC%ld:SWE:MEAS:POW:HREF:DISP:ANN", trace);
        break;
        case RSSMF_SENSE_POWER_DISP_POWER_REF:
            sprintf (buffer, "TRAC%ld:SWE:MEAS:POW:REF:DISP:ANN", trace);
        break;
        case RSSMF_SENSE_POWER_DISP_POWER_LREF:
            sprintf (buffer, "TRAC%ld:SWE:MEAS:POW:LREF:DISP:ANN", trace);
        break;
        case RSSMF_SENSE_POWER_DISP_POWER_MAX:
            sprintf (buffer, "TRAC%ld:SWE:MEAS:POW:MAX:DISP:ANN", trace);
        break;
        case RSSMF_SENSE_POWER_DISP_POWER_MIN:
            sprintf (buffer, "TRAC%ld:SWE:MEAS:POW:MIN:DISP:ANN", trace);
        break;
        case RSSMF_SENSE_POWER_DISP_POWER_PULSE_BASE:
            sprintf (buffer, "TRAC%ld:SWE:MEAS:POW:PULS:BASE:DISP:ANN", trace);
        break;
        case RSSMF_SENSE_POWER_DISP_POWER_PULSE_TOP:
            sprintf (buffer, "TRAC%ld:SWE:MEAS:POW:PULS:TOP:DISP:ANN", trace);
        break;
        case RSSMF_SENSE_POWER_DISP_PULSE_DCYCLE :
            sprintf (buffer, "TRAC%ld:SWE:MEAS:PULS:DCYC:DISP:ANN", trace);
        break;
        case RSSMF_SENSE_POWER_DISP_PULSE_DUR:
            sprintf (buffer, "TRAC%ld:SWE:MEAS:PULS:DUR:DISP:ANN", trace);
        break;
        case RSSMF_SENSE_POWER_DISP_PULSE_PERIOD:
            sprintf (buffer, "TRAC%ld:SWE:MEAS:PULS:PER:DISP:ANN", trace);
        break;
        case RSSMF_SENSE_POWER_DISP_PULSE_SEP:
            sprintf (buffer, "TRAC%ld:SWE:MEAS:PULS:SEP:DISP:ANN", trace);
        break;
        case RSSMF_SENSE_POWER_DISP_TRAN_NEG_DUR:
            sprintf (buffer, "TRAC%ld:SWE:MEAS:TRAN:NEG:DUR:DISP:ANN", trace);
        break;
        case RSSMF_SENSE_POWER_DISP_TRAN_NEG_OCC:
            sprintf (buffer, "TRAC%ld:SWE:MEAS:TRAN:NEG:OCC:DISP:ANN", trace);
        break;
        case RSSMF_SENSE_POWER_DISP_TRAN_NEG_OVER :
            sprintf (buffer, "TRAC%ld:SWE:MEAS:TRAN:NEG:OVER:DISP:ANN", trace);
        break;
        case RSSMF_SENSE_POWER_DISP_TRAN_POS_DUR:
            sprintf (buffer, "TRAC%ld:SWE:MEAS:TRAN:POS:DUR:DISP:ANN", trace);
        break;
        case RSSMF_SENSE_POWER_DISP_TRAN_POS_OCC:
            sprintf (buffer, "TRAC%ld:SWE:MEAS:TRAN:POS:OCC:DISP:ANN", trace);
        break;
        case RSSMF_SENSE_POWER_DISP_TRAN_POS_OVER:    
            sprintf (buffer, "TRAC%ld:SWE:MEAS:TRAN:POS:OVER:DISP:ANN", trace);
        break;
        default:
	        return rssmf_ParameterError (instrSession, "type");
    }
    
    return SETPARAMBOOL (instrSession,
                               buffer,
                               indication);
}

/*===========================================================================
 * Function: Get Power Display Indication
 * Purpose:  Returns the state of the indication of the selected type.
 *           
 *           Required Option(s):
 *           R&S SMF-K28 
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerDisplayIndication (ViSession instrSession,
                                                   ViInt32 trace, ViInt32 type,
                                                   ViBoolean *indication)
{
    ViChar buffer[BUFFER_SIZE];
    
    INIT;
    
    CHECKOPT (K28);
    
    switch (type)
    {
        case RSSMF_SENSE_POWER_DISP_PULS_ALL:
            sprintf (buffer, "TRAC%ld:SWE:MEAS:PULS:ALL:DISP:ANN:STAT?", trace);
        break;
        case RSSMF_SENSE_POWER_DISP_STAN:
            sprintf (buffer, "TRAC:SWE:MEAS:STAN:DISP:ANN?");
        break;
        case RSSMF_SENSE_POWER_DISP_MARK:
            sprintf (buffer, "TRAC:SWE:MEAS:MARK:DISP:ANN?");
        break;
        case RSSMF_SENSE_POWER_DISP_GATE:
            sprintf (buffer, "TRAC:SWE:MEAS:GATE:DISP:ANN?");
        break;
        case RSSMF_SENSE_POWER_DISP_PULS:
            sprintf (buffer, "TRAC:SWE:MEAS:PULS:DISP:ANN?");
        break;
        case RSSMF_SENSE_POWER_DISP_FULL_SCR:
            sprintf (buffer, "TRAC:SWE:MEAS:FULL:DISP:ANN?");
        break;

        case RSSMF_SENSE_POWER_DISP_POWER_AVER:
            sprintf (buffer, "TRAC%ld:SWE:MEAS:POW:AVER:DISP:ANN?", trace);
        break;
        case RSSMF_SENSE_POWER_DISP_POWER_HREF:
            sprintf (buffer, "TRAC%ld:SWE:MEAS:POW:HREF:DISP:ANN?", trace);
        break;
        case RSSMF_SENSE_POWER_DISP_POWER_REF:
            sprintf (buffer, "TRAC%ld:SWE:MEAS:POW:REF:DISP:ANN?", trace);
        break;
        case RSSMF_SENSE_POWER_DISP_POWER_LREF:
            sprintf (buffer, "TRAC%ld:SWE:MEAS:POW:LREF:DISP:ANN?", trace);
        break;
        case RSSMF_SENSE_POWER_DISP_POWER_MAX:
            sprintf (buffer, "TRAC%ld:SWE:MEAS:POW:MAX:DISP:ANN?", trace);
        break;
        case RSSMF_SENSE_POWER_DISP_POWER_MIN:
            sprintf (buffer, "TRAC%ld:SWE:MEAS:POW:MIN:DISP:ANN?", trace);
        break;
        case RSSMF_SENSE_POWER_DISP_POWER_PULSE_BASE:
            sprintf (buffer, "TRAC%ld:SWE:MEAS:POW:PULS:BASE:DISP:ANN?", trace);
        break;
        case RSSMF_SENSE_POWER_DISP_POWER_PULSE_TOP:
            sprintf (buffer, "TRAC%ld:SWE:MEAS:POW:PULS:TOP:DISP:ANN?", trace);
        break;
        case RSSMF_SENSE_POWER_DISP_PULSE_DCYCLE :
            sprintf (buffer, "TRAC%ld:SWE:MEAS:PULS:DCYC:DISP:ANN?", trace);
        break;
        case RSSMF_SENSE_POWER_DISP_PULSE_DUR:
            sprintf (buffer, "TRAC%ld:SWE:MEAS:PULS:DUR:DISP:ANN?", trace);
        break;
        case RSSMF_SENSE_POWER_DISP_PULSE_PERIOD:
            sprintf (buffer, "TRAC%ld:SWE:MEAS:PULS:PER:DISP:ANN?", trace);
        break;
        case RSSMF_SENSE_POWER_DISP_PULSE_SEP:
            sprintf (buffer, "TRAC%ld:SWE:MEAS:PULS:SEP:DISP:ANN?", trace);
        break;
        case RSSMF_SENSE_POWER_DISP_TRAN_NEG_DUR:
            sprintf (buffer, "TRAC%ld:SWE:MEAS:TRAN:NEG:DUR:DISP:ANN?", trace);
        break;
        case RSSMF_SENSE_POWER_DISP_TRAN_NEG_OCC:
            sprintf (buffer, "TRAC%ld:SWE:MEAS:TRAN:NEG:OCC:DISP:ANN?", trace);
        break;
        case RSSMF_SENSE_POWER_DISP_TRAN_NEG_OVER :
            sprintf (buffer, "TRAC%ld:SWE:MEAS:TRAN:NEG:OVER:DISP:ANN?", trace);
        break;
        case RSSMF_SENSE_POWER_DISP_TRAN_POS_DUR:
            sprintf (buffer, "TRAC%ld:SWE:MEAS:TRAN:POS:DUR:DISP:ANN?", trace);
        break;
        case RSSMF_SENSE_POWER_DISP_TRAN_POS_OCC:
            sprintf (buffer, "TRAC%ld:SWE:MEAS:TRAN:POS:OCC:DISP:ANN?", trace);
        break;
        case RSSMF_SENSE_POWER_DISP_TRAN_POS_OVER:    
            sprintf (buffer, "TRAC%ld:SWE:MEAS:TRAN:POS:OVER:DISP:ANN?", trace);
        break;
        default:
        	return rssmf_ParameterError (instrSession, "type");
    }
    
    return GETPARAMBOOL (instrSession,
                               buffer,
                               indication);
}

/*===========================================================================*/
/* Function: Get Power Display Pulse Data Analysis
/* Purpose:  The function returns the measured pulse parameters values.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerDisplayPulseDataAnalysis (ViSession instrSession,
                                                          ViInt32 trace,
                                                          ViInt32 type,
                                                          ViReal64 *pulseDataAnalysis)
{
    ViChar buffer[BUFFER_SIZE];
    
    INIT;
    
    CHECKOPT (K28);
    
    switch (type)
    {
        case RSSMF_SENSE_POWER_DISP_POWER_AVER:
            sprintf (buffer, "TRAC%ld:POW:SWE:MEAS:POW:AVER?", trace);
        break;
        case RSSMF_SENSE_POWER_DISP_POWER_HREF:
            sprintf (buffer, "TRAC%ld:POW:SWE:MEAS:POW:HREF?", trace);
        break;
        case RSSMF_SENSE_POWER_DISP_POWER_REF:
            sprintf (buffer, "TRAC%ld:POW:SWE:MEAS:POW:REF?", trace);
        break;
        case RSSMF_SENSE_POWER_DISP_POWER_LREF:
            sprintf (buffer, "TRAC%ld:POW:SWE:MEAS:POW:LREF?", trace);
        break;
        case RSSMF_SENSE_POWER_DISP_POWER_MAX:
            sprintf (buffer, "TRAC%ld:POW:SWE:MEAS:POW:MAX?", trace);
        break;
        case RSSMF_SENSE_POWER_DISP_POWER_MIN:
            sprintf (buffer, "TRAC%ld:POW:SWE:MEAS:POW:MIN?", trace);
        break;
        case RSSMF_SENSE_POWER_DISP_POWER_PULSE_BASE:
            sprintf (buffer, "TRAC%ld:POW:SWE:MEAS:POW:PULS:BASE?", trace);
        break;
        case RSSMF_SENSE_POWER_DISP_POWER_PULSE_TOP:
            sprintf (buffer, "TRAC%ld:POW:SWE:MEAS:POW:PULS:TOP?", trace);
        break;
        case RSSMF_SENSE_POWER_DISP_PULSE_DCYCLE :
            sprintf (buffer, "TRAC%ld:POW:SWE:MEAS:PULS:DCYC?", trace);
        break;
        case RSSMF_SENSE_POWER_DISP_PULSE_DUR:
            sprintf (buffer, "TRAC%ld:POW:SWE:MEAS:PULS:DUR?", trace);
        break;
        case RSSMF_SENSE_POWER_DISP_PULSE_PERIOD:
            sprintf (buffer, "TRAC%ld:POW:SWE:MEAS:PULS:PER?", trace);
        break;
        case RSSMF_SENSE_POWER_DISP_PULSE_SEP:
            sprintf (buffer, "TRAC%ld:POW:SWE:MEAS:PULS:SEP?", trace);
        break;
        case RSSMF_SENSE_POWER_DISP_TRAN_NEG_DUR:
            sprintf (buffer, "TRAC%ld:POW:SWE:MEAS:TRAN:NEG:DUR?", trace);
        break;
        case RSSMF_SENSE_POWER_DISP_TRAN_NEG_OCC:
            sprintf (buffer, "TRAC%ld:POW:SWE:MEAS:TRAN:NEG:OCC?", trace);
        break;
        case RSSMF_SENSE_POWER_DISP_TRAN_NEG_OVER :
            sprintf (buffer, "TRAC%ld:POW:SWE:MEAS:TRAN:NEG:OVER?", trace);
        break;
        case RSSMF_SENSE_POWER_DISP_TRAN_POS_DUR:
            sprintf (buffer, "TRAC%ld:POW:SWE:MEAS:TRAN:POS:DUR?", trace);
        break;
        case RSSMF_SENSE_POWER_DISP_TRAN_POS_OCC:
            sprintf (buffer, "TRAC%ld:POW:SWE:MEAS:TRAN:POS:OCC?", trace);
        break;
        case RSSMF_SENSE_POWER_DISP_TRAN_POS_OVER:    
            sprintf (buffer, "TRAC%ld:POW:SWE:MEAS:TRAN:POS:OVER?", trace);
        break;
        default:
	        return rssmf_ParameterError (instrSession, "type");
    }
    
    return GETPARAMREAL64 (instrSession,
                               buffer,
                               pulseDataAnalysis);
}

/*===========================================================================*/
/* Function: Set Power Sensor Mathematics State
/* Purpose:  Activates / deactivates the trace mathematics mode for selected 
/*           sweep measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPowerSensorMathematicsState (ViSession instrSession,
                                                        ViInt32 trace,
                                                        ViInt32 sweepMode,
                                                        ViBoolean state)
{
    ViChar buffer[BUFFER_SIZE];
    
    CHECKVIINT32 (instrSession, trace, 1, 4);
    CHECKVIINT32 (instrSession, sweepMode, 0, 2);
    
  sprintf (buffer, "CALC:SWE:%s:MATH%ld:STAT", sweepModeArr[sweepMode], trace);
  
  return SETPARAMBOOL (instrSession,
                           buffer,
                 state);
}

/*===========================================================================*/
/* Function: Get Power Sensor Mathematics State
/* Purpose:  Queries state of the trace mathematics mode for selected 
/*           sweep measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerSensorMathematicsState (ViSession instrSession,
                                                        ViInt32 trace,
                                                        ViInt32 sweepMode,
                                                        ViBoolean *state)
{
    ViChar buffer[BUFFER_SIZE];
    
    CHECKVIINT32 (instrSession, trace, 1, 4);
    CHECKVIINT32 (instrSession, sweepMode, 0, 2);
    
  sprintf (buffer, "CALC:SWE:%s:MATH%ld:STAT?", sweepModeArr[sweepMode], trace);
  
  return GETPARAMBOOL (instrSession,
                           buffer,
                 state);
}

/*===========================================================================*/
/* Function: Set Power Sensor Mathematics Subtraction
/* Purpose:  Executes the subtraction of the operands 1 and 2 and assigns the
/*           result to the selected trace in selected measurement mode.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPowerSensorMathematicsSubtraction (ViSession instrSession,
                                                              ViInt32 resultTrace,
                                                              ViInt32 sweepMode,
                                                              ViInt32 firstOperand,
                                                              ViInt32 secondOperand)
{
    ViChar buffer[BUFFER_SIZE];
    
    CHECKVIINT32 (instrSession, resultTrace, 1, 4);
    CHECKVIINT32 (instrSession, sweepMode, 0, 2);
    CHECKVIINT32 (instrSession, firstOperand, 1, 4);
    CHECKVIINT32 (instrSession, secondOperand, 0, 4);
    
  if (secondOperand != 0)
    sprintf (buffer, "CALC:SWE:%s:MATH%ld:SUBT T%ldT%ld", sweepModeArr[sweepMode], resultTrace, firstOperand, secondOperand);
  else
    sprintf (buffer, "CALC:SWE:%s:MATH%ld:SUBT T%ldREF", sweepModeArr[sweepMode], resultTrace, firstOperand);
  
  return rssmf_sendCmd (instrSession, buffer);
}

/*===========================================================================*/
/* Function: Power Sensor Device
/* Purpose:  This function queries if a sensor is connected at the selected 
/*           port to the signal generator. The sensor is selected by suffix 
/*           1, 2 or 3 in key word SENSe or READ of the command header. 
/*           Suffix 1 denotes the sensor connected to the SENSOR connector, 
/*           suffix 2 the sensor connected first to one of the USB interfaces 
/*           and suffix 3 the sensor connected second to one of the USB 
/*           interfaces.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_PowerSensorDevice(
    ViSession   instrSession,
    ViInt32 sense,
    ViInt32*    device
)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "SENS%ld:POW:STAT:DEV?", sense);

    return GETPARAMINT32 (instrSession, 
                             buffer,
                             device);
}

/*===========================================================================*/
/* Function: Power Sensor Type
/* Purpose:  This function queries the type of sensor connected at the 
/*           selected port. The type is automatically detected.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_PowerSensorType(
    ViSession   instrSession,
    ViInt32 sense,
    ViChar _VI_FAR  type[]
)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "SENS%ld:POW:TYPE?", sense);

    return GETPARAMSTRING (instrSession, 
                              buffer,
                              type,
                              1024);
}

/*===========================================================================*/
/* Function: Power Read Power
/* Purpose:  This function retrieves the power measurement result of the 
/*           selected power sensor. The value is provided with the unit set 
/*           with command SENSe<[1]...3>:UNIT[:POWer]. 
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_PowerReadPower(
    ViSession   instrSession,
    ViInt32 read,
    ViReal64*   power
)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, read, 1, 3);
    
    sprintf (buffer, "READ%ld:POW?", read);

    return GETPARAMREAL64 (instrSession, 
                              buffer,
                              power);
}

/*===========================================================================*/ 
/* Function: Power Read Powers 
/* Purpose:  This function retrieves two power measurement results of the 
/*           selected power sensor. The values are provided with the units set 
/*           with command SENSe<[1]...3>:UNIT[:POWer]. 
/*===========================================================================*/ 
ViStatus _VI_FUNC rssmf_PowerReadPowers( 
    ViSession   instrSession, 
    ViInt32 read, 
    ViReal64*   avgPower, 
    ViReal64*   peakPower 
) 
{ 
    ViChar buffer[BUFFER_SIZE]; 
    ViReal64 values[2]; 
    INIT; 

    CHECKVIINT32 (instrSession, read, 1, 3); 
    
    sprintf (buffer, "READ%ld:POW?", read); 

    
    CHECKERR ( GETPARAMREAL64ARRAY (instrSession, 
                              buffer, 
                              values, 
                               2)); 
    *avgPower = values[0]; 
    *peakPower = values[1]; 
    
    return rssmf_status; 
} 

/*===========================================================================*/
/* Function: Power Sensor Version
/* Purpose:  This function queries the software version of the connected NRP 
/*           power sensor.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerSensorVersion(
    ViSession   instrSession,
    ViInt32 sense,
    ViChar _VI_FAR  version[]
)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "SENS%ld:POW:SVER?", sense);

    return GETPARAMSTRING (instrSession, 
                              buffer,
                              version,
                              1024);
}

/*===========================================================================*/
/* Function: Power Sensor Serial Number
/* Purpose:  This function queries the serial number of the sensor. 
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_PowerSensorSerialNumber(
    ViSession   instrSession,
    ViInt32 sense,
    ViChar _VI_FAR  serialNumber[]
)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "SENS%ld:POW:SNUM?", sense);

    return GETPARAMSTRING (instrSession, 
                              buffer,
                              serialNumber,
                              1024);
}

/*===========================================================================*/
/* Function: Set Initiate Power Measurement
/* Purpose:  This function activates/deactivates the continuous power 
/*           measurement by the R&S NRP-Z power sensors. 
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_SetInitiatePowerMeasurement(
    ViSession   instrSession,
    ViInt32 sense,
    ViBoolean   initPowerMeas
)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "INIT%ld:POW:CONT", sense);

    return SETPARAMBOOL (instrSession, 
                               buffer,
                               initPowerMeas);
}

/*===========================================================================*/
/* Function: Get Initiate Power Measurement
/* Purpose:  This function returns activation the continuous power 
/*           measurement by the R&S NRP-Z power sensors. 
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetInitiatePowerMeasurement(
    ViSession   instrSession,
    ViInt32 sense,
    ViBoolean*  initPowerMeas
)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "INIT%ld:POW:CONT?", sense);

    return GETPARAMBOOL (instrSession, 
                               buffer,
                               initPowerMeas);
}

/*===========================================================================*/
/* Function: Get Power Use SParameters
/* Purpose:  This function returns the state of usage of the s-parameters 
/*           correction data of the connected power sensor. 
/*           
/*           Note(s):
/*           (1) For power sensor with attenuator this command is 
/*           automatically set to ON.
/*           
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerUseSParameters(
    ViSession   instrSession,
    ViInt32 sense,
    ViBoolean*  useSParameters
)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "SENS%ld:POW:CORR:SPD:STAT?", sense);

    return GETPARAMBOOL (instrSession, 
                               buffer,
                               useSParameters);
}

/*===========================================================================*/
/* Function: Set Power Frequency
/* Purpose:  This function sets the RF frequency of the source if the user 
/*           source is selected (SENSe[:POWer]:SOURce USER.)
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPowerFrequency(
    ViSession   instrSession,
    ViInt32 sense,
    ViReal64    frequency
)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "SENS%ld:POW:FREQ", sense);

    return SETPARAMREAL64 (instrSession, 
                              buffer,
                              frequency,
                              0.0,0.0);
}

/*===========================================================================*/
/* Function: Get Power Frequency
/* Purpose:  This function returns the RF frequency of the source if the 
/*           user source is selected (SENSe[:POWer]:SOURce USER.)
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerFrequency(
    ViSession   instrSession,
    ViInt32 sense,
    ViReal64*   frequency
)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "SENS%ld:POW:FREQ?", sense);

    return GETPARAMREAL64 (instrSession, 
                              buffer,
                              frequency);
}

/*===========================================================================*/
/* Function: Set Power Offset
/* Purpose:  This function sets a level offset which is added to the 
/*           measured level value after activation with command 
/*           SENSe[:POWer]:OFFSet:STATe ON. This allows e.g. an attenuator in 
/*           the signal path to be taken into account.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPowerOffset(
    ViSession   instrSession,
    ViInt32 sense,
    ViReal64    offset
)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    CHECKVIREAL64 (instrSession, offset, -100.0, 100.0);
    
    sprintf (buffer, "SENS%ld:POW:OFFS %f", sense, offset);

    return rssmf_sendCmd (instrSession, buffer);
}

/*===========================================================================*/
/* Function: Get Power Offset
/* Purpose:  This function returns a level offset which is added to the 
/*           measured level value after activation with command 
/*           SENSe[:POWer]:OFFSet:STATe ON. This allows e.g. an attenuator in 
/*           the signal path to be taken into account.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerOffset(
    ViSession   instrSession,
    ViInt32 sense,
    ViReal64*   offset
)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "SENS%ld:POW:OFFS?", sense);

    return GETPARAMREAL64 (instrSession, 
                              buffer,
                              offset);
}

/*===========================================================================*/
/* Function: Set Power Offset State
/* Purpose:  This function activates/deactivates the addition of  the level 
/*           offset to the measured value. The level offset value is set with 
/*           command SENSe[:POWer]:OFFSet.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPowerOffsetState(
    ViSession   instrSession,
    ViInt32 sense,
    ViBoolean   offsetState
)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "SENS%ld:POW:OFFS:STAT", sense);

    return SETPARAMBOOL (instrSession, 
                               buffer,
                               offsetState);
}

/*===========================================================================*/
/* Function: Get Power Offset State
/* Purpose:  This function returns the state of activation the addition of  
/*           the level offset to the measured value. The level offset value 
/*           is set with command SENSe[:POWer]:OFFSet.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerOffsetState(
    ViSession   instrSession,
    ViInt32 sense,
    ViBoolean*  offsetState
)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "SENS%ld:POW:OFFS:STAT?", sense);

    return GETPARAMBOOL (instrSession, 
                               buffer,
                               offsetState);
}

/*===========================================================================*/
/* Function: Set Power Source
/* Purpose:  The command selects the signal source for the measurement. The 
/*           RF signal or a user defined source can be selected.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPowerSource(
    ViSession   instrSession,
    ViInt32 sense,
    ViInt32 source
)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "SENS%ld:POW:SOUR", sense);

    return SETPARAMENUM (instrSession, 
                          buffer,
                          source,
                          powerSourceArr);
}

/*===========================================================================*/
/* Function: Get Power Source
/* Purpose:  The command queries the signal source for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerSource(
    ViSession   instrSession,
    ViInt32 sense,
    ViInt32*    source
)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "SENS%ld:POW:SOUR?", sense);

    return GETPARAMENUM (instrSession, 
                          buffer,
                          source,
                          powerSourceArr);
}

/*===========================================================================*/
/* Function: Set Power Unit
/* Purpose:  The command selects the unit used for result query with command 
/*           READ. The power sensor provides the measured value in Watt. In 
/*           which unit the measured value is returned is selected here
/*           and might be either Watt, dBm or dBuV.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPowerUnit(
    ViSession   instrSession,
    ViInt32 sense,
    ViInt32 unit
)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "SENS%ld:UNIT:POW", sense);

    return SETPARAMENUM (instrSession, 
                          buffer,
                          unit,
                          sensePowerUnitArr);
}

/*===========================================================================*/
/* Function: Get Power Unit
/* Purpose:  This function queries the unit used for result query with 
/*           command READ.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerUnit(
    ViSession   instrSession,
    ViInt32 sense,
    ViInt32*    unit
)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "SENS%ld:UNIT:POW?", sense);

    return GETPARAMENUM (instrSession, 
                          buffer,
                          unit,
                          sensePowerUnitArr);
}

/*===========================================================================*/
/* Function: Set Power Display Permanent State
/* Purpose:  This function switches on and off  the permanent indication of 
/*           the power measurement result in the upper right corner of the 
/*           block diagram. For each sensor, the type of sensor, the 
/*           connector, the measurement source and - if set - the offset is 
/*           indicated.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPowerDisplayPermanentState(
    ViSession   instrSession,
    ViInt32 sense,
    ViBoolean   permanentDisplay
)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "SENS%ld:POW:DISP:PERM:STAT", sense);

    return SETPARAMBOOL (instrSession, 
                               buffer,
                               permanentDisplay);
}

/*===========================================================================*/
/* Function: Get Power Display Permanent State
/* Purpose:  This function returns on and off state of the permanent 
/*           indication of the power measurement result in the upper right 
/*           corner of the block diagram. For each sensor, the type of 
/*           sensor, the connector, the measurement source and - if set - the 
/*           offset is indicated.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerDisplayPermanentState(
    ViSession   instrSession,
    ViInt32 sense,
    ViBoolean*  permanentDisplay
)
{
    ViChar buffer[BUFFER_SIZE];
    INIT;
    
    CHECKVIINT32 (instrSession, sense, 1, 3);
    
    sprintf (buffer, "SENS%ld:POW:DISP:PERM:STAT?", sense);

    return GETPARAMBOOL (instrSession, 
                               buffer,
                               permanentDisplay);
}

/*===========================================================================
 * Function: Set Power Sweep Hardcopy Device
 * Purpose:  This function selects the output device. The setting is fixed to
 *       FILE, i.e. the  hardcopy is stored in a file.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPowerSweepHardcopyDevice (ViSession instrSession,
                                                     ViInt32 hardcopyDevice)
{
    INIT;
    return SETPARAMENUM (instrSession,
                          "SENS:POW:SWE:HCOP:DEV",
                          hardcopyDevice,
                          hcopDeviceArr);    
}

/*===========================================================================
 * Function: Get Power Sweep Hardcopy Device
 * Purpose:  This function returns the output device. The setting is fixed to
 *       FILE, i.e. the  hardcopy is stored in a file.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerSweepHardcopyDevice (ViSession instrSession,
                                                     ViInt32 *hardcopyDevice)
{
    INIT;
    return GETPARAMENUM (instrSession,
                          "SENS:POW:SWE:HCOP:DEV?",
                          hardcopyDevice,
                          hcopDeviceArr);
}

/*===========================================================================
 * Function: Set Power Sweep Hardcopy Image Size
 * Purpose:  This function sets the size of the hardcopy in number of pixels.
 *       The first value of the size setting defines the width, the
 *       second value the height of the image.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPowerSweepHardcopyImageSize (ViSession instrSession,
                                                        ViInt32 imageSize)
{
    INIT;
    return SETPARAMENUM (instrSession,
                          "SENS:POW:SWE:HCOP:DEV:SIZE",
                          imageSize,
                          hcopImageSizeArr);    
}

/*===========================================================================
 * Function: Get Power Sweep Hardcopy Image Size
 * Purpose:  This function returns the size of the hardcopy in number of pixels.
 *       The first value of the size setting defines the width, the
 *       second value the height of the image.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerSweepHardcopyImageSize (ViSession instrSession,
                                                        ViInt32 *imageSize)
{
    INIT;
    return GETPARAMENUM (instrSession,
                          "SENS:POW:SWE:HCOP:DEV:SIZE?",
                          imageSize,
                          hcopImageSizeArr);    
}

/*===========================================================================
 * Function: Set Power Sweep Hardcopy Marker 
 * Purpose:  This function selects if the markers in the measurement diagram
 *       and the marker list below the diagram are also indicated in the
 *       hardcopy file.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPowerSweepHardcopyMarkerState (ViSession instrSession,
                                                          ViBoolean state)
{
    INIT;
    return SETPARAMBOOL (instrSession,
                               "SENS:POW:SWE:HCOP:ITEM:WIND:STAT:MARK:STAT",
                               state);
}

/*===========================================================================
 * Function: Get Power Sweep Hardcopy Marker 
 * Purpose:  This function returns if the markers in the measurement diagram
 *       and the marker list below the diagram are also indicated in the
 *       hardcopy file.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerSweepHardcopyMarkerState (ViSession instrSession,
                                                          ViBoolean *state)
{
    INIT;
    return GETPARAMBOOL (instrSession,
                               "SENS:POW:SWE:HCOP:ITEM:WIND:STAT:MARK:STAT?",
                               state);
}

/*===========================================================================
 * Function: Save Power Sweep Hardcopy 
 * Purpose:  This function triggers the generation of a hardcopy of the
 *       current measurement diagram.. The data is written into the file
 *       selected/created with the SENS:SWE:HCOP:FILE command.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_SavePowerSweepHardcopy (ViSession instrSession)
{
    INIT;
  return rssmf_sendCmd (instrSession,"SENS:POW:SWE:HCOP:EXEC");
}

/*===========================================================================
 * Function: Set Power Sweep Hardcopy CSV Decimal Header
 * Purpose:  This function defines whether each row (or column depending on
 *       the orientation) should be preceded by a header containing
 *       information about the trace (see also
 *       'SENSe[:POWer]:SWEep:HCOPy:DATA?').
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPowerSweepHardcopyCSVHeader (ViSession instrSession,
                                                        ViInt32 CSVHeader)
{
    INIT;
    return SETPARAMENUM (instrSession,
                          "SENS:POW:SWE:HCOP:DEV:LANG:CSV:HEAD",
                          CSVHeader,
                          hcopHeaderArr);    
}

/*===========================================================================
 * Function: Get Power Sweep Hardcopy CSV Decimal Header
 * Purpose:  This function returns whether each row (or column depending on
 *       the orientation) should be preceded by a header containing
 *       information about the trace (see also
 *       'SENSe[:POWer]:SWEep:HCOPy:DATA?').
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerSweepHardcopyCSVHeader (ViSession instrSession,
                                                        ViInt32 *CSVHeader)
{
    INIT;
    return GETPARAMENUM (instrSession,
                          "SENS:POW:SWE:HCOP:DEV:LANG:CSV:HEAD?",
                          CSVHeader,
                          hcopHeaderArr);    
}

/*===========================================================================
 * Function: Set Power Sweep Hardcopy CSV Orientation
 * Purpose:  This function defines the orientation of the X/Y value pairs.
 *       For examples on how the data are arranged see , section CSV
 *       Options Hardkey.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPowerSweepHardcopyCSVOrientation (ViSession instrSession,
                                                             ViInt32 CSVOrientation)
{
   INIT;
   return SETPARAMENUM (instrSession,
                          "SENS:POW:SWE:HCOP:DEV:LANG:CSV:ORI",
                          CSVOrientation,
                          hcopOrientationArr);    
}

/*===========================================================================
 * Function: Get Power Sweep Hardcopy CSV Orientation
 * Purpose:  This function returns the orientation of the X/Y value pairs.
 *       For examples on how the data are arranged see , section CSV
 *       Options Hardkey.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerSweepHardcopyCSVOrientation (ViSession instrSession,
                                                             ViInt32 *CSVOrientation)
{
    INIT;
    return GETPARAMENUM (instrSession,
                          "SENS:POW:SWE:HCOP:DEV:LANG:CSV:ORI?",
                          CSVOrientation,
                          hcopOrientationArr);    
}

/*===========================================================================
 * Function: Set Power Sweep Hardcopy CSV Column Separator
 * Purpose:  This function defines which character is to separate the values,
 *       either tabulator, semicolon, comma or blank.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPowerSweepHardcopyCSVColumnSeparator (ViSession instrSession,
                                                                 ViInt32 CSVColumnSeparator)
{
    INIT;
    return SETPARAMENUM (instrSession,
                          "SENS:POW:SWE:HCOP:DEV:LANG:CSV:COL:SEP",
                          CSVColumnSeparator,
                          hcopColumnSeparatorArr);    
}

/*===========================================================================
 * Function: Get Power Sweep Hardcopy CSV Column Separator
 * Purpose:  This function returns which character is to separate the values,
 *       either tabulator, semicolon, comma or blank.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerSweepHardcopyCSVColumnSeparator (ViSession instrSession,
                                                                 ViInt32 *CSVColumnSeparator)
{
    INIT;
    return GETPARAMENUM (instrSession,
                          "SENS:POW:SWE:HCOP:DEV:LANG:CSV:COL:SEP?",
                          CSVColumnSeparator,
                          hcopColumnSeparatorArr);    
}

/*===========================================================================
 * Function: Set Power Sweep Hardcopy CSV Decimal Point
 * Purpose:  This function defines which character should be used as the
 *       decimal point of the values, either dot or comma.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPowerSweepHardcopyCSVDecimalPoint (ViSession instrSession,
                                                              ViInt32 CSVDecimalPoint)
{
    INIT;
    return SETPARAMENUM (instrSession,
                          "SENS:POW:SWE:HCOP:DEV:LANG:CSV:DPO",
                          CSVDecimalPoint,
                          dexcDecimalSeparatorArr);    
}

/*===========================================================================
 * Function: Get Power Sweep Hardcopy CSV Decimal Point 
 * Purpose:  This function returns which character should be used as the
 *       decimal point of the values, either dot or comma.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerSweepHardcopyCSVDecimalPoint (ViSession instrSession,
                                                              ViInt32 *CSVDecimalPoint)
{
    INIT;
    return GETPARAMENUM (instrSession,
                          "SENS:POW:SWE:HCOP:DEV:LANG:CSV:DPO?",
                          CSVDecimalPoint,
                          dexcDecimalSeparatorArr);    
}

/*===========================================================================
 * Function: Get Power Sweep Hardcopy CSV Data
 * Purpose:  This function queries the measurement data directly. The data is
 *       transferred to the remote client as data stream, e.g. for
 *       further processing.
 *       Readable ASCII data is available for hardcopy language CSV. The
 *       representation of the values depends on the selected orientation
 *       for the CSV format.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerSweepHardcopyCSVData (ViSession instrSession,
                                                      ViString destination)
{
  return rssmf_readDataToFile (instrSession, "SENS:POW:SWE:HCOP:DATA?", destination); 
}

/*===========================================================================
 * Function: Set Power Sweep Hardcopy Automatic Naming State 
 * Purpose:  This function activates/deactivates automatic naming of the
 *       hardcopy files.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPowerSweepHardcopyAutomaticNamingState (ViSession instrSession,
                                                                   ViBoolean state)
{
    INIT;
    return SETPARAMBOOL (instrSession,
                               "SENS:POW:SWE:HCOP:FILE:NAME:AUTO:STAT",
                               state);
}

/*===========================================================================
 * Function: Get Power Sweep Hardcopy Automatic Naming State 
 * Purpose:  This function returns automatic naming of the hardcopy files.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerSweepHardcopyAutomaticNamingState (ViSession instrSession,
                                                                   ViBoolean *state)
{
    INIT;
    return GETPARAMBOOL (instrSession,
                               "SENS:POW:SWE:HCOP:FILE:NAME:AUTO:STAT?",
                               state);
}

/*===========================================================================
 * Function: Get Power Sweep Hardcopy Automatic File Name 
 * Purpose:  This function returns the file name that what generated using
 *       the automatic naming settings.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerSweepHardcopyAutomaticFileName (ViSession instrSession,
                                                                ViChar fileName[])
{
    INIT;
    return GETPARAMSTRING (instrSession,
                              "SENS:POW:SWE:HCOP:FILE:NAME:AUTO:FILE?",
                              fileName,
                              1024);
}

/*===========================================================================
 * Function: Set Power Sweep Hardcopy Automatic Directory
 * Purpose:  This function defines the directory into which the hardcopy
 *       files will be stored if auto naming is activated
 *       (SENS:SWE:HCOP:FILE:AUTO:STAT ON).
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPowerSweepHardcopyAutomaticDirectory (ViSession instrSession,
                                                                 ViString directoryName)
{
    INIT;
    
    return SETPARAMSTRINGQUOTED (instrSession,
                              "SENS:POW:SWE:HCOP:FILE:NAME:AUTO:DIR",
                              "'",
                              directoryName);
}

/*===========================================================================
 * Function: Get Power Sweep Hardcopy Automatic Directory 
 * Purpose:  This function returns the directory into which the hardcopy
 *       files will be stored if auto naming is activated
 *       (SENS:SWE:HCOP:FILE:AUTO:STAT ON).
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerSweepHardcopyAutomaticDirectory (ViSession instrSession,
                                                                 ViChar directoryName[])
{
    INIT;
  
    return GETPARAMSTRING (instrSession,
                              "SENS:POW:SWE:HCOP:FILE:NAME:AUTO:DIR?",
                              directoryName,
                              1204);
}

/*===========================================================================
 * Function: Delete Power Sweep Hardcopy Image Files 
 * Purpose:  This function deletes all files with extensions "bmp", "img",
 *       "png", "xpm" and "csv" in the directory set for automatic
 *       naming.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_DeletePowerSweepHardcopyImageFiles (ViSession instrSession)
{
    INIT;

  return rssmf_sendCmd (instrSession,
                    "SENS:POW:SWE:HCOP:FILE:NAME:AUTO:DIR:CLE");
}

/*===========================================================================
 * Function: Set Power Sweep Hardcopy Automatic File Date State 
 * Purpose:  This function activates/deactivates the usage of the
 *       day/month/year in the automatic file name.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPowerSweepHardcopyAutomaticFileDateState (ViSession instrSession,
                                                                     ViInt32 fileNamePart,
                                                                     ViBoolean state)
{
    INIT;
    
    CHECKVIINT32 (instrSession, fileNamePart, 0, 2);
    
    switch (fileNamePart){
        case RSSMF_HCOPY_AUTO_FILE_DAY:
            CHECKERR (SETPARAMBOOL (instrSession,
                               "SENS:POW:SWE:HCOP:FILE:NAME:AUTO:FILE:DAY:STAT",
                               state));
        break;
        case RSSMF_HCOPY_AUTO_FILE_MONTH:
            CHECKERR (SETPARAMBOOL (instrSession,
                               "SENS:POW:SWE:HCOP:FILE:NAME:AUTO:FILE:MONTH:STAT",
                               state));
        break;                         
        case RSSMF_HCOPY_AUTO_FILE_YEAR:
            CHECKERR (SETPARAMBOOL (instrSession,
                               "SENS:POW:SWE:HCOP:FILE:NAME:AUTO:FILE:YEAR:STAT",
                               state));
        break;
    }
  
    return rssmf_status;
}

/*===========================================================================
 * Function: Get Power Sweep Hardcopy Automatic File Date State 
 * Purpose:  This function returns the usage of the
 *       day/month/year in the automatic file name.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerSweepHardcopyAutomaticFileDateState (ViSession instrSession,
                                                                     ViInt32 fileNamePart,
                                                                     ViBoolean *state)
{
    INIT;

    CHECKVIINT32 (instrSession, fileNamePart, 0, 2);
    
    switch (fileNamePart){
        case RSSMF_HCOPY_AUTO_FILE_DAY:
            CHECKERR (GETPARAMBOOL (instrSession,
                               "SENS:POW:SWE:HCOP:FILE:NAME:AUTO:FILE:DAY:STAT?",
                               state));
        break;
        case RSSMF_HCOPY_AUTO_FILE_MONTH:
            CHECKERR (GETPARAMBOOL (instrSession,
                               "SENS:POW:SWE:HCOP:FILE:NAME:AUTO:FILE:MONTH:STAT?",
                               state));
        break;                         
        case RSSMF_HCOPY_AUTO_FILE_YEAR:
            CHECKERR (GETPARAMBOOL (instrSession,
                               "SENS:POW:SWE:HCOP:FILE:NAME:AUTO:FILE:YEAR:STAT?",
                               state));
        break;
    }
    return rssmf_status;
}

/*===========================================================================
 * Function: Get Power Sweep Hardcopy Automatic File Date 
 * Purpose:  This function queries the day/month/year part in the automatic
 *       file name.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerSweepHardcopyAutomaticFileDate (ViSession instrSession,
                                                                ViInt32 fileNamePart,
                                                                ViChar part[])
{
    INIT;
    
    CHECKVIINT32 (instrSession, fileNamePart, 0, 2);
    
    switch (fileNamePart){
        case RSSMF_HCOPY_AUTO_FILE_DAY:
            CHECKERR (GETPARAMSTRING (instrSession,
                "SENS:POW:SWE:HCOP:FILE:NAME:AUTO:FILE:DAY?",
                part,
                              1024));
        break;
        case RSSMF_HCOPY_AUTO_FILE_MONTH:
            CHECKERR (GETPARAMSTRING (instrSession,
                "SENS:POW:SWE:HCOP:FILE:NAME:AUTO:FILE:MONTH?",
                              part,
                              1024));
        break;                         
        case RSSMF_HCOPY_AUTO_FILE_YEAR:
            CHECKERR (GETPARAMSTRING (instrSession,
                "SENS:POW:SWE:HCOP:FILE:NAME:AUTO:FILE:YEAR?",
                              part,
                              1024));
        break;
    } 
    return rssmf_status; 
}

/*===========================================================================
 * Function: Set Power Sweep Hardcopy Automatic File Prefix State 
 * Purpose:  This function activates/deactivates the usage of the prefix in
 *       the automatic file name.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPowerSweepHardcopyAutomaticFilePrefixState (ViSession instrSession,
                                                                       ViBoolean state)
{
    INIT;
    return SETPARAMBOOL (instrSession,
                               "SENS:POW:SWE:HCOP:FILE:NAME:AUTO:PREF:STAT",
                               state);
}

/*===========================================================================
 * Function: Get Power Sweep Hardcopy Automatic File Prefix State 
 * Purpose:  This function returns the usage of the prefix in
 *       the automatic file name.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerSweepHardcopyAutomaticFilePrefixState (ViSession instrSession,
                                                                       ViBoolean *state)
{
    INIT;
    return GETPARAMBOOL (instrSession,
                               "SENS:POW:SWE:HCOP:FILE:NAME:AUTO:PREF:STAT?",
                               state);
}

/*===========================================================================
 * Function: Set Power Sweep Hardcopy Automatic File Prefix 
 * Purpose:  This function defines the prefix part in the automatic file
 *       name.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPowerSweepHardcopyAutomaticFilePrefix (ViSession instrSession,
                                                                  ViString prefix)
{
    INIT;
    return SETPARAMSTRINGQUOTED (instrSession,
                              "SENS:POW:SWE:HCOP:FILE:NAME:AUTO:FILE:PREF",
                              "'",
                              prefix); 
}

/*===========================================================================
 * Function: Get Power Sweep Hardcopy Automatic File Prefix 
 * Purpose:  This function returns the prefix part in the automatic file
 *       name.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerSweepHardcopyAutomaticFilePrefix (ViSession instrSession,
                                                                  ViChar prefix[])
{
    INIT;
    return GETPARAMSTRING (instrSession,
                              "SENS:POW:SWE:HCOP:FILE:NAME:AUTO:FILE:PREF?",
                              prefix,
                              1024); 
}

/*===========================================================================
 * Function: Get Power Sweep Hardcopy Automatic File Number 
 * Purpose:  This function  queries the generated number in the automatic
 *       file name.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerSweepHardcopyAutomaticFileNumber (ViSession instrSession,
                                                                  ViInt32 *number)
{
    INIT;
    return GETPARAMINT32 (instrSession,
                              "SENS:POW:SWE:HCOP:FILE:NAME:AUTO:FILE:NUMB?",
                              number);        
}

/*****************************************************************************
 * Function: Set All RF Outputs State
 * Purpose:  This function switches on or off all RF output signals of the 
 *           instrument.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetAllRFOutputsState(
    ViSession   instrSession,
    ViBoolean   state
)
{
    INIT;

    return SETPARAMBOOL (instrSession,
                               "OUTP:ALL:STAT",
                               state);
}

/*****************************************************************************
 * Function: Configure Fixed RF Level
 * Purpose:  This function sets all parameters of fixed RF level and changes 
 *           the mode to fixed RF level.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_confRFLevel(
    ViSession   instrSession,
    ViReal64    amplitude,
    ViReal64    offset,
    ViReal64    limit,
    ViInt32 powerResolution,
    ViBoolean   variationActive,
    ViReal64    variationStep,
    ViInt32 rfLevelonRecall
)
{
    ViChar      buffer[BUFFER_SIZE];
    INIT;
    
    CHECKERR (rssmf_sendCmd (instrSession, "SOUR:POW:MODE FIX"));
    
    
    CHECKVIREAL64 (instrSession, offset, -100.0, 100.0);

    sprintf (buffer, ":POW %f;:POW:LIM %f;:POW:OFFS %f", amplitude, limit, offset);

    CHECKERR (rssmf_sendCmd (instrSession, buffer));

    CHECKERR (rssmf_SetRFPowerResolution (instrSession, powerResolution));    
    CHECKERR (rssmf_SetRFLevelVariationActive (instrSession, variationActive));    
    CHECKERR (rssmf_SetRFLevelVariationStep (instrSession, variationStep));    
    CHECKERR (rssmf_SetRFLevelonRecall (instrSession, rfLevelonRecall));    
    RETURN;
    
}

/*****************************************************************************
 * Function: Set RF Amplitude
 * Purpose:  This function sets the RF output level in CW mode.
 *           
 *           As with the Level value entered in the header, the OFFSet value 
 *           is also taken into consideration with this command.
 *           
 *           The specified value range is therefore only effective if 
 *           :SOURce:POWer:OFFSet is set to 0. The value range for other OFFSet 
 *           values can be calculated using the following formula:
 *           
 *           Minimum level + OFFSet ... Maximum level + OFFSet
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetRFAmplitude(
    ViSession   instrSession,
    ViReal64    amplitude
)
{
    INIT;

    return SETPARAMREAL64 (instrSession,
                              "SOUR:POW",
                              amplitude,
                              0.0,0.0);
}

/*****************************************************************************
 * Function: Get RF Amplitude
 * Purpose:  This function returns the RF output level in CW mode.
 *           
 *           As with the Level value entered in the header, the OFFSet value 
 *           is also taken into consideration with this function.
 *           
 *           The specified value range is therefore only effective if 
 *           :SOURce:POWer:OFFSet is set to 0. The value range for other OFFSet 
 *           values can be calculated using the following formula:
 *           
 *           Minimum level + OFFSet ... Maximum level + OFFSet
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetRFAmplitude(
    ViSession   instrSession,
    ViReal64*   amplitude
)
{
    INIT;

    return GETPARAMREAL64 (instrSession,
                              "SOUR:POW?",
                              amplitude);
}

/*****************************************************************************
 * Function: Set RF Amplitude Ignore Offset
 * Purpose:  This functions sets RF level.
 *           The RF output level entered and displayed here corresponds to the 
 *           output level at the RF connector, that is any offset entry is not 
 *           taken into consideration
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetRFAmplitudeIgnoreOffset(
    ViSession   instrSession,
    ViReal64    amplitude
)
{
    INIT;

    return SETPARAMREAL64 (instrSession,
                              "SOUR:POW:POW",
                              amplitude,
                              -130.0,30.0);
}

/*****************************************************************************
 * Function: Set RF Level Limit
 * Purpose:  This function limits the maximum RF output level in CW and SWEEP 
 *           mode. It does not influence the LEVEL display or the response to 
 *           the POW? query command.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetRFLevelLimit(
    ViSession   instrSession,
    ViReal64    limit
)
{
    INIT;

    return SETPARAMREAL64 (instrSession,
                              "SOUR:POW:LIM",
                              limit,
                              0.0,0.0);
}

/*****************************************************************************
 * Function: Get RF Level Limit
 * Purpose:  This function returns the RF output level limits in CW and SWEEP 
 *           mode.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetRFLevelLimit(
    ViSession   instrSession,
    ViReal64*   limit
)
{
    INIT;

    return GETPARAMREAL64 (instrSession,
                              "SOUR:POW:LIM?",
                              limit);
}

/*****************************************************************************
 * Function: Set RF Level Offset
 * Purpose:  This function specifies the constant level offset of a downstream 
 *           attenuator/amplifier. If a level offset is entered, the level 
 *           entered with :POWer no longer corresponds to the RF output level. 
 *           The following correlation applies:
 *           
 *           POWer = RF output level + POWer:OFFSet.
 *           
 *           Entering a level offset does not change the RF output level, but 
 *           rather the query value of :POWer.
 *           
 *           Only dB is permitted as the unit here. The linear units (V, W, 
 *           etc.) are not permitted. 
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetRFLevelOffset(
    ViSession   instrSession,
    ViReal64    offset
)
{
    INIT;

    return SETPARAMREAL64 (instrSession,
                              "SOUR:POW:OFFS",
                              offset,
                              0.0,0.0);
}

/*****************************************************************************
 * Function: Get RF Level Offset
 * Purpose:  This function returns the constant level offset of a downstream 
 *           attenuator/amplifier. If a level offset is entered, the level 
 *           entered with :POWer no longer corresponds to the RF output level. 
 *           The following correlation applies:
 *           
 *           POWer = RF output level + POWer:OFFSet.
 *           
 *           Entering a level offset does not change the RF output level, but 
 *           rather the query value of :POWer.
 *           
 *           Only dB is permitted as the unit here. The linear units (V, W, 
 *           etc.) are not permitted. 
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetRFLevelOffset(
    ViSession   instrSession,
    ViReal64*   offset
)
{
    INIT;

    return GETPARAMREAL64 (instrSession,
                              "SOUR:POW:OFFS?",
                              offset);
}

/*****************************************************************************
 * Function: Set RF Power Resolution
 * Purpose:  This function selects the resolution for the level settings.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetRFPowerResolution(
    ViSession   instrSession,
    ViInt32 powerResolution
)
{
    INIT;

    return SETPARAMENUM (instrSession,
                          "SOUR:POW:RES",
                          powerResolution,
                          powerResolutionArr);
}

/*****************************************************************************
 * Function: Get RF Power Resolution
 * Purpose:  This function queries the resolution for the level settings.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetRFPowerResolution(
    ViSession   instrSession,
    ViInt32*    powerResolution
)
{
    INIT;

    return GETPARAMENUM (instrSession,
                          "SOUR:POW:RES?",
                          powerResolution,
                          powerResolutionArr);
}

/*****************************************************************************
 * Function: Set RF Level on Recall
 * Purpose:  This function determines whether the current level is retained or 
 *           whether the stored level setting is adopted when an instrument 
 *           configuration is loaded.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetRFLevelonRecall(
    ViSession   instrSession,
    ViInt32 rfLevelonRecall
)
{
    INIT;

    return SETPARAMENUM (instrSession,
                          "SOUR:POW:RCL",
                          rfLevelonRecall,
                          onRecallArr);
}

/*****************************************************************************
 * Function: Get RF Level on Recall
 * Purpose:  This function returns whether the current level is retained or 
 *           whether the stored level setting is adopted when an instrument 
 *           configuration is loaded.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetRFLevelonRecall(
    ViSession   instrSession,
    ViInt32*    rfLevelonRecall
)
{
    INIT;

    return GETPARAMENUM (instrSession,
                          "SOUR:POW:RCL?",
                          rfLevelonRecall,
                          onRecallArr);
}

/*****************************************************************************
 * Function: Set RF Level Variation Active
 * Purpose:  This function activates (USER) or deactivates (DECimal) the 
 *           user-defined step width used when varying the level value with the 
 *           level values UP/DOWN. This function is linked to setting Variation 
 *           Active for manual control, i.e. the command also 
 *           activates/deactives the user-defined step width used when varying 
 *           the level value with the rotary knob.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetRFLevelVariationActive(
    ViSession   instrSession,
    ViBoolean   variationActive
)
{
    INIT;

    return SETPARAMENUM (instrSession,
                          "SOUR:POW:STEP:MODE",
                          (ViInt32) variationActive,
                          variationArr);
}

/*****************************************************************************
 * Function: Get RF Level Variation Active
 * Purpose:  This function returns level step mode. This function is linked to 
 *           setting Variation Active for manual control, i.e. the function 
 *           also activates/deactives the user-defined step width used when 
 *           varying the level value with the rotary knob.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetRFLevelVariationActive(
    ViSession   instrSession,
    ViBoolean*  variationActive
)
{
    ViStatus    rssmf_status;
    ViInt32     variation = 0;
    
    CHECKERR (GETPARAMENUM (instrSession,
                             "SOUR:POW:STEP:MODE?",
                             &variation,
                             variationArr));
    if (variationActive != NULL)
        *variationActive = (ViBoolean)((variation == 1)? 1 : 0);

    return rssmf_status;
}

/*****************************************************************************
 * Function: Set RF Level Variation Step
 * Purpose:  This function sets the step width for the level setting if UP and 
 *           DOWN are used as the level values and variation mode 
 *           :SOUR:POW:STEP:MODE USER is selected. This function is linked to 
 *           setting Variation Step for manual control, i.e. the function also 
 *           sets the step width of the rotary knob for Variation Active on.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetRFLevelVariationStep(
    ViSession   instrSession,
    ViReal64    variationStep
)
{
    INIT;

    return SETPARAMREAL64 (instrSession,
                              "SOUR:POW:STEP:INCR",
                              variationStep,
                              0.0,100.0);
}

/*****************************************************************************
 * Function: Get RF Level Variation Step
 * Purpose:  This function returns the step width for the level setting if UP 
 *           and DOWN are used as the level values and variation mode 
 *           :SOUR:POW:STEP:MODE USER is selected. This function is linked to 
 *           setting Variation Step for manual control, i.e. the function also 
 *           sets the step width of the rotary knob for Variation Active on.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetRFLevelVariationStep(
    ViSession   instrSession,
    ViReal64*   variationStep
)
{
    INIT;

    return GETPARAMREAL64 (instrSession,
                              "SOUR:POW:STEP:INCR?",
                              variationStep);
}

/*****************************************************************************
 * Function: Set Power On State
 * Purpose:  This function selects the state which the RF output assumes when 
 *           the instrument is switched on.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetRFPowerOnState(
    ViSession   instrSession,
    ViInt32 powerOnState
)
{
    INIT;

    return SETPARAMENUM (instrSession,
                          "OUTP:PON",
                          powerOnState,
                          powerOnStateArr);
}

/*****************************************************************************
 * Function: Get Power On State
 * Purpose:  This function returns the state which the RF output assumes when 
 *           the instrument is switched on.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetRFPowerOnState(
    ViSession   instrSession,
    ViInt32*    powerOnState
)
{
    INIT;

    return GETPARAMENUM (instrSession,
                          "OUTP:PON?",
                          powerOnState,
                          powerOnStateArr);
}

/*****************************************************************************
 * Function: Set ALC State
 * Purpose:  This function activates/deactivates automatic level control. 
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetALCState(
    ViSession   instrSession,
    ViBoolean alcState
)
{
    INIT;

    return SETPARAMBOOL (instrSession,
                               "SOUR:POW:ALC",
                               alcState);
}

/*****************************************************************************
 * Function: Get ALC State
 * Purpose:  This function state of the automatic level control. 
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetALCState(
    ViSession   instrSession,
    ViBoolean*    alcState
)
{
    INIT;

    return GETPARAMBOOL (instrSession,
                               "SOUR:POW:ALC?",
                               alcState);
}

/*****************************************************************************
 * Function: Set ALC RF Power During Power Search
 * Purpose:  This function activates/deactivates the RF output during the 
 *           power search.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetALCRFPowerDuringPowerSearch(
    ViSession   instrSession,
    ViInt32 rfPowerDuringSearch
)
{
    INIT;

    return SETPARAMENUM (instrSession,
                          "OUTP:ALC:SEAR:MODE",
                          rfPowerDuringSearch,
                          rfPowerDuringSearchArr);
}

/*****************************************************************************
 * Function: Get ALC RF Power During Power Search
 * Purpose:  This function queries state of the RF output during the power 
 *           search.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetALCRFPowerDuringPowerSearch(
    ViSession   instrSession,
    ViInt32*    rfPowerDuringSearch
)
{
    INIT;

    return GETPARAMENUM (instrSession,
                          "OUTP:ALC:SEAR:MODE?",
                          rfPowerDuringSearch,
                          rfPowerDuringSearchArr);
}

/*****************************************************************************
 * Function: ALC Search Once
 * Purpose:  This function briefly activates level control for correction 
 *           purposes. 
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_ALCSearchOnce(
    ViSession   instrSession
)
{
    return rssmf_sendCmd (instrSession, "SOUR:POW:ALC:SONC");
}

/*****************************************************************************
 * Function: Set ALC Detector
 * Purpose:  Selects the detector for level control. 
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetALCDetector (ViSession instrSession,
                                        ViInt32 detector)
{
    return SETPARAMENUM (instrSession,
                          "POW:ALC:SOUR",
                          detector,
                          ALCDetectorArr);
}

/*****************************************************************************
 * Function: Get ALC Detector
 * Purpose:  Queries the detector for level control. 
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetALCDetector (ViSession instrSession,
                                        ViInt32 *detector)
{
    return GETPARAMENUM (instrSession,
                          "POW:ALC:SOUR?",
                          detector,
                          ALCDetectorArr);
}

/*****************************************************************************
 * Function: Set ALC Power Sensor Type
 * Purpose:  Selects the power meter used for external level control. 
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetALCPowerSensorType (ViSession instrSession,
                                               ViInt32 powerSensorType)
{
    return SETPARAMENUM (instrSession,
                          "POW:ALC:PMET:TYPE",
                          powerSensorType,
                          powerSensorTypeArr);
}

/*****************************************************************************
 * Function: Get ALC Power Sensor Type
 * Purpose:  Queries the power meter used for external level control. 
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetALCPowerSensorType (ViSession instrSession,
                                               ViInt32 *powerSensorType)
{
    return GETPARAMENUM (instrSession,
                          "POW:ALC:PMET:TYPE?",
                          powerSensorType,
                          powerSensorTypeArr);
}

/*****************************************************************************
 * Function: Set ALC Reference Voltage
 * Purpose:  Sets the reference voltage for external power control. 
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetALCReferenceVoltage (ViSession instrSession,
                                                ViReal64 referenceVoltage)
{
    return SETPARAMREAL64 (instrSession,
                              "POW:ALC:REF",
                              referenceVoltage,
                              0.0, 2.5);
}

/*****************************************************************************
 * Function: Get ALC Reference Voltage
 * Purpose:  Queries the reference voltage for external power control. 
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetALCReferenceVoltage (ViSession instrSession,
                                                ViReal64 *referenceVoltage)
{
    return GETPARAMREAL64 (instrSession,
                              "POW:ALC:REF?",
                              referenceVoltage);
}

/*****************************************************************************
 * Function: Set User Correction Data State
 * Purpose:  This function activates/deactivates level correction. Level 
 *           correction is performed using the table which has been selected 
 *           with the command CORRection:CSET:SELect.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetUserCorrectionDataState(
    ViSession   instrSession,
    ViBoolean   correctionState
)
{
    return SETPARAMBOOL (instrSession,
                               "SOUR:CORR",
                               correctionState);
}

/*****************************************************************************
 * Function: Get User Correction Data State
 * Purpose:  This function queries state of the level correction. Level 
 *           correction is performed using the table which has been selected 
 *           with the command CORRection:CSET:SELect.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetUserCorrectionDataState(
    ViSession   instrSession,
    ViBoolean*  correctionState
)
{
    INIT;

    return GETPARAMBOOL (instrSession,
                               "SOUR:CORR?",
                               correctionState);
}

/*****************************************************************************
 * Function: Get User Correction Current Value
 * Purpose:  This function requests the current value for user correction.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetUserCorrectionCurrentValue(
    ViSession   instrSession,
    ViReal64*   correctionState
)
{
    INIT;

    return GETPARAMREAL64 (instrSession,
                              "SOUR:CORR:VAL?",
                              correctionState);
}

/*****************************************************************************
 * Function: Trigger User Correction Current Measurement
 * Purpose:  Triggers the external measurement of the user correction of the level
 *           according to the user defined frequencies.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_TriggerUserCorrectionMeasurement (ViSession instrSession)
{
    return rssmf_sendCmd (instrSession, "SOUR:CORR:MEAS");
}

/*****************************************************************************
 * Function: Get User Correction Data Catalog
 * Purpose:  This function requests a list of user correction tables. The 
 *           individual lists are separated by commas. 
 *           
 *           The lists are stored with the fixed file extensions *.uco in a 
 *           directory of the user's choice. The directory applicable to the 
 *           commands is defined with the command MMEMory:CDIR. A path can also 
 *           be specified in command :SOUR:CORR:CSET:CAT?, in which case the 
 *           files in the specified folder are read.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetUserCorrectionDataCatalog(
    ViSession   instrSession,
    ViString    directoryPath,
    ViInt32 arraySize,
    ViChar _VI_FAR catalogList[]
)
{
    ViChar buffer[BUFFER_SIZE];

    if (!directoryPath)
        strncpy (buffer, "CORR:CSET:CAT?;*OPC?", (size_t)BUFFER_SIZE);
    else
        sprintf (buffer, "CORR:CSET:CAT? '%s'", directoryPath);

    return rssmf_getCatalog (instrSession,
                             buffer,
                             (ViUInt32) arraySize,
                             catalogList,"catalogList");
}

/*****************************************************************************
 * Function: Set User Correction Data Table
 * Purpose:  This function selects the table for user correction. Level 
 *           correction must also be activated with the command 
 *           [OURce:CORRection:CSET:STATe ON.
 *           
 *           The lists are stored with the fixed file extensions *.uco in a 
 *           directory of the user's choice. The directory applicable to the 
 *           commands is defined with the command MMEMory:CDIR. A path can also 
 *           be specified in command :SOUR:CORR:CSET:SEL, in which case the 
 *           files in the specified folder are selected.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetUserCorrectionDataTable(
    ViSession   instrSession,
    ViString    correctionTable
)
{
    INIT;

    return SETPARAMSTRINGQUOTED (instrSession,
                                    "SOUR:CORR:CSET",
                                    "'",
                                    correctionTable);
}

/*****************************************************************************
 * Function: Get User Correction Data Table
 * Purpose:  This function returns the table name for user correction. Level 
 *           correction must also be activated with the command 
 *           SOURce:CORRection:CSET:STATe ON.
 *           
 *           The lists are stored with the fixed file extensions *.uco in a 
 *           directory of the user's choice. The directory applicable to the 
 *           commands is defined with the command MMEMory:CDIR. A path can also 
 *           be specified in command :SOUR:CORR:CSET:SEL, in which case the 
 *           files in the specified folder are selected.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetUserCorrectionDataTable(
    ViSession   instrSession,
    ViChar _VI_FAR correctionTable[]
)
{
    return GETPARAMSTRING (instrSession,
                              "SOUR:CORR:CSET?",
                              correctionTable,
                              128);
}

/*****************************************************************************
 * Function: Set User Correction Data Frequency Values
 * Purpose:  This function transfers the frequency data to the table selected 
 *           with :CORRection:CSET:SELect. 
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetUserCorrectionDataFrequencyValues(
    ViSession   instrSession,
    ViInt32 arraySize,
    ViReal64 _VI_FAR frequencyValues[]
)
{
    ViChar* pbuffer;
    ViChar* p2buf;
    ViInt32 i;
    ViStatus rssmf_status;

    CHECKNULL (frequencyValues);
    p2buf = pbuffer = (ViChar*) malloc ((size_t) arraySize * 20 + 20);

    p2buf += sprintf (pbuffer, "CORR:CSET:DATA:FREQ ");

    for (i = 0; i < arraySize; i++)
        p2buf += sprintf (p2buf, "%f,", frequencyValues[i]);

    *--p2buf = '\0';

    CHECKERR (rssmf_sendCmd (instrSession, pbuffer));
    free (pbuffer);
    
    return rssmf_status;
}

/*****************************************************************************
 * Function: Get User Correction Data Frequency Values
 * Purpose:  This function queries the frequency data from the table selected 
 *           with :CORRection:CSET:SELect.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetUserCorrectionDataFrequencyValues(
    ViSession   instrSession,
    ViInt32 arraySize,
    ViReal64 _VI_FAR frequencyValues[]
)
{
    INIT;

    return GETPARAMREAL64ARRAY (instrSession,
                                   "CORR:CSET:DATA:FREQ?",
                                   frequencyValues,
                                   arraySize);
}

/*****************************************************************************
 * Function: Get User Correction Data Number of Frequency Values
 * Purpose:  This function queries the number of frequency values in the table 
 *           selected with :CORRection:CSET:SELect.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetUserCorrectionDataNumberofFrequencyValues(
    ViSession   instrSession,
    ViInt32*    numberofFrequencyValues
)
{
    INIT;

    return GETPARAMINT32 (instrSession,
                             "CORR:CSET:DATA:FREQ:POIN?",
                             numberofFrequencyValues);
}

/*****************************************************************************
 * Function: Set User Correction Data Level Values
 * Purpose:  This function transfers the level correction data to the table 
 *           selected with :CORRection:CSET:SELect.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetUserCorrectionDataLevelValues(
    ViSession   instrSession,
    ViInt32 arraySize,
    ViReal64 _VI_FAR  levelValues[]
)
{
    ViChar* pbuffer;
    ViChar* p2buf;
    ViInt32 i;
    ViStatus rssmf_status;

    CHECKNULL (levelValues);
    p2buf = pbuffer = malloc ((size_t) arraySize * 20 + 20);

    p2buf += sprintf (pbuffer, "CORR:CSET:DATA:POW ");

    for (i = 0; i < arraySize; i++)
        p2buf += sprintf (p2buf, "%f,", levelValues[i]);

    *--p2buf = '\0';

    CHECKERR (rssmf_sendCmd (instrSession, pbuffer));
    free (pbuffer);
    
    return rssmf_status;
}

/*****************************************************************************
 * Function: Get User Correction Data Level Values
 * Purpose:  This function queries the level correction data of the table 
 *           selected with :CORRection:CSET:SELect.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetUserCorrectionDataLevelValues(
    ViSession   instrSession,
    ViInt32 arraySize,
    ViReal64 _VI_FAR  levelValues[]
)
{
    INIT;

    return GETPARAMREAL64ARRAY (instrSession,
                                   "CORR:CSET:DATA:POW?",
                                   levelValues,
                                   arraySize);
}

/*****************************************************************************
 * Function: Get User Correction Data Number of Level Values
 * Purpose:  This function queries the number of level values in the selected 
 *           table. 
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetUserCorrectionDataNumberofLevelValues(
    ViSession   instrSession,
    ViInt32*    numberofLevelValues
)
{
    return GETPARAMINT32 (instrSession,
                             "CORR:CSET:DATA:POW:POIN?",
                             numberofLevelValues);
}

/*****************************************************************************
 * Function: Set User Correction Power Sensor Type
 * Purpose:  Selects the power meter used for user correction. 
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetUserCorrectionPowerSensorType (ViSession instrSession,
                                                          ViInt32 powerSensorType)
{
    return SETPARAMENUM (instrSession,
                          "CORR:PMET:TYPE",
                          powerSensorType,
                          powerSensorTypeArr);
}

/*****************************************************************************
 * Function: Get User Correction Power Sensor Type
 * Purpose:  Queries the power meter used for user correction. 
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetUserCorrectionPowerSensorType (ViSession instrSession,
                                                          ViInt32 *powerSensorType)
{
    return GETPARAMENUM (instrSession,
                          "CORR:PMET:TYPE?",
              powerSensorType,
                          powerSensorTypeArr);
}

/*============================================================================
 * Function: User Correction  Fill List With Sensor
 * Purpose:  This function fills the selected user correction list with the
 *           level values measured by the power sensor for the given
 *           frequencies
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_UserCorrectionFillListWithSensor (ViSession instrSession,
                                                          ViInt32 sensor,
                              ViInt32 timeout)
{
  ViChar  buffer[BUFFER_SIZE] = "";
  
  INIT;

    CHECKVIINT32 (instrSession, sensor, 1, 3);
    
    sprintf (buffer, "SOUR:CORR:CSET:DATA:SENS%ld:POW:SONC;*OPC?", sensor);
  
  CHECKERR (rssmf_waitOPC (instrSession, buffer, buffer, timeout));
    
    return rssmf_status;
}

/*****************************************************************************
 * Function: User Correction Data Delete Table
 * Purpose:  This function deletes the specified table.
 *           
 *           The lists are stored with the fixed file extensions *.uco in a 
 *           directory of the user's choice. The directory applicable to the 
 *           commands is defined with the command MMEMory:CDIR. A path can also 
 *           be specified in command :SOUR:CORR:CSET:CAT?, in which case the 
 *           file in the specified folder is deleted.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_UserCorrectionDataDeleteTable(
    ViSession   instrSession,
    ViString    tableName
)
{
    INIT;

    return SETPARAMSTRINGQUOTED (instrSession,
                                    "CORR:CSET:DEL",
                                    "'",
                                    tableName);
}

/*****************************************************************************
 * Function: Set CORRection Import Export List Mode
 * Purpose:  This function sets the dexchange list mode.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetCORRectionImportExportListMode(
    ViSession   instrSession,
    ViInt32 listMode
)
{
    INIT;

    return SETPARAMENUM (instrSession,
                          "SOUR:CORR:DEXC:MODE",
                          listMode,
                          dexcListModeArr);
}

/*****************************************************************************
 * Function: Get CORRection Import Export List Mode
 * Purpose:  This function returns the dexchange list mode.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetCORRectionImportExportListMode(
    ViSession   instrSession,
    ViInt32*    listMode
)
{
    INIT;

    return GETPARAMENUM (instrSession,
                          "SOUR:CORR:DEXC:MODE?",
                          listMode,
                          dexcListModeArr);
}

/*****************************************************************************
 * Function: Set CORRection Import Export List File
 * Purpose:  This function calls the File Manager for selecting the list mode 
 *           list to be exported (source) into an ASCII file or the destination 
 *           for the ASCII file to be imported (destination) in. 
 *           
 *           The list mode files are stored with the fixed file extensions 
 *           *.lsw in a directory of the user's choice. The directory 
 *           applicable to the commands is defined with the command 
 *           MMEMory:CDIR. A path can also be specified in command 
 *           SOUR:LIST:DEXC:SEL, in which case the files are stored or loaded 
 *           in the specified directory.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetCORRectionImportExportListFile(
    ViSession   instrSession,
    ViString    sourceFile
)
{
    INIT;

    return SETPARAMSTRINGQUOTED (instrSession,
                                    "SOUR:CORR:DEXC:SEL",
                                    "'",
                                    sourceFile);
}

/*****************************************************************************
 * Function: Get CORRection Import Export List File
 * Purpose:  This function calls the File Manager for querying the list mode 
 *           list to be exported (source) into an ASCII file or the destination 
 *           for the ASCII file to be imported (destination) in.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetCORRectionImportExportListFile(
    ViSession   instrSession,
    ViChar _VI_FAR sourceFile[]
)
{
    INIT;

    return GETPARAMSTRING (instrSession,
                              "SOUR:CORR:DEXC:SEL?",
                              sourceFile,
                              128);
}

/*****************************************************************************
 * Function: CORRection Import Export Execute
 * Purpose:  This function starts the export or import of the selected file. 
 *           When import is selected, the ASCII file is imported as list mode 
 *           list.
 *           
 *           When export is selected, the list mode list is exported into the 
 *           selected ASCII file.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_CORRectionImportExportExecute(
    ViSession   instrSession
)
{
    INIT;

    return rssmf_sendCmd (instrSession, "SOUR:CORR:DEXC:EXEC");
}

/*****************************************************************************
 * Function: Set CORRection Import Export ASCII File
 * Purpose:  This function calls the File Manager for selecting the ASCII file 
 *           to be imported into a list mode list (source) or the ASCII file 
 *           the list mode list is exported (destination) in.
 *           
 *           The ASCII files are stored with the fixed file extensions *.txt 
 *           or *.csv in a directory of the user's choice. The directory 
 *           applicable to the commands is defined with the command 
 *           MMEMory:CDIR.  A path can also be specified in command 
 *           SOUR:CORR:DEXC:AFIL:SEL, in which case the files are stored or 
 *           loaded in the specified directory.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetCORRectionImportExportASCIIFile(
    ViSession   instrSession,
    ViString    asciiSourceFile
)
{
    INIT;

    return SETPARAMSTRINGQUOTED (instrSession,
                                    "SOUR:CORR:DEXC:AFIL:SEL",
                                    "'",
                                    asciiSourceFile);
}

/*****************************************************************************
 * Function: Get CORRection Import Export ASCII File
 * Purpose:  This function calls the File Manager for querying the ASCII file 
 *           to be imported into a list mode list (source) or the ASCII file 
 *           the list mode list is exported (destination) in.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetCORRectionImportExportASCIIFile(
    ViSession   instrSession,
    ViChar _VI_FAR asciiSourceFile[]
)
{
    INIT;

    return GETPARAMSTRING (instrSession,
                              "SOUR:CORR:DEXC:AFIL:SEL?",
                              asciiSourceFile,
                              128);
}

/*****************************************************************************
 * Function: Set CORRection Import Export ASCII Extension
 * Purpose:  This function selects the file extension of the ASCII file to be 
 *           imported or exported. Selection TXT (text file) or CSV (Excel 
 *           file) is available. 
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetCORRectionImportExportASCIIExtension(
    ViSession   instrSession,
    ViInt32 extension
)
{
    INIT;

    return SETPARAMENUM (instrSession,
                          "SOUR:CORR:DEXC:AFIL:EXT",
                          extension,
                          dexcExtensionArr);
}

/*****************************************************************************
 * Function: Get CORRection Import Export ASCII Extension
 * Purpose:  This function queries the selected file extension of the ASCII 
 *           file to be imported or exported. Selection TXT (text file) or CSV 
 *           (Excel file) is available. 
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetCORRectionImportExportASCIIExtension(
    ViSession   instrSession,
    ViInt32*    extension
)
{
    INIT;

    return GETPARAMENUM (instrSession,
                          "SOUR:CORR:DEXC:AFIL:EXT?",
                          extension,
                          dexcExtensionArr);
}

/*****************************************************************************
 * Function: Set CORRection Import Export ASCII Column Separator
 * Purpose:  This function selects the separator between the frequency and 
 *           level column of the ASCII table. 
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetCORRectionImportExportASCIIColumnSeparator(
    ViSession   instrSession,
    ViInt32 separator
)
{
    INIT;

    return SETPARAMENUM (instrSession,
                          "SOUR:CORR:DEXC:AFIL:SEP:COL",
                          separator,
                          dexcSeparatorArr);
}

/*****************************************************************************
 * Function: Get CORRection Import Export ASCII Column Separator
 * Purpose:  This function queries the selected separator between the 
 *           frequency and level column of the ASCII table. 
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetCORRectionImportExportASCIIColumnSeparator(
    ViSession   instrSession,
    ViInt32*    separator
)
{
    INIT;

    return GETPARAMENUM (instrSession,
                          "SOUR:CORR:DEXC:AFIL:SEP:COL?",
                          separator,
                          dexcSeparatorArr);
}

/*****************************************************************************
 * Function: Set CORRection Import Export ASCII Column Decimal Separator
 * Purpose:  This function selects the decimal separator used in the ASCII 
 *           data between '.' (decimal point) and ',' (comma) with 
 *           floating-point numerals.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetCORRectionImportExportASCIIColumnDecimalSeparator(
    ViSession   instrSession,
    ViInt32 decimalSeparator
)
{
    INIT;

    return SETPARAMENUM (instrSession,
                          "SOUR:CORR:DEXC:AFIL:SEP:DEC",
                          decimalSeparator,
                          dexcDecimalSeparatorArr);
}

/*****************************************************************************
 * Function: Get CORRection Import Export ASCII Column Decimal Separator
 * Purpose:  This function displays the selected decimal separator used in the 
 *           ASCII data - '.' (decimal point) and ',' (comma) with 
 *           floating-point numerals.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetCORRectionImportExportASCIIColumnDecimalSeparator(
    ViSession   instrSession,
    ViInt32*    decimalSeparator
)
{
    INIT;

    return GETPARAMENUM (instrSession,
                          "SOUR:CORR:DEXC:AFIL:SEP:DEC?",
                          decimalSeparator,
                          dexcDecimalSeparatorArr);
}

/*****************************************************************************
 * Function: CORRection Import Export Catalog
 * Purpose:  This function requests a list of available ASCII files for 
 *           export/import of list mode data. The individual files are 
 *           separated by commas.
 *            
 *           The ASCII files are stored with the fixed file extensions *.txt 
 *           or *.csv in a directory of the user's choice. The directory 
 *           applicable to the commands is defined with the command 
 *           MMEMory:CDIR.  A path can also be specified in command 
 *           SOUR:CORR:DEXC:AFIL:CAT?, in which case the files in the specified 
 *           directory are read.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_CORRectionImportExportCatalog(
    ViSession   instrSession,
    ViString    directoryPath,
    ViInt32 arraySize,
    ViChar _VI_FAR    catalogList[]
)
{
    ViStatus rssmf_status = VI_SUCCESS;
    ViChar      buffer[BUFFER_SIZE];
    
    if (!directoryPath)
        sprintf (buffer, ":CORR:DEXC:AFIL:CAT?;*OPC?");
    else
        sprintf (buffer, ":CORR:DEXC:AFIL:CAT? '%s';*OPC?", directoryPath);

    CHECKERR (rssmf_getCatalog (instrSession,
                                     buffer,
                                     (ViUInt32) arraySize,
                                     catalogList,"catalogList"));

    return rssmf_status;
}

/*****************************************************************************
 * Function: Configure Level Sweep
 * Purpose:  This function sets the RF sweep parameters and changes the mode 
 *           of RF level to Sweep mode.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_confRFLevelSweep(
    ViSession   instrSession,
    ViInt32 levelSweepMode,
    ViReal64    startLevel,
    ViReal64    stopLevel,
    ViReal64    stepLin,
    ViReal64    dwellTime
)
{
    ViStatus rssmf_status;
    
    CHECKERR (rssmf_SetLevelSweepMode (instrSession, levelSweepMode));
    
    CHECKERR (rssmf_SetLevelSweepStartLevel (instrSession, startLevel));    
    CHECKERR (rssmf_SetLevelSweepStopLevel (instrSession, stopLevel));    
    CHECKERR (rssmf_SetLevelSweepStep (instrSession, stepLin));    
    CHECKERR (rssmf_SetLevelSweepDwell (instrSession, dwellTime));    
    return rssmf_status;
    
}

/*****************************************************************************
 * Function: Level Sweep Execute
 * Purpose:  This function triggers a sweep.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_LevelSweepExecute(
    ViSession   instrSession
)
{
    INIT;

    return rssmf_sendCmd (instrSession, "SOUR:SWE:POW:EXEC");
}

/*****************************************************************************
 * Function: Configure Level Sweep Marker
 * Purpose:  This function switches on or off the selected marker. If the
 *           marker is switched on, the signal level at the MARKER output
 *           changes on reaching the level mark.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_ConfigureLevelSweepMarker (ViSession instrSession,
                                                   ViUInt32 channel,
                                                   ViBoolean state,
                                                   ViReal64 level,
                                                   ViInt32 polarity,
                                                   ViInt32 activeMarker)
{
    ViStatus    rssmf_status;

    CHECKERR (rssmf_SetLevelSweepMarkerState (instrSession, channel, state));
    
    CHECKERR (rssmf_SetLevelSweepMarkerLevel (instrSession, channel, level));    
    CHECKERR (rssmf_SetLevelSweepMarkerPolarity (instrSession, polarity));
    CHECKERR (rssmf_SetLevelSweepActiveMarker (instrSession, activeMarker));    
    RETURN;    
}

/*****************************************************************************
 * Function: Set Level Sweep Mode
 * Purpose:  This function sets the sweep mode.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetLevelSweepMode (ViSession instrSession,
                                           ViInt32 mode)
{
    INIT;
    
    switch (mode)
    {
    case RSSMF_SWEEP_MODE_AUTO:
        CHECKERR (rssmf_SetSweepLevelMode (instrSession, RSSMF_SWEEP_LOW_MODE_AUTO));
        CHECKERR (rssmf_SetLevelSweepTriggerSource (instrSession, RSSMF_TRIG_SOURCE_SWEEP_AUTO));
        CHECKERR (rssmf_SetLevelMode (instrSession, RSSMF_POWER_MODE_SWEEP));
        break;
    case RSSMF_SWEEP_MODE_SINGLE:
        CHECKERR (rssmf_SetSweepLevelMode (instrSession, RSSMF_SWEEP_LOW_MODE_AUTO));
        CHECKERR (rssmf_SetLevelSweepTriggerSource (instrSession, RSSMF_TRIG_SOURCE_SWEEP_SINGLE));
        CHECKERR (rssmf_SetLevelMode (instrSession, RSSMF_POWER_MODE_SWEEP));
        CHECKERR (rssmf_LevelSweepExecute (instrSession));
        break;
    case RSSMF_SWEEP_MODE_STEP:
        CHECKERR (rssmf_SetSweepLevelMode (instrSession, RSSMF_SWEEP_LOW_MODE_STEP));
        CHECKERR (rssmf_SetLevelSweepTriggerSource (instrSession, RSSMF_TRIG_SOURCE_SWEEP_SINGLE));
        CHECKERR (rssmf_SetLevelMode (instrSession, RSSMF_POWER_MODE_SWEEP));
        break;
    case RSSMF_SWEEP_MODE_EXT_SINGLE:
        CHECKERR (rssmf_SetSweepLevelMode (instrSession, RSSMF_SWEEP_LOW_MODE_AUTO));
        CHECKERR (rssmf_SetLevelSweepTriggerSource (instrSession, RSSMF_TRIG_SOURCE_SWEEP_EXTERNAL));
        CHECKERR (rssmf_SetLevelMode (instrSession, RSSMF_POWER_MODE_SWEEP));
        break;
    case RSSMF_SWEEP_MODE_EXT_STEP:
        CHECKERR (rssmf_SetSweepLevelMode (instrSession, RSSMF_SWEEP_LOW_MODE_STEP));
        CHECKERR (rssmf_SetLevelSweepStep (instrSession, 0.5));
        CHECKERR (rssmf_SetLevelSweepTriggerSource (instrSession, RSSMF_TRIG_SOURCE_SWEEP_EXTERNAL));
        CHECKERR (rssmf_SetLevelMode (instrSession, RSSMF_POWER_MODE_SWEEP));
        break;
    default:
        rssmf_status = rssmf_ParameterError (instrSession, "mode");
    }

    RETURN;
}

/*****************************************************************************
 * Function: Set Level Sweep Start Level
 * Purpose:  This function sets the RF start level in Sweep mode. 
 *           
 *           As with the Level value entered in the RF Level menu, the OFFSet 
 *           value is also taken into consideration with this function.
 *           
 *           The specified value range is therefore only effective if 
 *           :SOURce:POWer:OFFSet is set to 0. The value range for other OFFset 
 *           values can be calculated using the following formula:
 *           
 *           Minimum level + OFFSet ... Maximum level + OFFSet
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetLevelSweepStartLevel(
    ViSession   instrSession,
    ViReal64    startLevel
)
{
    INIT;

    return SETPARAMREAL64 (instrSession,
                              "SOUR:POW:STAR",
                              startLevel,
                              0.0, 0.0);
}

/*****************************************************************************
 * Function: Get Level Sweep Start Level
 * Purpose:  This function returns the RF start level in Sweep mode. 
 *           
 *           As with the Level value entered in the RF Level menu, the OFFSet 
 *           value is also taken into consideration with this function.
 *           
 *           The specified value range is therefore only effective if 
 *           :SOURce:POWer:OFFSet is set to 0. The value range for other OFFset 
 *           values can be calculated using the following formula:
 *           
 *           Minimum level + OFFSet ... Maximum level + OFFSet
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetLevelSweepStartLevel(
    ViSession   instrSession,
    ViReal64*   startLevel
)
{
    INIT;

    return GETPARAMREAL64 (instrSession,
                              "SOUR:POW:STAR?",
                              startLevel);
}

/*****************************************************************************
 * Function: Set Level Sweep Stop Level
 * Purpose:  This function sets the stop level in Sweep mode. 
 *           
 *           As with the Level value entered in the RF Level menu, the OFFSet 
 *           value is also taken into consideration with this function.
 *           
 *           The specified value range is therefore only effective if 
 *           :SOURce:POWer:OFFSet is set to 0. The value range for other OFFset 
 *           values can be calculated using the following formula:
 *           
 *           Minimum level + OFFSet ... Maximum level + OFFSet
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetLevelSweepStopLevel(
    ViSession   instrSession,
    ViReal64    stopLevel
)
{
    INIT;

    return SETPARAMREAL64 (instrSession,
                              "SOUR:POW:STOP",
                              stopLevel,
                              0.0, 0.0);
}

/*****************************************************************************
 * Function: Get Level Sweep Stop Level
 * Purpose:  This function returns the stop level in Sweep mode. 
 *           
 *           As with the Level value entered in the RF Level menu, the OFFSet 
 *           value is also taken into consideration with this function.
 *           
 *           The specified value range is therefore only effective if 
 *           :SOURce:POWer:OFFSet is set to 0. The value range for other OFFset 
 *           values can be calculated using the following formula:
 *           
 *           Minimum level + OFFSet ... Maximum level + OFFSet
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetLevelSweepStopLevel(
    ViSession   instrSession,
    ViReal64*   stopLevel
)
{
    INIT;

    return GETPARAMREAL64 (instrSession,
                              "SOUR:POW:STOP?",
                              stopLevel);
}

/*****************************************************************************
 * Function: Set Level Sweep Step
 * Purpose:  This function sets the step width factor for logarithmic sweeps. 
 *           The next level value of a sweep is calculated (for STARt < STOP) 
 *           using the following formula:
 *           
 *           New level = Old level + STEP:LOG x Old level
 *           
 *           STEP:LOG therefore gives the fraction of the old level. The level 
 *           is increased by this fraction for the next sweep step. Usually 
 *           STEP:LOG is given in decibels, whereby the suffix dB must always 
 *           be used.
 *           
 *           This function is linked to the command :SWEep:POWer:POINts for 
 *           STARt < STOP as follows:
 *           
 *           POINts = ((STOP - STARt) / STEP:LOG) + 1
 *           
 *           If STEP:LOG changes, the value of POINTs is adjusted. The STARt 
 *           and STOP value is retained.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetLevelSweepStep(
    ViSession   instrSession,
    ViReal64    step
)
{
    INIT;

    return SETPARAMREAL64 (instrSession,
                              "SOUR:SWE:POW:STEP",
                              step,
                              0.0, 160.0);
}

/*****************************************************************************
 * Function: Get Level Sweep Step
 * Purpose:  This function returns the step width factor for logarithmic 
 *           sweeps. The next level value of a sweep is calculated (for STARt < 
 *           STOP) using the following formula:
 *           
 *           New level = Old level + STEP:LOG x Old level
 *           
 *           STEP:LOG therefore gives the fraction of the old level. The level 
 *           is increased by this fraction for the next sweep step. Usually 
 *           STEP:LOG is given in decibels, whereby the suffix dB must always 
 *           be used.
 *           
 *           This function is linked to the command :SWEep:POWer:POINts for 
 *           STARt < STOP as follows:
 *           
 *           POINts = ((STOP - STARt) / STEP:LOG) + 1
 *           
 *           If STEP:LOG changes, the value of POINTs is adjusted. The STARt 
 *           and STOP value is retained.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetLevelSweepStep(
    ViSession   instrSession,
    ViReal64*   step
)
{
    INIT;

    return GETPARAMREAL64 (instrSession,
                              "SOUR:SWE:POW:STEP?",
                              step);
}

/*****************************************************************************
 * Function: Set Level Sweep Dwell Time
 * Purpose:  This function sets the time taken for each level step of the 
 *           sweep. 
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetLevelSweepDwell(
    ViSession   instrSession,
    ViReal64    dwellTime
)
{
    INIT;

    return SETPARAMREAL64 (instrSession,
                              "SOUR:SWE:POW:DWEL",
                              dwellTime,
                              2E-3, 10.0);
}

/*****************************************************************************
 * Function: Get Level Sweep Dwell Time
 * Purpose:  This function returns the time taken for each level step of the 
 *           sweep. 
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetLevelSweepDwell(
    ViSession   instrSession,
    ViReal64*   dwellTime
)
{
    INIT;

    return GETPARAMREAL64 (instrSession,
                              "SOUR:SWE:POW:DWEL?",
                              dwellTime);
}

/*****************************************************************************
 * Function: Set Level Sweep Manual Step
 * Purpose:  In Sweep mode (:SOUR:POW:MODE SWE) this function sets the level 
 *           for the next sweep step in the Step sweep mode (:SOUR:SWE:POW:MODE 
 *           MAN). Here only level values between the settings [SOUR]:POW:STAR 
 *           and ...:STOP are permitted. Each sweep step is triggered by a 
 *           separate :SOUR:POW:MAN command.
 *           
 *           As with the Level value entered in the RF Level menu, the OFFSet 
 *           value is also taken into consideration with this function.
 *           
 *           The specified value range is therefore only effective if 
 *           :SOURce:POWer:OFFSet is set to 0. The value range for other OFFset 
 *           values can be calculated using the following formula (see also 
 *           Chapter 4, section Level Offset - RF Signal):
 *           
 *           Minimum level + OFFSet ... Maximum level + OFFSet
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetLevelSweepManualStep(
    ViSession   instrSession,
    ViReal64    manualStep
)
{
    INIT;

    return SETPARAMREAL64 (instrSession,
                              "SOUR:POW:MAN",
                              manualStep,
                              0.0, 0.0);
}

/*****************************************************************************
 * Function: Get Level Sweep Manual Step
 * Purpose:  This function returns the level of the next sweep step in the 
 *           Step sweep mode.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetLevelSweepManualStep(
    ViSession   instrSession,
    ViReal64*   manualStep
)
{
    INIT;

    return GETPARAMREAL64 (instrSession,
                              "SOUR:POW:MAN?",
                              manualStep);
}

/*****************************************************************************
 * Function: Set Level Sweep Points
 * Purpose:  This function sets the number of steps in a level sweep. This 
 *           function is linked to the command :SWEep:POWer:STEP as follows:
 *           
 *           POINts = ((STOP - STARt) / STEP:LOG) + 1
 *           
 *           If POINTs changes, the value of STEP is adjusted. The STARt and 
 *           STOP value is retained.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetLevelSweepPoints(
    ViSession   instrSession,
    ViInt32 levelSweepPoints
)
{
    INIT;

    return SETPARAMINT32 (instrSession,
                             "SOUR:SWE:POW:POIN",
                             levelSweepPoints,
                             0, 0);
}

/*****************************************************************************
 * Function: Get Level Sweep Points
 * Purpose:  This function returns the number of steps in a level sweep. This 
 *           function is linked to the command :SWEep:POWer:STEP as follows:
 *           
 *           POINts = ((STOP - STARt) / STEP:LOG) + 1
 *           
 *           If POINTs changes, the value of STEP is adjusted. The STARt and 
 *           STOP value is retained.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetLevelSweepPoints(
    ViSession   instrSession,
    ViInt32*    levelSweepPoints
)
{
    INIT;

    return GETPARAMINT32 (instrSession,
                             "SOUR:SWE:POW:POIN?",
                             levelSweepPoints);
}

/*============================================================================
 * Function: Set Level Sweep Attenuator Mode
 * Purpose:  This function selects the ranges of level settings for the list
 *           mode. The level settings are either performed in the low level
 *           or in the high level ranges.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_SetLevelSweepAttenuatorMode (ViSession instrSession,
                                                     ViInt32 attenuatorMode)
{
    return SETPARAMENUM (instrSession,
                          "SOUR:SWE:POW:AMOD",
                          attenuatorMode,
                          ListAttenuatorModeArr);
}

/*============================================================================
 * Function: Get Level Sweep Attenuator Mode
 * Purpose:  This function returns the ranges of level settings for the list
 *           mode. The level settings are either performed in the low level
 *           or in the high level ranges.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_GetLevelSweepAttenuatorMode (ViSession instrSession,
                                                     ViInt32 *attenuatorMode)
{
    return GETPARAMENUM (instrSession,
                          "SOUR:SWE:POW:AMOD?",
                          attenuatorMode,
                          ListAttenuatorModeArr);
}

/*============================================================================
 * Function: Set Level Sweep Shape
 * Purpose:  This function sets the cycle mode for a sweep sequence (shape).
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_SetLevelSweepShape (ViSession instrSession,
                                            ViInt32 shape)
{
    return SETPARAMENUM (instrSession,
                          "SOUR:SWE:POW:SHAP",
                          shape,
                          frequencySweepShapeArr);
}

/*============================================================================
 * Function: Get Level Sweep Shape
 * Purpose:  This function returns the cycle mode for a sweep sequence (shape).
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_GetLevelSweepShape (ViSession instrSession,
                                            ViInt32 *shape)
{
    return GETPARAMENUM (instrSession,
                          "SOUR:SWE:POW:SHAP?",
                          shape,
                          frequencySweepShapeArr);
}

/*============================================================================
 * Function: Get Level Sweep Spacing
 * Purpose:  This function queries the sweep spacing. The sweep spacing for
 *           level sweeps is always linear.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_GetLevelSweepSpacing (ViSession instrSession,
                                              ViInt32 *spacing)
{
    return GETPARAMENUM (instrSession,
                          "SOUR:SWE:POW:SPAC:MODE?",
                          spacing,
                          spacingArr);
}

/*****************************************************************************
 * Function: Set Level Sweep Marker State
 * Purpose:  This function switches on or off the selected marker. If the 
 *           marker is switched on, the signal level at the MARKER output 
 *           changes on reaching the level mark.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetLevelSweepMarkerState (ViSession instrSession,
                                                  ViUInt32 channel,
                                                  ViBoolean state)
{
    INIT;
    CHECKOPT (B20);

    CHECKVIUINT32 (instrSession, channel, 1, 10);
    
    return SETPARAMBOOLPATH (instrSession,
                                   "SOUR:SWE:POW:MARK%ld:STAT",
                                   channel,
                                   state);
}

/*****************************************************************************
 * Function: Get Level Sweep Marker State
 * Purpose:  This function returns the state of the selected marker.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetLevelSweepMarkerState (ViSession instrSession,
                                                  ViUInt32 channel,
                                                  ViBoolean *state)
{
    INIT;
    CHECKOPT (B20);

    CHECKVIUINT32 (instrSession, channel, 1, 10);
    
    return GETPARAMBOOLPATH (instrSession,
                                   "SOUR:SWE:POW:MARK%ld:STAT?",
                                   channel,
                                   state);
}

/*****************************************************************************
 * Function: Set Level Sweep Marker Level
 * Purpose:  This function sets the level mark for the selected marker. If
 *           the marker is switched on, the signal level at the MARKER output
 *           changes on reaching the level mark. 
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetLevelSweepMarkerLevel (ViSession instrSession,
                                                  ViUInt32 channel,
                                                  ViReal64 level)
{
    INIT;
    CHECKOPT (B20);

    CHECKVIUINT32 (instrSession, channel, 1, 10);
    
    return SETPARAMREAL64PATH (instrSession,
                                   "SOUR:SWE:POW:MARK%ld:POW",
                                   channel,
                                   level,
                                   0.0,0.0);
}

/*****************************************************************************
 * Function: Get Level Sweep Marker Level
 * Purpose:  This function returns the level mark for the selected marker. 
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetLevelSweepMarkerLevel (ViSession instrSession,
                                                  ViUInt32 channel,
                                                  ViReal64 *level)
{
    INIT;
    CHECKOPT (B20);

    CHECKVIUINT32 (instrSession, channel, 1, 10);
    
    return GETPARAMREAL64PATH (instrSession,
                                   "SOUR:SWE:POW:MARK%ld:POW?",
                                   channel,
                                   level);
}

/*****************************************************************************
 * Function: Set Level Sweep Marker Polarity
 * Purpose:  This function selects the marker output polarity.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetLevelSweepMarkerPolarity (ViSession instrSession,
                                                     ViInt32 polarity)
{
    INIT;
    CHECKOPT (B20);

    return SETPARAMENUM (instrSession,
                          "SOUR:SWE:POW:MARK:OUTP:POL",
                          polarity,
                          polarityArr);
}

/*****************************************************************************
 * Function: Get Level Sweep Marker Polarity
 * Purpose:  This function returns the marker output polarity.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetLevelSweepMarkerPolarity (ViSession instrSession,
                                                     ViInt32 *polarity)
{
    INIT;
    CHECKOPT (B20);

    return GETPARAMENUM (instrSession,
                          "SOUR:SWE:POW:MARK:OUTP:POL?",
                          polarity,
                          polarityArr);
}

/*****************************************************************************
 * Function: Set Level Sweep Active Marker
 * Purpose:  This function activates the selected marker. The active marker
 *           is output with a higher voltage than all other markers.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetLevelSweepActiveMarker (ViSession instrSession,
                                                   ViInt32 activeMarker)
{
    INIT;
    CHECKOPT (B20);

    CHECKVIINT32 (instrSession, activeMarker, RSSMF_SWEEP_MARKER_ACTIVE_NONE, RSSMF_SWEEP_MARKER_ACTIVE_10);
    
    return SETPARAMENUM (instrSession,
                          "SOUR:SWE:POW:MARK:ACT",
                          activeMarker,
                          activeMarkerArr);
}

/*****************************************************************************
 * Function: Get Level Sweep Active Marker
 * Purpose:  This function returns the active marker.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetLevelSweepActiveMarker (ViSession instrSession,
                                                   ViInt32 *activeMarker)
{
    INIT;
    CHECKOPT (B20);

    return GETPARAMENUM (instrSession,
                          "SOUR:SWE:POW:MARK:ACT?",
                          activeMarker,
                          activeMarkerArr);
}

/*****************************************************************************
 * Function: Set Level Sweep All Markers Off
 * Purpose:  This function switches off all level markers. 
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetLevelSweepAllMarkersOff (ViSession instrSession)
{
    INIT;
    CHECKOPT (B20);

    return rssmf_sendCmd (instrSession, "SOUR:SWE:POW:MARK:AOFF");
}

/*============================================================================
 * Function: Reset Level Sweep
 * Purpose:  This function resets all active sweeps to the starting point.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_ResetLevelSweep (ViSession instrSession)
{
  return rssmf_sendCmd (instrSession, "SOUR:SWE:RES:ALL");   
}

/*****************************************************************************
 * Function: Set RF Attenuator Mode
 * Purpose:  This function switches the mode of the attenuator at the RF 
 *           output (Attenuator MODe).
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetRFAttenuatorMode(
    ViSession   instrSession,
    ViInt32 attenuatorMode
)
{
    return SETPARAMENUM (instrSession,
                          "OUTP:AMOD",
                          attenuatorMode,
                          attenuatorModeArr);
}

/*****************************************************************************
 * Function: Get RF Attenuator Mode
 * Purpose:  This function returns the mode of the attenuator at the RF output 
 *           (Attenuator MODe).
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetRFAttenuatorMode(
    ViSession   instrSession,
    ViInt32*    attenuatorMode
)
{
    return GETPARAMENUM (instrSession,
                          "OUTP:AMOD?",
                          attenuatorMode,
                          attenuatorModeArr);
}

/*****************************************************************************
 * Function: Set RF Attenuation
 * Purpose:  This functions sets the attenuation.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetRFAttenuation(
    ViSession   instrSession,
    ViReal64    attenuation
)
{
    return SETPARAMREAL64 (instrSession,
                              "SOUR:POW:ATT",
                              attenuation,
                              0.0,110.0);
}

/*****************************************************************************
 * Function: Get RF Attenuation
 * Purpose:  This functions queries the attenuation.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetRFAttenuation(
    ViSession   instrSession,
    ViReal64*   attenuation
)
{
    return GETPARAMREAL64 (instrSession,
                              "SOUR:POW:ATT?",
                              attenuation);
}

/*****************************************************************************
 * Function: Get RF Attenuator Lower Range
 * Purpose:  This function queries the minimum level which can be set without 
 *           the attenuator being adjusted (Attenuator FIXed).
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetRFAttenuatorLowerRange(
    ViSession   instrSession,
    ViReal64*   attenuatorLowerRange
)
{
    return GETPARAMREAL64 (instrSession,
                              "OUTP:AFIX:RANG:LOW?",
                              attenuatorLowerRange);
}

/*****************************************************************************
 * Function: Get RF Attenuator Upper Range
 * Purpose:  This function queries the maximum level which can be set without 
 *           the attenuator being adjusted (Attenuator FIXed).
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetRFAttenuatorUpperRange(
    ViSession   instrSession,
    ViReal64*   attenuatorUpperRange
)
{
    return GETPARAMREAL64 (instrSession,
                              "OUTP:AFIX:RANG:UPP?",
                              attenuatorUpperRange);
}

/*****************************************************************************
 * Function: Set RF OFF Attenuator Mode
 * Purpose:  Selects the mode of the mechanical attenuator, when the RF signal
 *           is switched off
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetRFOFFAttenuatorMode (ViSession instrSession,
                                                ViInt32 OFFAttenuatorMode)
{
    return SETPARAMENUM (instrSession,
                          "POW:ATT:RFOF:MODE",
                          OFFAttenuatorMode,
                          OFFattenuatorModeArr);
}

/*****************************************************************************
 * Function: Get RF OFF Attenuator Mode
 * Purpose:  Queries the mode of the mechanical attenuator, when the RF signal
 *           is switched off
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetRFOFFAttenuatorMode (ViSession instrSession,
                                                ViInt32 *OFFAttenuatorMode)
{
    return GETPARAMENUM (instrSession,
                          "POW:ATT:RFOF:MODE?",
                          OFFAttenuatorMode,
                          OFFattenuatorModeArr);
}

/*****************************************************************************
 * Function: CALibration All
 * Purpose:  This function starts all internal adjustments for which no 
 *           external measuring equipment is needed. 
 *           
 *           Note:
 *           
 *           If the calibration fails, this function returns an error code.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_CALibrationAll(
    ViSession   instrSession,
    ViInt32 timeout,
    ViInt32*    response
)
{
    ViStatus    rssmf_status = VI_SUCCESS;
    ViChar      buffer[BUFFER_SIZE];

    CHECKVIINT32 (instrSession, timeout, 0, 600000);
    CHECKNULL(response);

    sprintf (buffer, "CAL:ALL?;*OPC?");

    CHECKERR (rssmf_waitOPC (instrSession, buffer, buffer, timeout));

    if (sscanf (buffer, "%ld", response) != 1)
        return VI_ERROR_INSTR_INTERPRETING_RESPONSE;

    if (*response == 1) /* Calibration failed. */
        rssmf_status = RSSMF_ERROR_CALIBRATION_FAILED;

    return rssmf_status;
}

/*****************************************************************************
 * Function: CALibration Frequency
 * Purpose:  This function starts all adjustments which affect the frequency. 
 *           
 *           Note:
 *           
 *           If the calibration fails, this function returns an error code.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_CALibrationFrequency(
    ViSession   instrSession,
    ViInt32 timeout,
    ViInt32*    response
)
{
    ViStatus    rssmf_status = VI_SUCCESS;
    ViChar      buffer[BUFFER_SIZE];

    CHECKVIINT32 (instrSession, timeout, 0, 600000);
    CHECKNULL (response);

    sprintf (buffer, "CAL:FREQ:MEAS?;*OPC?");

    CHECKERR (rssmf_waitOPC (instrSession, buffer, buffer, timeout));

    if (sscanf (buffer, "%ld", response) != 1)
        return VI_ERROR_INSTR_INTERPRETING_RESPONSE;

    if (*response == 1) /* Calibration failed. */
        rssmf_status = RSSMF_ERROR_CALIBRATION_FAILED;

    return rssmf_status;
}

/*****************************************************************************
 * Function: CALibration Modulation Generators
 * Purpose:  This function performs all adjustments which affect the internal 
 *           modulation generators.
 *           
 *           Note:
 *           
 *           If the calibration fails, this function returns an error code.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_CALibrationModulationGenerators(
    ViSession   instrSession,
    ViInt32 timeout,
    ViInt32*    response
)
{
    ViStatus    rssmf_status = VI_SUCCESS;
    ViChar      buffer[BUFFER_SIZE];

    CHECKVIINT32 (instrSession, timeout, 0, 600000);
    CHECKNULL(response);

    sprintf (buffer, "CAL:LFO?;*OPC?");

    CHECKERR (rssmf_waitOPC (instrSession, buffer, buffer, timeout));

    if (sscanf (buffer, "%ld", response) != 1)
        return VI_ERROR_INSTR_INTERPRETING_RESPONSE;

    if (*response == 1) /* Calibration failed. */
        rssmf_status = RSSMF_ERROR_CALIBRATION_FAILED;

    return rssmf_status;
}

/*****************************************************************************
 * Function: CALibration Level
 * Purpose:  This function starts all adjustments which affect the level.
 *           
 *           Note:
 *           
 *           If the calibration fails, this function returns an error code.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_CALibrationLevel(
    ViSession   instrSession,
    ViInt32 timeout,
    ViInt32*    response
)
{
    ViStatus    rssmf_status = VI_SUCCESS;
    ViChar      buffer[BUFFER_SIZE];

    CHECKVIINT32 (instrSession, timeout, 0, 600000);
    CHECKNULL(response);

    sprintf (buffer, "CAL:LEV:MEAS?;*OPC?");

    CHECKERR (rssmf_waitOPC (instrSession, buffer, buffer, timeout));

    if (sscanf (buffer, "%ld", response) != 1)
        return VI_ERROR_INSTR_INTERPRETING_RESPONSE;

    if (*response == 1) /* Calibration failed. */
        rssmf_status = RSSMF_ERROR_CALIBRATION_FAILED;

    return rssmf_status;
}

/*****************************************************************************
 * Function: Set CALibration Level State
 * Purpose:  This function switches on or off use of external level correction 
 *           data. This switch can be used in case of corrupt external level 
 *           correction data.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetCALibrationLevelState(
    ViSession   instrSession,
    ViBoolean   levelState
)
{
    INIT;

    return SETPARAMBOOL (instrSession,
                               "CAL:LEV:STAT",
                               levelState);
}

/*****************************************************************************
 * Function: Get CALibration Level State
 * Purpose:  This function returns state of external level correction data.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetCALibrationLevelState(
    ViSession   instrSession,
    ViBoolean*  levelState
)
{
    INIT;

    return GETPARAMBOOL (instrSession,
                               "CAL:LEV:STAT?",
                               levelState);
}

/*===========================================================================*/
/* Function: Set CALibration Level Loop Gain State
/* Purpose:  This function switches on or off use of external loopgain 
/*           correction data. 
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_SetCALibrationLevelLoopGainState(
    ViSession   instrSession,
    ViBoolean   levelLoopGainState
)
{
    INIT;

    return SETPARAMBOOL (instrSession,
                               "CAL:LEV:LOOP:STAT",
                               levelLoopGainState);
}

/*===========================================================================*/
/* Function: Get CALibration Level Loop Gain State
/* Purpose:  This function returns on or off use of external loopgain 
/*           correction data. 
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetCALibrationLevelLoopGainState(
    ViSession   instrSession,
    ViBoolean*  levelLoopGainState
)
{
    INIT;

    return GETPARAMBOOL (instrSession,
                               "CAL:LEV:LOOP:STAT?",
                               levelLoopGainState);
}

/*****************************************************************************
 * Function: Clear Status
 * Purpose:  CLEAR STATUS sets the status byte (STB), the standard event 
 *           register (ESR), and the EVENt part of the QUEStionable and 
 *           OPERation register to zero. The function does not change the 
 *           enable and transition parts of the registers. It deletes the 
 *           output buffer.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_ClearStatus(
    ViSession   instrSession
)
{
    INIT;

    return rssmf_sendCmd ( instrSession, "*CLS" );
}

/*****************************************************************************
 * Function: Event Status Enable
 * Purpose:  EVENT STATUS ENABLE sets the event status enable register to the 
 *           specified value. The *ESE? query command returns the content of 
 *           the event status enable register in decimal form.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_EventStatusEnable(
    ViSession   instrSession,
    ViInt32 registerValue
)
{
    INIT;

    return SETPARAMINT32 (instrSession,
                             "*ESE",
                             registerValue,
                             0, 255);
}

/*****************************************************************************
 * Function: Event Status Query
 * Purpose:  STANDARD EVENT STATUS QUERY returns the content of the event 
 *           status register in decimal form (0...255) and then sets the 
 *           register to zero.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_EventStatusQuery(
    ViSession   instrSession,
    ViInt32*    registerValue
)
{
    INIT;

    return GETPARAMINT32 (instrSession,
                             "*ESR?",
                             registerValue);
}

/*****************************************************************************
 * Function: Identification Query
 * Purpose:  IDENTIFICATION QUERY queries the instrument identification. The 
 *           instrument type, serial number and firmware version are returned.
 *           
 *           Example:
 *           
 *           "Rohde&Schwarz,SMF100A,1141.2005k02/123456,1.00.0.0 (Release)"
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_IdentificationQuery(
    ViSession   instrSession,
    ViChar _VI_FAR instrumentIdentification[]
)
{
    ViStatus rssmf_status = VI_SUCCESS;

    CHECKERR (GETPARAMSTRING (instrSession,
                                      "*IDN?",
                                      instrumentIdentification,
                                      256));

    return (rssmf_status < VI_SUCCESS) ? rssmf_status : VI_SUCCESS;
}

/*****************************************************************************
 * Function: Individual Status Query
 * Purpose:  INDIVIDUAL STATUS QUERY returns the content of the IST flag in 
 *           decimal form (0 | 1). The IST flag is the status bit which is sent 
 *           during a parallel poll.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_IndividualStatusQuery(
    ViSession   instrSession,
    ViInt32*    istFlag
)
{
    INIT;

    return GETPARAMINT32 (instrSession,
                             "*IST?",
                             istFlag);
}

/*****************************************************************************
 * Function: Operation Complete
 * Purpose:  OPERATION COMPLETE sets bit 0 in the event status register when 
 *           all previous commands have been processed. This bit can be used to 
 *           trigger a service request.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_OperationComplete(
    ViSession   instrSession
)
{
    ViStatus            rssmf_status;
    rssmf_instrRange    instrPtr = NULL;
    ViBoolean           err_check;

    CHECKERR (viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr));
    if (instrPtr == NULL)
        return VI_ERROR_INV_SESSION;

    err_check = instrPtr -> errorChecking;
    
    CHECKERR (rssmf_errorCheckState (instrSession, VI_FALSE));
    CHECKERR (rssmf_sendCmd (instrSession, "*OPC"));
    (void) rssmf_errorCheckState (instrSession, err_check);
    
    return rssmf_status;
}

/*****************************************************************************
 * Function: Operation Complete Query
 * Purpose:  OPERATION COMPLETE QUERY returns a 1 when all previous commands 
 *           have been processed. It is important to ensure that the timeout 
 *           set at the IEC/IEEE bus is long enough.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_OperationCompleteQuery(
    ViSession   instrSession,
    ViInt32*    opcState
)
{
    INIT;

    return GETPARAMINT32 (instrSession,
                             "*OPC?",
                             opcState);
}

/*****************************************************************************
 * Function: Option Identification Query
 * Purpose:  OPTION IDENTIFICATION QUERY queries the options configured in the 
 *           instrument and returns a list of the installed options. The 
 *           options are separated by commas. 
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_OptionIdentificationQuery(
    ViSession   instrSession,
    ViChar _VI_FAR  optionIdentification[]
)
{
    INIT;

    return GETPARAMSTRING (instrSession,
                              "*OPT?",
                              optionIdentification,
                              1024);
}

/*****************************************************************************
 * Function: Parallel Poll Register Enable
 * Purpose:  PARALLEL POLL REGISTER ENABLE sets the parallel poll enable 
 *           register to the specified value. The *PRE? query command returns 
 *           the content of the parallel poll enable register in decimal form.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_ParallelPollRegisterEnable(
    ViSession   instrSession,
    ViInt32 registerValue
)
{
    INIT;

    return SETPARAMINT32 (instrSession,
                             "*PRE",
                             registerValue,
                             0, 655);
}

/*****************************************************************************
 * Function: Parallel Poll Register Query
 * Purpose:  PARALLEL POLL REGISTER QUERY returns the content of the parallel 
 *           poll enable register in decimal form.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_ParallelPollRegisterQuery(
    ViSession   instrSession,
    ViInt32*    registerValue
)
{
    INIT;

    return GETPARAMINT32 (instrSession,
                             "*PRE?",
                             registerValue);
}

/*****************************************************************************
 * Function: Power On Status Clear
 * Purpose:  POWER ON STATUS CLEAR determines whether the content of the 
 *           ENABle registers are retained or reset at power on.
 *           
 *           The query *PSC? retrieves the contents of the 
 *           Power-on-Status-Clear flag. The answer is either 0 or 1.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_PowerOnStatusClear(
    ViSession   instrSession,
    ViInt32 registerValue
)
{
    INIT;

    return SETPARAMINT32 (instrSession,
                             "*PSC",
                             registerValue,
                             0, 1);
}

/*****************************************************************************
 * Function: Power On Status Clear Query
 * Purpose:  POWER ON STATUS CLEAR QUERY retrieves the contents of the 
 *           Power-on-Status-Clear flag. The answer is either 0 or 1.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_PowerOnStatusClearQuery(
    ViSession   instrSession,
    ViInt32*    registerValue
)
{
    INIT;

    return GETPARAMINT32 (instrSession,
                             "*PSC?",
                             registerValue);
}

/*****************************************************************************
 * Function: Recall
 * Purpose:  RECALL calls up the instrument status which was stored under the 
 *           specified number using the *SAV command or using the 
 *           MMEMory:STORe:STATe command. "0" corresponds to the power-on 
 *           state, unless a new instrument setting was stored under this 
 *           number in the meantime using the MMEMory:STORe:STATe command. This 
 *           function can also be used to call up the 3 intermediate instrument 
 *           states which are stored with *SAV.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_Recall(
    ViSession   instrSession,
    ViInt32 instrumentStatus
)
{
    INIT;

    return SETPARAMINT32 (instrSession,
                             "*RCL",
                             instrumentStatus,
                             0, 10);
}

/*****************************************************************************
 * Function: Save
 * Purpose:  SAVE stores the current device state under the specified number 
 *           (see also *RCL). This function is used to store the 3 intermediate 
 *           instrument states and to store the current instrument state 
 *           internally when the instrument is switched off. This state is then 
 *           restored at power on.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_Save(
    ViSession   instrSession,
    ViInt32 instrumentStatus
)
{
    INIT;

    return SETPARAMINT32 (instrSession,
                             "*SAV",
                             instrumentStatus,
                             0, 10);
}

/*****************************************************************************
 * Function: Service Request Enable
 * Purpose:  SERVICE REQUEST ENABLE sets the service request enable register 
 *           to the specified value. Bit 6 (MSS enable bit) remains 0. This 
 *           function determines the conditions under which a service request 
 *           is triggered. The *SRE? query command reads out the content of the 
 *           service request enable register in decimal form. Bit 6 is always 
 *           0.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_ServiceRequestEnable(
    ViSession   instrSession,
    ViInt32 registerValue
)
{
    INIT;

    return SETPARAMINT32 (instrSession,
                             "*SRE",
                             registerValue,
                             0, 255);
}

/*****************************************************************************
 * Function: Service Request Enable Query
 * Purpose:  SERVICE REQUEST ENABLE reads out the content of the service 
 *           request enable register in decimal form. Bit 6 is always 0.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_ServiceRequestEnableQuery(
    ViSession   instrSession,
    ViInt32*    registerValue
)
{
    INIT;

    return GETPARAMINT32 (instrSession,
                             "*SRE?",
                             registerValue);
}

/*****************************************************************************
 * Function: Status Byte Query
 * Purpose:  READ STATUS BYTE QUERY reads out the content of the status byte 
 *           in decimal form.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_StatusByteQuery(
    ViSession   instrSession,
    ViInt32*    statusByte
)
{
    INIT;

    return GETPARAMINT32 (instrSession,
                             "*STB?",
                             statusByte);
}

/*****************************************************************************
 * Function: Trigger
 * Purpose:  TRIGGER triggers all actions which are waiting for a trigger 
 *           event. Specific trigger events can be triggered by means of the 
 *           "TRIGger" command system (sweep and lists) or the SOURce 
 *           subsystems (baseband).
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_Trigger(
    ViSession   instrSession
)
{
    INIT;

    return rssmf_sendCmd (instrSession, "*TRG");
}

/*****************************************************************************
 * Function: Trigger and Wait for OPC
 * Purpose:  This function triggers all actions waiting for a trigger event in 
 *           the currently active window and waits for operation completed 
 *           (OPC) before returning the status code.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_TriggerWaitOPC(
    ViSession   instrSession,
    ViInt32 timeout
)
{
    ViStatus rssmf_status = VI_SUCCESS;
    ViChar buffer[BUFFER_SIZE] = "";

    CHECKVIINT32 (instrSession, timeout, 0, 600000);

    CHECKERR (rssmf_waitOPC (instrSession, "*TRG;*OPC?", buffer, timeout));

    return rssmf_status;
}

/*****************************************************************************
 * Function: Self Test Query
 * Purpose:  SELF TEST QUERY triggers all self tests of the instrument and 
 *           outputs an error code in decimal form (see Service Manual supplied 
 *           with the instrument).
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SelfTestQuery(
    ViSession   instrSession,
    ViInt32*    errorCode
)
{
    INIT;

    return GETPARAMINT32 (instrSession,
                             "*TST?",
                             errorCode);
}

/*****************************************************************************
 * Function: Wait to Continue
 * Purpose:  WAIT-to-CONTINUE does not allow subsequent commands to be 
 *           processed until all previous commands have been executed and all 
 *           signals are in their transient condition.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_WaittoContinue(
    ViSession   instrSession
)
{
    INIT;

    return rssmf_sendCmd (instrSession, "*WAI");
}

/*===========================================================================*/
/* Function: Preset Signal Path
/* Purpose:  This function presets all parameters which are related to the 
/*           signal path.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_PresetSignalPath(
    ViSession   instrSession
)
{
    INIT;

    return rssmf_sendCmd (instrSession, "SOUR:PRES");
}

/*===========================================================================*/
/* Function: Set Image File Name
/* Purpose:  This function creates/selects a file into which the hardcopy 
/*           will be stored after the HCOP:EXEC command is sent. The 
/*           directory is either defined with the command MMEMory:CDIR or the 
/*           path is specified together with the file name. Access via remote 
/*           control is possible using the commands of the MMEM-Subsystem.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_SetImageFileName(
    ViSession   instrSession,
    ViString    fileName
)
{
    INIT;

    return SETPARAMSTRINGQUOTED (instrSession,
                              "HCOP:FILE:NAME",
                              "'",
                              fileName);
}

/*===========================================================================*/
/* Function: Get Image File Name
/* Purpose:  This function returns a file name where the hardcopy will be 
/*           stored after the HCOP:EXEC command is sent. The directory is 
/*           either defined with the command MMEMory:CDIR or the path is 
/*           specified together with the file name. Access via remote control 
/*           is possible using the commands of the MMEM-Subsystem.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetImageFileName(
    ViSession   instrSession,
    ViChar _VI_FAR  fileName[]
)
{
    INIT;

    return GETPARAMSTRING (instrSession,
                              "HCOP:FILE:NAME?",
                              fileName,
                              1024);
}

/*===========================================================================*/
/* Function: Set Image Format
/* Purpose:  This function sets the image format in which the hard copy 
/*           should be stored.
/*           
/*           Example(s):
/*           HCOP:DEV:LANG BMP
/*             - 'selects bmp as imge format.
/*           HCOP:FILE 'C:/TEMP/snapshot001'
/*             - 'defines directory, path and file for storing the hard 
/*           copy.
/*           HCOP
/*             - 'executees the hard copy procedure.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_SetImageFormat(
    ViSession   instrSession,
    ViInt32 imageFormat
)
{
    INIT;

    return SETPARAMENUM (instrSession,
                          "HCOP:DEV:LANG",
                          imageFormat,
                          sweepHardcopyFormatArr);
}

/*===========================================================================*/
/* Function: Get Image Format
/* Purpose:  This function returns the image format in which the hard copy 
/*           should be stored.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetImageFormat(
    ViSession   instrSession,
    ViInt32*    imageFormat
)
{
    INIT;

    return GETPARAMENUM (instrSession,
                          "HCOP:DEV:LANG?",
                          imageFormat,
                          sweepHardcopyFormatArr);
}

/*===========================================================================*/
/* Function: Get Image Snapshot
/* Purpose:  This function transfers the hardcopy (snapshot) as a NByte 
/*           stream to the remote client. 
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetImageSnapshot (ViSession instrSession,
                                          ViString destination)
{
    return rssmf_readDataToFile (instrSession, "HCOP:DATA?", destination); 
}

/*============================================================================
 * Function: Set Image Size
 * Purpose:  This function sets the size of the hardcopy in number of pixels. 
 *           The first value of the size setting defines the width, the second 
 *           value the height of the image.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_SetImageSize (ViSession instrSession,
                                      ViInt32 imageSize)
{
    return SETPARAMENUM (instrSession,
                          "HCOP:IMAG:SIZE",
                          imageSize,
                          hcopImageSizeArr);     
}

/*============================================================================
 * Function: Get Image Size
 * Purpose:  This function returns the size of the hardcopy in number of pixels. 
 *           The first value of the size setting defines the width, the second 
 *           value the height of the image.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_GetImageSize (ViSession instrSession,
                                      ViInt32 *imageSize)
{
    return GETPARAMENUM (instrSession,
                          "HCOP:IMAG:SIZE?",
                          imageSize,
                          hcopImageSizeArr);         
}

/*============================================================================
 * Function: Set Output Device
 * Purpose:  This function sets the output device.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_SetOutputDevice (ViSession instrSession,
                                         ViInt32 outputDevice)
{
    return SETPARAMENUM (instrSession,
                          "HCOP:DEV",
                          outputDevice,
                          hcopDeviceArr);        
}

/*============================================================================
 * Function: Get Output Device
 * Purpose:  This function returns the output device.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_GetOutputDevice (ViSession instrSession,
                                         ViInt32 *outputDevice)
{
    return GETPARAMENUM (instrSession,
                          "HCOP:DEV?",
                          outputDevice,
                          hcopDeviceArr);               
}

/*============================================================================
 * Function: Save Hard Copy
 * Purpose:  This function triggers the generation of a hardcopy of 
 *           the display.. The data is written into the file selected/created 
 *           with the HCOP:FILE commands.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_SaveHardCopy (ViSession instrSession)
{
    return rssmf_sendCmd (instrSession, "HCOP:EXEC");
}

/*============================================================================
 * Function: Set Automatic Naming State
 * Purpose:  This function activates/deactivates automatic naming of 
 *           the hardcopy files.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_SetAutomaticNamingState (ViSession instrSession,
                                                 ViBoolean state)
{
    return SETPARAMBOOL (instrSession,
                               "HCOP:FILE:AUTO:STAT",
                               state);
}

/*============================================================================
 * Function: Get Automatic Naming State
 * Purpose:  This function returns state of automatic naming of the hardcopy 
 *           files.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_GetAutomaticNamingState (ViSession instrSession,
                                                 ViBoolean *state)
{
    return GETPARAMBOOL (instrSession,
                               "HCOP:FILE:AUTO:STAT?",
                               state);    
}

/*============================================================================
 * Function: Get Automatic File Path
 * Purpose:  This function returns the file name generated using 
 *           the automatic naming settings. As default the automatically 
 *           generated file name is composed of:
 *           "<Path>/<Prefix><YYYY><MM><DD><Number>.<Format>". Each component 
 *           can be deactivated/activated separately to individually design 
 *           the file name.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_GetAutomaticFilePath (ViSession instrSession,
                                              ViInt32 arraySize,
                                              ViChar filePath[])
{
    return GETPARAMSTRING (instrSession,
                              "HCOP:FILE:AUTO?",
                              filePath,
                              arraySize);   
}

/*============================================================================
 * Function: Get Automatic File Name
 * Purpose:  This function returns the file name generated using 
 *           the automatic naming settings. As default the automatically 
 *           generated file name is composed of:
 *           "<Path>/<Prefix><YYYY><MM><DD><Number>.<Format>". Each component 
 *           can be deactivated/activated separately to individually design 
 *           the file name.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_GetAutomaticFileName (ViSession instrSession,
                                              ViChar fileName[])
{
    return GETPARAMSTRING (instrSession,
                              "HCOP:FILE:AUTO:FILE?",
                              fileName,
                              1024);   
}

/*============================================================================
 * Function: Set Automatic Directory
 * Purpose:  This function defines the directory into which the hardcopy files 
 *           will be stored if auto naming is activated 
 *           (HCOP:FILE:AUTO:STAT ON).
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_SetAutomaticDirectory (ViSession instrSession,
                                               ViString directoryName)
{
    return SETPARAMSTRINGQUOTED (instrSession,
                              "HCOP:FILE:AUTO:DIR",
                              "'",
                              directoryName);     
}

/*============================================================================
 * Function: Get Automatic Directory
 * Purpose:  This function returns the directory into which the hardcopy files 
 *           will be stored if auto naming is activated 
 *           (HCOP:FILE:AUTO:STAT ON).
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_GetAutomaticDirectory (ViSession instrSession,
                                               ViChar directory[])
{
    return GETPARAMSTRING (instrSession,
                              "HCOP:FILE:AUTO:DIR?",
                              directory,
                              1024);      
}

/*============================================================================
 * Function: Delete Image Files
 * Purpose:  This function deletes all files with extensions "bmp", "img", 
 *           "png" and "xpm" in the directory set for automatic naming.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_DeleteImageFiles (ViSession instrSession)
{
    return rssmf_sendCmd (instrSession,
                          "HCOP:FILE:AUTO:DIR:CLE");    
}

/*============================================================================
 * Function: Set Automatic File Date State
 * Purpose:  This function activates/deactivates the usage of the day/month/year 
 *           in the automatic file name.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_SetAutomaticFileDateState (ViSession instrSession,
                                                   ViInt32 fileNamePart,
                                                   ViBoolean state)
{
    INIT;
  
  CHECKVIINT32 (instrSession, fileNamePart, 0, 2);
    
    switch (fileNamePart){
        case RSSMF_HCOPY_AUTO_FILE_DAY:
            CHECKERR (SETPARAMBOOL (instrSession,
                               "HCOP:FILE:AUTO:DAY:STAT",
                               state));
        break;
        case RSSMF_HCOPY_AUTO_FILE_MONTH:
            CHECKERR (SETPARAMBOOL (instrSession,
                               "HCOP:FILE:AUTO:MONT:STAT",
                               state));
        break;                         
        case RSSMF_HCOPY_AUTO_FILE_YEAR:
            CHECKERR (SETPARAMBOOL (instrSession,
                               "HCOP:FILE:AUTO:YEAR:STAT",
                               state));
        break;
    }
    return rssmf_status;
}

/*============================================================================
 * Function: Get Automatic File Date State
 * Purpose:  This function returns the state of usage of the day/month/year in 
 *           the automatic file name
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_GetAutomaticFileDateState (ViSession instrSession,
                                                   ViInt32 fileNamePart,
                                                   ViBoolean *state)
{
    INIT;
  
  CHECKVIINT32 (instrSession, fileNamePart, 0, 2);
    
    switch (fileNamePart){
        case RSSMF_HCOPY_AUTO_FILE_DAY:
            CHECKERR (GETPARAMBOOL (instrSession,
                               "HCOP:FILE:AUTO:DAY:STAT?",
                               state));
        break;
        case RSSMF_HCOPY_AUTO_FILE_MONTH:
            CHECKERR (GETPARAMBOOL (instrSession,
                               "HCOP:FILE:AUTO:MONT:STAT?",
                               state));
        break;                         
        case RSSMF_HCOPY_AUTO_FILE_YEAR:
            CHECKERR (GETPARAMBOOL (instrSession,
                               "HCOP:FILE:AUTO:YEAR:STAT?",
                               state));
        break;
    }
    return rssmf_status;     
}

/*============================================================================
 * Function: Set Automatic File Date State
 * Purpose:  This function queries the day/month/year part in the automatic 
 *           file name.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_GetAutomaticFileDate (ViSession instrSession,
                                              ViInt32 fileNamePart,
                                              ViChar part[])
{
    INIT;
  
  CHECKVIINT32 (instrSession, fileNamePart, 0, 2);
    
    switch (fileNamePart){
        case RSSMF_HCOPY_AUTO_FILE_DAY:
            CHECKERR (GETPARAMSTRING (instrSession,
                              "HCOP:FILE:AUTO:DAY?",
                              part,
                              1024));
        break;
        case RSSMF_HCOPY_AUTO_FILE_MONTH:
            CHECKERR (GETPARAMSTRING (instrSession,
                              "HCOP:FILE:AUTO:MONT?",
                              part,
                              1024));
        break;                         
        case RSSMF_HCOPY_AUTO_FILE_YEAR:
            CHECKERR (GETPARAMSTRING (instrSession,
                              "HCOP:FILE:AUTO:YEAR?",
                              part,
                              1024));
        break;
    } 
    return rssmf_status; 
}

/*============================================================================
 * Function: Set Automatic File Prefix State
 * Purpose:  This function activates/deactivates the usage of the prefix 
 *           in the automatic file name.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_SetAutomaticFilePrefixState (ViSession instrSession,
                                                     ViBoolean state)
{
    return SETPARAMBOOL (instrSession,
                               "HCOP:FILE:AUTO:PREF:STAT",
                               state);
}

/*============================================================================
 * Function: Get Automatic File Prefix State
 * Purpose:  This function returns the state of the usage of the prefix 
 *           in the automatic file name.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_GetAutomaticFilePrefixState (ViSession instrSession,
                                                     ViBoolean *state)
{
    return GETPARAMBOOL (instrSession,
                               "HCOP:FILE:AUTO:PREF:STAT?",
                               state);    
}

/*============================================================================
 * Function: Set Automatic File Prefix
 * Purpose:  This function defines the prefix part in the automatic file name.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_SetAutomaticFilePrefix (ViSession instrSession,
                                                ViString prefix)
{
    return SETPARAMSTRINGQUOTED (instrSession,
                              "HCOP:FILE:AUTO:PREF",
                              "'",
                              prefix);     
}

/*============================================================================
 * Function: Get Automatic File Prefix
 * Purpose:  This function returns the prefix part in the automatic file name.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_GetAutomaticFilePrefix (ViSession instrSession,
                                                ViChar fileName[])
{
    return GETPARAMSTRING (instrSession,
                              "HCOP:FILE:AUTO:PREF?",
                              fileName,
                              1024);     
}

/*============================================================================
 * Function: Get Automatic File Number
 * Purpose:  This function returns queries the generated number in the automatic
 *           file name.
 *===========================================================================*/
ViStatus _VI_FUNC rssmf_GetAutomaticFileNumber (ViSession instrSession,
                                                ViInt32 *number)
{
    return GETPARAMINT32 (instrSession,
                              "HCOP:FILE:AUTO:NUMB?",
                              number);        
}

/*****************************************************************************
 * Function: DIAGnostic Modules
 * Purpose:  This function checks the assemblies available in the instrument 
 *           using the variant and revision state. 
 *           
 *           If the function is sent without parameters being specified (empty 
 *           string at the 'Module Name' parameter), a complete list of all 
 *           assemblies is returned (the various entries are separated by 
 *           commas). The length of the list is variable, depends on the 
 *           instrument equipment configuration and is limited to the size 
 *           defined by the 'Array Size' parameter. 
 *           
 *           If the function is sent with parameters ('Module Name' parameter 
 *           is not empty string), a list of the specified assemblies is 
 *           returned (the various entries are separated by commas). The length 
 *           of the list is variable, depends on the instrument equipment 
 *           configuration and is limited to the size defined by the 'Array 
 *           Size' parameter. A list of assembly names can be called up using 
 *           the :DIAG:BGIN:CATalog? command.
 *           
 *           Each entry consists of three parts which are separated by space 
 *           characters:
 *           
 *           Assembly name  Assembly variant VarXX Assembly revision RevX.X.X.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_DIAGnosticModules(
    ViSession   instrSession,
    ViString    moduleName,
    ViInt32 arraySize,
    ViChar _VI_FAR moduleConfiguration[]
)
{
    ViChar      buffer [BUFFER_SIZE];

    CHECKNULL (moduleConfiguration);

    if (!moduleName)
        sprintf (buffer, "DIAG:BGIN?;*OPC?");
    else
        sprintf (buffer, "DIAG:BGIN? '%s';*OPC?", moduleName);

    return rssmf_getCatalog (instrSession,
                             buffer,
                             (ViUInt32) arraySize,
                             moduleConfiguration,"moduleConfiguration");
}

/*****************************************************************************
 * Function: DIAGnostic Module Names
 * Purpose:  This function queries the names of the assemblies available in 
 *           the instrument. 
 *           
 *           A complete list of all assemblies is returned (the various 
 *           entries are separated by commas). The length of the list is 
 *           variable and depends on the instrument equipment configuration. 
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_DIAGnosticModuleNames(
    ViSession   instrSession,
    ViInt32 arraySize,
    ViChar _VI_FAR moduleNames[]
)
{
    ViChar  buffer [BUFFER_SIZE];

    sprintf (buffer, "DIAG:BGIN:CAT?;*OPC?");

    return rssmf_getCatalog (instrSession,
                             buffer,
                             (ViUInt32) arraySize,
                             moduleNames,"moduleNames");
}

/*****************************************************************************
 * Function: DIAGnostic Test Points
 * Purpose:  This function queries the test points available in the 
 *           instrument. A detailed description of the test points can be found 
 *           in Chapter 3 of the Service Manual (supplied with the instrument). 
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_DIAGnosticTestPoints(
    ViSession   instrSession,
    ViInt32 arraySize,
    ViChar _VI_FAR testPoints[]
)
{
    ViChar  buffer [BUFFER_SIZE];

    sprintf (buffer, "DIAG:POIN:CAT?;*OPC?");

    return rssmf_getCatalog (instrSession,
                             buffer,
                             (ViUInt32) arraySize,
                             testPoints,"testPoints");
}

/*****************************************************************************
 * Function: DIAGnostic Test Point Voltages
 * Purpose:  This function triggers voltage measurement at the specified test 
 *           point and returns the measured voltage. A detailed description of 
 *           the test points can be found in Chapter 3 of the Service Manual 
 *           (supplied with the instrument). 
 *           
 *           A list of the available test points can be queried using the 
 *           DIAG:POIN:CAT? command .   
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_DIAGnosticTestPointVoltages(
    ViSession   instrSession,
    ViString    testPointName,
    ViReal64*   measuredVoltage
)
{
    ViChar      buffer [BUFFER_SIZE];

    CHECKNULL (testPointName);

    sprintf (buffer, "DIAG:POIN? '%s'", testPointName);

    return GETPARAMREAL64 (instrSession,
                              buffer,
                              measuredVoltage);
}

/*****************************************************************************
 * Function: DIAGnostic Operation Time
 * Purpose:  This function queries the number of operation hours.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_DIAGnosticOperationTime(
    ViSession   instrSession,
    ViUInt32*   operationTime
)
{
    INIT;

    return GETPARAMUINT32 (instrSession,
                              "DIAG:INFO:OTIM?",
                              operationTime);
}

/*****************************************************************************
 * Function: DIAGnostic Power On Events
 * Purpose:  This function queries the number of power-on events.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_DIAGnosticPowerOnEvents(
    ViSession   instrSession,
    ViUInt32*   powerOnEvents
)
{
    INIT;

    return GETPARAMUINT32 (instrSession,
                              "DIAG:INFO:PCO?",
                              powerOnEvents);
}

/*****************************************************************************
 * Function: TEST Direct
 * Purpose:  The respective hardware assembly responds directly to this 
 *           function; any safety mechanisms are bypassed. 
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_TESTDirect(
    ViSession   instrSession,
    ViInt32 command,
    ViChar _VI_FAR assemblyResponse[]
)
{
    ViChar  buffer [BUFFER_SIZE];

    CHECKVIINT32 (instrSession, command, 0, 7);

    sprintf (buffer, "TEST:DIR? '%s',0", testCommandsArr[command]);

    return GETPARAMSTRING (instrSession,
                              buffer,
                              assemblyResponse,
                              256);
}

/*****************************************************************************
 * Function: Set Keyboard Lock
 * Purpose:  This function (Keyboard LOCk) disables the front panel keyboard 
 *           of the R&S Signal Generator including the  LOCAL  key, or enables 
 *           it again (OFF).
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetKeyboardLock(
    ViSession   instrSession,
    ViBoolean   keyboardLock
)
{
    INIT;

    return SETPARAMBOOL (instrSession,
                               "SYST:KLOC",
                               keyboardLock);
}

/*****************************************************************************
 * Function: Get Keyboard Lock
 * Purpose:  This function returns if the front panel keyboard of the R&S 
 *           Signal Generator including the LOCAL key is disabled or enabled.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetKeyboardLock(
    ViSession   instrSession,
    ViBoolean*  keyboardLock
)
{
    INIT;

    return GETPARAMBOOL (instrSession,
                               "SYST:KLOC?",
                               keyboardLock);
}

/*****************************************************************************
 * Function: Set Display Power Save State
 * Purpose:  This function sets the display power save state. With the 
 *           screen-save mode activated the display including backlight is 
 *           completely switched off after the elapse of the wait time (see 
 *           command DISPlay:PSAVe:HOLDoff) when no entries via front panel, 
 *           external mouse or external keyboard are made.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetDisplayPowerSaveState(
    ViSession   instrSession,
    ViBoolean   state
)
{
    ViStatus rssmf_status = VI_SUCCESS;
    
    CHECKERR (SETPARAMBOOL (instrSession,
                                       "DISP:PSAV:STAT",
                                       state));
    
    return (rssmf_status < VI_SUCCESS) ? rssmf_status : VI_SUCCESS;
}

/*****************************************************************************
 * Function: Get Display Power Save State
 * Purpose:  This function returns the state of display power save.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetDisplayPowerSaveState(
    ViSession   instrSession,
    ViBoolean*  state
)
{
    ViStatus rssmf_status = VI_SUCCESS;
    
    CHECKERR (GETPARAMBOOL (instrSession,
                                       "DISP:PSAV:STAT?",
                                       state));
    
    return (rssmf_status < VI_SUCCESS) ? rssmf_status : VI_SUCCESS;
}

/*****************************************************************************
 * Function: Set Display Power Save Holdoff
 * Purpose:  This function sets the display power save holdoff.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetDisplayPowerSaveHoldoff(
    ViSession   instrSession,
    ViInt32 holdoff
)
{
    ViStatus rssmf_status = VI_SUCCESS;
    
    CHECKERR (SETPARAMINT32 (instrSession,
                                     "DISP:PSAV:HOLD",
                                     holdoff,
                                     1, 60));
    
    return (rssmf_status < VI_SUCCESS) ? rssmf_status : VI_SUCCESS;
}

/*****************************************************************************
 * Function: Get Display Power Save Holdoff
 * Purpose:  This function returns the state of display power save holdoff.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetDisplayPowerSaveHoldoff(
    ViSession   instrSession,
    ViInt32*    holdoff
)
{
    ViStatus rssmf_status = VI_SUCCESS;
    
    CHECKERR (GETPARAMINT32 (instrSession,
                                     "DISP:PSAV:HOLD?",
                                     holdoff));
    
    return (rssmf_status < VI_SUCCESS) ? rssmf_status : VI_SUCCESS;
}

/*****************************************************************************
 * Function: Set Display Blank Mode
 * Purpose:  This function sets the display blank mode.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetDisplayBlankMode(
    ViSession   instrSession,
    ViInt32 blankMode
)
{
    ViStatus rssmf_status = VI_SUCCESS;
    
    CHECKERR (SETPARAMENUM (instrSession,
                                  "OUTP:BLAN:MODE",
                                  blankMode,
                                  blankModeArr));
    
    return (rssmf_status < VI_SUCCESS) ? rssmf_status : VI_SUCCESS;
}

/*****************************************************************************
 * Function: Get Display Blank Mode
 * Purpose:  This function returns the display blank mode.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetDisplayBlankMode(
    ViSession   instrSession,
    ViInt32*    blankMode
)
{
    ViStatus rssmf_status = VI_SUCCESS;
    
    CHECKERR (GETPARAMENUM (instrSession,
                                  "OUTP:BLAN:MODE?",
                                  blankMode,
                                  blankModeArr));
    
    return (rssmf_status < VI_SUCCESS) ? rssmf_status : VI_SUCCESS;
}

/*****************************************************************************
 * Function: Set Display Proportional Scale
 * Purpose:  This function sets the display proportional scale.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetDisplayProportionalScale(
    ViSession   instrSession,
    ViInt32 proportionalScale
)
{
    ViStatus rssmf_status = VI_SUCCESS;
    
    CHECKERR (SETPARAMENUM (instrSession,
                                  "OUTP:FPR:SCAL",
                                  proportionalScale,
                                  proportionalScaleArr));
    
    return (rssmf_status < VI_SUCCESS) ? rssmf_status : VI_SUCCESS;
}

/*****************************************************************************
 * Function: Get Display Proportional Scale
 * Purpose:  This function returns the display proportional scale.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetDisplayProportionalScale(
    ViSession   instrSession,
    ViInt32*    proportionalScale
)
{
    ViStatus rssmf_status = VI_SUCCESS;
    
    CHECKERR (GETPARAMENUM (instrSession,
                                  "OUTP:FPR:SCAL?",
                                  proportionalScale,
                                  proportionalScaleArr));
    
    return (rssmf_status < VI_SUCCESS) ? rssmf_status : VI_SUCCESS;
}

/*===========================================================================*/
/* Function: Set Display Update
/* Purpose:  This function sets the update of the display on/off. A
/*           switchover from remote control to manual control always sets the
/*           status of the update of the display to ON.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_SetDisplayUpdate (ViSession instrSession,
                                                ViBoolean displayUpdate)
{
    INIT;

    return SETPARAMBOOL (instrSession,
                               "SYST:DISP:UPD",
                               displayUpdate);
}

/*===========================================================================*/
/* Function: Get Display Update
/* Purpose:  This function returns the update of the display on/off. A
/*           switchover from remote control to manual control always sets the
/*           status of the update of the display to ON.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetDisplayUpdate (ViSession instrSession,
                                                ViBoolean *displayUpdate)
{
    INIT;

    return GETPARAMBOOL (instrSession,
                               "SYST:DISP:UPD?",
                               displayUpdate);
}

/*===========================================================================*/
/* Function: Set Display Lock
/* Purpose:  This function sets the manual operation via the display, or
/*           enables it again (OFF).
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_SetDisplayLock (ViSession instrSession,
                                              ViBoolean displayLock)
{
    INIT;

    return SETPARAMBOOL (instrSession,
                               "SYST:DLOC",
                               displayLock);
}

/*===========================================================================*/
/* Function: Get Display Lock
/* Purpose:  This function sets the manual operation via the display, or
/*           enables it again (OFF).
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetDisplayLock (ViSession instrSession,
                                              ViBoolean *displayLock)
{
    INIT;

    return GETPARAMBOOL (instrSession,
                               "SYST:DLOC?",
                               displayLock);
}

/*****************************************************************************
 * Function: MMEMory Catalog
 * Purpose:  This function reads out the subdirectories and files in the 
 *           specified directory. If no directory is specified, the default 
 *           directory selected with the MMEM:CDIR command is read out on the 
 *           default drive selected with the MMEM:MSIS command. 
 *           
 *           The response has the following format:
 *           
 *           
 *           <used_bytes_in_this_directory>,<free_bytes_on_this_disk>,"<file_name>,<file_type>,<filesize_in_bytes>","<file_name>,<file_type>,<filesize_in_bytes>", 
 *           ...
 *           
 *           Where:
 *           
 *           <file_name> ... File or directory name
 *           
 *           <file_type> ... File type. There are the following file types: 
 *           DIR (directory), ASCii (ASCII file), BINary (Binary file), and 
 *           STATe (file with instrument settings).
 *           
 *           <filesize_in_bytes> ... File size. The size "0" is returned for a 
 *           directory. 
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_MMEMoryCatalog(
    ViSession   instrSession,
    ViString    directoryPath,
    ViInt32 arraySize,
    ViChar _VI_FAR catalogList[]
)
{
    ViChar  buffer [BUFFER_SIZE];

    if (!directoryPath)
        sprintf (buffer, "MMEM:CAT?;*OPC?");
    else
        sprintf (buffer, "MMEM:CAT? '%s';*OPC?", directoryPath);

    return rssmf_getCatalog (instrSession,
                             buffer,
                             (ViUInt32) arraySize,
                             catalogList,"catalogList");
}

/*****************************************************************************
 * Function: MMEMory Catalog Length
 * Purpose:  This function reads out the number of files in the specified 
 *           directory. If no directory is specified, the default directory 
 *           selected with the MMEM:CDIR command is read out on the default 
 *           drive selected with the MMEM:MSIS command. 
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_MMEMoryCatalogLength(
    ViSession   instrSession,
    ViString    directoryPath,
    ViInt32*    catalogLength
)
{
    ViChar  buffer [BUFFER_SIZE];

    if (!directoryPath)
        sprintf (buffer, "MMEM:CAT:LENG?");
    else
        sprintf (buffer, "MMEM:CAT:LENG? '%s'", directoryPath);

    return GETPARAMINT32 (instrSession,
                             buffer,
                             catalogLength);
}

/*****************************************************************************
 * Function: MMEMory Change Directory
 * Purpose:  This function changes the default directory. This directory is 
 *           used for all subsequent MMEM commands if no path is specified with 
 *           them. It is also possible to change to a higher directory using 
 *           two dots '..'.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_MMEMoryChangeDirectory(
    ViSession   instrSession,
    ViString    directoryName
)
{
    INIT;

    return SETPARAMSTRINGQUOTED (instrSession,
                                    "MMEM:CDIR",
                                    "'",
                                    directoryName);
}

/*****************************************************************************
 * Function: MMEMory Copy
 * Purpose:  This function copies the first specified file to the second 
 *           specified file. Instead of just a file, this function can also be 
 *           used to copy a complete directory together with all its files. 
 *           
 *           If <destination> is not specified, <source> is copied to the 
 *           MMEM:MSIS drive and the MMEM:CDIR directory. Files which already 
 *           exist with the same name in the destination directory are 
 *           overwritten without an error message.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_MMEMoryCopy(
    ViSession   instrSession,
    ViString    sourcePath,
    ViString    destinationPath
)
{
    ViStatus    rssmf_status;
    ViChar      buffer[BUFFER_SIZE];

    CHECKNULL (sourcePath);

    if (destinationPath)
        sprintf (buffer, "MMEM:COPY '%s','%s'", sourcePath, destinationPath);
    else
        sprintf (buffer, "MMEM:COPY '%s'", sourcePath);

    CHECKERR (rssmf_sendCmd (instrSession, buffer));

    return rssmf_status;
}

/*****************************************************************************
 * Function: MMEMory Block Data Write
 * Purpose:  This function writes the block data <binary block data> to the 
 *           file identified by <file_name>. The IEC/IEEE-bus terminator should 
 *           be set to EOI in order to ensure correct data transfer.
 *           
 *           This function can be used to transfer stored instrument settings 
 *           or waveforms directly to the instrument.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_MMEMoryBlockDataWrite (ViSession instrSession,
                                      ViString fileName,
                                      ViInt32 binaryBlockLength,
                                      ViChar _VI_FAR binaryBlockData[])
{
    ViStatus    rssmf_status    = VI_SUCCESS;
    ViUInt16    intfType        = VI_INTF_GPIB;
    ViChar*     pbuffer;
    ViChar*     p2buf;

    CHECKNULL (fileName);
    CHECKNULL (binaryBlockData);

    CHECKERR (viGetAttribute (instrSession, VI_ATTR_INTF_TYPE, &intfType));

    if (intfType == VI_INTF_GPIB)
        CHECKERR (viWrite (instrSession, (ViBuf) "SYST:COMM:GPIB:LTER EOI\n", 25, VI_NULL));

    p2buf = pbuffer = malloc (strlen (fileName) + binaryBlockLength + 1000);

    p2buf += sprintf (pbuffer, "MMEM:DATA '%s',#%ld%ld",
                               fileName,
                               (ViInt32)(floor(log10((double)binaryBlockLength)) + 1),
                               binaryBlockLength);

    memcpy (p2buf, binaryBlockData, (size_t) binaryBlockLength);
//    p2buf[binaryBlockLength] = '\n';

    rssmf_status = viWrite (instrSession, (ViPBuf)pbuffer, (ViUInt32) ((p2buf - pbuffer) + binaryBlockLength), VI_NULL);

    if (pbuffer)
        free (pbuffer);

    if (intfType == VI_INTF_GPIB)
        CHECKERR (viWrite (instrSession, (ViBuf) "SYST:COMM:GPIB:LTER STAN\n", 26, VI_NULL));

    return rssmf_status;
}

/*****************************************************************************
 * Function: MMEMory Block Data Read
 * Purpose:  This function transfers the specified file from the R&S SMF to 
 *           the IEC/IEEE bus and then on to the control computer. It is 
 *           important to ensure that the intermediate memory on the control 
 *           computer is large enough to take the file. In this case, the 
 *           setting for the IEC/IEEE-bus terminator is irrelevant.
 *           
 *           This function can be used to read stored instrument settings or 
 *           waveforms directly from the instrument.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_MMEMoryBlockDataRead(
    ViSession   instrSession,
    ViString    fileName,
    ViInt32 binaryBlockLength,
    ViChar _VI_FAR binaryBlockData[]
)
{
    ViStatus    rssmf_status    = VI_SUCCESS;
    ViUInt16    intfType        = VI_INTF_GPIB;
    ViUInt32    count           = 0,
                lengthOfLength  = 0;
    ViChar      buffer[BUFFER_SIZE],
                format[32],
                *pbuffer = NULL, *p2buffer = NULL;

    CHECKNULL (fileName);

    CHECKERR (viGetAttribute (instrSession, VI_ATTR_INTF_TYPE, &intfType));

    if (intfType == VI_INTF_GPIB)
        CHECKERR (viWrite (instrSession, (ViBuf) "SYST:COMM:GPIB:LTER EOI\n", 25, VI_NULL));

    sprintf (buffer, "MMEM:DATA? '%s'\n", fileName);

    CHECKERR (viWrite (instrSession, (ViBuf) buffer, (ViUInt32) strlen(buffer), VI_NULL));
    CHECKERR (rssmf_readDataUnknownLength (instrSession, &pbuffer, &count));

    p2buffer = pbuffer;

    if (sscanf (p2buffer, "#%1lu", &lengthOfLength) != 1)
        {
        free (pbuffer);
        return VI_ERROR_INSTR_INTERPRETING_RESPONSE;
        }

    sprintf (format, "%%%lud", lengthOfLength);
    p2buffer += 2;

    if (sscanf (p2buffer, format, &count) != 1)
        {
        free (pbuffer);
        return VI_ERROR_INSTR_INTERPRETING_RESPONSE;
        }

    p2buffer += lengthOfLength;

    if (intfType == VI_INTF_GPIB)
        if ((rssmf_status = viWrite (instrSession, (ViBuf) "SYST:COMM:GPIB:LTER STAN\n", 26, VI_NULL)) < VI_SUCCESS)
            {
            free (pbuffer);
            return rssmf_status;
            }

    if ((rssmf_status = rssmf_checkStatus (instrSession)) < VI_SUCCESS)
        {
        free (pbuffer);
        return rssmf_status;
        }

    if (count > (ViUInt32) binaryBlockLength)
        {
        rssmf_status = RSSMF_WARNING_SMALL_BUFFER;
        count = (ViUInt32) binaryBlockLength;
        memcpy (binaryBlockData, p2buffer, (size_t) count);
        }
    else
        {
        rssmf_status = VI_SUCCESS;
        memcpy (binaryBlockData, p2buffer, (size_t) count);
        }

    free (pbuffer);

    return rssmf_status;
}

/*****************************************************************************
 * Function: MMEMory Directory Catalog
 * Purpose:  This function reads out the subdirectories of the specified 
 *           directory. If no directory is specified, the default directory 
 *           selected with the MMEM:CDIR command is read out. The directories 
 *           are output in a list (the list entries are separated by commas). 
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_MMEMoryDirectoryCatalog(
    ViSession   instrSession,
    ViString    directoryPath,
    ViInt32 arraySize,
    ViChar _VI_FAR catalogList[]
)
{
    ViStatus    rssmf_status;
    ViChar      buffer[BUFFER_SIZE];

    if (!directoryPath)
        sprintf (buffer, "MMEM:DCAT?;*OPC?");
    else
        sprintf (buffer, "MMEM:DCAT? '%s';*OPC?", directoryPath);

    CHECKERR (rssmf_getCatalog (instrSession,
                                     buffer,
                                     (ViUInt32) arraySize,
                                     catalogList,"catalogList"));

    return rssmf_status;
}

/*****************************************************************************
 * Function: MMEMory Directory Catalog Length
 * Purpose:  This function reads out the number of subdirectories in the 
 *           specified directory. If no directory is specified, the directory 
 *           selected with the MMEM:CDIR command is read out.  
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_MMEMoryDirectoryCatalogLength(
    ViSession   instrSession,
    ViString    directoryPath,
    ViInt32*    catalogLength
)
{
    ViStatus    rssmf_status;
    ViChar      buffer[BUFFER_SIZE];

    if (!directoryPath)
        sprintf (buffer, "MMEM:DCAT:LENG?");
    else
        sprintf (buffer, "MMEM:DCAT:LENG? '%s'", directoryPath);

    CHECKERR (GETPARAMINT32 (instrSession,
                                     buffer,
                                     catalogLength));

    return rssmf_status;
}

/*****************************************************************************
 * Function: MMEMory Delete
 * Purpose:  This function deletes the specified file.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_MMEMoryDelete(
    ViSession   instrSession,
    ViString    fileName
)
{
    INIT;

    return SETPARAMSTRINGQUOTED (instrSession,
                                    "MMEM:DEL",
                                    "'",
                                    fileName);
}

/*****************************************************************************
 * Function: MMEMory Load
 * Purpose:  This function loads the specified file stored under the specified 
 *           name in an internal memory. If 0 is used, the instrument setting 
 *           of the selected file is set directly in the R&S SMF. The *RCL 
 *           command is used to load the intermediate instrument setting (see 
 *           the section Common Functions (Commands)).
 *           
 *           If a number other than 0 is used when storing, the instrument 
 *           setting must be activated using an *RCL command with this number 
 *           after the file has been loaded.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_MMEMoryLoad(
    ViSession   instrSession,
    ViInt32 instrumentSetting,
    ViString    fileName
)
{
    ViChar buffer[BUFFER_SIZE];

    CHECKVIINT32 (instrSession, instrumentSetting, 0, 10);
    CHECKNULL (fileName);

    sprintf (buffer, "MMEM:LOAD:STAT %ld,'%s'", instrumentSetting, fileName);

    return rssmf_sendCmd (instrSession, buffer);
}

/*****************************************************************************
 * Function: MMEMory Make Directory
 * Purpose:  This function creates a new subdirectory in the specified 
 *           directory. If no directory is specified, a subdirectory is created 
 *           in the default directory. This function can also be used to create 
 *           a directory tree.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_MMEMoryMakeDirectory(
    ViSession   instrSession,
    ViString    directoryName
)
{
    INIT;

    return SETPARAMSTRINGQUOTED (instrSession,
                                    "MMEM:MDIR",
                                    "'",
                                    directoryName);
}

/*****************************************************************************
 * Function: MMEMory Move
 * Purpose:  This function renames an existing file ('File Source') if no path 
 *           is specified for 'File Destination'. Otherwise the file is moved 
 *           to the specified path and stored under the original file name or, 
 *           if specified, a new file name.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_MMEMoryMove(
    ViSession   instrSession,
    ViString    fileSource,
    ViString    fileDestination
)
{
    ViStatus    rssmf_status;
    ViChar*     pbuffer;

    CHECKNULL (fileSource);
    CHECKNULL (fileDestination);

    pbuffer = malloc (strlen (fileSource) + strlen (fileDestination) + 20);

    sprintf (pbuffer, "MMEM:MOVE '%s','%s'", fileSource, fileDestination);

    CHECKERR (rssmf_sendCmd (instrSession, pbuffer));

    free (pbuffer);

    RETURN;
}

/*****************************************************************************
 * Function: MMEMory Remove Directory
 * Purpose:  This function deletes the specified subdirectory in the specified 
 *           directory. If no directory is specified, the subdirectory with the 
 *           specified name is deleted in the default directory.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_MMEMoryRemoveDirectory(
    ViSession   instrSession,
    ViString    directoryName
)
{
    INIT;

    return SETPARAMSTRINGQUOTED (instrSession,
                                    "MMEM:RDIR",
                                    "'",
                                    directoryName);
}

/*****************************************************************************
 * Function: MMEMory Store
 * Purpose:  This function stores the current instrument setting in the 
 *           specified file. If 0 is specified, the current instrument setting 
 *           is stored directly in the specified file. The intermediate 
 *           instrument settings can be stored using the *SAV command (see the 
 *           section Common Functions (Commands)).
 *           
 *           If a number other than 0 is specified, the instrument setting 
 *           must first be stored in an internal memory with the same number 
 *           using the common command *SAV.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_MMEMoryStore(
    ViSession   instrSession,
    ViInt32 instrumentSetting,
    ViString    fileName
)
{
    ViChar buffer[BUFFER_SIZE];

    CHECKVIINT32 (instrSession, instrumentSetting, 0, 10);
    CHECKNULL (fileName);

    sprintf (buffer, "MMEM:STOR:STAT %ld,'%s'", instrumentSetting, fileName);

    return rssmf_sendCmd (instrSession, buffer);
}

/*****************************************************************************
 * Function: Set Register
 * Purpose:  This function sets the value of selected status register.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_setRegister(
    ViSession   instrSession,
    ViInt32 registerGroup,
    ViInt32 registerType,
    ViInt32 value
)
{
    ViChar  buffer[BUFFER_SIZE];

    CHECKVIINT32 (instrSession, registerGroup, 0, 1);
    CHECKVIINT32 (instrSession, registerType, 2, 4);

    sprintf (buffer, "STAT:%s:%s", regGroupArr[registerGroup], regTypeArr[registerType]);

    return SETPARAMINT32 (instrSession,
                             buffer,
                             value,
                             0, 0);
}

/*****************************************************************************
 * Function: Get Register
 * Purpose:  This function sets the value of selected status register.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_getRegister(
    ViSession   instrSession,
    ViInt32 registerGroup,
    ViInt32 registerType,
    ViInt32*    value
)
{
    ViChar  buffer[BUFFER_SIZE];

    CHECKVIINT32 (instrSession, registerGroup, 0, 1);
    CHECKVIINT32 (instrSession, registerType, 2, 4);

    sprintf (buffer, "STAT:%s:%s?", regGroupArr[registerGroup], regTypeArr[registerType]);

    return GETPARAMINT32 (instrSession,
                             buffer,
                             value);
}

/*****************************************************************************
 * Function: STATus PRESet
 * Purpose:  This function resets the status registers. All PTRansition parts 
 *           are set to FFFFh (32767), i.e. all transitions from 0 to 1 are 
 *           detected. All NTRansition parts are set to 0, i.e. a transition 
 *           from 1 to 0 in a CONDition bit is not detected. The ENABle parts 
 *           of STATus:OPERation and STATus:QUEStionable are set to 0, i.e. all 
 *           events in these registers are not passed on.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_STATusPRESet(
    ViSession   instrSession
)
{
    INIT;

    return rssmf_sendCmd (instrSession, "STAT:PRES");
}

/*****************************************************************************
 * Function: Set SYSTem Beeper
 * Purpose:  This function switches the key beep on or off.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetSYSTemBeeper(
    ViSession   instrSession,
    ViBoolean   systemBeeper
)
{
    INIT;

    return SETPARAMBOOL (instrSession,
                               "SYST:BEEP:STAT",
                               systemBeeper);
}

/*****************************************************************************
 * Function: Get SYSTem Beeper
 * Purpose:  This function returns status of the key beep on or off.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetSYSTemBeeper(
    ViSession   instrSession,
    ViBoolean*  systemBeeper
)
{
    INIT;

    return GETPARAMBOOL (instrSession,
                               "SYST:BEEP:STAT?",
                               systemBeeper);
}

/*****************************************************************************
 * Function: SYSTem Error Queue All
 * Purpose:  This function queries all entries in the error queue and then 
 *           deletes them. Positive error numbers denote instrument-specific 
 *           errors, and negative error numbers denote error messages defined 
 *           by SCPI (see Chapter 9). If the error queue is empty, 0 ("No 
 *           error") is returned. 
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SYSTemErrorQueueAll(
    ViSession   instrSession,
    ViInt32 arraySize,
    ViChar _VI_FAR errorQueue[]
)
{
    INIT;

    return GETPARAMSTRING (instrSession,
                              "SYST:ERR:ALL?",
                              errorQueue,
                              (ViUInt32) arraySize);
}

/*****************************************************************************
 * Function: SYSTem Error Queue Code All
 * Purpose:  This function queries all entries in the error queue and then 
 *           deletes them. Only the error numbers are returned and not the 
 *           entire error text. Positive error numbers denote 
 *           instrument-specific errors, and negative error numbers denote 
 *           error messages defined by SCPI (see Chapter 9). If the error queue 
 *           is empty, 0 ("No error") is returned. 
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SYSTemErrorQueueCodeAll(
    ViSession   instrSession,
    ViInt32 arraySize,
    ViChar _VI_FAR errorQueueCode[]
)
{
    INIT;

    return GETPARAMSTRING (instrSession,
                              "SYST:ERR:CODE:ALL?",
                              errorQueueCode,
                              (ViUInt32) arraySize);
}

/*****************************************************************************
 * Function: SYSTem Error Queue Code Next
 * Purpose:  This function queries the oldest entry in the error queue and 
 *           then deletes it. Only the error number is returned and not the 
 *           entire error text. Positive error numbers denote 
 *           instrument-specific errors, and negative error numbers denote 
 *           error messages defined by SCPI (see Chapter 9). If the error queue 
 *           is empty, 0 is returned. 
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SYSTemErrorQueueCodeNext(
    ViSession   instrSession,
    ViInt32*    errorQueueCodeNext
)
{
    INIT;

    return GETPARAMINT32 (instrSession,
                             "SYST:ERR:CODE?",
                             errorQueueCodeNext);
}

/*****************************************************************************
 * Function: SYSTem Error Queue Count
 * Purpose:  This function queries the number of entries in the error queue. 
 *           If the error queue is empty, '0' is returned.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SYSTemErrorQueueCount(
    ViSession   instrSession,
    ViInt32*    errorQueueCount
)
{
    INIT;

    return GETPARAMINT32 (instrSession,
                             "SYST:ERR:COUN?",
                             errorQueueCount);
}

/*****************************************************************************
 * Function: SYSTem USB Resource
 * Purpose:  This function queries the USB resource.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SYSTemUSBResource(
    ViSession   instrSession,
    ViInt32 arraySize,
    ViChar    usbResource[]
)
{
    INIT;

    return GETPARAMSTRING (instrSession,
                              ":SYST:COMM:USB:RES?",
                              usbResource,
                              (ViUInt32) arraySize);
}

/*****************************************************************************
 * Function: SYSTem GPIB Resource
 * Purpose:  This function queries the visa resource string for the GPIB
 *       remote control interface. This string is used for remote control
 *       of the instrument.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SYSTemGPIBResource(
    ViSession   instrSession,
    ViInt32 arraySize,
    ViChar    gpibResource[]
)
{
    INIT;

    return GETPARAMSTRING (instrSession,
                              ":SYST:COMM:GPIB:RES?",
                              gpibResource,
                              (ViUInt32) arraySize);
}

/*****************************************************************************
 * Function: SYSTem Serial Resource
 * Purpose:  This function queries the visa resource string for the serial
 *       remote control interface. This string is used for remote control
 *       of the instrument.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SYSTemSerialResource(
    ViSession   instrSession,
    ViInt32 arraySize,
    ViChar    serialResource[]
)
{
    INIT;

    return GETPARAMSTRING (instrSession,
                              ":SYST:COMM:SER:RES?",
                              serialResource,
                              (ViUInt32) arraySize);
}

/*****************************************************************************
 * Function: SYSTem Option User Defined
 * Purpose:  This function defines the OPT string for selection user defined
 *       (SYST:IDEN USER).
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SYSTemOptionUserDefined(
    ViSession   instrSession,
    ViString    userDefinedIdentification
)
{
    INIT;

    return SETPARAMSTRING (instrSession,
                              ":SYST:ORES",
                              userDefinedIdentification);
}

/*****************************************************************************
 * Function: Set SYSTem Protect
 * Purpose:  This function activates and deactivates the specified protection 
 *           level. There are several protection levels which disable specific 
 *           service functions (authorized personnel of R&S Service Deparments 
 *           only). These levels are identified by the suffix under PROTect.
 *           
 *           The respective functions are disabled when the protection level 
 *           is activated. No password is required for activation. A password 
 *           must be entered to deactivate the protection level.  The password 
 *           for the first level is 123456. This protection level can be used 
 *           to lock-out internal adjustments.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetSYSTemProtect(
    ViSession   instrSession,
    ViInt32 protectionLevel,
    ViBoolean   protection,
    ViString    password
)
{
    ViChar  buffer [BUFFER_SIZE];

    CHECKVIINT32 (instrSession, protectionLevel, 1, 5);
    CHECKNULL (password);

    if (protection == VI_FALSE)
        sprintf (buffer, "SYST:PROT%ld OFF,%s", protectionLevel, password);
    else
        sprintf (buffer, "SYST:PROT%ld ON", protectionLevel);

    return rssmf_sendCmd (instrSession, buffer);
}

/*****************************************************************************
 * Function: Get SYSTem Version
 * Purpose:  This function queries the SCPI version with which the instrument 
 *           complies.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetSYSTemVersion(
    ViSession   instrSession,
    ViChar _VI_FAR scpiVersion[]
)
{
    ViStatus rssmf_status = VI_SUCCESS;

    CHECKERR (GETPARAMSTRING (instrSession,
                                      "SYST:VERS?",
                                      scpiVersion,
                                      32));

    return (rssmf_status < VI_SUCCESS) ? rssmf_status : VI_SUCCESS;
}

/*===========================================================================*/
/* Function: Get SYSTem Startup Status
/* Purpose:  This function returns if the startup of the instrument is 
/*           completed.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetSYSTemStartupStatus(
    ViSession   instrSession,
    ViInt32*    startupComplete
)
{
    INIT;

    return GETPARAMINT32 (instrSession,
                             "SYST:STAR:COMP?",
                             startupComplete);
}

/*===========================================================================*/
/* Function: SYSTem Factory Preset
/* Purpose:  This function  triggers an instrument reset to the original
/*           state of delivery.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_SYSTemFactoryPreset (ViSession instrSession)
{
    INIT;

    return rssmf_sendCmd (instrSession, "SYST:FPR");
}

/*===========================================================================*/
/* Function: Get SYSTem Error List
/* Purpose:  The function returns a list of all errors existing at the time
/*           when the query is started. This list corresponds to the display
/*           on the info page under manual control.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetSYSTemErrorList (ViSession instrSession,
                                            ViInt32 arraySize,
                                            ViChar errorQueue[])
{
    INIT;

    return GETPARAMSTRING (instrSession,
                              "SYST:SERR?",
                              errorQueue,
                              (ViUInt32) arraySize);
}

/*****************************************************************************
 * Function: Set SYSTem Network IP Address
 * Purpose:  This function sets the ip address.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetSYSTemNetworkIPAddress(
    ViSession   instrSession,
    ViString    ipAddress
)
{
    INIT;

    return SETPARAMSTRINGQUOTED (instrSession,
                                    "SYST:COMM:NETW:IPAD",
                                    "'",
                                    ipAddress);
}

/*****************************************************************************
 * Function: Get SYSTem Network IP Address
 * Purpose:  This function returns the IP address.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetSYSTemNetworkIPAddress(
    ViSession   instrSession,
    ViInt32 arraySize,
    ViChar _VI_FAR ipAddress[]
)
{
    INIT;

    return GETPARAMSTRING (instrSession,
                              "SYST:COMM:NETW:IPAD?",
                              ipAddress,
                              (ViUInt32)arraySize);
}

/*****************************************************************************
 * Function: Set SYSTem Network IP Address Subnet Mask
 * Purpose:  This function sets the subnet mask.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetSYSTemNetworkIPAddressSubnetMask(
    ViSession   instrSession,
    ViString    ipAddressSubnetMask
)
{
    INIT;

    return SETPARAMSTRINGQUOTED (instrSession,
                                    "SYST:COMM:NETW:IPAD:SUBN:MASK",
                                    "'",
                                    ipAddressSubnetMask);
}

/*****************************************************************************
 * Function: Get SYSTem Network IP Address Subnet Mask
 * Purpose:  This function returns the IP address subnet mask.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetSYSTemNetworkIPAddressSubnetMask(
    ViSession   instrSession,
    ViInt32 arraySize,
    ViChar _VI_FAR  ipAddressSubnetMask[]
)
{
    INIT;

    return GETPARAMSTRING (instrSession,
                              "SYST:COMM:NETW:IPAD:SUBN:MASK?",
                              ipAddressSubnetMask,
                              (ViUInt32)arraySize);
}

/*****************************************************************************
 * Function: Set SYSTem Network IP Address Gateway
 * Purpose:  This function sets the ip adress gateway.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetSYSTemNetworkIPAddressGateway(
    ViSession   instrSession,
    ViString    ipAddressGateway
)
{
    INIT;

    return SETPARAMSTRINGQUOTED (instrSession,
                                    "SYST:COMM:NETW:IPAD:GAT",
                                    "'",
                                    ipAddressGateway);
}

/*****************************************************************************
 * Function: Get SYSTem Network IP Address Gateway
 * Purpose:  This function returns the gateway.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetSYSTemNetworkIPAddressGateway(
    ViSession   instrSession,
    ViInt32 arraySize,
    ViChar _VI_FAR ipAddressGateway[]
)
{
    INIT;

    return GETPARAMSTRING (instrSession,
                              "SYST:COMM:NETW:IPAD:GAT?",
                              ipAddressGateway,
                              (ViUInt32)arraySize);
}

/*****************************************************************************
 * Function: Set SYSTem Network IP Address Mode
 * Purpose:  This function sets the IP address mode.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetSYSTemNetworkIPAddressMode(
    ViSession   instrSession,
    ViInt32 ipAddressMode
)
{
    INIT;

    return SETPARAMENUM (instrSession,
                          "SYST:COMM:NETW:IPAD:MODE",
                          ipAddressMode,
                          ipAddressModeArr);
}

/*****************************************************************************
 * Function: Get SYSTem Network IP Address Mode
 * Purpose:  This function returns the IP address mode.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetSYSTemNetworkIPAddressMode(
    ViSession   instrSession,
    ViInt32*    ipAddressMode
)
{
    INIT;

    return GETPARAMENUM (instrSession,
                          "SYST:COMM:NETW:IPAD:MODE?",
                          ipAddressMode,
                          ipAddressModeArr);
}

/*****************************************************************************
 * Function: SYSTem Network IP Address Execute
 * Purpose:  This function execute the IP address settings.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SYSTemNetworkIPAddressExecute(
    ViSession   instrSession
)
{
    INIT;

    return rssmf_sendCmd (instrSession, "SYST:COMM:NETW:IPAD:SET");
}

/*****************************************************************************
 * Function: Set SYSTem Network Common Workgroup
 * Purpose:  This function sets the common workgroup.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetSYSTemNetworkCommonWorkgroup(
    ViSession   instrSession,
    ViString    commonWorkgroup
)
{
    INIT;

    return SETPARAMSTRINGQUOTED (instrSession,
                                    "SYST:COMM:NETW:COMM:WORK",
                                    "'",
                                    commonWorkgroup);
}

/*****************************************************************************
 * Function: Get SYSTem Network Common Workgroup
 * Purpose:  This function returns the common workgroup.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetSYSTemNetworkCommonWorkgroup(
    ViSession   instrSession,
    ViInt32 arraySize,
    ViChar _VI_FAR commonWorkgroup[]
)
{
    INIT;

    return GETPARAMSTRING (instrSession,
                              "SYST:COMM:NETW:COMM:WORK?",
                              commonWorkgroup,
                              (ViUInt32)arraySize);
}

/*****************************************************************************
 * Function: Set SYSTem Network Common Domain
 * Purpose:  This function sets the common domain.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetSYSTemNetworkCommonDomain(
    ViSession   instrSession,
    ViString    commonDomain
)
{
    INIT;

    return SETPARAMSTRINGQUOTED (instrSession,
                                    "SYST:COMM:NETW:COMM:DOM",
                                    "'",
                                    commonDomain);
}

/*****************************************************************************
 * Function: Get SYSTem Network Common Domain
 * Purpose:  This function returns the common domain.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetSYSTemNetworkCommonDomain(
    ViSession   instrSession,
    ViInt32 arraySize,
    ViChar _VI_FAR commonDomain[]
)
{
    INIT;

    return GETPARAMSTRING (instrSession,
                              "SYST:COMM:NETW:COMM:DOM?",
                              commonDomain,
                              (ViUInt32)arraySize);
}

/*****************************************************************************
 * Function: Set SYSTem Network Common Hostname
 * Purpose:  This function sets the individual computer name of the R&S SMF.
 *           
 *           Note(s):
 *           
 *           (1) The entry is only activated after sending command 
 *           SYST:COMM:NETW:COMM:SET (function 
 *           rssmf_SYSTemNetworkCommonExecute).
 *           
 *           (2) The hostname can only be changed after deactivating 
 *           protection level 1 (command SYSTem:PROTect<n>:STATe OFF, password) 
 *           - function rssmf_SetSYSTemProtect.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetSYSTemNetworkCommonHostname(
    ViSession   instrSession,
    ViString    commonHostname
)
{
    INIT;

    return SETPARAMSTRINGQUOTED (instrSession,
                                    "SYST:COMM:NETW:COMM:HOST",
                                    "'",
                                    commonHostname);
}

/*****************************************************************************
 * Function: Get SYSTem Network Common Hostname
 * Purpose:  This function returns the individual computer name of the R&S 
 *           SMF.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetSYSTemNetworkCommonHostname(
    ViSession   instrSession,
    ViInt32 arraySize,
    ViChar    commonHostname[]
)
{
    INIT;

    return GETPARAMSTRING (instrSession,
                              "SYST:COMM:NETW:COMM:HOST?",
                              commonHostname,
                              (ViUInt32)arraySize);
}

/*****************************************************************************
 * Function: SYSTem Network Common Execute
 * Purpose:  This function execute the common settings.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SYSTemNetworkCommonExecute(
    ViSession   instrSession
)
{
    INIT;

    return rssmf_sendCmd (instrSession,"SYST:COMM:NETW:COMM:SET");
}

/*****************************************************************************
 * Function: Set SYSTem Network Prefered DNS
 * Purpose:  This function sets the prefered DNS.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetSYSTemNetworkPreferedDNS(
    ViSession   instrSession,
    ViString    preferedDNS
)
{
    INIT;

    return SETPARAMSTRINGQUOTED (instrSession,
                                    "SYST:COMM:NETW:DNS:PREF",
                                    "'",
                                    preferedDNS);
}

/*****************************************************************************
 * Function: Get SYSTem Network Prefered DNS
 * Purpose:  This function displays the prefered DNS.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetSYSTemNetworkPreferedDNS(
    ViSession   instrSession,
    ViInt32 arraySize,
    ViChar _VI_FAR preferedDNS[]
)
{
    INIT;

    return GETPARAMSTRING (instrSession,
                              "SYST:COMM:NETW:DNS:PREF?",
                              preferedDNS,
                              (ViUInt32)arraySize);
}

/*****************************************************************************
 * Function: Set SYSTem Network Alternate DNS
 * Purpose:  This function sets the alternate DNS.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetSYSTemNetworkAlternateDNS(
    ViSession   instrSession,
    ViString    alternateDNS
)
{
    INIT;

    return SETPARAMSTRINGQUOTED (instrSession,
                                    "SYST:COMM:NETW:DNS:ALT",
                                    "'",
                                    alternateDNS);
}

/*****************************************************************************
 * Function: Get SYSTem Network Alternate DNS
 * Purpose:  This function displays the prefered DNS.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetSYSTemNetworkAlternateDNS(
    ViSession   instrSession,
    ViInt32 arraySize,
    ViChar _VI_FAR alternateDNS[]
)
{
    INIT;

    return GETPARAMSTRING (instrSession,
                              "SYST:COMM:NETW:DNS:ALT?",
                              alternateDNS,
                              (ViUInt32)arraySize);
}

/*****************************************************************************
 * Function: Set SYSTem Network DNS Mode
 * Purpose:  This function sets the DNS mode.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetSYSTemNetworkDNSMode(
    ViSession   instrSession,
    ViInt32 dnsMode
)
{
    INIT;

    return SETPARAMENUM (instrSession,
                          "SYST:COMM:NETW:DNS:MODE",
                          dnsMode,
                          dnsModeArr);
}

/*****************************************************************************
 * Function: Get SYSTem Network DNS Mode
 * Purpose:  This function returns the DNS mode.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetSYSTemNetworkDNSMode(
    ViSession   instrSession,
    ViInt32*    dnsMode
)
{
    INIT;

    return GETPARAMENUM (instrSession,
                          "SYST:COMM:NETW:DNS:MODE?",
                          dnsMode,
                          dnsModeArr);
}

/*****************************************************************************
 * Function: SYSTem Network DNS Execute
 * Purpose:  This function execute the DNS settings.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SYSTemNetworkDNSExecute(
    ViSession   instrSession
)
{
    INIT;

    return rssmf_sendCmd (instrSession, "SYST:COMM:NETW:DNS:SET");
}

/*****************************************************************************
 * Function: Set SYSTem Network Domain
 * Purpose:  This function sets the domain.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetSYSTemNetworkDomain(
    ViSession   instrSession,
    ViString    domain
)
{
    INIT;

    return SETPARAMSTRINGQUOTED (instrSession,
                                    "SYST:COMM:NETW:DOM",
                                    "'",
                                    domain);
}

/*****************************************************************************
 * Function: Get SYSTem Network Domain
 * Purpose:  This function returns the domain.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetSYSTemNetworkDomain(
    ViSession   instrSession,
    ViInt32 arraySize,
    ViChar _VI_FAR domain[]
)
{
    INIT;

    return GETPARAMSTRING (instrSession,
                              "SYST:COMM:NETW:DOM?",
                              domain,
                              (ViUInt32)arraySize);
}

/*****************************************************************************
 * Function: Set SYSTem Network Gateway
 * Purpose:  This function sets the gateway.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetSYSTemNetworkGateway(
    ViSession   instrSession,
    ViString    gateway
)
{
    INIT;

    return SETPARAMSTRINGQUOTED (instrSession,
                                    "SYST:COMM:NETW:GAT",
                                    "'",
                                    gateway);
}

/*****************************************************************************
 * Function: Get SYSTem Network Gateway
 * Purpose:  This function returns the gateway.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetSYSTemNetworkGateway(
    ViSession   instrSession,
    ViInt32 arraySize,
    ViChar _VI_FAR gateway[]
)
{
    INIT;

    return GETPARAMSTRING (instrSession,
                              "SYST:COMM:NETW:GAT?",
                              gateway,
                              (ViUInt32)arraySize);
}

/*****************************************************************************
 * Function: Get SYSTem Network Resource
 * Purpose:  This function returns the resource string.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetSYSTemNetworkResource(
    ViSession   instrSession,
    ViInt32 arraySize,
    ViChar _VI_FAR resource[]
)
{
    INIT;

    return GETPARAMSTRING (instrSession,
                              "SYST:COMM:NETW:RES?",
                              resource,
                              (ViUInt32)arraySize);
}

/*****************************************************************************
 * Function: Set SYSTem Network Subnet Mask
 * Purpose:  This function sets the subnet mask.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetSYSTemNetworkSubnetMask(
    ViSession   instrSession,
    ViString    subnetMask
)
{
    INIT;

    return SETPARAMSTRINGQUOTED (instrSession,
                                    "SYST:COMM:NETW:SUBN:MASK",
                                    "'",
                                    subnetMask);
}

/*****************************************************************************
 * Function: Get SYSTem Network Subnet Mask
 * Purpose:  This function returns the subnet mask.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetSYSTemNetworkSubnetMask(
    ViSession   instrSession,
    ViInt32 arraySize,
    ViChar _VI_FAR subnetMask[]
)
{
    INIT;

    return GETPARAMSTRING (instrSession,
                              "SYST:COMM:NETW:SUBN:MASK?",
                              subnetMask,
                              (ViUInt32)arraySize);
}

/*****************************************************************************
 * Function: Set SYSTem Network Workgroup
 * Purpose:  This function sets the workgroup.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetSYSTemNetworkWorkgroup(
    ViSession   instrSession,
    ViString    workgroup
)
{
    INIT;

    return SETPARAMSTRINGQUOTED (instrSession,
                                    "SYST:COMM:NETW:WORK",
                                    "'",
                                    workgroup);
}

/*****************************************************************************
 * Function: Get SYSTem Network Workgroup
 * Purpose:  This function returns the workgroup.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetSYSTemNetworkWorkgroup(
    ViSession   instrSession,
    ViInt32 arraySize,
    ViChar _VI_FAR workgroup[]
)
{
    INIT;

    return GETPARAMSTRING (instrSession,
                              "SYST:COMM:NETW:WORK?",
                              workgroup,
                              (ViUInt32)arraySize);
}

/*****************************************************************************
 * Function: Get SYSTem Network Mac Address
 * Purpose:  This function returns the MAC Address.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetSYSTemNetworkMACAddress(
    ViSession   instrSession,
    ViInt32 arraySize,
    ViChar _VI_FAR macAddress[]
)
{
    INIT;

    return GETPARAMSTRING (instrSession,
                              "SYST:COMM:NETW:MACaddress?",
                              macAddress,
                              (ViUInt32)arraySize);
}

/*****************************************************************************
 * Function: Get SYSTem Network
 * Purpose:  This function retrieves the current network settings. They can be 
 *           queried with the corresponding functions.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetSYSTemNetwork(
    ViSession   instrSession
)
{
    INIT;

    return rssmf_sendCmd (instrSession,"SYST:COMM:NETW:GET");
}

/*****************************************************************************
 * Function: Trigger Source For All Sweeps
 * Purpose:  This function sets the trigger source for all sweeps. 
 *           
 *           The names of the parameters correspond directly to the various 
 *           settings under manual control. SCPI uses other names for the 
 *           parameters; these names are also accepted by the instrument. The 
 *           SCPI names should be used if compatibility is an important 
 *           consideration.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_TriggerSourceAllSweeps(
    ViSession   instrSession,
    ViInt32 triggerSourceAllSweeps
)
{
    INIT;

    return SETPARAMENUM (instrSession,
                          "TRIG:SWE:SOUR",
                          triggerSourceAllSweeps,
                          triggerRFSourceArr);
}

/*****************************************************************************
 * Function: Trigger All Sweeps
 * Purpose:  This function starts the sweeps which is activated. The sweep to 
 *           be executed depends on the respective MODE setting 
 *           (:SOUR:SWEep:POW|FREQ:MODE and :SOUR:LFO:SWEep[:FREQ]:MODE). This 
 *           function corresponds to the manual-control command
 *           Execute Trigger.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_TriggerAllSweeps(
    ViSession   instrSession
)
{
    INIT;

    return rssmf_sendCmd (instrSession, "TRIG");
}

/*****************************************************************************
 * Function: All Sweep Reset
 * Purpose:  This function resets all active sweeps to the starting point.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SweepReset(
    ViSession   instrSession
)
{
    INIT;

    return rssmf_sendCmd (instrSession, "SOUR:SWE:RES");
}

/*****************************************************************************
 * Function: Trigger RF Frequency Sweep
 * Purpose:  This function immediately starts an RF frequency sweep. The sweep 
 *           to be executed depends on the respective MODE setting 
 *           (:SOURce:SWEep:FREQuency:MODE SING). This function corresponds to 
 *           the manual-control command Execute Trigger. 
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_TriggerRFFrequencySweep(
    ViSession   instrSession
)
{
    INIT;

    return rssmf_sendCmd (instrSession, "TRIG:FSW");
}

/*****************************************************************************
 * Function: Trigger RF Level Sweep
 * Purpose:  This function immediately starts an RF level sweep. The sweep to 
 *           be executed depends on the set sweep mode 
 *           (:SOURce:SWEep:POWer:MODE). This function corresponds to the 
 *           manual-control command Execute Trigger. 
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_TriggerRFLevelSweep(
    ViSession   instrSession
)
{
    INIT;

    return rssmf_sendCmd (instrSession, "TRIG:PSW");
}

/*****************************************************************************
 * Function: Set No Signal Marker Polarity
 * Purpose:  This function sets the polarity of the No Signal (Blank) Marker.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetNoSignalMarkerPolarity(
    ViSession   instrSession,
    ViInt32 markerPolarity
)
{
    INIT;

    return SETPARAMENUM (instrSession,
                          "OUTP:BLAN:POL",
                          markerPolarity,
                          markerPolarityArr);
}

/*****************************************************************************
 * Function: Get No Signal Marker Polarity
 * Purpose:  This function returns the polarity of the No Signal (Blank) 
 *           Marker.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetNoSignalMarkerPolarity(
    ViSession   instrSession,
    ViInt32*    markerPolarity
)
{
    INIT;

    return GETPARAMENUM (instrSession,
                          "OUTP:BLAN:POL?",
                          markerPolarity,
                          markerPolarityArr);
}

/*****************************************************************************
 * Function: Set Blank Width
 * Purpose:  This function selects the width of the blank mark.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_SetBlankWidth (ViSession instrSession,
                                       ViInt32 blankWidth)
{
    INIT;

    return SETPARAMENUM (instrSession,
                          "OUTP:BLAN:WIDT",
                          blankWidth,
                          blankWidthArr);
}

/*****************************************************************************
 * Function: Get Blank Width
 * Purpose:  This function returns the width of the blank mark.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_GetBlankWidth (ViSession instrSession,
                                       ViInt32 *blankWidth)
{
    INIT;

    return GETPARAMENUM (instrSession,
                          "OUTP:BLAN:WIDT?",
                          blankWidth,
                          blankWidthArr);
}

/*===========================================================================*/
/* Function: Set Angle Units
/* Purpose:  This function sets the default unit for angles. It is valid for 
/*           all commands which determine angle values. It does not influence 
/*           the manual control parameter unit and the display.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_SetAngleUnits(
    ViSession   instrSession,
    ViInt32 angleUnits
)
{
    INIT;

    return SETPARAMENUM (instrSession,
                          "UNIT:ANGL",
                          angleUnits,
                          angleUnitsArr);
}

/*===========================================================================*/
/* Function: Get Angle Units
/* Purpose:  This function returns the unit for angles. 
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetAngleUnits(
    ViSession   instrSession,
    ViInt32*    angleUnits
)
{
    INIT;

    return GETPARAMENUM (instrSession,
                          "UNIT:ANGL?",
                          angleUnits,
                          angleUnitsArr);
}

/*===========================================================================*/
/* Function: Set Power Units
/* Purpose:  This function sets the default unit for power. It is valid for 
/*           all commands which determine power values. It does not influence 
/*           the manual control parameter unit and the display.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_SetPowerUnits(
    ViSession   instrSession,
    ViInt32 powerUnits
)
{
    INIT;

    return SETPARAMENUM (instrSession,
                          "UNIT:POW",
                          powerUnits,
                          powerUnitsArr);
}

/*===========================================================================*/
/* Function: Get Power Units
/* Purpose:  This function returns the unit for power.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetPowerUnits(
    ViSession   instrSession,
    ViInt32*    powerUnits
)
{
    INIT;

    return GETPARAMENUM (instrSession,
                          "UNIT:POW?",
                          powerUnits,
                          powerUnitsArr);
}

/*===========================================================================*/
/* Function: Set Velocity Units
/* Purpose:  This function sets the default unit for velocity. It is valid 
/*           for all commands which determine velocity values. It does not 
/*           influence the manual control parameter unit and the display.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_SetVelocityUnits(
    ViSession   instrSession,
    ViInt32 velocityUnits
)
{
    INIT;

    return SETPARAMENUM (instrSession,
                          "UNIT:VEL",
                          velocityUnits,
                          velocityUnitsArr);
}

/*===========================================================================*/
/* Function: Get Velocity Units
/* Purpose:  This function returns the default unit for velocity. It is 
/*           valid for all commands which determine velocity values. It does 
/*           not influence the manual control parameter unit and the display.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_GetVelocityUnits(
    ViSession   instrSession,
    ViInt32*    velocityUnits
)
{
    INIT;

    return GETPARAMENUM (instrSession,
                          "UNIT:VEL?",
                          velocityUnits,
                          velocityUnitsArr);
}

/*****************************************************************************
 * Function: Read To File From Instrument
 * Purpose:  This function is used to read data from the instrument and write 
 *           it to a user specified file on the host computer.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_readToFile(
    ViSession   instrSession,
    ViString    source,
    ViString    destination
)
{
    ViChar      buffer[BUFFER_SIZE];
    
    sprintf (buffer, ":MMEM:DATA? '%s'", source);
    
    return rssmf_readDataToFile (instrSession, buffer, destination);
}

/*****************************************************************************
 * Function: Write From File To Instrument
 * Purpose:  This function is used to read data from the host computer and 
 *           write it to a user specified file in the instrument.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_writeFromFile(
    ViSession   instrSession,
    ViString    source,
    ViString    destination
)
{
    ViStatus    rssmf_status = VI_SUCCESS;
    ViUInt32    digits = 0;
    FILE        *sourceFile = NULL;
    ViUInt64    fileSize = 0;
#if defined (_CVI_)
	ViUInt32      fileSize32 = 0;
#endif
    
    /* Open source file from host controller */
    if ((sourceFile = fopen (source, "rb")) == NULL)
	{
        CHECKERR(VI_ERROR_INSTR_FILE_OPEN);
	}

    /* Get size of file */
    (void) fseek (sourceFile, 0, SEEK_END);
#if defined (_CVI_)
    GetFileSize (source, &fileSize32);
	fileSize = (ViUInt64) fileSize32;
#elif defined(_MSC_VER)
    fileSize = (ViUInt64) _ftelli64 (sourceFile);
#else
    fileSize = (ViUInt64) ftell (sourceFile);
#endif
    (void) fseek (sourceFile, 0, SEEK_SET);

    /* Create command header */
    digits = (ViUInt32) ((int)floor(log10((double)fileSize))) + 1;
    if (digits < 10)
	{
		CHECKERR (viPrintf (instrSession, ":MMEM:DATA '%s',#%ld%lld", destination, digits, fileSize));
	}
	else
	{
		CHECKERR (viPrintf (instrSession, ":MMEM:DATA '%s',#(%lld)", destination, fileSize));
	}
    
    CHECKERR (rssmf_WriteFromFile(instrSession, source, fileSize, 0));
        
    CHECKERR( rssmf_checkStatus (instrSession));
 
    if (sourceFile) (void) fclose (sourceFile);
    
    return rssmf_status;
}

/*****************************************************************************
 * Function: State Checking
 * Purpose:  This function switches state checking of the instrument (reading 
 *           of the Standard Event Register and checking it for error) status 
 *           subsystem. Driver functions are using state checking which is by 
 *           default enabled.
 *           
 *           Note:
 *           
 *           (1) In debug mode enable state checking.
 *           
 *           (2) For better bus throughput and instruments performance disable 
 *           state checking.
 *           
 *           (3) When state checking is disabled driver does not check if 
 *           correct instrument model or option is used with each of the 
 *           functions. This might cause unexpected behaviour of the 
 *           instrument.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_errorCheckState(
    ViSession   instrSession,
    ViBoolean   stateChecking
)
{
    ViStatus    rssmf_status = VI_SUCCESS;
    rssmf_instrRange instrPtr = NULL;

    CHECKERR (viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr));

    CHECKNULL (instrPtr);
    
    instrPtr -> errorChecking = stateChecking;

    return rssmf_status;
}

/*****************************************************************************
 * Function: Option Checking
 * Purpose:  This function switches option checking of the instrument.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_optionCheckState(
    ViSession   instrSession,
    ViBoolean   state
)
{
    ViStatus    rssmf_status = VI_SUCCESS;
    rssmf_instrRange instrPtr = NULL;

    CHECKERR (viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr != NULL)
        instrPtr -> optionChecking = state;

    return rssmf_status;
    
}

/*===========================================================================*/
/* Function: Range Checking                                                  */
/* Purpose:  This function switches ON/OFF range checking of the instrument  */
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_rangeCheckState (ViSession instrSession,
                                ViBoolean rangeChecking)
{
    ViStatus    rssmf_status = VI_SUCCESS;
    rssmf_instrRange instrPtr = NULL;

    CHECKERR (viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr));

    instrPtr -> rangeChecking = rangeChecking;

    return rssmf_status;
}

/*****************************************************************************
 * Function: Write To Instrument
 * Purpose:  This function writes commands and queries to the instrument to 
 *           modify parameters and query device settings.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_writeInstrData(
    ViSession   instrSession,
    ViString    writeBuffer
)
{
    ViStatus rssmf_status = VI_SUCCESS;

    CHECKERR (viPrintf (instrSession, "%s\n", writeBuffer));

    return rssmf_status;
}

/*****************************************************************************
 * Function: Read Instrument Data
 * Purpose:  This function reads data from the instrument's output buffer and 
 *           returns it to the specified variable in memory.
 *           
 *           Notes:
 *           
 *           (1) Because the instrument may return both numeric and text data 
 *           in response to queries this function returns the data in string 
 *           format.
 *           
 *           (2) If valid data is not available at the instrument's output 
 *           buffer when this function is called the instrument will hang up 
 *           and the function will not return until it times out.  If the 
 *           time-out is disabled this function will hang indefinitely and it 
 *           may be necessary to reboot the computer to break out.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_readInstrData(
    ViSession   instrSession,
    ViInt32 numberBytesToRead,
    ViChar _VI_FAR readBuffer[],
    ViInt32*    numbytesRead
)
{
    ViStatus    rssmf_status = VI_SUCCESS;
    ViUInt32    tmpCnt = 0;

    if (numbytesRead != NULL)
        *numbytesRead = 0L;

    CHECKERR (viRead (instrSession, (ViBuf)readBuffer, (ViUInt32) numberBytesToRead, &tmpCnt));

    if (numbytesRead)
        *numbytesRead = (ViInt32)tmpCnt;

    return rssmf_status;
}

/*===========================================================================*/
/* Function: Device Preset
/* Purpose:  This function presets all parameters which are not related to 
/*           the signal path. This includes presetting the LF generator.
/*===========================================================================*/
ViStatus _VI_FUNC rssmf_DevicePreset(
    ViSession   instrSession
)
{
    INIT;

    return rssmf_sendCmd (instrSession, "DEV:PRES");
}

/*****************************************************************************
 * Function: Reset
 * Purpose:  RESET resets the instrument to a defined default state. The 
 *           function has the same effect as pressing the PRESET key.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_reset(
    ViSession   instrSession
)
{
    ViStatus rssmf_status = VI_SUCCESS;

    /*  Initialize the instrument to a known state.  */
    CHECKERR (viPrintf (instrSession, "*RST;*CLS;*WAI\n"));
    CHECKERR (rssmf_defaultInstrSetup (instrSession));

    return rssmf_status;
}

/*****************************************************************************
 * Function: Self-Test
 * Purpose:  This function runs the instrument's self test routine and returns 
 *           the test result(s).
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_self_test(
    ViSession   instrSession,
    ViInt16*    selfTestResult,
    ViChar _VI_FAR selfTestMessage[]
)
{
    ViStatus rssmf_status = VI_SUCCESS;

    CHECKERR( viQueryf (instrSession, "*TST?\n", "%hd", selfTestResult));

    sprintf (selfTestMessage, "%s", (*selfTestResult == 0) ? "Self-Test Passed" : "Self-Test Failed");

    return rssmf_status;
}

/*****************************************************************************
 * Function: Error-Query
 * Purpose:  This function reads an error code from the instrument's error 
 *           queue.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_error_query(
    ViSession   instrSession,
    ViInt32*    errorCode,
    ViChar _VI_FAR errorMessage[]
)
{
    ViStatus    rssmf_status = VI_SUCCESS;
	ViChar      buffer[BUFFER_SIZE] = "";
    ViInt32     oldCode = 0;
    ViChar      oldMessage[256] = "";
    ViChar      *p2buf = NULL;
    ViInt32     i = 0;
	ViUInt32    retCnt = 0;

	p2buf = (char *)malloc (1);

    *p2buf='\0';
        
    do
	{
		CHECKERR (viWrite (instrSession, (ViBuf) ":SYST:ERR?\n", 11, VI_NULL));
		CHECKERR (viRead (instrSession, (ViBuf)buffer, BUFFER_SIZE, &retCnt));

	    if  (sscanf (buffer, "%ld,%*[^0-9a-zA-Z]%256[^\"]", &oldCode, oldMessage) != 2)
        {
            return VI_ERROR_INSTR_INTERPRETING_RESPONSE;
        }
        else
        {
            if (oldCode != 0)
            {
                *errorCode = oldCode;
                p2buf = (char *)realloc (p2buf, strlen(p2buf) + strlen (oldMessage) + 2);
                strcat (p2buf, oldMessage);
                strcat (p2buf, "\n");
                i++;
            }
            else if (i == 0)
            {
                *errorCode = oldCode;
                strncpy (errorMessage, oldMessage, 1024);
            }
        }

    } while (oldCode != 0);
    
    if (i > 0)
    {
        p2buf[strlen (p2buf) - 1] = '\0'; 
        strncpy (errorMessage, p2buf, 1024);
    }
   
	if (p2buf) free (p2buf);

    return rssmf_status;    
}

/*****************************************************************************
 * Function: Error Message
 * Purpose:  This function takes the Status Code returned by the instrument 
 *           driver functions, interprets it and returns it as a user readable 
 *           string.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_error_message(
    ViSession   instrSession,
    ViStatus    statusCode,
    ViChar _VI_FAR errMessage[]
)
{
    ViStatus rssmf_status = VI_SUCCESS;
    ViInt16 i;

    static rssmf_tStringValPair statusDescArray[] = {
        {VI_WARN_NSUP_ID_QUERY,                 "WARNING: ID Query not supported"},
        {VI_WARN_NSUP_RESET,                    "WARNING: Reset not supported"},
        {VI_WARN_NSUP_SELF_TEST,                "WARNING: Self-test not supported"},
        {VI_WARN_NSUP_ERROR_QUERY,              "WARNING: Error Query not supported"},
        {VI_WARN_NSUP_REV_QUERY,                "WARNING: Revision Query not supported"},
        {VI_ERROR_FAIL_ID_QUERY,                "ERROR: Identification query failed"},
        {VI_ERROR_INV_RESPONSE,                 "ERROR: Interpreting instrument response"},
        {VI_ERROR_INSTR_FILE_OPEN,              "ERROR: Opening the specified file"},
        {VI_ERROR_INSTR_FILE_WRITE,             "ERROR: Writing to the specified file"},
        {VI_ERROR_INSTR_INTERPRETING_RESPONSE,  "ERROR: Interpreting the instrument's response"},

        /* --- Instrument specific error codes --- */

        {RSSMF_ERROR_INSTRUMENT_ERROR,          "ERROR: Instrument status error"},
        {RSSMF_ERROR_INVALID_CONFIGURATION,     "ERROR: Instrument configuration error"},
        {RSSMF_ERROR_INSTRUMENT_OPTION,         "ERROR: Option not installed"},
        {RSSMF_ERROR_INSTRUMENT_NSUP_MODEL,     "ERROR: Required Instrument model is not available."},
        {RSSMF_ERROR_SETTINGS_CONFLICT,         "ERROR: Instrument settings conflict."},
        {RSSMF_ERROR_CALIBRATION_FAILED,        "ERROR: Calibration failed."},

        /* --- Instrument specific warnings --- */

        {RSSMF_WARNING_SMALL_BUFFER,            "WARNING: Buffer too small"},

        {VI_NULL, VI_NULL}
    };

    if (statusCode == VI_ERROR_INSTR_PARAMETER)
	{
	    rssmf_instrRange   instrPtr;
	    CHECKERR (viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr));
		sprintf (errMessage, "ERROR: Invalid parameter '%s'", instrPtr->parameterErrorMessage);
	}
	else
	{
		rssmf_status = viStatusDesc (instrSession, statusCode, errMessage);
	    if ((rssmf_status != VI_SUCCESS) || (strstr (errMessage, "Unknown status value") != NULL))
	        {
	        for (i = 0; statusDescArray[i].stringName; i++)
	            {
	            if (statusDescArray[i].stringVal == statusCode)
	                {
	                sprintf (errMessage, "%s", statusDescArray[i].stringName);
	                return (VI_SUCCESS);
	                }
	            }
	        sprintf (errMessage, "Unknown Error 0x%X", statusCode);
	        return (VI_WARN_UNKNOWN_STATUS);
	        }
	}

    rssmf_status = VI_SUCCESS;
    return rssmf_status;
}

/*****************************************************************************
 * Function: Revision Query
 * Purpose:  This function returns the revision numbers of the instrument 
 *           driver and instrument firmware, and tells the user with which  
 *           instrument firmware this revision of the driver is compatible.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_revision_query(
    ViSession   instrSession,
    ViChar _VI_FAR instrumentDriverRevision[],
    ViChar _VI_FAR firmwareRevision[]
)
{
    ViStatus rssmf_status = VI_SUCCESS;

    CHECKERR (viPrintf (instrSession, "*IDN?\n"));
    //CHECKERR (viScanf (instrSession, "%*[^,],%*[^,],%*[^,],%[\r\n]", firmwareRevision));
  CHECKERR (viScanf (instrSession, "%*[^-]-%[^ (\r\n]", firmwareRevision));

    sprintf (instrumentDriverRevision, "%s", RSSMF_REVISION);

    return rssmf_status;
}

/*****************************************************************************
 * Function: Delay
 * Purpose:  This function suspends the program for the selected number of 
 *           second.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_delay(
    ViSession   instrSession,
    ViReal64    seconds
)
{
  clock_t StartTime = clock();
  
  while ((((double)(clock() - StartTime))/CLOCKS_PER_SEC) < (seconds)){
#ifdef _WIN32
  #ifdef _CVI_
          ProcessSystemEvents ();
  #else
          Sleep(0);
  #endif
#endif
  }
  instrSession;
  return VI_SUCCESS;
}

/// HIFN  This function returns the ID Query response string.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmf_init or 
/// HIPAR instrSession/rssmf_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR bufferSize/Size of IDQueryResponse buffer
/// HIPAR idQueryResponse/Returns the ID Query response string. The array should consist of at 
/// HIPAR idQueryResponse/least 256 elements.
ViStatus _VI_FUNC rssmf_IDQueryResponse (ViSession instrSession,
                                         ViUInt32 bufferSize,
                                         ViChar IDQueryResponse[])
{
	ViStatus	rssmf_status = VI_SUCCESS;

	CHECKERR (rssmf_getViString (instrSession, (ViString) "*IDN?", IDQueryResponse, bufferSize, "ID Query Respone"));

	return rssmf_status;
}

/// HIFN  Stops further command processing until all commands sent before *WAI 
/// HIFN  have been executed.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmf_init or 
/// HIPAR instrSession/rssmf_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rssmf_ProcessAllPreviousCommands(
	ViSession	instrSession
)
{
    ViStatus	rssmf_status = VI_SUCCESS;

	CHECKERR (rssmf_sendCmd (instrSession, "*WAI"));
	
    return rssmf_status;
}

/// HIFN  This function queries the OPC.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmf_init or 
/// HIPAR instrSession/rssmf_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR opc/Queries the OPC.
ViStatus _VI_FUNC rssmf_QueryOPC(
	ViSession	instrSession,
	ViInt32*	opc
)
{
    ViStatus  rssmf_status = VI_SUCCESS;

	CHECKERR (rssmf_getViInt32 (instrSession, "*OPC?", opc, "OPC"));

	return rssmf_status;
}


/*****************************************************************************
 * Function: Close
 * Purpose:  This function performs the following operations:
 *           viClose (instrSession) and viClose (rmSession).
 *           
 *           Notes:
 *           
 *           (1) The instrument must be reinitialized to use it again.
 *****************************************************************************/
ViStatus _VI_FUNC rssmf_close(
    ViSession   instrSession
)
{
    rssmf_instrRange instrPtr = NULL;
    ViSession rmSession = 0;
    ViStatus rssmf_status = VI_SUCCESS;

    CHECKERR( viGetAttribute (instrSession, VI_ATTR_RM_SESSION, &rmSession));
    CHECKERR( viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr != NULL)
        free (instrPtr);

    rssmf_status = viClose (instrSession);
    (void) viClose (rmSession);

    return rssmf_status;
}

/*===========================================================================*/
/* Function: Default Instrument Setup                                        */
/* Purpose:  This function sends a default setup to the instrument.  This    */
/*           function is called by the rssmf_reset operation and by the     */
/*           rssmf_init function if the reset option has not been           */
/*           selected.  This function is useful for configuring any          */
/*           instrument settings that are required by the rest of the        */
/*           instrument driver functions such as turning headers ON or OFF   */
/*           or using the long or short form for commands, queries, and data.*/
/*===========================================================================*/
ViStatus rssmf_defaultInstrSetup (ViSession instrSession)
{
    ViChar              buffer[BUFFER_SIZE] = "";

    ViStatus            rssmf_status = VI_SUCCESS;
    rssmf_instrRange    instrPtr = NULL;

    CHECKERR (viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr));
    
    CHECKNULL (instrPtr);
    
    /* Determine if the structure has been initialized for the current VISA  */
    /* Session and malloc if it has not.                                     */
    CHECKERR (viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr));

    instrPtr -> errorChecking = VI_TRUE;
    instrPtr -> optionChecking = VI_TRUE;
    strcpy (instrPtr -> instrDriverRevision, RSSMF_REVISION);

    /* Check for instrument version */
    CHECKERR (viQueryf (instrSession, "*IDN?\n", "%*[^,],%[^,],%*[\r\n]", buffer));
    
    /* Check for instruments options */
    if ((rssmf_status = rssmf_OptionIdentificationQuery (instrSession, buffer)) < VI_SUCCESS)
        return rssmf_status;
    else
        rssmf_status = VI_SUCCESS;

    instrPtr->instrOptions.B20 = (strstr (buffer, "SMF-B20") != VI_NULL) ? 1 : 0;
    instrPtr->instrOptions.B22 = (strstr (buffer, "SMF-B22") != VI_NULL) ? 1 : 0;
    instrPtr->instrOptions.B29 = (strstr (buffer, "SMF-B29") != VI_NULL) ? 1 : 0;
    instrPtr->instrOptions.B80 = (strstr (buffer, "SMF-B80") != VI_NULL) ? 1 : 0;
    instrPtr->instrOptions.B81 = (strstr (buffer, "SMF-B81") != VI_NULL) ? 1 : 0;
    instrPtr->instrOptions.B103 = (strstr (buffer, "SMF-B103") != VI_NULL) ? 1 : 0;
    instrPtr->instrOptions.B106 = (strstr (buffer, "SMF-B106") != VI_NULL) ? 1 : 0;
    instrPtr->instrOptions.K23 = (strstr (buffer, "SMF-K23") != VI_NULL) ? 1 : 0;
    instrPtr->instrOptions.K24 = (strstr (buffer, "SMF-K24") != VI_NULL) ? 1 : 0;
    instrPtr->instrOptions.K25 = (strstr (buffer, "SMF-K25") != VI_NULL) ? 1 : 0;
    instrPtr->instrOptions.K83 = (strstr (buffer, "SMF-K83") != VI_NULL) ? 1 : 0;
    instrPtr->instrOptions.K27 = (strstr (buffer, "SMF-K27") != VI_NULL) ? 1 : 0;
    instrPtr->instrOptions.K22 = (strstr (buffer, "SMF-K22") != VI_NULL) ? 1 : 0;
    instrPtr->instrOptions.K20 = (strstr (buffer, "SMF-K20") != VI_NULL) ? 1 : 0;
    instrPtr->instrOptions.K4 = (strstr (buffer, "SMF-K4") != VI_NULL) ? 1 : 0;
  instrPtr->instrOptions.K28 = (strstr (buffer, "SMF-K28") != VI_NULL) ? 1 : 0;
    
    return rssmf_status;
}

/*===========================================================================*/
/* Function: Initialize Clean Up                                             */
/* Purpose:  This function is used only by the rssmf_init function.  When   */
/*           an error is detected this function is called to close the       */
/*           open resource manager and instrument object sessions and to     */
/*           set the instrSession that is returned from rssmf_init to       */
/*           VI_NULL.                                                        */
/*===========================================================================*/
ViStatus rssmf_initCleanUp (ViSession openRMSession,
                             ViPSession openInstrSession,
                             ViStatus currentStatus)
{
    rssmf_instrRange instrPtr = NULL;

    if (viGetAttribute (*openInstrSession, VI_ATTR_USER_DATA, &instrPtr) >= 0)
        if (instrPtr != NULL)
            free (instrPtr);

    (void) viClose (*openInstrSession);
    (void) viClose (openRMSession);
    *openInstrSession = VI_NULL;

    return currentStatus;
}

/*============================================================================
 * Function: rssmf_SetSweepMode
 * Purpose:  This function sets the sweep mode.
 *===========================================================================*/
ViStatus rssmf_SetSweepMode (ViSession instrSession, 
                             ViInt32   mode)
{
    
    return SETPARAMENUM (instrSession,
                          "SOUR:SWE:MODE",
                          mode,
                          lfSweepModeArr);
}

/*============================================================================
 * Function: rssmf_SetFrequencySweepTriggerSource
 * Purpose:  This function sets the trigger source for the RF frequency sweep.
 *===========================================================================*/
ViStatus rssmf_SetFrequencySweepTriggerSource (ViSession instrSession,
                                               ViInt32 triggerSourceRFFreqSweep)
{
    return SETPARAMENUM (instrSession,
                          "TRIG:FSW:SOUR",
                          triggerSourceRFFreqSweep,
                          triggerRFSourceArr);
}

/*============================================================================
 * Function: rssmf_SetFrequencyMode
 * Purpose:  This function sets the instrument operating mode and therefore
 *           also the functions used to set the output frequency.
 *===========================================================================*/
ViStatus rssmf_SetFrequencyMode (ViSession instrSession,
                                 ViInt32 frequencyMode)
{
    return SETPARAMENUM (instrSession,
                          "SOUR:FREQ:MODE",
                          frequencyMode,
                          frequencyModeArr);
}

/*============================================================================
 * Function: rssmf_SetLFMode
 * Purpose:  This function sets the instrument operating mode and therefore
 *           also the functions used to set the output frequency.
 *===========================================================================*/
ViStatus rssmf_SetLFMode (ViSession instrSession, ViInt32 LFOutputMode)
{
    return SETPARAMENUM (instrSession,
                          "LFO:FREQ:MODE",
                          LFOutputMode,
                          lfOutputModeArr);
}

/*============================================================================
 * Function: rssmf_SetLFOutputLFSweepMode
 * Purpose:  This function sets the cycle mode of the LF sweep.
 *===========================================================================*/
ViStatus rssmf_SetSweepLFMode(ViSession    instrSession,
                              ViInt32  lfSweepMode)
{
    return SETPARAMENUM (instrSession,
                          "SOUR:LFO:SWE:MODE",
                          lfSweepMode,
                          lfSweepModeArr);
}

/*============================================================================
 * Function: rssmf_SetLFSweepTriggerSource
 * Purpose:  This function sets the trigger source for the LF sweep. The
 *           trigger is triggered by the command
 *           :SOURce:LFOutput:SWEep[:FREQuency]EXECute.
 *===========================================================================*/
ViStatus rssmf_SetLFSweepTriggerSource (ViSession instrSession,
                                        ViInt32 triggerSourceLFSweep)
{
    return SETPARAMENUM (instrSession,
                          "TRIG:LFFS:SOUR",
                          triggerSourceLFSweep,
                          triggerRFSourceArr);
}

/*============================================================================
 * Function: rssmf_SetLevelSweepTriggerSource
 * Purpose:  This function sets the trigger source for the RF level sweep.
 *===========================================================================*/
ViStatus rssmf_SetLevelSweepTriggerSource (ViSession instrSession,
                                             ViInt32 triggerSourceRFLevelSweep)
{
    return SETPARAMENUM (instrSession,
                              "TRIG:PSW:SOUR",
                              triggerSourceRFLevelSweep,
                              triggerRFSourceArr);
}

/*============================================================================
 * Function: rssmf_SetSweepLevelMode
 * Purpose:  This function sets the cycle mode of the level sweep.
 *===========================================================================*/
ViStatus rssmf_SetSweepLevelMode (ViSession instrSession,
                                  ViInt32 sweepLevelMode)
{
    return SETPARAMENUM (instrSession,
                              "SOUR:SWE:POW:MODE",
                              sweepLevelMode,
                              sweepLevelModeArr);
}

/*============================================================================
 * Function: rssmf_SetLevelMode
 * Purpose:  This function sets the instrument operating mode and therefore
 *           also the functions used to set the output level.
 *===========================================================================*/
ViStatus rssmf_SetLevelMode (ViSession instrSession,
                                    ViInt32 RFLevelMode)
{
    return SETPARAMENUM (instrSession,
                              "SOUR:POW:MODE",
                              RFLevelMode,
                              frequencyModeArr);
}
